import { IObjectMeta } from "@soft-stech/apimachinery/apis/meta/v1/ObjectMeta";
import { Model, ModelData } from "@soft-stech/base";
export interface IOperatorConfiguration {
    "kind": "OperatorConfiguration";
    "apiVersion": "acid.zalan.do/v1";
    "configuration": {
        "crd_categories"?: Array<string>;
        /**
         *
         * @default "ghcr.io/zalando/spilo-16:3.2-p2"
         */
        "docker_image"?: string;
        /**
         *
         * @default true
         */
        "enable_crd_registration"?: boolean;
        /**
         * deprecated
         * @default true
         */
        "enable_crd_validation"?: boolean;
        "enable_lazy_spilo_upgrade"?: boolean;
        /**
         *
         * @default true
         */
        "enable_pgversion_env_var"?: boolean;
        /**
         *
         * @default true
         */
        "enable_shm_volume"?: boolean;
        "enable_spilo_wal_path_compat"?: boolean;
        "enable_team_id_clustername_prefix"?: boolean;
        "etcd_host"?: string;
        "ignore_instance_limits_annotation_key"?: string;
        "kubernetes_use_configmaps"?: boolean;
        /**
         * -1 = disabled
         * @default -1
         * @minimum -1
         */
        "max_instances"?: number;
        /**
         * -1 = disabled
         * @default -1
         * @minimum -1
         */
        "min_instances"?: number;
        /**
         *
         * @default "30m"
         */
        "resync_period"?: string;
        /**
         *
         * @default "5m"
         */
        "repair_period"?: string;
        "set_memory_request_to_limit"?: boolean;
        "sidecar_docker_images"?: Record<string, string>;
        "sidecars"?: Array<{}>;
        /**
         *
         * @default 8
         * @minimum 1
         */
        "workers"?: number;
        "users"?: {
            "additional_owner_roles"?: Array<string>;
            "enable_password_rotation"?: boolean;
            /**
             *
             * @default 90
             */
            "password_rotation_interval"?: number;
            /**
             *
             * @default 180
             */
            "password_rotation_user_retention"?: number;
            /**
             *
             * @default "standby"
             */
            "replication_username"?: string;
            /**
             *
             * @default "postgres"
             */
            "super_username"?: string;
        };
        "major_version_upgrade"?: {
            /**
             *
             * @default "off"
             */
            "major_version_upgrade_mode"?: string;
            "major_version_upgrade_team_allow_list"?: Array<string>;
            /**
             *
             * @default "12"
             */
            "minimal_major_version"?: string;
            /**
             *
             * @default "16"
             */
            "target_major_version"?: string;
        };
        "kubernetes"?: {
            "additional_pod_capabilities"?: Array<string>;
            /**
             *
             * @default "cluster.local"
             */
            "cluster_domain"?: string;
            "cluster_labels"?: Record<string, string>;
            /**
             *
             * @default "cluster-name"
             */
            "cluster_name_label"?: string;
            "custom_pod_annotations"?: Record<string, string>;
            "delete_annotation_date_key"?: string;
            "delete_annotation_name_key"?: string;
            "downscaler_annotations"?: Array<string>;
            "enable_cross_namespace_secret"?: boolean;
            "enable_finalizers"?: boolean;
            /**
             *
             * @default true
             */
            "enable_init_containers"?: boolean;
            /**
             *
             * @default true
             */
            "enable_persistent_volume_claim_deletion"?: boolean;
            "enable_pod_antiaffinity"?: boolean;
            /**
             *
             * @default true
             */
            "enable_pod_disruption_budget"?: boolean;
            "enable_readiness_probe"?: boolean;
            /**
             *
             * @default true
             */
            "enable_sidecars"?: boolean;
            "ignored_annotations"?: Array<string>;
            "infrastructure_roles_secret_name"?: string;
            "infrastructure_roles_secrets"?: Array<{
                "secretname": string;
                "userkey": string;
                "passwordkey": string;
                "rolekey"?: string;
                "defaultuservalue"?: string;
                "defaultrolevalue"?: string;
                "details"?: string;
                "template"?: boolean;
            }>;
            "inherited_annotations"?: Array<string>;
            "inherited_labels"?: Array<string>;
            /**
             *
             * @default "20m"
             */
            "master_pod_move_timeout"?: string;
            "node_readiness_label"?: Record<string, string>;
            "node_readiness_label_merge"?: "AND" | "OR";
            /**
             *
             * @default "postgresql-operator"
             */
            "oauth_token_secret_name"?: string;
            /**
             *
             * @default "postgres-{cluster}-pdb"
             */
            "pdb_name_format"?: string;
            "persistent_volume_claim_retention_policy"?: {
                "when_deleted"?: "delete" | "retain";
                "when_scaled"?: "delete" | "retain";
            };
            "pod_antiaffinity_preferred_during_scheduling"?: boolean;
            /**
             *
             * @default "kubernetes.io/hostname"
             */
            "pod_antiaffinity_topology_key"?: string;
            "pod_environment_configmap"?: string;
            "pod_environment_secret"?: string;
            /**
             *
             * @default "ordered_ready"
             */
            "pod_management_policy"?: "ordered_ready" | "parallel";
            "pod_priority_class_name"?: string;
            /**
             *
             * @default "spilo-role"
             */
            "pod_role_label"?: string;
            "pod_service_account_definition"?: string;
            /**
             *
             * @default "postgres-pod"
             */
            "pod_service_account_name"?: string;
            "pod_service_account_role_binding_definition"?: string;
            /**
             *
             * @default "5m"
             */
            "pod_terminate_grace_period"?: string;
            /**
             *
             * @default "{username}.{cluster}.credentials.{tprkind}.{tprgroup}"
             */
            "secret_name_template"?: string;
            "share_pgsocket_with_sidecars"?: boolean;
            /**
             *
             * @default true
             */
            "spilo_allow_privilege_escalation"?: boolean;
            "spilo_runasuser"?: number;
            "spilo_runasgroup"?: number;
            "spilo_fsgroup"?: number;
            "spilo_privileged"?: boolean;
            /**
             *
             * @default "pvc"
             */
            "storage_resize_mode"?: "ebs" | "mixed" | "pvc" | "off";
            "toleration"?: Record<string, string>;
            "watched_namespace"?: string;
        };
        "postgres_pod_resources"?: {
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "default_cpu_limit"?: string;
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "default_cpu_request"?: string;
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "default_memory_limit"?: string;
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "default_memory_request"?: string;
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "max_cpu_request"?: string;
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "max_memory_request"?: string;
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "min_cpu_limit"?: string;
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "min_memory_limit"?: string;
        };
        "timeouts"?: {
            /**
             *
             * @default "1s"
             */
            "patroni_api_check_interval"?: string;
            /**
             *
             * @default "5s"
             */
            "patroni_api_check_timeout"?: string;
            /**
             *
             * @default "10m"
             */
            "pod_label_wait_timeout"?: string;
            /**
             *
             * @default "10m"
             */
            "pod_deletion_wait_timeout"?: string;
            /**
             *
             * @default "4s"
             */
            "ready_wait_interval"?: string;
            /**
             *
             * @default "30s"
             */
            "ready_wait_timeout"?: string;
            /**
             *
             * @default "3s"
             */
            "resource_check_interval"?: string;
            /**
             *
             * @default "10m"
             */
            "resource_check_timeout"?: string;
        };
        "load_balancer"?: {
            "custom_service_annotations"?: Record<string, string>;
            /**
             *
             * @default "db.example.com"
             */
            "db_hosted_zone"?: string;
            /**
             *
             * @default true
             */
            "enable_master_load_balancer"?: boolean;
            "enable_master_pooler_load_balancer"?: boolean;
            "enable_replica_load_balancer"?: boolean;
            "enable_replica_pooler_load_balancer"?: boolean;
            /**
             *
             * @default "Cluster"
             */
            "external_traffic_policy"?: "Cluster" | "Local";
            /**
             *
             * @default "{cluster}.{namespace}.{hostedzone}"
             */
            "master_dns_name_format"?: string;
            /**
             *
             * @default "{cluster}.{team}.{hostedzone}"
             */
            "master_legacy_dns_name_format"?: string;
            /**
             *
             * @default "{cluster}-repl.{namespace}.{hostedzone}"
             */
            "replica_dns_name_format"?: string;
            /**
             *
             * @default "{cluster}-repl.{team}.{hostedzone}"
             */
            "replica_legacy_dns_name_format"?: string;
        };
        "aws_or_gcp"?: {
            "additional_secret_mount"?: string;
            /**
             *
             * @default "/meta/credentials"
             */
            "additional_secret_mount_path"?: string;
            /**
             *
             * @default "eu-central-1"
             */
            "aws_region"?: string;
            "enable_ebs_gp3_migration"?: boolean;
            /**
             *
             * @default 1000
             */
            "enable_ebs_gp3_migration_max_size"?: number;
            "gcp_credentials"?: string;
            "kube_iam_role"?: string;
            "log_s3_bucket"?: string;
            "wal_az_storage_account"?: string;
            "wal_gs_bucket"?: string;
            "wal_s3_bucket"?: string;
        };
        "logical_backup"?: {
            "logical_backup_azure_storage_account_name"?: string;
            "logical_backup_azure_storage_container"?: string;
            "logical_backup_azure_storage_account_key"?: string;
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "logical_backup_cpu_limit"?: string;
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "logical_backup_cpu_request"?: string;
            /**
             *
             * @default "registry.opensource.zalan.do/acid/logical-backup:v1.11.0"
             */
            "logical_backup_docker_image"?: string;
            "logical_backup_google_application_credentials"?: string;
            /**
             *
             * @default "logical-backup-"
             */
            "logical_backup_job_prefix"?: string;
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "logical_backup_memory_limit"?: string;
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "logical_backup_memory_request"?: string;
            /**
             *
             * @default "s3"
             */
            "logical_backup_provider"?: "az" | "gcs" | "s3";
            "logical_backup_s3_access_key_id"?: string;
            "logical_backup_s3_bucket"?: string;
            "logical_backup_s3_endpoint"?: string;
            "logical_backup_s3_region"?: string;
            "logical_backup_s3_secret_access_key"?: string;
            "logical_backup_s3_sse"?: string;
            "logical_backup_s3_retention_time"?: string;
            /**
             *
             * @default "30 00 * * *"
             * @pattern ^(\d+|\*)(\/\d+)?(\s+(\d+|\*)(\/\d+)?){4}$
             */
            "logical_backup_schedule"?: string;
            "logical_backup_cronjob_environment_secret"?: string;
        };
        "debug"?: {
            /**
             *
             * @default true
             */
            "debug_logging"?: boolean;
            /**
             *
             * @default true
             */
            "enable_database_access"?: boolean;
        };
        "teams_api"?: {
            /**
             *
             * @default true
             */
            "enable_admin_role_for_users"?: boolean;
            /**
             *
             * @default true
             */
            "enable_postgres_team_crd"?: boolean;
            "enable_postgres_team_crd_superusers"?: boolean;
            "enable_team_member_deprecation"?: boolean;
            "enable_team_superuser"?: boolean;
            /**
             *
             * @default true
             */
            "enable_teams_api"?: boolean;
            /**
             *
             * @default "https://info.example.com/oauth2/tokeninfo?access_token= uid realm=/employees"
             */
            "pam_configuration"?: string;
            /**
             *
             * @default "zalandos"
             */
            "pam_role_name"?: string;
            "postgres_superuser_teams"?: Array<string>;
            "protected_role_names"?: Array<string>;
            /**
             *
             * @default "_deleted"
             */
            "role_deletion_suffix"?: string;
            /**
             *
             * @default "admin"
             */
            "team_admin_role"?: string;
            "team_api_role_configuration"?: Record<string, string>;
            /**
             *
             * @default "https://teams.example.com/api/"
             */
            "teams_api_url"?: string;
        };
        "logging_rest_api"?: {
            /**
             *
             * @default 8080
             */
            "api_port"?: number;
            /**
             *
             * @default 1000
             */
            "cluster_history_entries"?: number;
            /**
             *
             * @default 100
             */
            "ring_log_lines"?: number;
        };
        "scalyr"?: {
            "scalyr_api_key"?: string;
            /**
             *
             * @default "1"
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "scalyr_cpu_limit"?: string;
            /**
             *
             * @default "100m"
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "scalyr_cpu_request"?: string;
            "scalyr_image"?: string;
            /**
             *
             * @default "500Mi"
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "scalyr_memory_limit"?: string;
            /**
             *
             * @default "50Mi"
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "scalyr_memory_request"?: string;
            /**
             *
             * @default "https://upload.eu.scalyr.com"
             */
            "scalyr_server_url"?: string;
        };
        "connection_pooler"?: {
            /**
             *
             * @default "pooler"
             */
            "connection_pooler_schema"?: string;
            /**
             *
             * @default "pooler"
             */
            "connection_pooler_user"?: string;
            /**
             *
             * @default "registry.opensource.zalan.do/acid/pgbouncer:master-32"
             */
            "connection_pooler_image"?: string;
            /**
             *
             * @default 60
             */
            "connection_pooler_max_db_connections"?: number;
            /**
             *
             * @default "transaction"
             */
            "connection_pooler_mode"?: "session" | "transaction";
            /**
             *
             * @default 2
             * @minimum 1
             */
            "connection_pooler_number_of_instances"?: number;
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "connection_pooler_default_cpu_limit"?: string;
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "connection_pooler_default_cpu_request"?: string;
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "connection_pooler_default_memory_limit"?: string;
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "connection_pooler_default_memory_request"?: string;
        };
        "patroni"?: {
            "enable_patroni_failsafe_mode"?: boolean;
        };
    };
    "status"?: Record<string, string>;
    "metadata"?: IObjectMeta;
}
export declare class OperatorConfiguration extends Model<IOperatorConfiguration> implements IOperatorConfiguration {
    "kind": IOperatorConfiguration["kind"];
    "apiVersion": IOperatorConfiguration["apiVersion"];
    "configuration": IOperatorConfiguration["configuration"];
    "status"?: IOperatorConfiguration["status"];
    "metadata"?: IOperatorConfiguration["metadata"];
    static apiVersion: IOperatorConfiguration["apiVersion"];
    static kind: IOperatorConfiguration["kind"];
    static is: import("@soft-stech/base").TypeMetaGuard<IOperatorConfiguration>;
    constructor(data?: ModelData<IOperatorConfiguration>);
}
