import { z } from "zod";
export declare const IOperatorConfigurationSchema: z.ZodObject<{
    kind: z.ZodLiteral<"OperatorConfiguration">;
    apiVersion: z.ZodLiteral<"acid.zalan.do/v1">;
    configuration: z.ZodObject<{
        crd_categories: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        /**
         *
         * @default "ghcr.io/zalando/spilo-16:3.2-p2"
         */
        docker_image: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        /**
         *
         * @default true
         */
        enable_crd_registration: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        /**
         * deprecated
         * @default true
         */
        enable_crd_validation: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        enable_lazy_spilo_upgrade: z.ZodOptional<z.ZodBoolean>;
        /**
         *
         * @default true
         */
        enable_pgversion_env_var: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        /**
         *
         * @default true
         */
        enable_shm_volume: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        enable_spilo_wal_path_compat: z.ZodOptional<z.ZodBoolean>;
        enable_team_id_clustername_prefix: z.ZodOptional<z.ZodBoolean>;
        etcd_host: z.ZodOptional<z.ZodString>;
        ignore_instance_limits_annotation_key: z.ZodOptional<z.ZodString>;
        kubernetes_use_configmaps: z.ZodOptional<z.ZodBoolean>;
        /**
         * -1 = disabled
         * @default -1
         * @minimum -1
         */
        max_instances: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        /**
         * -1 = disabled
         * @default -1
         * @minimum -1
         */
        min_instances: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        /**
         *
         * @default "30m"
         */
        resync_period: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        /**
         *
         * @default "5m"
         */
        repair_period: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        set_memory_request_to_limit: z.ZodOptional<z.ZodBoolean>;
        sidecar_docker_images: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        sidecars: z.ZodOptional<z.ZodArray<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>, "many">>;
        /**
         *
         * @default 8
         * @minimum 1
         */
        workers: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        users: z.ZodOptional<z.ZodObject<{
            additional_owner_roles: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            enable_password_rotation: z.ZodOptional<z.ZodBoolean>;
            /**
             *
             * @default 90
             */
            password_rotation_interval: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
            /**
             *
             * @default 180
             */
            password_rotation_user_retention: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
            /**
             *
             * @default "standby"
             */
            replication_username: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "postgres"
             */
            super_username: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            password_rotation_interval: number;
            password_rotation_user_retention: number;
            replication_username: string;
            super_username: string;
            additional_owner_roles?: string[] | undefined;
            enable_password_rotation?: boolean | undefined;
        }, {
            additional_owner_roles?: string[] | undefined;
            enable_password_rotation?: boolean | undefined;
            password_rotation_interval?: number | undefined;
            password_rotation_user_retention?: number | undefined;
            replication_username?: string | undefined;
            super_username?: string | undefined;
        }>>;
        major_version_upgrade: z.ZodOptional<z.ZodObject<{
            /**
             *
             * @default "off"
             */
            major_version_upgrade_mode: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            major_version_upgrade_team_allow_list: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            /**
             *
             * @default "12"
             */
            minimal_major_version: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "16"
             */
            target_major_version: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            major_version_upgrade_mode: string;
            minimal_major_version: string;
            target_major_version: string;
            major_version_upgrade_team_allow_list?: string[] | undefined;
        }, {
            major_version_upgrade_mode?: string | undefined;
            major_version_upgrade_team_allow_list?: string[] | undefined;
            minimal_major_version?: string | undefined;
            target_major_version?: string | undefined;
        }>>;
        kubernetes: z.ZodOptional<z.ZodObject<{
            additional_pod_capabilities: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            /**
             *
             * @default "cluster.local"
             */
            cluster_domain: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            cluster_labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
            /**
             *
             * @default "cluster-name"
             */
            cluster_name_label: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            custom_pod_annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
            delete_annotation_date_key: z.ZodOptional<z.ZodString>;
            delete_annotation_name_key: z.ZodOptional<z.ZodString>;
            downscaler_annotations: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            enable_cross_namespace_secret: z.ZodOptional<z.ZodBoolean>;
            enable_finalizers: z.ZodOptional<z.ZodBoolean>;
            /**
             *
             * @default true
             */
            enable_init_containers: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
            /**
             *
             * @default true
             */
            enable_persistent_volume_claim_deletion: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
            enable_pod_antiaffinity: z.ZodOptional<z.ZodBoolean>;
            /**
             *
             * @default true
             */
            enable_pod_disruption_budget: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
            enable_readiness_probe: z.ZodOptional<z.ZodBoolean>;
            /**
             *
             * @default true
             */
            enable_sidecars: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
            ignored_annotations: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            infrastructure_roles_secret_name: z.ZodOptional<z.ZodString>;
            infrastructure_roles_secrets: z.ZodOptional<z.ZodArray<z.ZodObject<{
                secretname: z.ZodString;
                userkey: z.ZodString;
                passwordkey: z.ZodString;
                rolekey: z.ZodOptional<z.ZodString>;
                defaultuservalue: z.ZodOptional<z.ZodString>;
                defaultrolevalue: z.ZodOptional<z.ZodString>;
                details: z.ZodOptional<z.ZodString>;
                template: z.ZodOptional<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                secretname: string;
                userkey: string;
                passwordkey: string;
                rolekey?: string | undefined;
                defaultuservalue?: string | undefined;
                defaultrolevalue?: string | undefined;
                details?: string | undefined;
                template?: boolean | undefined;
            }, {
                secretname: string;
                userkey: string;
                passwordkey: string;
                rolekey?: string | undefined;
                defaultuservalue?: string | undefined;
                defaultrolevalue?: string | undefined;
                details?: string | undefined;
                template?: boolean | undefined;
            }>, "many">>;
            inherited_annotations: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            inherited_labels: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            /**
             *
             * @default "20m"
             */
            master_pod_move_timeout: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            node_readiness_label: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
            node_readiness_label_merge: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"AND">, z.ZodLiteral<"OR">]>>;
            /**
             *
             * @default "postgresql-operator"
             */
            oauth_token_secret_name: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "postgres-{cluster}-pdb"
             */
            pdb_name_format: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            persistent_volume_claim_retention_policy: z.ZodOptional<z.ZodObject<{
                when_deleted: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"delete">, z.ZodLiteral<"retain">]>>;
                when_scaled: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"delete">, z.ZodLiteral<"retain">]>>;
            }, "strip", z.ZodTypeAny, {
                when_deleted?: "delete" | "retain" | undefined;
                when_scaled?: "delete" | "retain" | undefined;
            }, {
                when_deleted?: "delete" | "retain" | undefined;
                when_scaled?: "delete" | "retain" | undefined;
            }>>;
            pod_antiaffinity_preferred_during_scheduling: z.ZodOptional<z.ZodBoolean>;
            /**
             *
             * @default "kubernetes.io/hostname"
             */
            pod_antiaffinity_topology_key: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            pod_environment_configmap: z.ZodOptional<z.ZodString>;
            pod_environment_secret: z.ZodOptional<z.ZodString>;
            /**
             *
             * @default "ordered_ready"
             */
            pod_management_policy: z.ZodDefault<z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"ordered_ready">, z.ZodLiteral<"parallel">]>>>;
            pod_priority_class_name: z.ZodOptional<z.ZodString>;
            /**
             *
             * @default "spilo-role"
             */
            pod_role_label: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            pod_service_account_definition: z.ZodOptional<z.ZodString>;
            /**
             *
             * @default "postgres-pod"
             */
            pod_service_account_name: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            pod_service_account_role_binding_definition: z.ZodOptional<z.ZodString>;
            /**
             *
             * @default "5m"
             */
            pod_terminate_grace_period: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "{username}.{cluster}.credentials.{tprkind}.{tprgroup}"
             */
            secret_name_template: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            share_pgsocket_with_sidecars: z.ZodOptional<z.ZodBoolean>;
            /**
             *
             * @default true
             */
            spilo_allow_privilege_escalation: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
            spilo_runasuser: z.ZodOptional<z.ZodNumber>;
            spilo_runasgroup: z.ZodOptional<z.ZodNumber>;
            spilo_fsgroup: z.ZodOptional<z.ZodNumber>;
            spilo_privileged: z.ZodOptional<z.ZodBoolean>;
            /**
             *
             * @default "pvc"
             */
            storage_resize_mode: z.ZodDefault<z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"ebs">, z.ZodLiteral<"mixed">, z.ZodLiteral<"pvc">, z.ZodLiteral<"off">]>>>;
            toleration: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
            watched_namespace: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            cluster_domain: string;
            cluster_name_label: string;
            enable_init_containers: boolean;
            enable_persistent_volume_claim_deletion: boolean;
            enable_pod_disruption_budget: boolean;
            enable_sidecars: boolean;
            master_pod_move_timeout: string;
            oauth_token_secret_name: string;
            pdb_name_format: string;
            pod_antiaffinity_topology_key: string;
            pod_management_policy: "ordered_ready" | "parallel";
            pod_role_label: string;
            pod_service_account_name: string;
            pod_terminate_grace_period: string;
            secret_name_template: string;
            spilo_allow_privilege_escalation: boolean;
            storage_resize_mode: "off" | "ebs" | "mixed" | "pvc";
            additional_pod_capabilities?: string[] | undefined;
            cluster_labels?: Record<string, string> | undefined;
            custom_pod_annotations?: Record<string, string> | undefined;
            delete_annotation_date_key?: string | undefined;
            delete_annotation_name_key?: string | undefined;
            downscaler_annotations?: string[] | undefined;
            enable_cross_namespace_secret?: boolean | undefined;
            enable_finalizers?: boolean | undefined;
            enable_pod_antiaffinity?: boolean | undefined;
            enable_readiness_probe?: boolean | undefined;
            ignored_annotations?: string[] | undefined;
            infrastructure_roles_secret_name?: string | undefined;
            infrastructure_roles_secrets?: {
                secretname: string;
                userkey: string;
                passwordkey: string;
                rolekey?: string | undefined;
                defaultuservalue?: string | undefined;
                defaultrolevalue?: string | undefined;
                details?: string | undefined;
                template?: boolean | undefined;
            }[] | undefined;
            inherited_annotations?: string[] | undefined;
            inherited_labels?: string[] | undefined;
            node_readiness_label?: Record<string, string> | undefined;
            node_readiness_label_merge?: "AND" | "OR" | undefined;
            persistent_volume_claim_retention_policy?: {
                when_deleted?: "delete" | "retain" | undefined;
                when_scaled?: "delete" | "retain" | undefined;
            } | undefined;
            pod_antiaffinity_preferred_during_scheduling?: boolean | undefined;
            pod_environment_configmap?: string | undefined;
            pod_environment_secret?: string | undefined;
            pod_priority_class_name?: string | undefined;
            pod_service_account_definition?: string | undefined;
            pod_service_account_role_binding_definition?: string | undefined;
            share_pgsocket_with_sidecars?: boolean | undefined;
            spilo_runasuser?: number | undefined;
            spilo_runasgroup?: number | undefined;
            spilo_fsgroup?: number | undefined;
            spilo_privileged?: boolean | undefined;
            toleration?: Record<string, string> | undefined;
            watched_namespace?: string | undefined;
        }, {
            additional_pod_capabilities?: string[] | undefined;
            cluster_domain?: string | undefined;
            cluster_labels?: Record<string, string> | undefined;
            cluster_name_label?: string | undefined;
            custom_pod_annotations?: Record<string, string> | undefined;
            delete_annotation_date_key?: string | undefined;
            delete_annotation_name_key?: string | undefined;
            downscaler_annotations?: string[] | undefined;
            enable_cross_namespace_secret?: boolean | undefined;
            enable_finalizers?: boolean | undefined;
            enable_init_containers?: boolean | undefined;
            enable_persistent_volume_claim_deletion?: boolean | undefined;
            enable_pod_antiaffinity?: boolean | undefined;
            enable_pod_disruption_budget?: boolean | undefined;
            enable_readiness_probe?: boolean | undefined;
            enable_sidecars?: boolean | undefined;
            ignored_annotations?: string[] | undefined;
            infrastructure_roles_secret_name?: string | undefined;
            infrastructure_roles_secrets?: {
                secretname: string;
                userkey: string;
                passwordkey: string;
                rolekey?: string | undefined;
                defaultuservalue?: string | undefined;
                defaultrolevalue?: string | undefined;
                details?: string | undefined;
                template?: boolean | undefined;
            }[] | undefined;
            inherited_annotations?: string[] | undefined;
            inherited_labels?: string[] | undefined;
            master_pod_move_timeout?: string | undefined;
            node_readiness_label?: Record<string, string> | undefined;
            node_readiness_label_merge?: "AND" | "OR" | undefined;
            oauth_token_secret_name?: string | undefined;
            pdb_name_format?: string | undefined;
            persistent_volume_claim_retention_policy?: {
                when_deleted?: "delete" | "retain" | undefined;
                when_scaled?: "delete" | "retain" | undefined;
            } | undefined;
            pod_antiaffinity_preferred_during_scheduling?: boolean | undefined;
            pod_antiaffinity_topology_key?: string | undefined;
            pod_environment_configmap?: string | undefined;
            pod_environment_secret?: string | undefined;
            pod_management_policy?: "ordered_ready" | "parallel" | undefined;
            pod_priority_class_name?: string | undefined;
            pod_role_label?: string | undefined;
            pod_service_account_definition?: string | undefined;
            pod_service_account_name?: string | undefined;
            pod_service_account_role_binding_definition?: string | undefined;
            pod_terminate_grace_period?: string | undefined;
            secret_name_template?: string | undefined;
            share_pgsocket_with_sidecars?: boolean | undefined;
            spilo_allow_privilege_escalation?: boolean | undefined;
            spilo_runasuser?: number | undefined;
            spilo_runasgroup?: number | undefined;
            spilo_fsgroup?: number | undefined;
            spilo_privileged?: boolean | undefined;
            storage_resize_mode?: "off" | "ebs" | "mixed" | "pvc" | undefined;
            toleration?: Record<string, string> | undefined;
            watched_namespace?: string | undefined;
        }>>;
        postgres_pod_resources: z.ZodOptional<z.ZodObject<{
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            default_cpu_limit: z.ZodOptional<z.ZodString>;
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            default_cpu_request: z.ZodOptional<z.ZodString>;
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            default_memory_limit: z.ZodOptional<z.ZodString>;
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            default_memory_request: z.ZodOptional<z.ZodString>;
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            max_cpu_request: z.ZodOptional<z.ZodString>;
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            max_memory_request: z.ZodOptional<z.ZodString>;
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            min_cpu_limit: z.ZodOptional<z.ZodString>;
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            min_memory_limit: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            default_cpu_limit?: string | undefined;
            default_cpu_request?: string | undefined;
            default_memory_limit?: string | undefined;
            default_memory_request?: string | undefined;
            max_cpu_request?: string | undefined;
            max_memory_request?: string | undefined;
            min_cpu_limit?: string | undefined;
            min_memory_limit?: string | undefined;
        }, {
            default_cpu_limit?: string | undefined;
            default_cpu_request?: string | undefined;
            default_memory_limit?: string | undefined;
            default_memory_request?: string | undefined;
            max_cpu_request?: string | undefined;
            max_memory_request?: string | undefined;
            min_cpu_limit?: string | undefined;
            min_memory_limit?: string | undefined;
        }>>;
        timeouts: z.ZodOptional<z.ZodObject<{
            /**
             *
             * @default "1s"
             */
            patroni_api_check_interval: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "5s"
             */
            patroni_api_check_timeout: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "10m"
             */
            pod_label_wait_timeout: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "10m"
             */
            pod_deletion_wait_timeout: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "4s"
             */
            ready_wait_interval: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "30s"
             */
            ready_wait_timeout: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "3s"
             */
            resource_check_interval: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "10m"
             */
            resource_check_timeout: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            patroni_api_check_interval: string;
            patroni_api_check_timeout: string;
            pod_label_wait_timeout: string;
            pod_deletion_wait_timeout: string;
            ready_wait_interval: string;
            ready_wait_timeout: string;
            resource_check_interval: string;
            resource_check_timeout: string;
        }, {
            patroni_api_check_interval?: string | undefined;
            patroni_api_check_timeout?: string | undefined;
            pod_label_wait_timeout?: string | undefined;
            pod_deletion_wait_timeout?: string | undefined;
            ready_wait_interval?: string | undefined;
            ready_wait_timeout?: string | undefined;
            resource_check_interval?: string | undefined;
            resource_check_timeout?: string | undefined;
        }>>;
        load_balancer: z.ZodOptional<z.ZodObject<{
            custom_service_annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
            /**
             *
             * @default "db.example.com"
             */
            db_hosted_zone: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default true
             */
            enable_master_load_balancer: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
            enable_master_pooler_load_balancer: z.ZodOptional<z.ZodBoolean>;
            enable_replica_load_balancer: z.ZodOptional<z.ZodBoolean>;
            enable_replica_pooler_load_balancer: z.ZodOptional<z.ZodBoolean>;
            /**
             *
             * @default "Cluster"
             */
            external_traffic_policy: z.ZodDefault<z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"Cluster">, z.ZodLiteral<"Local">]>>>;
            /**
             *
             * @default "{cluster}.{namespace}.{hostedzone}"
             */
            master_dns_name_format: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "{cluster}.{team}.{hostedzone}"
             */
            master_legacy_dns_name_format: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "{cluster}-repl.{namespace}.{hostedzone}"
             */
            replica_dns_name_format: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "{cluster}-repl.{team}.{hostedzone}"
             */
            replica_legacy_dns_name_format: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            db_hosted_zone: string;
            enable_master_load_balancer: boolean;
            external_traffic_policy: "Cluster" | "Local";
            master_dns_name_format: string;
            master_legacy_dns_name_format: string;
            replica_dns_name_format: string;
            replica_legacy_dns_name_format: string;
            custom_service_annotations?: Record<string, string> | undefined;
            enable_master_pooler_load_balancer?: boolean | undefined;
            enable_replica_load_balancer?: boolean | undefined;
            enable_replica_pooler_load_balancer?: boolean | undefined;
        }, {
            custom_service_annotations?: Record<string, string> | undefined;
            db_hosted_zone?: string | undefined;
            enable_master_load_balancer?: boolean | undefined;
            enable_master_pooler_load_balancer?: boolean | undefined;
            enable_replica_load_balancer?: boolean | undefined;
            enable_replica_pooler_load_balancer?: boolean | undefined;
            external_traffic_policy?: "Cluster" | "Local" | undefined;
            master_dns_name_format?: string | undefined;
            master_legacy_dns_name_format?: string | undefined;
            replica_dns_name_format?: string | undefined;
            replica_legacy_dns_name_format?: string | undefined;
        }>>;
        aws_or_gcp: z.ZodOptional<z.ZodObject<{
            additional_secret_mount: z.ZodOptional<z.ZodString>;
            /**
             *
             * @default "/meta/credentials"
             */
            additional_secret_mount_path: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "eu-central-1"
             */
            aws_region: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            enable_ebs_gp3_migration: z.ZodOptional<z.ZodBoolean>;
            /**
             *
             * @default 1000
             */
            enable_ebs_gp3_migration_max_size: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
            gcp_credentials: z.ZodOptional<z.ZodString>;
            kube_iam_role: z.ZodOptional<z.ZodString>;
            log_s3_bucket: z.ZodOptional<z.ZodString>;
            wal_az_storage_account: z.ZodOptional<z.ZodString>;
            wal_gs_bucket: z.ZodOptional<z.ZodString>;
            wal_s3_bucket: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            additional_secret_mount_path: string;
            aws_region: string;
            enable_ebs_gp3_migration_max_size: number;
            additional_secret_mount?: string | undefined;
            enable_ebs_gp3_migration?: boolean | undefined;
            gcp_credentials?: string | undefined;
            kube_iam_role?: string | undefined;
            log_s3_bucket?: string | undefined;
            wal_az_storage_account?: string | undefined;
            wal_gs_bucket?: string | undefined;
            wal_s3_bucket?: string | undefined;
        }, {
            additional_secret_mount?: string | undefined;
            additional_secret_mount_path?: string | undefined;
            aws_region?: string | undefined;
            enable_ebs_gp3_migration?: boolean | undefined;
            enable_ebs_gp3_migration_max_size?: number | undefined;
            gcp_credentials?: string | undefined;
            kube_iam_role?: string | undefined;
            log_s3_bucket?: string | undefined;
            wal_az_storage_account?: string | undefined;
            wal_gs_bucket?: string | undefined;
            wal_s3_bucket?: string | undefined;
        }>>;
        logical_backup: z.ZodOptional<z.ZodObject<{
            logical_backup_azure_storage_account_name: z.ZodOptional<z.ZodString>;
            logical_backup_azure_storage_container: z.ZodOptional<z.ZodString>;
            logical_backup_azure_storage_account_key: z.ZodOptional<z.ZodString>;
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            logical_backup_cpu_limit: z.ZodOptional<z.ZodString>;
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            logical_backup_cpu_request: z.ZodOptional<z.ZodString>;
            /**
             *
             * @default "registry.opensource.zalan.do/acid/logical-backup:v1.11.0"
             */
            logical_backup_docker_image: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            logical_backup_google_application_credentials: z.ZodOptional<z.ZodString>;
            /**
             *
             * @default "logical-backup-"
             */
            logical_backup_job_prefix: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            logical_backup_memory_limit: z.ZodOptional<z.ZodString>;
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            logical_backup_memory_request: z.ZodOptional<z.ZodString>;
            /**
             *
             * @default "s3"
             */
            logical_backup_provider: z.ZodDefault<z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"az">, z.ZodLiteral<"gcs">, z.ZodLiteral<"s3">]>>>;
            logical_backup_s3_access_key_id: z.ZodOptional<z.ZodString>;
            logical_backup_s3_bucket: z.ZodOptional<z.ZodString>;
            logical_backup_s3_endpoint: z.ZodOptional<z.ZodString>;
            logical_backup_s3_region: z.ZodOptional<z.ZodString>;
            logical_backup_s3_secret_access_key: z.ZodOptional<z.ZodString>;
            logical_backup_s3_sse: z.ZodOptional<z.ZodString>;
            logical_backup_s3_retention_time: z.ZodOptional<z.ZodString>;
            /**
             *
             * @default "30 00 * * *"
             * @pattern ^(\d+|\*)(\/\d+)?(\s+(\d+|\*)(\/\d+)?){4}$
             */
            logical_backup_schedule: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            logical_backup_cronjob_environment_secret: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            logical_backup_docker_image: string;
            logical_backup_job_prefix: string;
            logical_backup_provider: "az" | "gcs" | "s3";
            logical_backup_schedule: string;
            logical_backup_azure_storage_account_name?: string | undefined;
            logical_backup_azure_storage_container?: string | undefined;
            logical_backup_azure_storage_account_key?: string | undefined;
            logical_backup_cpu_limit?: string | undefined;
            logical_backup_cpu_request?: string | undefined;
            logical_backup_google_application_credentials?: string | undefined;
            logical_backup_memory_limit?: string | undefined;
            logical_backup_memory_request?: string | undefined;
            logical_backup_s3_access_key_id?: string | undefined;
            logical_backup_s3_bucket?: string | undefined;
            logical_backup_s3_endpoint?: string | undefined;
            logical_backup_s3_region?: string | undefined;
            logical_backup_s3_secret_access_key?: string | undefined;
            logical_backup_s3_sse?: string | undefined;
            logical_backup_s3_retention_time?: string | undefined;
            logical_backup_cronjob_environment_secret?: string | undefined;
        }, {
            logical_backup_azure_storage_account_name?: string | undefined;
            logical_backup_azure_storage_container?: string | undefined;
            logical_backup_azure_storage_account_key?: string | undefined;
            logical_backup_cpu_limit?: string | undefined;
            logical_backup_cpu_request?: string | undefined;
            logical_backup_docker_image?: string | undefined;
            logical_backup_google_application_credentials?: string | undefined;
            logical_backup_job_prefix?: string | undefined;
            logical_backup_memory_limit?: string | undefined;
            logical_backup_memory_request?: string | undefined;
            logical_backup_provider?: "az" | "gcs" | "s3" | undefined;
            logical_backup_s3_access_key_id?: string | undefined;
            logical_backup_s3_bucket?: string | undefined;
            logical_backup_s3_endpoint?: string | undefined;
            logical_backup_s3_region?: string | undefined;
            logical_backup_s3_secret_access_key?: string | undefined;
            logical_backup_s3_sse?: string | undefined;
            logical_backup_s3_retention_time?: string | undefined;
            logical_backup_schedule?: string | undefined;
            logical_backup_cronjob_environment_secret?: string | undefined;
        }>>;
        debug: z.ZodOptional<z.ZodObject<{
            /**
             *
             * @default true
             */
            debug_logging: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
            /**
             *
             * @default true
             */
            enable_database_access: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        }, "strip", z.ZodTypeAny, {
            debug_logging: boolean;
            enable_database_access: boolean;
        }, {
            debug_logging?: boolean | undefined;
            enable_database_access?: boolean | undefined;
        }>>;
        teams_api: z.ZodOptional<z.ZodObject<{
            /**
             *
             * @default true
             */
            enable_admin_role_for_users: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
            /**
             *
             * @default true
             */
            enable_postgres_team_crd: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
            enable_postgres_team_crd_superusers: z.ZodOptional<z.ZodBoolean>;
            enable_team_member_deprecation: z.ZodOptional<z.ZodBoolean>;
            enable_team_superuser: z.ZodOptional<z.ZodBoolean>;
            /**
             *
             * @default true
             */
            enable_teams_api: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
            /**
             *
             * @default "https://info.example.com/oauth2/tokeninfo?access_token= uid realm=/employees"
             */
            pam_configuration: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "zalandos"
             */
            pam_role_name: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            postgres_superuser_teams: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            protected_role_names: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            /**
             *
             * @default "_deleted"
             */
            role_deletion_suffix: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "admin"
             */
            team_admin_role: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            team_api_role_configuration: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
            /**
             *
             * @default "https://teams.example.com/api/"
             */
            teams_api_url: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            enable_admin_role_for_users: boolean;
            enable_postgres_team_crd: boolean;
            enable_teams_api: boolean;
            pam_configuration: string;
            pam_role_name: string;
            role_deletion_suffix: string;
            team_admin_role: string;
            teams_api_url: string;
            enable_postgres_team_crd_superusers?: boolean | undefined;
            enable_team_member_deprecation?: boolean | undefined;
            enable_team_superuser?: boolean | undefined;
            postgres_superuser_teams?: string[] | undefined;
            protected_role_names?: string[] | undefined;
            team_api_role_configuration?: Record<string, string> | undefined;
        }, {
            enable_admin_role_for_users?: boolean | undefined;
            enable_postgres_team_crd?: boolean | undefined;
            enable_postgres_team_crd_superusers?: boolean | undefined;
            enable_team_member_deprecation?: boolean | undefined;
            enable_team_superuser?: boolean | undefined;
            enable_teams_api?: boolean | undefined;
            pam_configuration?: string | undefined;
            pam_role_name?: string | undefined;
            postgres_superuser_teams?: string[] | undefined;
            protected_role_names?: string[] | undefined;
            role_deletion_suffix?: string | undefined;
            team_admin_role?: string | undefined;
            team_api_role_configuration?: Record<string, string> | undefined;
            teams_api_url?: string | undefined;
        }>>;
        logging_rest_api: z.ZodOptional<z.ZodObject<{
            /**
             *
             * @default 8080
             */
            api_port: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
            /**
             *
             * @default 1000
             */
            cluster_history_entries: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
            /**
             *
             * @default 100
             */
            ring_log_lines: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        }, "strip", z.ZodTypeAny, {
            api_port: number;
            cluster_history_entries: number;
            ring_log_lines: number;
        }, {
            api_port?: number | undefined;
            cluster_history_entries?: number | undefined;
            ring_log_lines?: number | undefined;
        }>>;
        scalyr: z.ZodOptional<z.ZodObject<{
            scalyr_api_key: z.ZodOptional<z.ZodString>;
            /**
             *
             * @default "1"
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            scalyr_cpu_limit: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "100m"
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            scalyr_cpu_request: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            scalyr_image: z.ZodOptional<z.ZodString>;
            /**
             *
             * @default "500Mi"
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            scalyr_memory_limit: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "50Mi"
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            scalyr_memory_request: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "https://upload.eu.scalyr.com"
             */
            scalyr_server_url: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            scalyr_cpu_limit: string;
            scalyr_cpu_request: string;
            scalyr_memory_limit: string;
            scalyr_memory_request: string;
            scalyr_server_url: string;
            scalyr_api_key?: string | undefined;
            scalyr_image?: string | undefined;
        }, {
            scalyr_api_key?: string | undefined;
            scalyr_cpu_limit?: string | undefined;
            scalyr_cpu_request?: string | undefined;
            scalyr_image?: string | undefined;
            scalyr_memory_limit?: string | undefined;
            scalyr_memory_request?: string | undefined;
            scalyr_server_url?: string | undefined;
        }>>;
        connection_pooler: z.ZodOptional<z.ZodObject<{
            /**
             *
             * @default "pooler"
             */
            connection_pooler_schema: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "pooler"
             */
            connection_pooler_user: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default "registry.opensource.zalan.do/acid/pgbouncer:master-32"
             */
            connection_pooler_image: z.ZodDefault<z.ZodOptional<z.ZodString>>;
            /**
             *
             * @default 60
             */
            connection_pooler_max_db_connections: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
            /**
             *
             * @default "transaction"
             */
            connection_pooler_mode: z.ZodDefault<z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"session">, z.ZodLiteral<"transaction">]>>>;
            /**
             *
             * @default 2
             * @minimum 1
             */
            connection_pooler_number_of_instances: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            connection_pooler_default_cpu_limit: z.ZodOptional<z.ZodString>;
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            connection_pooler_default_cpu_request: z.ZodOptional<z.ZodString>;
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            connection_pooler_default_memory_limit: z.ZodOptional<z.ZodString>;
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            connection_pooler_default_memory_request: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            connection_pooler_schema: string;
            connection_pooler_user: string;
            connection_pooler_image: string;
            connection_pooler_max_db_connections: number;
            connection_pooler_mode: "session" | "transaction";
            connection_pooler_number_of_instances: number;
            connection_pooler_default_cpu_limit?: string | undefined;
            connection_pooler_default_cpu_request?: string | undefined;
            connection_pooler_default_memory_limit?: string | undefined;
            connection_pooler_default_memory_request?: string | undefined;
        }, {
            connection_pooler_schema?: string | undefined;
            connection_pooler_user?: string | undefined;
            connection_pooler_image?: string | undefined;
            connection_pooler_max_db_connections?: number | undefined;
            connection_pooler_mode?: "session" | "transaction" | undefined;
            connection_pooler_number_of_instances?: number | undefined;
            connection_pooler_default_cpu_limit?: string | undefined;
            connection_pooler_default_cpu_request?: string | undefined;
            connection_pooler_default_memory_limit?: string | undefined;
            connection_pooler_default_memory_request?: string | undefined;
        }>>;
        patroni: z.ZodOptional<z.ZodObject<{
            enable_patroni_failsafe_mode: z.ZodOptional<z.ZodBoolean>;
        }, "strip", z.ZodTypeAny, {
            enable_patroni_failsafe_mode?: boolean | undefined;
        }, {
            enable_patroni_failsafe_mode?: boolean | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        docker_image: string;
        enable_crd_registration: boolean;
        enable_crd_validation: boolean;
        enable_pgversion_env_var: boolean;
        enable_shm_volume: boolean;
        max_instances: number;
        min_instances: number;
        resync_period: string;
        repair_period: string;
        workers: number;
        crd_categories?: string[] | undefined;
        enable_lazy_spilo_upgrade?: boolean | undefined;
        enable_spilo_wal_path_compat?: boolean | undefined;
        enable_team_id_clustername_prefix?: boolean | undefined;
        etcd_host?: string | undefined;
        ignore_instance_limits_annotation_key?: string | undefined;
        kubernetes_use_configmaps?: boolean | undefined;
        set_memory_request_to_limit?: boolean | undefined;
        sidecar_docker_images?: Record<string, string> | undefined;
        sidecars?: {}[] | undefined;
        users?: {
            password_rotation_interval: number;
            password_rotation_user_retention: number;
            replication_username: string;
            super_username: string;
            additional_owner_roles?: string[] | undefined;
            enable_password_rotation?: boolean | undefined;
        } | undefined;
        major_version_upgrade?: {
            major_version_upgrade_mode: string;
            minimal_major_version: string;
            target_major_version: string;
            major_version_upgrade_team_allow_list?: string[] | undefined;
        } | undefined;
        kubernetes?: {
            cluster_domain: string;
            cluster_name_label: string;
            enable_init_containers: boolean;
            enable_persistent_volume_claim_deletion: boolean;
            enable_pod_disruption_budget: boolean;
            enable_sidecars: boolean;
            master_pod_move_timeout: string;
            oauth_token_secret_name: string;
            pdb_name_format: string;
            pod_antiaffinity_topology_key: string;
            pod_management_policy: "ordered_ready" | "parallel";
            pod_role_label: string;
            pod_service_account_name: string;
            pod_terminate_grace_period: string;
            secret_name_template: string;
            spilo_allow_privilege_escalation: boolean;
            storage_resize_mode: "off" | "ebs" | "mixed" | "pvc";
            additional_pod_capabilities?: string[] | undefined;
            cluster_labels?: Record<string, string> | undefined;
            custom_pod_annotations?: Record<string, string> | undefined;
            delete_annotation_date_key?: string | undefined;
            delete_annotation_name_key?: string | undefined;
            downscaler_annotations?: string[] | undefined;
            enable_cross_namespace_secret?: boolean | undefined;
            enable_finalizers?: boolean | undefined;
            enable_pod_antiaffinity?: boolean | undefined;
            enable_readiness_probe?: boolean | undefined;
            ignored_annotations?: string[] | undefined;
            infrastructure_roles_secret_name?: string | undefined;
            infrastructure_roles_secrets?: {
                secretname: string;
                userkey: string;
                passwordkey: string;
                rolekey?: string | undefined;
                defaultuservalue?: string | undefined;
                defaultrolevalue?: string | undefined;
                details?: string | undefined;
                template?: boolean | undefined;
            }[] | undefined;
            inherited_annotations?: string[] | undefined;
            inherited_labels?: string[] | undefined;
            node_readiness_label?: Record<string, string> | undefined;
            node_readiness_label_merge?: "AND" | "OR" | undefined;
            persistent_volume_claim_retention_policy?: {
                when_deleted?: "delete" | "retain" | undefined;
                when_scaled?: "delete" | "retain" | undefined;
            } | undefined;
            pod_antiaffinity_preferred_during_scheduling?: boolean | undefined;
            pod_environment_configmap?: string | undefined;
            pod_environment_secret?: string | undefined;
            pod_priority_class_name?: string | undefined;
            pod_service_account_definition?: string | undefined;
            pod_service_account_role_binding_definition?: string | undefined;
            share_pgsocket_with_sidecars?: boolean | undefined;
            spilo_runasuser?: number | undefined;
            spilo_runasgroup?: number | undefined;
            spilo_fsgroup?: number | undefined;
            spilo_privileged?: boolean | undefined;
            toleration?: Record<string, string> | undefined;
            watched_namespace?: string | undefined;
        } | undefined;
        postgres_pod_resources?: {
            default_cpu_limit?: string | undefined;
            default_cpu_request?: string | undefined;
            default_memory_limit?: string | undefined;
            default_memory_request?: string | undefined;
            max_cpu_request?: string | undefined;
            max_memory_request?: string | undefined;
            min_cpu_limit?: string | undefined;
            min_memory_limit?: string | undefined;
        } | undefined;
        timeouts?: {
            patroni_api_check_interval: string;
            patroni_api_check_timeout: string;
            pod_label_wait_timeout: string;
            pod_deletion_wait_timeout: string;
            ready_wait_interval: string;
            ready_wait_timeout: string;
            resource_check_interval: string;
            resource_check_timeout: string;
        } | undefined;
        load_balancer?: {
            db_hosted_zone: string;
            enable_master_load_balancer: boolean;
            external_traffic_policy: "Cluster" | "Local";
            master_dns_name_format: string;
            master_legacy_dns_name_format: string;
            replica_dns_name_format: string;
            replica_legacy_dns_name_format: string;
            custom_service_annotations?: Record<string, string> | undefined;
            enable_master_pooler_load_balancer?: boolean | undefined;
            enable_replica_load_balancer?: boolean | undefined;
            enable_replica_pooler_load_balancer?: boolean | undefined;
        } | undefined;
        aws_or_gcp?: {
            additional_secret_mount_path: string;
            aws_region: string;
            enable_ebs_gp3_migration_max_size: number;
            additional_secret_mount?: string | undefined;
            enable_ebs_gp3_migration?: boolean | undefined;
            gcp_credentials?: string | undefined;
            kube_iam_role?: string | undefined;
            log_s3_bucket?: string | undefined;
            wal_az_storage_account?: string | undefined;
            wal_gs_bucket?: string | undefined;
            wal_s3_bucket?: string | undefined;
        } | undefined;
        logical_backup?: {
            logical_backup_docker_image: string;
            logical_backup_job_prefix: string;
            logical_backup_provider: "az" | "gcs" | "s3";
            logical_backup_schedule: string;
            logical_backup_azure_storage_account_name?: string | undefined;
            logical_backup_azure_storage_container?: string | undefined;
            logical_backup_azure_storage_account_key?: string | undefined;
            logical_backup_cpu_limit?: string | undefined;
            logical_backup_cpu_request?: string | undefined;
            logical_backup_google_application_credentials?: string | undefined;
            logical_backup_memory_limit?: string | undefined;
            logical_backup_memory_request?: string | undefined;
            logical_backup_s3_access_key_id?: string | undefined;
            logical_backup_s3_bucket?: string | undefined;
            logical_backup_s3_endpoint?: string | undefined;
            logical_backup_s3_region?: string | undefined;
            logical_backup_s3_secret_access_key?: string | undefined;
            logical_backup_s3_sse?: string | undefined;
            logical_backup_s3_retention_time?: string | undefined;
            logical_backup_cronjob_environment_secret?: string | undefined;
        } | undefined;
        debug?: {
            debug_logging: boolean;
            enable_database_access: boolean;
        } | undefined;
        teams_api?: {
            enable_admin_role_for_users: boolean;
            enable_postgres_team_crd: boolean;
            enable_teams_api: boolean;
            pam_configuration: string;
            pam_role_name: string;
            role_deletion_suffix: string;
            team_admin_role: string;
            teams_api_url: string;
            enable_postgres_team_crd_superusers?: boolean | undefined;
            enable_team_member_deprecation?: boolean | undefined;
            enable_team_superuser?: boolean | undefined;
            postgres_superuser_teams?: string[] | undefined;
            protected_role_names?: string[] | undefined;
            team_api_role_configuration?: Record<string, string> | undefined;
        } | undefined;
        logging_rest_api?: {
            api_port: number;
            cluster_history_entries: number;
            ring_log_lines: number;
        } | undefined;
        scalyr?: {
            scalyr_cpu_limit: string;
            scalyr_cpu_request: string;
            scalyr_memory_limit: string;
            scalyr_memory_request: string;
            scalyr_server_url: string;
            scalyr_api_key?: string | undefined;
            scalyr_image?: string | undefined;
        } | undefined;
        connection_pooler?: {
            connection_pooler_schema: string;
            connection_pooler_user: string;
            connection_pooler_image: string;
            connection_pooler_max_db_connections: number;
            connection_pooler_mode: "session" | "transaction";
            connection_pooler_number_of_instances: number;
            connection_pooler_default_cpu_limit?: string | undefined;
            connection_pooler_default_cpu_request?: string | undefined;
            connection_pooler_default_memory_limit?: string | undefined;
            connection_pooler_default_memory_request?: string | undefined;
        } | undefined;
        patroni?: {
            enable_patroni_failsafe_mode?: boolean | undefined;
        } | undefined;
    }, {
        crd_categories?: string[] | undefined;
        docker_image?: string | undefined;
        enable_crd_registration?: boolean | undefined;
        enable_crd_validation?: boolean | undefined;
        enable_lazy_spilo_upgrade?: boolean | undefined;
        enable_pgversion_env_var?: boolean | undefined;
        enable_shm_volume?: boolean | undefined;
        enable_spilo_wal_path_compat?: boolean | undefined;
        enable_team_id_clustername_prefix?: boolean | undefined;
        etcd_host?: string | undefined;
        ignore_instance_limits_annotation_key?: string | undefined;
        kubernetes_use_configmaps?: boolean | undefined;
        max_instances?: number | undefined;
        min_instances?: number | undefined;
        resync_period?: string | undefined;
        repair_period?: string | undefined;
        set_memory_request_to_limit?: boolean | undefined;
        sidecar_docker_images?: Record<string, string> | undefined;
        sidecars?: {}[] | undefined;
        workers?: number | undefined;
        users?: {
            additional_owner_roles?: string[] | undefined;
            enable_password_rotation?: boolean | undefined;
            password_rotation_interval?: number | undefined;
            password_rotation_user_retention?: number | undefined;
            replication_username?: string | undefined;
            super_username?: string | undefined;
        } | undefined;
        major_version_upgrade?: {
            major_version_upgrade_mode?: string | undefined;
            major_version_upgrade_team_allow_list?: string[] | undefined;
            minimal_major_version?: string | undefined;
            target_major_version?: string | undefined;
        } | undefined;
        kubernetes?: {
            additional_pod_capabilities?: string[] | undefined;
            cluster_domain?: string | undefined;
            cluster_labels?: Record<string, string> | undefined;
            cluster_name_label?: string | undefined;
            custom_pod_annotations?: Record<string, string> | undefined;
            delete_annotation_date_key?: string | undefined;
            delete_annotation_name_key?: string | undefined;
            downscaler_annotations?: string[] | undefined;
            enable_cross_namespace_secret?: boolean | undefined;
            enable_finalizers?: boolean | undefined;
            enable_init_containers?: boolean | undefined;
            enable_persistent_volume_claim_deletion?: boolean | undefined;
            enable_pod_antiaffinity?: boolean | undefined;
            enable_pod_disruption_budget?: boolean | undefined;
            enable_readiness_probe?: boolean | undefined;
            enable_sidecars?: boolean | undefined;
            ignored_annotations?: string[] | undefined;
            infrastructure_roles_secret_name?: string | undefined;
            infrastructure_roles_secrets?: {
                secretname: string;
                userkey: string;
                passwordkey: string;
                rolekey?: string | undefined;
                defaultuservalue?: string | undefined;
                defaultrolevalue?: string | undefined;
                details?: string | undefined;
                template?: boolean | undefined;
            }[] | undefined;
            inherited_annotations?: string[] | undefined;
            inherited_labels?: string[] | undefined;
            master_pod_move_timeout?: string | undefined;
            node_readiness_label?: Record<string, string> | undefined;
            node_readiness_label_merge?: "AND" | "OR" | undefined;
            oauth_token_secret_name?: string | undefined;
            pdb_name_format?: string | undefined;
            persistent_volume_claim_retention_policy?: {
                when_deleted?: "delete" | "retain" | undefined;
                when_scaled?: "delete" | "retain" | undefined;
            } | undefined;
            pod_antiaffinity_preferred_during_scheduling?: boolean | undefined;
            pod_antiaffinity_topology_key?: string | undefined;
            pod_environment_configmap?: string | undefined;
            pod_environment_secret?: string | undefined;
            pod_management_policy?: "ordered_ready" | "parallel" | undefined;
            pod_priority_class_name?: string | undefined;
            pod_role_label?: string | undefined;
            pod_service_account_definition?: string | undefined;
            pod_service_account_name?: string | undefined;
            pod_service_account_role_binding_definition?: string | undefined;
            pod_terminate_grace_period?: string | undefined;
            secret_name_template?: string | undefined;
            share_pgsocket_with_sidecars?: boolean | undefined;
            spilo_allow_privilege_escalation?: boolean | undefined;
            spilo_runasuser?: number | undefined;
            spilo_runasgroup?: number | undefined;
            spilo_fsgroup?: number | undefined;
            spilo_privileged?: boolean | undefined;
            storage_resize_mode?: "off" | "ebs" | "mixed" | "pvc" | undefined;
            toleration?: Record<string, string> | undefined;
            watched_namespace?: string | undefined;
        } | undefined;
        postgres_pod_resources?: {
            default_cpu_limit?: string | undefined;
            default_cpu_request?: string | undefined;
            default_memory_limit?: string | undefined;
            default_memory_request?: string | undefined;
            max_cpu_request?: string | undefined;
            max_memory_request?: string | undefined;
            min_cpu_limit?: string | undefined;
            min_memory_limit?: string | undefined;
        } | undefined;
        timeouts?: {
            patroni_api_check_interval?: string | undefined;
            patroni_api_check_timeout?: string | undefined;
            pod_label_wait_timeout?: string | undefined;
            pod_deletion_wait_timeout?: string | undefined;
            ready_wait_interval?: string | undefined;
            ready_wait_timeout?: string | undefined;
            resource_check_interval?: string | undefined;
            resource_check_timeout?: string | undefined;
        } | undefined;
        load_balancer?: {
            custom_service_annotations?: Record<string, string> | undefined;
            db_hosted_zone?: string | undefined;
            enable_master_load_balancer?: boolean | undefined;
            enable_master_pooler_load_balancer?: boolean | undefined;
            enable_replica_load_balancer?: boolean | undefined;
            enable_replica_pooler_load_balancer?: boolean | undefined;
            external_traffic_policy?: "Cluster" | "Local" | undefined;
            master_dns_name_format?: string | undefined;
            master_legacy_dns_name_format?: string | undefined;
            replica_dns_name_format?: string | undefined;
            replica_legacy_dns_name_format?: string | undefined;
        } | undefined;
        aws_or_gcp?: {
            additional_secret_mount?: string | undefined;
            additional_secret_mount_path?: string | undefined;
            aws_region?: string | undefined;
            enable_ebs_gp3_migration?: boolean | undefined;
            enable_ebs_gp3_migration_max_size?: number | undefined;
            gcp_credentials?: string | undefined;
            kube_iam_role?: string | undefined;
            log_s3_bucket?: string | undefined;
            wal_az_storage_account?: string | undefined;
            wal_gs_bucket?: string | undefined;
            wal_s3_bucket?: string | undefined;
        } | undefined;
        logical_backup?: {
            logical_backup_azure_storage_account_name?: string | undefined;
            logical_backup_azure_storage_container?: string | undefined;
            logical_backup_azure_storage_account_key?: string | undefined;
            logical_backup_cpu_limit?: string | undefined;
            logical_backup_cpu_request?: string | undefined;
            logical_backup_docker_image?: string | undefined;
            logical_backup_google_application_credentials?: string | undefined;
            logical_backup_job_prefix?: string | undefined;
            logical_backup_memory_limit?: string | undefined;
            logical_backup_memory_request?: string | undefined;
            logical_backup_provider?: "az" | "gcs" | "s3" | undefined;
            logical_backup_s3_access_key_id?: string | undefined;
            logical_backup_s3_bucket?: string | undefined;
            logical_backup_s3_endpoint?: string | undefined;
            logical_backup_s3_region?: string | undefined;
            logical_backup_s3_secret_access_key?: string | undefined;
            logical_backup_s3_sse?: string | undefined;
            logical_backup_s3_retention_time?: string | undefined;
            logical_backup_schedule?: string | undefined;
            logical_backup_cronjob_environment_secret?: string | undefined;
        } | undefined;
        debug?: {
            debug_logging?: boolean | undefined;
            enable_database_access?: boolean | undefined;
        } | undefined;
        teams_api?: {
            enable_admin_role_for_users?: boolean | undefined;
            enable_postgres_team_crd?: boolean | undefined;
            enable_postgres_team_crd_superusers?: boolean | undefined;
            enable_team_member_deprecation?: boolean | undefined;
            enable_team_superuser?: boolean | undefined;
            enable_teams_api?: boolean | undefined;
            pam_configuration?: string | undefined;
            pam_role_name?: string | undefined;
            postgres_superuser_teams?: string[] | undefined;
            protected_role_names?: string[] | undefined;
            role_deletion_suffix?: string | undefined;
            team_admin_role?: string | undefined;
            team_api_role_configuration?: Record<string, string> | undefined;
            teams_api_url?: string | undefined;
        } | undefined;
        logging_rest_api?: {
            api_port?: number | undefined;
            cluster_history_entries?: number | undefined;
            ring_log_lines?: number | undefined;
        } | undefined;
        scalyr?: {
            scalyr_api_key?: string | undefined;
            scalyr_cpu_limit?: string | undefined;
            scalyr_cpu_request?: string | undefined;
            scalyr_image?: string | undefined;
            scalyr_memory_limit?: string | undefined;
            scalyr_memory_request?: string | undefined;
            scalyr_server_url?: string | undefined;
        } | undefined;
        connection_pooler?: {
            connection_pooler_schema?: string | undefined;
            connection_pooler_user?: string | undefined;
            connection_pooler_image?: string | undefined;
            connection_pooler_max_db_connections?: number | undefined;
            connection_pooler_mode?: "session" | "transaction" | undefined;
            connection_pooler_number_of_instances?: number | undefined;
            connection_pooler_default_cpu_limit?: string | undefined;
            connection_pooler_default_cpu_request?: string | undefined;
            connection_pooler_default_memory_limit?: string | undefined;
            connection_pooler_default_memory_request?: string | undefined;
        } | undefined;
        patroni?: {
            enable_patroni_failsafe_mode?: boolean | undefined;
        } | undefined;
    }>;
    status: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    metadata: z.ZodOptional<z.ZodObject<{
        annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        creationTimestamp: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        deletionGracePeriodSeconds: z.ZodOptional<z.ZodNumber>;
        deletionTimestamp: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        finalizers: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        generateName: z.ZodOptional<z.ZodString>;
        generation: z.ZodOptional<z.ZodNumber>;
        labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        managedFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
            apiVersion: z.ZodOptional<z.ZodString>;
            fieldsType: z.ZodOptional<z.ZodString>;
            fieldsV1: z.ZodOptional<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
            manager: z.ZodOptional<z.ZodString>;
            operation: z.ZodOptional<z.ZodString>;
            subresource: z.ZodOptional<z.ZodString>;
            time: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }, {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }>, "many">>; /**
         *
         * @default "postgresql-operator"
         */
        name: z.ZodOptional<z.ZodString>;
        namespace: z.ZodOptional<z.ZodString>;
        ownerReferences: z.ZodOptional<z.ZodArray<z.ZodObject<{
            apiVersion: z.ZodString;
            blockOwnerDeletion: z.ZodOptional<z.ZodBoolean>;
            controller: z.ZodOptional<z.ZodBoolean>;
            kind: z.ZodString;
            name: z.ZodString;
            uid: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }, {
            apiVersion: string;
            kind: string; /**
             *
             * @default "5m"
             */
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }>, "many">>; /**
         *
         * @default "{username}.{cluster}.credentials.{tprkind}.{tprgroup}"
         */
        resourceVersion: z.ZodOptional<z.ZodString>;
        selfLink: z.ZodOptional<z.ZodString>;
        uid: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined; /**
         *
         * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
         */
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined; /**
         *
         * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
         */
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined; /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined; /**
         *
         * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
         */
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    }, {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined; /**
         *
         * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
         */
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined; /**
             *
             * @default "5s"
             */
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined; /**
             *
             * @default "10m"
             */
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined; /**
             *
             * @default "4s"
             */
            controller?: boolean | undefined;
        }[] | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    kind: "OperatorConfiguration";
    apiVersion: "acid.zalan.do/v1";
    configuration: {
        docker_image: string;
        enable_crd_registration: boolean;
        enable_crd_validation: boolean;
        enable_pgversion_env_var: boolean;
        enable_shm_volume: boolean;
        max_instances: number;
        min_instances: number;
        resync_period: string;
        repair_period: string;
        workers: number;
        crd_categories?: string[] | undefined;
        enable_lazy_spilo_upgrade?: boolean | undefined;
        enable_spilo_wal_path_compat?: boolean | undefined;
        enable_team_id_clustername_prefix?: boolean | undefined;
        etcd_host?: string | undefined;
        ignore_instance_limits_annotation_key?: string | undefined;
        kubernetes_use_configmaps?: boolean | undefined;
        set_memory_request_to_limit?: boolean | undefined;
        sidecar_docker_images?: Record<string, string> | undefined;
        sidecars?: {}[] | undefined;
        users?: {
            password_rotation_interval: number;
            password_rotation_user_retention: number;
            replication_username: string;
            super_username: string;
            additional_owner_roles?: string[] | undefined;
            enable_password_rotation?: boolean | undefined;
        } | undefined;
        major_version_upgrade?: {
            major_version_upgrade_mode: string;
            minimal_major_version: string;
            target_major_version: string;
            major_version_upgrade_team_allow_list?: string[] | undefined;
        } | undefined;
        kubernetes?: {
            cluster_domain: string;
            cluster_name_label: string;
            enable_init_containers: boolean;
            enable_persistent_volume_claim_deletion: boolean;
            enable_pod_disruption_budget: boolean;
            enable_sidecars: boolean;
            master_pod_move_timeout: string;
            oauth_token_secret_name: string;
            pdb_name_format: string;
            pod_antiaffinity_topology_key: string;
            pod_management_policy: "ordered_ready" | "parallel";
            pod_role_label: string;
            pod_service_account_name: string;
            pod_terminate_grace_period: string;
            secret_name_template: string;
            spilo_allow_privilege_escalation: boolean;
            storage_resize_mode: "off" | "ebs" | "mixed" | "pvc";
            additional_pod_capabilities?: string[] | undefined;
            cluster_labels?: Record<string, string> | undefined;
            custom_pod_annotations?: Record<string, string> | undefined;
            delete_annotation_date_key?: string | undefined;
            delete_annotation_name_key?: string | undefined;
            downscaler_annotations?: string[] | undefined;
            enable_cross_namespace_secret?: boolean | undefined;
            enable_finalizers?: boolean | undefined;
            enable_pod_antiaffinity?: boolean | undefined;
            enable_readiness_probe?: boolean | undefined;
            ignored_annotations?: string[] | undefined;
            infrastructure_roles_secret_name?: string | undefined;
            infrastructure_roles_secrets?: {
                secretname: string;
                userkey: string;
                passwordkey: string;
                rolekey?: string | undefined;
                defaultuservalue?: string | undefined;
                defaultrolevalue?: string | undefined;
                details?: string | undefined;
                template?: boolean | undefined;
            }[] | undefined;
            inherited_annotations?: string[] | undefined;
            inherited_labels?: string[] | undefined;
            node_readiness_label?: Record<string, string> | undefined;
            node_readiness_label_merge?: "AND" | "OR" | undefined;
            persistent_volume_claim_retention_policy?: {
                when_deleted?: "delete" | "retain" | undefined;
                when_scaled?: "delete" | "retain" | undefined;
            } | undefined;
            pod_antiaffinity_preferred_during_scheduling?: boolean | undefined;
            pod_environment_configmap?: string | undefined;
            pod_environment_secret?: string | undefined;
            pod_priority_class_name?: string | undefined;
            pod_service_account_definition?: string | undefined;
            pod_service_account_role_binding_definition?: string | undefined;
            share_pgsocket_with_sidecars?: boolean | undefined;
            spilo_runasuser?: number | undefined;
            spilo_runasgroup?: number | undefined;
            spilo_fsgroup?: number | undefined;
            spilo_privileged?: boolean | undefined;
            toleration?: Record<string, string> | undefined;
            watched_namespace?: string | undefined;
        } | undefined;
        postgres_pod_resources?: {
            default_cpu_limit?: string | undefined;
            default_cpu_request?: string | undefined;
            default_memory_limit?: string | undefined;
            default_memory_request?: string | undefined;
            max_cpu_request?: string | undefined;
            max_memory_request?: string | undefined;
            min_cpu_limit?: string | undefined;
            min_memory_limit?: string | undefined;
        } | undefined;
        timeouts?: {
            patroni_api_check_interval: string;
            patroni_api_check_timeout: string;
            pod_label_wait_timeout: string;
            pod_deletion_wait_timeout: string;
            ready_wait_interval: string;
            ready_wait_timeout: string;
            resource_check_interval: string;
            resource_check_timeout: string;
        } | undefined;
        load_balancer?: {
            db_hosted_zone: string;
            enable_master_load_balancer: boolean;
            external_traffic_policy: "Cluster" | "Local";
            master_dns_name_format: string;
            master_legacy_dns_name_format: string;
            replica_dns_name_format: string;
            replica_legacy_dns_name_format: string;
            custom_service_annotations?: Record<string, string> | undefined;
            enable_master_pooler_load_balancer?: boolean | undefined;
            enable_replica_load_balancer?: boolean | undefined;
            enable_replica_pooler_load_balancer?: boolean | undefined;
        } | undefined;
        aws_or_gcp?: {
            additional_secret_mount_path: string;
            aws_region: string;
            enable_ebs_gp3_migration_max_size: number;
            additional_secret_mount?: string | undefined;
            enable_ebs_gp3_migration?: boolean | undefined;
            gcp_credentials?: string | undefined;
            kube_iam_role?: string | undefined;
            log_s3_bucket?: string | undefined;
            wal_az_storage_account?: string | undefined;
            wal_gs_bucket?: string | undefined;
            wal_s3_bucket?: string | undefined;
        } | undefined;
        logical_backup?: {
            logical_backup_docker_image: string;
            logical_backup_job_prefix: string;
            logical_backup_provider: "az" | "gcs" | "s3";
            logical_backup_schedule: string;
            logical_backup_azure_storage_account_name?: string | undefined;
            logical_backup_azure_storage_container?: string | undefined;
            logical_backup_azure_storage_account_key?: string | undefined;
            logical_backup_cpu_limit?: string | undefined;
            logical_backup_cpu_request?: string | undefined;
            logical_backup_google_application_credentials?: string | undefined;
            logical_backup_memory_limit?: string | undefined;
            logical_backup_memory_request?: string | undefined;
            logical_backup_s3_access_key_id?: string | undefined;
            logical_backup_s3_bucket?: string | undefined;
            logical_backup_s3_endpoint?: string | undefined;
            logical_backup_s3_region?: string | undefined;
            logical_backup_s3_secret_access_key?: string | undefined;
            logical_backup_s3_sse?: string | undefined;
            logical_backup_s3_retention_time?: string | undefined;
            logical_backup_cronjob_environment_secret?: string | undefined;
        } | undefined;
        debug?: {
            debug_logging: boolean;
            enable_database_access: boolean;
        } | undefined;
        teams_api?: {
            enable_admin_role_for_users: boolean;
            enable_postgres_team_crd: boolean;
            enable_teams_api: boolean;
            pam_configuration: string;
            pam_role_name: string;
            role_deletion_suffix: string;
            team_admin_role: string;
            teams_api_url: string;
            enable_postgres_team_crd_superusers?: boolean | undefined;
            enable_team_member_deprecation?: boolean | undefined;
            enable_team_superuser?: boolean | undefined;
            postgres_superuser_teams?: string[] | undefined;
            protected_role_names?: string[] | undefined;
            team_api_role_configuration?: Record<string, string> | undefined;
        } | undefined;
        logging_rest_api?: {
            api_port: number;
            cluster_history_entries: number;
            ring_log_lines: number;
        } | undefined;
        scalyr?: {
            scalyr_cpu_limit: string;
            scalyr_cpu_request: string;
            scalyr_memory_limit: string;
            scalyr_memory_request: string;
            scalyr_server_url: string;
            scalyr_api_key?: string | undefined;
            scalyr_image?: string | undefined;
        } | undefined;
        connection_pooler?: {
            connection_pooler_schema: string;
            connection_pooler_user: string;
            connection_pooler_image: string;
            connection_pooler_max_db_connections: number;
            connection_pooler_mode: "session" | "transaction";
            connection_pooler_number_of_instances: number;
            connection_pooler_default_cpu_limit?: string | undefined;
            connection_pooler_default_cpu_request?: string | undefined;
            connection_pooler_default_memory_limit?: string | undefined;
            connection_pooler_default_memory_request?: string | undefined;
        } | undefined;
        patroni?: {
            enable_patroni_failsafe_mode?: boolean | undefined;
        } | undefined;
    };
    status?: Record<string, string> | undefined;
    metadata?: {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined; /**
         *
         * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
         */
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined; /**
         *
         * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
         */
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined; /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined; /**
         *
         * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
         */
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    } | undefined;
}, {
    kind: "OperatorConfiguration";
    apiVersion: "acid.zalan.do/v1";
    configuration: {
        crd_categories?: string[] | undefined;
        docker_image?: string | undefined;
        enable_crd_registration?: boolean | undefined;
        enable_crd_validation?: boolean | undefined;
        enable_lazy_spilo_upgrade?: boolean | undefined;
        enable_pgversion_env_var?: boolean | undefined;
        enable_shm_volume?: boolean | undefined;
        enable_spilo_wal_path_compat?: boolean | undefined;
        enable_team_id_clustername_prefix?: boolean | undefined;
        etcd_host?: string | undefined;
        ignore_instance_limits_annotation_key?: string | undefined;
        kubernetes_use_configmaps?: boolean | undefined;
        max_instances?: number | undefined;
        min_instances?: number | undefined;
        resync_period?: string | undefined;
        repair_period?: string | undefined;
        set_memory_request_to_limit?: boolean | undefined;
        sidecar_docker_images?: Record<string, string> | undefined;
        sidecars?: {}[] | undefined;
        workers?: number | undefined;
        users?: {
            additional_owner_roles?: string[] | undefined;
            enable_password_rotation?: boolean | undefined;
            password_rotation_interval?: number | undefined;
            password_rotation_user_retention?: number | undefined;
            replication_username?: string | undefined;
            super_username?: string | undefined;
        } | undefined;
        major_version_upgrade?: {
            major_version_upgrade_mode?: string | undefined;
            major_version_upgrade_team_allow_list?: string[] | undefined;
            minimal_major_version?: string | undefined;
            target_major_version?: string | undefined;
        } | undefined;
        kubernetes?: {
            additional_pod_capabilities?: string[] | undefined;
            cluster_domain?: string | undefined;
            cluster_labels?: Record<string, string> | undefined;
            cluster_name_label?: string | undefined;
            custom_pod_annotations?: Record<string, string> | undefined;
            delete_annotation_date_key?: string | undefined;
            delete_annotation_name_key?: string | undefined;
            downscaler_annotations?: string[] | undefined;
            enable_cross_namespace_secret?: boolean | undefined;
            enable_finalizers?: boolean | undefined;
            enable_init_containers?: boolean | undefined;
            enable_persistent_volume_claim_deletion?: boolean | undefined;
            enable_pod_antiaffinity?: boolean | undefined;
            enable_pod_disruption_budget?: boolean | undefined;
            enable_readiness_probe?: boolean | undefined;
            enable_sidecars?: boolean | undefined;
            ignored_annotations?: string[] | undefined;
            infrastructure_roles_secret_name?: string | undefined;
            infrastructure_roles_secrets?: {
                secretname: string;
                userkey: string;
                passwordkey: string;
                rolekey?: string | undefined;
                defaultuservalue?: string | undefined;
                defaultrolevalue?: string | undefined;
                details?: string | undefined;
                template?: boolean | undefined;
            }[] | undefined;
            inherited_annotations?: string[] | undefined;
            inherited_labels?: string[] | undefined;
            master_pod_move_timeout?: string | undefined;
            node_readiness_label?: Record<string, string> | undefined;
            node_readiness_label_merge?: "AND" | "OR" | undefined;
            oauth_token_secret_name?: string | undefined;
            pdb_name_format?: string | undefined;
            persistent_volume_claim_retention_policy?: {
                when_deleted?: "delete" | "retain" | undefined;
                when_scaled?: "delete" | "retain" | undefined;
            } | undefined;
            pod_antiaffinity_preferred_during_scheduling?: boolean | undefined;
            pod_antiaffinity_topology_key?: string | undefined;
            pod_environment_configmap?: string | undefined;
            pod_environment_secret?: string | undefined;
            pod_management_policy?: "ordered_ready" | "parallel" | undefined;
            pod_priority_class_name?: string | undefined;
            pod_role_label?: string | undefined;
            pod_service_account_definition?: string | undefined;
            pod_service_account_name?: string | undefined;
            pod_service_account_role_binding_definition?: string | undefined;
            pod_terminate_grace_period?: string | undefined;
            secret_name_template?: string | undefined;
            share_pgsocket_with_sidecars?: boolean | undefined;
            spilo_allow_privilege_escalation?: boolean | undefined;
            spilo_runasuser?: number | undefined;
            spilo_runasgroup?: number | undefined;
            spilo_fsgroup?: number | undefined;
            spilo_privileged?: boolean | undefined;
            storage_resize_mode?: "off" | "ebs" | "mixed" | "pvc" | undefined;
            toleration?: Record<string, string> | undefined;
            watched_namespace?: string | undefined;
        } | undefined;
        postgres_pod_resources?: {
            default_cpu_limit?: string | undefined;
            default_cpu_request?: string | undefined;
            default_memory_limit?: string | undefined;
            default_memory_request?: string | undefined;
            max_cpu_request?: string | undefined;
            max_memory_request?: string | undefined;
            min_cpu_limit?: string | undefined;
            min_memory_limit?: string | undefined;
        } | undefined;
        timeouts?: {
            patroni_api_check_interval?: string | undefined;
            patroni_api_check_timeout?: string | undefined;
            pod_label_wait_timeout?: string | undefined;
            pod_deletion_wait_timeout?: string | undefined;
            ready_wait_interval?: string | undefined;
            ready_wait_timeout?: string | undefined;
            resource_check_interval?: string | undefined;
            resource_check_timeout?: string | undefined;
        } | undefined;
        load_balancer?: {
            custom_service_annotations?: Record<string, string> | undefined;
            db_hosted_zone?: string | undefined;
            enable_master_load_balancer?: boolean | undefined;
            enable_master_pooler_load_balancer?: boolean | undefined;
            enable_replica_load_balancer?: boolean | undefined;
            enable_replica_pooler_load_balancer?: boolean | undefined;
            external_traffic_policy?: "Cluster" | "Local" | undefined;
            master_dns_name_format?: string | undefined;
            master_legacy_dns_name_format?: string | undefined;
            replica_dns_name_format?: string | undefined;
            replica_legacy_dns_name_format?: string | undefined;
        } | undefined;
        aws_or_gcp?: {
            additional_secret_mount?: string | undefined;
            additional_secret_mount_path?: string | undefined;
            aws_region?: string | undefined;
            enable_ebs_gp3_migration?: boolean | undefined;
            enable_ebs_gp3_migration_max_size?: number | undefined;
            gcp_credentials?: string | undefined;
            kube_iam_role?: string | undefined;
            log_s3_bucket?: string | undefined;
            wal_az_storage_account?: string | undefined;
            wal_gs_bucket?: string | undefined;
            wal_s3_bucket?: string | undefined;
        } | undefined;
        logical_backup?: {
            logical_backup_azure_storage_account_name?: string | undefined;
            logical_backup_azure_storage_container?: string | undefined;
            logical_backup_azure_storage_account_key?: string | undefined;
            logical_backup_cpu_limit?: string | undefined;
            logical_backup_cpu_request?: string | undefined;
            logical_backup_docker_image?: string | undefined;
            logical_backup_google_application_credentials?: string | undefined;
            logical_backup_job_prefix?: string | undefined;
            logical_backup_memory_limit?: string | undefined;
            logical_backup_memory_request?: string | undefined;
            logical_backup_provider?: "az" | "gcs" | "s3" | undefined;
            logical_backup_s3_access_key_id?: string | undefined;
            logical_backup_s3_bucket?: string | undefined;
            logical_backup_s3_endpoint?: string | undefined;
            logical_backup_s3_region?: string | undefined;
            logical_backup_s3_secret_access_key?: string | undefined;
            logical_backup_s3_sse?: string | undefined;
            logical_backup_s3_retention_time?: string | undefined;
            logical_backup_schedule?: string | undefined;
            logical_backup_cronjob_environment_secret?: string | undefined;
        } | undefined;
        debug?: {
            debug_logging?: boolean | undefined;
            enable_database_access?: boolean | undefined;
        } | undefined;
        teams_api?: {
            enable_admin_role_for_users?: boolean | undefined;
            enable_postgres_team_crd?: boolean | undefined;
            enable_postgres_team_crd_superusers?: boolean | undefined;
            enable_team_member_deprecation?: boolean | undefined;
            enable_team_superuser?: boolean | undefined;
            enable_teams_api?: boolean | undefined;
            pam_configuration?: string | undefined;
            pam_role_name?: string | undefined;
            postgres_superuser_teams?: string[] | undefined;
            protected_role_names?: string[] | undefined;
            role_deletion_suffix?: string | undefined;
            team_admin_role?: string | undefined;
            team_api_role_configuration?: Record<string, string> | undefined;
            teams_api_url?: string | undefined;
        } | undefined;
        logging_rest_api?: {
            api_port?: number | undefined;
            cluster_history_entries?: number | undefined;
            ring_log_lines?: number | undefined;
        } | undefined;
        scalyr?: {
            scalyr_api_key?: string | undefined;
            scalyr_cpu_limit?: string | undefined;
            scalyr_cpu_request?: string | undefined;
            scalyr_image?: string | undefined;
            scalyr_memory_limit?: string | undefined;
            scalyr_memory_request?: string | undefined;
            scalyr_server_url?: string | undefined;
        } | undefined;
        connection_pooler?: {
            connection_pooler_schema?: string | undefined;
            connection_pooler_user?: string | undefined;
            connection_pooler_image?: string | undefined;
            connection_pooler_max_db_connections?: number | undefined;
            connection_pooler_mode?: "session" | "transaction" | undefined;
            connection_pooler_number_of_instances?: number | undefined;
            connection_pooler_default_cpu_limit?: string | undefined;
            connection_pooler_default_cpu_request?: string | undefined;
            connection_pooler_default_memory_limit?: string | undefined;
            connection_pooler_default_memory_request?: string | undefined;
        } | undefined;
        patroni?: {
            enable_patroni_failsafe_mode?: boolean | undefined;
        } | undefined;
    };
    status?: Record<string, string> | undefined;
    metadata?: {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined; /**
         *
         * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
         */
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined; /**
             *
             * @default "5s"
             */
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined; /**
             *
             * @default "10m"
             */
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined; /**
             *
             * @default "4s"
             */
            controller?: boolean | undefined;
        }[] | undefined;
    } | undefined;
}>;
