import { z } from "zod";
import { iObjectMetaSchema } from "@soft-stech/apimachinery/apis/meta/v1/ObjectMeta.schema";
export const IOperatorConfigurationSchema = z.object({
    "kind": z.literal("OperatorConfiguration"),
    "apiVersion": z.literal("acid.zalan.do/v1"),
    "configuration": z.object({
        "crd_categories": z.array(z.string()).optional(),
        /**
         *
         * @default "ghcr.io/zalando/spilo-16:3.2-p2"
         */
        "docker_image": z.string().optional().default("ghcr.io/zalando/spilo-16:3.2-p2"),
        /**
         *
         * @default true
         */
        "enable_crd_registration": z.boolean().optional().default(true),
        /**
         * deprecated
         * @default true
         */
        "enable_crd_validation": z.boolean().optional().default(true),
        "enable_lazy_spilo_upgrade": z.boolean().optional(),
        /**
         *
         * @default true
         */
        "enable_pgversion_env_var": z.boolean().optional().default(true),
        /**
         *
         * @default true
         */
        "enable_shm_volume": z.boolean().optional().default(true),
        "enable_spilo_wal_path_compat": z.boolean().optional(),
        "enable_team_id_clustername_prefix": z.boolean().optional(),
        "etcd_host": z.string().optional(),
        "ignore_instance_limits_annotation_key": z.string().optional(),
        "kubernetes_use_configmaps": z.boolean().optional(),
        /**
         * -1 = disabled
         * @default -1
         * @minimum -1
         */
        "max_instances": z.number().min(-1).optional().default(-1),
        /**
         * -1 = disabled
         * @default -1
         * @minimum -1
         */
        "min_instances": z.number().min(-1).optional().default(-1),
        /**
         *
         * @default "30m"
         */
        "resync_period": z.string().optional().default("30m"),
        /**
         *
         * @default "5m"
         */
        "repair_period": z.string().optional().default("5m"),
        "set_memory_request_to_limit": z.boolean().optional(),
        "sidecar_docker_images": z.record(z.string()).optional(),
        "sidecars": z.array(z.object({})).optional(),
        /**
         *
         * @default 8
         * @minimum 1
         */
        "workers": z.number().min(1).optional().default(8),
        "users": z.object({
            "additional_owner_roles": z.array(z.string()).optional(),
            "enable_password_rotation": z.boolean().optional(),
            /**
             *
             * @default 90
             */
            "password_rotation_interval": z.number().optional().default(90),
            /**
             *
             * @default 180
             */
            "password_rotation_user_retention": z.number().optional().default(180),
            /**
             *
             * @default "standby"
             */
            "replication_username": z.string().optional().default("standby"),
            /**
             *
             * @default "postgres"
             */
            "super_username": z.string().optional().default("postgres")
        }).optional(),
        "major_version_upgrade": z.object({
            /**
             *
             * @default "off"
             */
            "major_version_upgrade_mode": z.string().optional().default("off"),
            "major_version_upgrade_team_allow_list": z.array(z.string()).optional(),
            /**
             *
             * @default "12"
             */
            "minimal_major_version": z.string().optional().default("12"),
            /**
             *
             * @default "16"
             */
            "target_major_version": z.string().optional().default("16")
        }).optional(),
        "kubernetes": z.object({
            "additional_pod_capabilities": z.array(z.string()).optional(),
            /**
             *
             * @default "cluster.local"
             */
            "cluster_domain": z.string().optional().default("cluster.local"),
            "cluster_labels": z.record(z.string()).optional(),
            /**
             *
             * @default "cluster-name"
             */
            "cluster_name_label": z.string().optional().default("cluster-name"),
            "custom_pod_annotations": z.record(z.string()).optional(),
            "delete_annotation_date_key": z.string().optional(),
            "delete_annotation_name_key": z.string().optional(),
            "downscaler_annotations": z.array(z.string()).optional(),
            "enable_cross_namespace_secret": z.boolean().optional(),
            "enable_finalizers": z.boolean().optional(),
            /**
             *
             * @default true
             */
            "enable_init_containers": z.boolean().optional().default(true),
            /**
             *
             * @default true
             */
            "enable_persistent_volume_claim_deletion": z.boolean().optional().default(true),
            "enable_pod_antiaffinity": z.boolean().optional(),
            /**
             *
             * @default true
             */
            "enable_pod_disruption_budget": z.boolean().optional().default(true),
            "enable_readiness_probe": z.boolean().optional(),
            /**
             *
             * @default true
             */
            "enable_sidecars": z.boolean().optional().default(true),
            "ignored_annotations": z.array(z.string()).optional(),
            "infrastructure_roles_secret_name": z.string().optional(),
            "infrastructure_roles_secrets": z.array(z.object({
                "secretname": z.string(),
                "userkey": z.string(),
                "passwordkey": z.string(),
                "rolekey": z.string().optional(),
                "defaultuservalue": z.string().optional(),
                "defaultrolevalue": z.string().optional(),
                "details": z.string().optional(),
                "template": z.boolean().optional()
            })).optional(),
            "inherited_annotations": z.array(z.string()).optional(),
            "inherited_labels": z.array(z.string()).optional(),
            /**
             *
             * @default "20m"
             */
            "master_pod_move_timeout": z.string().optional().default("20m"),
            "node_readiness_label": z.record(z.string()).optional(),
            "node_readiness_label_merge": z.union([z.literal("AND"), z.literal("OR")]).optional(),
            /**
             *
             * @default "postgresql-operator"
             */
            "oauth_token_secret_name": z.string().optional().default("postgresql-operator"),
            /**
             *
             * @default "postgres-{cluster}-pdb"
             */
            "pdb_name_format": z.string().optional().default("postgres-{cluster}-pdb"),
            "persistent_volume_claim_retention_policy": z.object({
                "when_deleted": z.union([z.literal("delete"), z.literal("retain")]).optional(),
                "when_scaled": z.union([z.literal("delete"), z.literal("retain")]).optional()
            }).optional(),
            "pod_antiaffinity_preferred_during_scheduling": z.boolean().optional(),
            /**
             *
             * @default "kubernetes.io/hostname"
             */
            "pod_antiaffinity_topology_key": z.string().optional().default("kubernetes.io/hostname"),
            "pod_environment_configmap": z.string().optional(),
            "pod_environment_secret": z.string().optional(),
            /**
             *
             * @default "ordered_ready"
             */
            "pod_management_policy": z.union([z.literal("ordered_ready"), z.literal("parallel")]).optional().default("ordered_ready"),
            "pod_priority_class_name": z.string().optional(),
            /**
             *
             * @default "spilo-role"
             */
            "pod_role_label": z.string().optional().default("spilo-role"),
            "pod_service_account_definition": z.string().optional(),
            /**
             *
             * @default "postgres-pod"
             */
            "pod_service_account_name": z.string().optional().default("postgres-pod"),
            "pod_service_account_role_binding_definition": z.string().optional(),
            /**
             *
             * @default "5m"
             */
            "pod_terminate_grace_period": z.string().optional().default("5m"),
            /**
             *
             * @default "{username}.{cluster}.credentials.{tprkind}.{tprgroup}"
             */
            "secret_name_template": z.string().optional().default("{username}.{cluster}.credentials.{tprkind}.{tprgroup}"),
            "share_pgsocket_with_sidecars": z.boolean().optional(),
            /**
             *
             * @default true
             */
            "spilo_allow_privilege_escalation": z.boolean().optional().default(true),
            "spilo_runasuser": z.number().optional(),
            "spilo_runasgroup": z.number().optional(),
            "spilo_fsgroup": z.number().optional(),
            "spilo_privileged": z.boolean().optional(),
            /**
             *
             * @default "pvc"
             */
            "storage_resize_mode": z.union([z.literal("ebs"), z.literal("mixed"), z.literal("pvc"), z.literal("off")]).optional().default("pvc"),
            "toleration": z.record(z.string()).optional(),
            "watched_namespace": z.string().optional()
        }).optional(),
        "postgres_pod_resources": z.object({
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "default_cpu_limit": z.string().regex(/^(\d+m|\d+(\.\d{1,3})?)$/).optional(),
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "default_cpu_request": z.string().regex(/^(\d+m|\d+(\.\d{1,3})?)$/).optional(),
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "default_memory_limit": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/).optional(),
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "default_memory_request": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/).optional(),
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "max_cpu_request": z.string().regex(/^(\d+m|\d+(\.\d{1,3})?)$/).optional(),
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "max_memory_request": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/).optional(),
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "min_cpu_limit": z.string().regex(/^(\d+m|\d+(\.\d{1,3})?)$/).optional(),
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "min_memory_limit": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/).optional()
        }).optional(),
        "timeouts": z.object({
            /**
             *
             * @default "1s"
             */
            "patroni_api_check_interval": z.string().optional().default("1s"),
            /**
             *
             * @default "5s"
             */
            "patroni_api_check_timeout": z.string().optional().default("5s"),
            /**
             *
             * @default "10m"
             */
            "pod_label_wait_timeout": z.string().optional().default("10m"),
            /**
             *
             * @default "10m"
             */
            "pod_deletion_wait_timeout": z.string().optional().default("10m"),
            /**
             *
             * @default "4s"
             */
            "ready_wait_interval": z.string().optional().default("4s"),
            /**
             *
             * @default "30s"
             */
            "ready_wait_timeout": z.string().optional().default("30s"),
            /**
             *
             * @default "3s"
             */
            "resource_check_interval": z.string().optional().default("3s"),
            /**
             *
             * @default "10m"
             */
            "resource_check_timeout": z.string().optional().default("10m")
        }).optional(),
        "load_balancer": z.object({
            "custom_service_annotations": z.record(z.string()).optional(),
            /**
             *
             * @default "db.example.com"
             */
            "db_hosted_zone": z.string().optional().default("db.example.com"),
            /**
             *
             * @default true
             */
            "enable_master_load_balancer": z.boolean().optional().default(true),
            "enable_master_pooler_load_balancer": z.boolean().optional(),
            "enable_replica_load_balancer": z.boolean().optional(),
            "enable_replica_pooler_load_balancer": z.boolean().optional(),
            /**
             *
             * @default "Cluster"
             */
            "external_traffic_policy": z.union([z.literal("Cluster"), z.literal("Local")]).optional().default("Cluster"),
            /**
             *
             * @default "{cluster}.{namespace}.{hostedzone}"
             */
            "master_dns_name_format": z.string().optional().default("{cluster}.{namespace}.{hostedzone}"),
            /**
             *
             * @default "{cluster}.{team}.{hostedzone}"
             */
            "master_legacy_dns_name_format": z.string().optional().default("{cluster}.{team}.{hostedzone}"),
            /**
             *
             * @default "{cluster}-repl.{namespace}.{hostedzone}"
             */
            "replica_dns_name_format": z.string().optional().default("{cluster}-repl.{namespace}.{hostedzone}"),
            /**
             *
             * @default "{cluster}-repl.{team}.{hostedzone}"
             */
            "replica_legacy_dns_name_format": z.string().optional().default("{cluster}-repl.{team}.{hostedzone}")
        }).optional(),
        "aws_or_gcp": z.object({
            "additional_secret_mount": z.string().optional(),
            /**
             *
             * @default "/meta/credentials"
             */
            "additional_secret_mount_path": z.string().optional().default("/meta/credentials"),
            /**
             *
             * @default "eu-central-1"
             */
            "aws_region": z.string().optional().default("eu-central-1"),
            "enable_ebs_gp3_migration": z.boolean().optional(),
            /**
             *
             * @default 1000
             */
            "enable_ebs_gp3_migration_max_size": z.number().optional().default(1000),
            "gcp_credentials": z.string().optional(),
            "kube_iam_role": z.string().optional(),
            "log_s3_bucket": z.string().optional(),
            "wal_az_storage_account": z.string().optional(),
            "wal_gs_bucket": z.string().optional(),
            "wal_s3_bucket": z.string().optional()
        }).optional(),
        "logical_backup": z.object({
            "logical_backup_azure_storage_account_name": z.string().optional(),
            "logical_backup_azure_storage_container": z.string().optional(),
            "logical_backup_azure_storage_account_key": z.string().optional(),
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "logical_backup_cpu_limit": z.string().regex(/^(\d+m|\d+(\.\d{1,3})?)$/).optional(),
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "logical_backup_cpu_request": z.string().regex(/^(\d+m|\d+(\.\d{1,3})?)$/).optional(),
            /**
             *
             * @default "registry.opensource.zalan.do/acid/logical-backup:v1.11.0"
             */
            "logical_backup_docker_image": z.string().optional().default("registry.opensource.zalan.do/acid/logical-backup:v1.11.0"),
            "logical_backup_google_application_credentials": z.string().optional(),
            /**
             *
             * @default "logical-backup-"
             */
            "logical_backup_job_prefix": z.string().optional().default("logical-backup-"),
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "logical_backup_memory_limit": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/).optional(),
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "logical_backup_memory_request": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/).optional(),
            /**
             *
             * @default "s3"
             */
            "logical_backup_provider": z.union([z.literal("az"), z.literal("gcs"), z.literal("s3")]).optional().default("s3"),
            "logical_backup_s3_access_key_id": z.string().optional(),
            "logical_backup_s3_bucket": z.string().optional(),
            "logical_backup_s3_endpoint": z.string().optional(),
            "logical_backup_s3_region": z.string().optional(),
            "logical_backup_s3_secret_access_key": z.string().optional(),
            "logical_backup_s3_sse": z.string().optional(),
            "logical_backup_s3_retention_time": z.string().optional(),
            /**
             *
             * @default "30 00 * * *"
             * @pattern ^(\d+|\*)(\/\d+)?(\s+(\d+|\*)(\/\d+)?){4}$
             */
            "logical_backup_schedule": z.string().regex(/^(\d+|\*)(\/\d+)?(\s+(\d+|\*)(\/\d+)?){4}$/).optional().default("30 00 * * *"),
            "logical_backup_cronjob_environment_secret": z.string().optional()
        }).optional(),
        "debug": z.object({
            /**
             *
             * @default true
             */
            "debug_logging": z.boolean().optional().default(true),
            /**
             *
             * @default true
             */
            "enable_database_access": z.boolean().optional().default(true)
        }).optional(),
        "teams_api": z.object({
            /**
             *
             * @default true
             */
            "enable_admin_role_for_users": z.boolean().optional().default(true),
            /**
             *
             * @default true
             */
            "enable_postgres_team_crd": z.boolean().optional().default(true),
            "enable_postgres_team_crd_superusers": z.boolean().optional(),
            "enable_team_member_deprecation": z.boolean().optional(),
            "enable_team_superuser": z.boolean().optional(),
            /**
             *
             * @default true
             */
            "enable_teams_api": z.boolean().optional().default(true),
            /**
             *
             * @default "https://info.example.com/oauth2/tokeninfo?access_token= uid realm=/employees"
             */
            "pam_configuration": z.string().optional().default("https://info.example.com/oauth2/tokeninfo?access_token= uid realm=/employees"),
            /**
             *
             * @default "zalandos"
             */
            "pam_role_name": z.string().optional().default("zalandos"),
            "postgres_superuser_teams": z.array(z.string()).optional(),
            "protected_role_names": z.array(z.string()).optional(),
            /**
             *
             * @default "_deleted"
             */
            "role_deletion_suffix": z.string().optional().default("_deleted"),
            /**
             *
             * @default "admin"
             */
            "team_admin_role": z.string().optional().default("admin"),
            "team_api_role_configuration": z.record(z.string()).optional(),
            /**
             *
             * @default "https://teams.example.com/api/"
             */
            "teams_api_url": z.string().optional().default("https://teams.example.com/api/")
        }).optional(),
        "logging_rest_api": z.object({
            /**
             *
             * @default 8080
             */
            "api_port": z.number().optional().default(8080),
            /**
             *
             * @default 1000
             */
            "cluster_history_entries": z.number().optional().default(1000),
            /**
             *
             * @default 100
             */
            "ring_log_lines": z.number().optional().default(100)
        }).optional(),
        "scalyr": z.object({
            "scalyr_api_key": z.string().optional(),
            /**
             *
             * @default "1"
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "scalyr_cpu_limit": z.string().regex(/^(\d+m|\d+(\.\d{1,3})?)$/).optional().default("1"),
            /**
             *
             * @default "100m"
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "scalyr_cpu_request": z.string().regex(/^(\d+m|\d+(\.\d{1,3})?)$/).optional().default("100m"),
            "scalyr_image": z.string().optional(),
            /**
             *
             * @default "500Mi"
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "scalyr_memory_limit": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/).optional().default("500Mi"),
            /**
             *
             * @default "50Mi"
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "scalyr_memory_request": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/).optional().default("50Mi"),
            /**
             *
             * @default "https://upload.eu.scalyr.com"
             */
            "scalyr_server_url": z.string().optional().default("https://upload.eu.scalyr.com")
        }).optional(),
        "connection_pooler": z.object({
            /**
             *
             * @default "pooler"
             */
            "connection_pooler_schema": z.string().optional().default("pooler"),
            /**
             *
             * @default "pooler"
             */
            "connection_pooler_user": z.string().optional().default("pooler"),
            /**
             *
             * @default "registry.opensource.zalan.do/acid/pgbouncer:master-32"
             */
            "connection_pooler_image": z.string().optional().default("registry.opensource.zalan.do/acid/pgbouncer:master-32"),
            /**
             *
             * @default 60
             */
            "connection_pooler_max_db_connections": z.number().optional().default(60),
            /**
             *
             * @default "transaction"
             */
            "connection_pooler_mode": z.union([z.literal("session"), z.literal("transaction")]).optional().default("transaction"),
            /**
             *
             * @default 2
             * @minimum 1
             */
            "connection_pooler_number_of_instances": z.number().min(1).optional().default(2),
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "connection_pooler_default_cpu_limit": z.string().regex(/^(\d+m|\d+(\.\d{1,3})?)$/).optional(),
            /**
             *
             * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
             */
            "connection_pooler_default_cpu_request": z.string().regex(/^(\d+m|\d+(\.\d{1,3})?)$/).optional(),
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "connection_pooler_default_memory_limit": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/).optional(),
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "connection_pooler_default_memory_request": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/).optional()
        }).optional(),
        "patroni": z.object({
            "enable_patroni_failsafe_mode": z.boolean().optional()
        }).optional()
    }),
    "status": z.record(z.string()).optional(),
    "metadata": iObjectMetaSchema.optional()
});
