import { z } from "zod";
export declare const IpostgresqlSchema: z.ZodObject<{
    kind: z.ZodLiteral<"postgresql">;
    apiVersion: z.ZodLiteral<"acid.zalan.do/v1">;
    spec: z.ZodObject<{
        additionalVolumes: z.ZodOptional<z.ZodArray<z.ZodObject<{
            name: z.ZodString;
            mountPath: z.ZodString;
            targetContainers: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            volumeSource: z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>;
            subPath: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            name: string;
            mountPath: string;
            volumeSource: {};
            targetContainers?: string[] | undefined;
            subPath?: string | undefined;
        }, {
            name: string;
            mountPath: string;
            volumeSource: {};
            targetContainers?: string[] | undefined;
            subPath?: string | undefined;
        }>, "many">>;
        allowedSourceRanges: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        clone: z.ZodOptional<z.ZodObject<{
            cluster: z.ZodString;
            s3_endpoint: z.ZodOptional<z.ZodString>;
            s3_access_key_id: z.ZodOptional<z.ZodString>;
            s3_secret_access_key: z.ZodOptional<z.ZodString>;
            s3_force_path_style: z.ZodOptional<z.ZodBoolean>;
            s3_wal_path: z.ZodOptional<z.ZodString>;
            /**
             *
             * @pattern ^([0-9]+)-(0[1-9]|1[012])-(0[1-9]|[12][0-9]|3[01])[Tt]([01][0-9]|2[0-3]):([0-5][0-9]):([0-5][0-9]|60)(\.[0-9]+)?(([+-]([01][0-9]|2[0-3]):[0-5][0-9]))$
             */
            timestamp: z.ZodOptional<z.ZodString>;
            /**
             *
             * @format uuid
             */
            uid: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            cluster: string;
            s3_wal_path?: string | undefined;
            s3_endpoint?: string | undefined;
            s3_access_key_id?: string | undefined;
            s3_secret_access_key?: string | undefined;
            s3_force_path_style?: boolean | undefined;
            timestamp?: string | undefined;
            uid?: string | undefined;
        }, {
            cluster: string;
            s3_wal_path?: string | undefined;
            s3_endpoint?: string | undefined;
            s3_access_key_id?: string | undefined;
            s3_secret_access_key?: string | undefined;
            s3_force_path_style?: boolean | undefined;
            timestamp?: string | undefined;
            uid?: string | undefined;
        }>>;
        connectionPooler: z.ZodOptional<z.ZodObject<{
            dockerImage: z.ZodOptional<z.ZodString>;
            maxDBConnections: z.ZodOptional<z.ZodNumber>;
            mode: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"session">, z.ZodLiteral<"transaction">]>>;
            /**
             *
             * @minimum 1
             */
            numberOfInstances: z.ZodOptional<z.ZodNumber>;
            resources: z.ZodOptional<z.ZodObject<{
                limits: z.ZodOptional<z.ZodObject<{
                    /**
                     *
                     * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
                     */
                    cpu: z.ZodOptional<z.ZodString>;
                    /**
                     *
                     * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
                     */
                    memory: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                }, {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                }>>;
                requests: z.ZodOptional<z.ZodObject<{
                    /**
                     *
                     * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
                     */
                    cpu: z.ZodOptional<z.ZodString>;
                    /**
                     *
                     * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
                     */
                    memory: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                }, {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                requests?: {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                } | undefined;
                limits?: {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                } | undefined;
            }, {
                requests?: {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                } | undefined;
                limits?: {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                } | undefined;
            }>>;
            schema: z.ZodOptional<z.ZodString>;
            user: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            resources?: {
                requests?: {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                } | undefined;
                limits?: {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                } | undefined;
            } | undefined;
            numberOfInstances?: number | undefined;
            dockerImage?: string | undefined;
            maxDBConnections?: number | undefined;
            mode?: "session" | "transaction" | undefined;
            schema?: string | undefined;
            user?: string | undefined;
        }, {
            resources?: {
                requests?: {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                } | undefined;
                limits?: {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                } | undefined;
            } | undefined;
            numberOfInstances?: number | undefined;
            dockerImage?: string | undefined;
            maxDBConnections?: number | undefined;
            mode?: "session" | "transaction" | undefined;
            schema?: string | undefined;
            user?: string | undefined;
        }>>;
        databases: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        dockerImage: z.ZodOptional<z.ZodString>;
        enableConnectionPooler: z.ZodOptional<z.ZodBoolean>;
        enableReplicaConnectionPooler: z.ZodOptional<z.ZodBoolean>;
        enableLogicalBackup: z.ZodOptional<z.ZodBoolean>;
        enableMasterLoadBalancer: z.ZodOptional<z.ZodBoolean>;
        enableMasterPoolerLoadBalancer: z.ZodOptional<z.ZodBoolean>;
        enableReplicaLoadBalancer: z.ZodOptional<z.ZodBoolean>;
        enableReplicaPoolerLoadBalancer: z.ZodOptional<z.ZodBoolean>;
        enableShmVolume: z.ZodOptional<z.ZodBoolean>;
        env: z.ZodOptional<z.ZodArray<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>, "many">>;
        /**
         * deprecated
         */
        init_containers: z.ZodOptional<z.ZodArray<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>, "many">>;
        initContainers: z.ZodOptional<z.ZodArray<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>, "many">>;
        /**
         *
         * @pattern ^(\d+|\*)(\/\d+)?(\s+(\d+|\*)(\/\d+)?){4}$
         */
        logicalBackupSchedule: z.ZodOptional<z.ZodString>;
        maintenanceWindows: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        masterServiceAnnotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        nodeAffinity: z.ZodOptional<z.ZodObject<{
            preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                preference: z.ZodObject<{
                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        key: z.ZodString;
                        operator: z.ZodString;
                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }, {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }>, "many">>;
                    matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        key: z.ZodString;
                        operator: z.ZodString;
                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }, {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }>, "many">>;
                }, "strip", z.ZodTypeAny, {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                }, {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                }>;
                /**
                 *
                 * @format int32
                 */
                weight: z.ZodNumber;
            }, "strip", z.ZodTypeAny, {
                preference: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                };
                weight: number;
            }, {
                preference: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                };
                weight: number;
            }>, "many">>;
            requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodObject<{
                nodeSelectorTerms: z.ZodArray<z.ZodObject<{
                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        key: z.ZodString;
                        operator: z.ZodString;
                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }, {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }>, "many">>;
                    matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        key: z.ZodString;
                        operator: z.ZodString;
                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }, {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }>, "many">>;
                }, "strip", z.ZodTypeAny, {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                }, {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                }>, "many">;
            }, "strip", z.ZodTypeAny, {
                nodeSelectorTerms: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                }[];
            }, {
                nodeSelectorTerms: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                }[];
            }>>;
        }, "strip", z.ZodTypeAny, {
            preferredDuringSchedulingIgnoredDuringExecution?: {
                preference: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                };
                weight: number;
            }[] | undefined;
            requiredDuringSchedulingIgnoredDuringExecution?: {
                nodeSelectorTerms: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                }[];
            } | undefined;
        }, {
            preferredDuringSchedulingIgnoredDuringExecution?: {
                preference: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                };
                weight: number;
            }[] | undefined;
            requiredDuringSchedulingIgnoredDuringExecution?: {
                nodeSelectorTerms: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                }[];
            } | undefined;
        }>>;
        numberOfInstances: z.ZodNumber;
        patroni: z.ZodOptional<z.ZodObject<{
            failsafe_mode: z.ZodOptional<z.ZodBoolean>;
            initdb: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
            loop_wait: z.ZodOptional<z.ZodNumber>;
            maximum_lag_on_failover: z.ZodOptional<z.ZodNumber>;
            pg_hba: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            retry_timeout: z.ZodOptional<z.ZodNumber>;
            slots: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodRecord<z.ZodString, z.ZodString>>>;
            synchronous_mode: z.ZodOptional<z.ZodBoolean>;
            synchronous_mode_strict: z.ZodOptional<z.ZodBoolean>;
            synchronous_node_count: z.ZodOptional<z.ZodNumber>;
            ttl: z.ZodOptional<z.ZodNumber>;
        }, "strip", z.ZodTypeAny, {
            failsafe_mode?: boolean | undefined;
            initdb?: Record<string, string> | undefined;
            loop_wait?: number | undefined;
            maximum_lag_on_failover?: number | undefined;
            pg_hba?: string[] | undefined;
            retry_timeout?: number | undefined;
            slots?: Record<string, Record<string, string>> | undefined;
            synchronous_mode?: boolean | undefined;
            synchronous_mode_strict?: boolean | undefined;
            synchronous_node_count?: number | undefined;
            ttl?: number | undefined;
        }, {
            failsafe_mode?: boolean | undefined;
            initdb?: Record<string, string> | undefined;
            loop_wait?: number | undefined;
            maximum_lag_on_failover?: number | undefined;
            pg_hba?: string[] | undefined;
            retry_timeout?: number | undefined;
            slots?: Record<string, Record<string, string>> | undefined;
            synchronous_mode?: boolean | undefined;
            synchronous_mode_strict?: boolean | undefined;
            synchronous_node_count?: number | undefined;
            ttl?: number | undefined;
        }>>;
        podAnnotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        /**
         * deprecated
         */
        pod_priority_class_name: z.ZodOptional<z.ZodString>;
        podPriorityClassName: z.ZodOptional<z.ZodString>;
        postgresql: z.ZodObject<{
            version: z.ZodUnion<[z.ZodLiteral<"11">, z.ZodLiteral<"12">, z.ZodLiteral<"13">, z.ZodLiteral<"14">, z.ZodLiteral<"15">, z.ZodLiteral<"16">]>;
            parameters: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            version: "11" | "12" | "13" | "14" | "15" | "16";
            parameters?: Record<string, string> | undefined;
        }, {
            version: "11" | "12" | "13" | "14" | "15" | "16";
            parameters?: Record<string, string> | undefined;
        }>;
        preparedDatabases: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
            defaultUsers: z.ZodOptional<z.ZodBoolean>;
            extensions: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
            schemas: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodObject<{
                defaultUsers: z.ZodOptional<z.ZodBoolean>;
                defaultRoles: z.ZodOptional<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                defaultUsers?: boolean | undefined;
                defaultRoles?: boolean | undefined;
            }, {
                defaultUsers?: boolean | undefined;
                defaultRoles?: boolean | undefined;
            }>>>;
            secretNamespace: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            defaultUsers?: boolean | undefined;
            extensions?: Record<string, string> | undefined;
            schemas?: Record<string, {
                defaultUsers?: boolean | undefined;
                defaultRoles?: boolean | undefined;
            }> | undefined;
            secretNamespace?: string | undefined;
        }, {
            defaultUsers?: boolean | undefined;
            extensions?: Record<string, string> | undefined;
            schemas?: Record<string, {
                defaultUsers?: boolean | undefined;
                defaultRoles?: boolean | undefined;
            }> | undefined;
            secretNamespace?: string | undefined;
        }>>>;
        /**
         * deprecated
         */
        replicaLoadBalancer: z.ZodOptional<z.ZodBoolean>;
        replicaServiceAnnotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        resources: z.ZodOptional<z.ZodObject<{
            limits: z.ZodOptional<z.ZodObject<{
                /**
                 *
                 * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
                 */
                cpu: z.ZodOptional<z.ZodString>;
                /**
                 *
                 * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
                 */
                memory: z.ZodOptional<z.ZodString>;
                /**
                 *
                 * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
                 */
                "hugepages-2Mi": z.ZodOptional<z.ZodString>;
                /**
                 *
                 * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
                 */
                "hugepages-1Gi": z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                cpu?: string | undefined;
                memory?: string | undefined;
                "hugepages-2Mi"?: string | undefined;
                "hugepages-1Gi"?: string | undefined;
            }, {
                cpu?: string | undefined;
                memory?: string | undefined;
                "hugepages-2Mi"?: string | undefined;
                "hugepages-1Gi"?: string | undefined;
            }>>;
            requests: z.ZodOptional<z.ZodObject<{
                /**
                 *
                 * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
                 */
                cpu: z.ZodOptional<z.ZodString>;
                /**
                 *
                 * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
                 */
                memory: z.ZodOptional<z.ZodString>;
                /**
                 *
                 * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
                 */
                "hugepages-2Mi": z.ZodOptional<z.ZodString>;
                /**
                 *
                 * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
                 */
                "hugepages-1Gi": z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                cpu?: string | undefined;
                memory?: string | undefined;
                "hugepages-2Mi"?: string | undefined;
                "hugepages-1Gi"?: string | undefined;
            }, {
                cpu?: string | undefined;
                memory?: string | undefined;
                "hugepages-2Mi"?: string | undefined;
                "hugepages-1Gi"?: string | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            requests?: {
                cpu?: string | undefined;
                memory?: string | undefined;
                "hugepages-2Mi"?: string | undefined;
                "hugepages-1Gi"?: string | undefined;
            } | undefined;
            limits?: {
                cpu?: string | undefined;
                memory?: string | undefined;
                "hugepages-2Mi"?: string | undefined;
                "hugepages-1Gi"?: string | undefined;
            } | undefined;
        }, {
            requests?: {
                cpu?: string | undefined;
                memory?: string | undefined;
                "hugepages-2Mi"?: string | undefined;
                "hugepages-1Gi"?: string | undefined;
            } | undefined;
            limits?: {
                cpu?: string | undefined;
                memory?: string | undefined;
                "hugepages-2Mi"?: string | undefined;
                "hugepages-1Gi"?: string | undefined;
            } | undefined;
        }>>;
        schedulerName: z.ZodOptional<z.ZodString>;
        serviceAnnotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        sidecars: z.ZodOptional<z.ZodArray<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>, "many">>;
        spiloRunAsUser: z.ZodOptional<z.ZodNumber>;
        spiloRunAsGroup: z.ZodOptional<z.ZodNumber>;
        spiloFSGroup: z.ZodOptional<z.ZodNumber>;
        standby: z.ZodOptional<z.ZodIntersection<z.ZodObject<{
            s3_wal_path: z.ZodOptional<z.ZodString>;
            gs_wal_path: z.ZodOptional<z.ZodString>;
            standby_host: z.ZodOptional<z.ZodString>;
            standby_port: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            s3_wal_path?: string | undefined;
            gs_wal_path?: string | undefined;
            standby_host?: string | undefined;
            standby_port?: string | undefined;
        }, {
            s3_wal_path?: string | undefined;
            gs_wal_path?: string | undefined;
            standby_host?: string | undefined;
            standby_port?: string | undefined;
        }>, z.ZodUnion<[z.ZodObject<{
            s3_wal_path: z.ZodString;
            gs_wal_path: z.ZodOptional<z.ZodString>;
            standby_host: z.ZodOptional<z.ZodString>;
            standby_port: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            s3_wal_path: string;
            gs_wal_path?: string | undefined;
            standby_host?: string | undefined;
            standby_port?: string | undefined;
        }, {
            s3_wal_path: string;
            gs_wal_path?: string | undefined;
            standby_host?: string | undefined;
            standby_port?: string | undefined;
        }>, z.ZodObject<{
            s3_wal_path: z.ZodOptional<z.ZodString>;
            gs_wal_path: z.ZodString;
            standby_host: z.ZodOptional<z.ZodString>;
            standby_port: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            gs_wal_path: string;
            s3_wal_path?: string | undefined;
            standby_host?: string | undefined;
            standby_port?: string | undefined;
        }, {
            gs_wal_path: string;
            s3_wal_path?: string | undefined;
            standby_host?: string | undefined;
            standby_port?: string | undefined;
        }>, z.ZodObject<{
            s3_wal_path: z.ZodOptional<z.ZodString>;
            gs_wal_path: z.ZodOptional<z.ZodString>;
            standby_host: z.ZodString;
            standby_port: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            standby_host: string;
            s3_wal_path?: string | undefined;
            gs_wal_path?: string | undefined;
            standby_port?: string | undefined;
        }, {
            standby_host: string;
            s3_wal_path?: string | undefined;
            gs_wal_path?: string | undefined;
            standby_port?: string | undefined;
        }>]>>>;
        streams: z.ZodOptional<z.ZodArray<z.ZodObject<{
            applicationId: z.ZodString;
            batchSize: z.ZodOptional<z.ZodNumber>;
            database: z.ZodString;
            enableRecovery: z.ZodOptional<z.ZodBoolean>;
            filter: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
            tables: z.ZodRecord<z.ZodString, z.ZodObject<{
                eventType: z.ZodString;
                idColumn: z.ZodOptional<z.ZodString>;
                payloadColumn: z.ZodOptional<z.ZodString>;
                recoveryEventType: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                eventType: string;
                idColumn?: string | undefined;
                payloadColumn?: string | undefined;
                recoveryEventType?: string | undefined;
            }, {
                eventType: string;
                idColumn?: string | undefined;
                payloadColumn?: string | undefined;
                recoveryEventType?: string | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            applicationId: string;
            database: string;
            tables: Record<string, {
                eventType: string;
                idColumn?: string | undefined;
                payloadColumn?: string | undefined;
                recoveryEventType?: string | undefined;
            }>;
            filter?: Record<string, string> | undefined;
            batchSize?: number | undefined;
            enableRecovery?: boolean | undefined;
        }, {
            applicationId: string;
            database: string;
            tables: Record<string, {
                eventType: string;
                idColumn?: string | undefined;
                payloadColumn?: string | undefined;
                recoveryEventType?: string | undefined;
            }>;
            filter?: Record<string, string> | undefined;
            batchSize?: number | undefined;
            enableRecovery?: boolean | undefined;
        }>, "many">>;
        teamId: z.ZodString;
        tls: z.ZodOptional<z.ZodObject<{
            secretName: z.ZodString;
            certificateFile: z.ZodOptional<z.ZodString>;
            privateKeyFile: z.ZodOptional<z.ZodString>;
            caFile: z.ZodOptional<z.ZodString>;
            caSecretName: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            secretName: string;
            certificateFile?: string | undefined;
            privateKeyFile?: string | undefined;
            caFile?: string | undefined;
            caSecretName?: string | undefined;
        }, {
            secretName: string;
            certificateFile?: string | undefined;
            privateKeyFile?: string | undefined;
            caFile?: string | undefined;
            caSecretName?: string | undefined;
        }>>;
        tolerations: z.ZodOptional<z.ZodArray<z.ZodObject<{
            key: z.ZodOptional<z.ZodString>;
            operator: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"Equal">, z.ZodLiteral<"Exists">]>>;
            value: z.ZodOptional<z.ZodString>;
            effect: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"NoExecute">, z.ZodLiteral<"NoSchedule">, z.ZodLiteral<"PreferNoSchedule">]>>;
            tolerationSeconds: z.ZodOptional<z.ZodNumber>;
        }, "strip", z.ZodTypeAny, {
            key?: string | undefined;
            operator?: "Equal" | "Exists" | undefined;
            value?: string | undefined;
            effect?: "NoExecute" | "NoSchedule" | "PreferNoSchedule" | undefined;
            tolerationSeconds?: number | undefined;
        }, {
            key?: string | undefined;
            operator?: "Equal" | "Exists" | undefined;
            value?: string | undefined;
            effect?: "NoExecute" | "NoSchedule" | "PreferNoSchedule" | undefined;
            tolerationSeconds?: number | undefined;
        }>, "many">>;
        /**
         * deprecated
         */
        useLoadBalancer: z.ZodOptional<z.ZodBoolean>;
        users: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodArray<z.ZodUnion<[z.ZodLiteral<"bypassrls">, z.ZodLiteral<"BYPASSRLS">, z.ZodLiteral<"nobypassrls">, z.ZodLiteral<"NOBYPASSRLS">, z.ZodLiteral<"createdb">, z.ZodLiteral<"CREATEDB">, z.ZodLiteral<"nocreatedb">, z.ZodLiteral<"NOCREATEDB">, z.ZodLiteral<"createrole">, z.ZodLiteral<"CREATEROLE">, z.ZodLiteral<"nocreaterole">, z.ZodLiteral<"NOCREATEROLE">, z.ZodLiteral<"inherit">, z.ZodLiteral<"INHERIT">, z.ZodLiteral<"noinherit">, z.ZodLiteral<"NOINHERIT">, z.ZodLiteral<"login">, z.ZodLiteral<"LOGIN">, z.ZodLiteral<"nologin">, z.ZodLiteral<"NOLOGIN">, z.ZodLiteral<"replication">, z.ZodLiteral<"REPLICATION">, z.ZodLiteral<"noreplication">, z.ZodLiteral<"NOREPLICATION">, z.ZodLiteral<"superuser">, z.ZodLiteral<"SUPERUSER">, z.ZodLiteral<"nosuperuser">, z.ZodLiteral<"NOSUPERUSER">]>, "many">>>;
        usersIgnoringSecretRotation: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        usersWithInPlaceSecretRotation: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        usersWithSecretRotation: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        volume: z.ZodObject<{
            iops: z.ZodOptional<z.ZodNumber>;
            selector: z.ZodOptional<z.ZodObject<{
                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    key: z.ZodString;
                    operator: z.ZodUnion<[z.ZodLiteral<"DoesNotExist">, z.ZodLiteral<"Exists">, z.ZodLiteral<"In">, z.ZodLiteral<"NotIn">]>;
                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                }, "strip", z.ZodTypeAny, {
                    key: string;
                    operator: "Exists" | "DoesNotExist" | "In" | "NotIn";
                    values?: string[] | undefined;
                }, {
                    key: string;
                    operator: "Exists" | "DoesNotExist" | "In" | "NotIn";
                    values?: string[] | undefined;
                }>, "many">>;
                matchLabels: z.ZodOptional<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
            }, "strip", z.ZodTypeAny, {
                matchExpressions?: {
                    key: string;
                    operator: "Exists" | "DoesNotExist" | "In" | "NotIn";
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: {} | undefined;
            }, {
                matchExpressions?: {
                    key: string;
                    operator: "Exists" | "DoesNotExist" | "In" | "NotIn";
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: {} | undefined;
            }>>;
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            size: z.ZodString;
            storageClass: z.ZodOptional<z.ZodString>;
            subPath: z.ZodOptional<z.ZodString>;
            throughput: z.ZodOptional<z.ZodNumber>;
        }, "strip", z.ZodTypeAny, {
            size: string;
            subPath?: string | undefined;
            iops?: number | undefined;
            selector?: {
                matchExpressions?: {
                    key: string;
                    operator: "Exists" | "DoesNotExist" | "In" | "NotIn";
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: {} | undefined;
            } | undefined;
            storageClass?: string | undefined;
            throughput?: number | undefined;
        }, {
            size: string;
            subPath?: string | undefined;
            iops?: number | undefined;
            selector?: {
                matchExpressions?: {
                    key: string;
                    operator: "Exists" | "DoesNotExist" | "In" | "NotIn";
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: {} | undefined;
            } | undefined;
            storageClass?: string | undefined;
            throughput?: number | undefined;
        }>;
    }, "strip", z.ZodTypeAny, {
        postgresql: {
            version: "11" | "12" | "13" | "14" | "15" | "16";
            parameters?: Record<string, string> | undefined;
        };
        numberOfInstances: number;
        teamId: string;
        volume: {
            size: string;
            subPath?: string | undefined;
            iops?: number | undefined;
            selector?: {
                matchExpressions?: {
                    key: string;
                    operator: "Exists" | "DoesNotExist" | "In" | "NotIn";
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: {} | undefined;
            } | undefined;
            storageClass?: string | undefined;
            throughput?: number | undefined;
        };
        resources?: {
            requests?: {
                cpu?: string | undefined;
                memory?: string | undefined;
                "hugepages-2Mi"?: string | undefined;
                "hugepages-1Gi"?: string | undefined;
            } | undefined;
            limits?: {
                cpu?: string | undefined;
                memory?: string | undefined;
                "hugepages-2Mi"?: string | undefined;
                "hugepages-1Gi"?: string | undefined;
            } | undefined;
        } | undefined;
        standby?: ({
            s3_wal_path?: string | undefined;
            gs_wal_path?: string | undefined;
            standby_host?: string | undefined;
            standby_port?: string | undefined;
        } & ({
            s3_wal_path: string;
            gs_wal_path?: string | undefined;
            standby_host?: string | undefined;
            standby_port?: string | undefined;
        } | {
            gs_wal_path: string;
            s3_wal_path?: string | undefined;
            standby_host?: string | undefined;
            standby_port?: string | undefined;
        } | {
            standby_host: string;
            s3_wal_path?: string | undefined;
            gs_wal_path?: string | undefined;
            standby_port?: string | undefined;
        })) | undefined;
        sidecars?: {}[] | undefined;
        users?: Record<string, ("bypassrls" | "BYPASSRLS" | "nobypassrls" | "NOBYPASSRLS" | "createdb" | "CREATEDB" | "nocreatedb" | "NOCREATEDB" | "createrole" | "CREATEROLE" | "nocreaterole" | "NOCREATEROLE" | "inherit" | "INHERIT" | "noinherit" | "NOINHERIT" | "login" | "LOGIN" | "nologin" | "NOLOGIN" | "replication" | "REPLICATION" | "noreplication" | "NOREPLICATION" | "superuser" | "SUPERUSER" | "nosuperuser" | "NOSUPERUSER")[]> | undefined;
        pod_priority_class_name?: string | undefined;
        patroni?: {
            failsafe_mode?: boolean | undefined;
            initdb?: Record<string, string> | undefined;
            loop_wait?: number | undefined;
            maximum_lag_on_failover?: number | undefined;
            pg_hba?: string[] | undefined;
            retry_timeout?: number | undefined;
            slots?: Record<string, Record<string, string>> | undefined;
            synchronous_mode?: boolean | undefined;
            synchronous_mode_strict?: boolean | undefined;
            synchronous_node_count?: number | undefined;
            ttl?: number | undefined;
        } | undefined;
        additionalVolumes?: {
            name: string;
            mountPath: string;
            volumeSource: {};
            targetContainers?: string[] | undefined;
            subPath?: string | undefined;
        }[] | undefined;
        allowedSourceRanges?: string[] | undefined;
        clone?: {
            cluster: string;
            s3_wal_path?: string | undefined;
            s3_endpoint?: string | undefined;
            s3_access_key_id?: string | undefined;
            s3_secret_access_key?: string | undefined;
            s3_force_path_style?: boolean | undefined;
            timestamp?: string | undefined;
            uid?: string | undefined;
        } | undefined;
        dockerImage?: string | undefined;
        connectionPooler?: {
            resources?: {
                requests?: {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                } | undefined;
                limits?: {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                } | undefined;
            } | undefined;
            numberOfInstances?: number | undefined;
            dockerImage?: string | undefined;
            maxDBConnections?: number | undefined;
            mode?: "session" | "transaction" | undefined;
            schema?: string | undefined;
            user?: string | undefined;
        } | undefined;
        databases?: Record<string, string> | undefined;
        enableConnectionPooler?: boolean | undefined;
        enableReplicaConnectionPooler?: boolean | undefined;
        enableLogicalBackup?: boolean | undefined;
        enableMasterLoadBalancer?: boolean | undefined;
        enableMasterPoolerLoadBalancer?: boolean | undefined;
        enableReplicaLoadBalancer?: boolean | undefined;
        enableReplicaPoolerLoadBalancer?: boolean | undefined;
        enableShmVolume?: boolean | undefined;
        env?: {}[] | undefined;
        init_containers?: {}[] | undefined;
        initContainers?: {}[] | undefined;
        logicalBackupSchedule?: string | undefined;
        maintenanceWindows?: string[] | undefined;
        masterServiceAnnotations?: Record<string, string> | undefined;
        nodeAffinity?: {
            preferredDuringSchedulingIgnoredDuringExecution?: {
                preference: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                };
                weight: number;
            }[] | undefined;
            requiredDuringSchedulingIgnoredDuringExecution?: {
                nodeSelectorTerms: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                }[];
            } | undefined;
        } | undefined;
        podAnnotations?: Record<string, string> | undefined;
        podPriorityClassName?: string | undefined;
        preparedDatabases?: Record<string, {
            defaultUsers?: boolean | undefined;
            extensions?: Record<string, string> | undefined;
            schemas?: Record<string, {
                defaultUsers?: boolean | undefined;
                defaultRoles?: boolean | undefined;
            }> | undefined;
            secretNamespace?: string | undefined;
        }> | undefined;
        replicaLoadBalancer?: boolean | undefined;
        replicaServiceAnnotations?: Record<string, string> | undefined;
        schedulerName?: string | undefined;
        serviceAnnotations?: Record<string, string> | undefined;
        spiloRunAsUser?: number | undefined;
        spiloRunAsGroup?: number | undefined;
        spiloFSGroup?: number | undefined;
        streams?: {
            applicationId: string;
            database: string;
            tables: Record<string, {
                eventType: string;
                idColumn?: string | undefined;
                payloadColumn?: string | undefined;
                recoveryEventType?: string | undefined;
            }>;
            filter?: Record<string, string> | undefined;
            batchSize?: number | undefined;
            enableRecovery?: boolean | undefined;
        }[] | undefined;
        tls?: {
            secretName: string;
            certificateFile?: string | undefined;
            privateKeyFile?: string | undefined;
            caFile?: string | undefined;
            caSecretName?: string | undefined;
        } | undefined;
        tolerations?: {
            key?: string | undefined;
            operator?: "Equal" | "Exists" | undefined;
            value?: string | undefined;
            effect?: "NoExecute" | "NoSchedule" | "PreferNoSchedule" | undefined;
            tolerationSeconds?: number | undefined;
        }[] | undefined;
        useLoadBalancer?: boolean | undefined;
        usersIgnoringSecretRotation?: string[] | undefined;
        usersWithInPlaceSecretRotation?: string[] | undefined;
        usersWithSecretRotation?: string[] | undefined;
    }, {
        postgresql: {
            version: "11" | "12" | "13" | "14" | "15" | "16";
            parameters?: Record<string, string> | undefined;
        };
        numberOfInstances: number;
        teamId: string;
        volume: {
            size: string;
            subPath?: string | undefined;
            iops?: number | undefined;
            selector?: {
                matchExpressions?: {
                    key: string;
                    operator: "Exists" | "DoesNotExist" | "In" | "NotIn";
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: {} | undefined;
            } | undefined;
            storageClass?: string | undefined;
            throughput?: number | undefined;
        };
        resources?: {
            requests?: {
                cpu?: string | undefined;
                memory?: string | undefined;
                "hugepages-2Mi"?: string | undefined;
                "hugepages-1Gi"?: string | undefined;
            } | undefined;
            limits?: {
                cpu?: string | undefined;
                memory?: string | undefined;
                "hugepages-2Mi"?: string | undefined;
                "hugepages-1Gi"?: string | undefined;
            } | undefined;
        } | undefined;
        standby?: ({
            s3_wal_path?: string | undefined;
            gs_wal_path?: string | undefined;
            standby_host?: string | undefined;
            standby_port?: string | undefined;
        } & ({
            s3_wal_path: string;
            gs_wal_path?: string | undefined;
            standby_host?: string | undefined;
            standby_port?: string | undefined;
        } | {
            gs_wal_path: string;
            s3_wal_path?: string | undefined;
            standby_host?: string | undefined;
            standby_port?: string | undefined;
        } | {
            standby_host: string;
            s3_wal_path?: string | undefined;
            gs_wal_path?: string | undefined;
            standby_port?: string | undefined;
        })) | undefined;
        sidecars?: {}[] | undefined;
        users?: Record<string, ("bypassrls" | "BYPASSRLS" | "nobypassrls" | "NOBYPASSRLS" | "createdb" | "CREATEDB" | "nocreatedb" | "NOCREATEDB" | "createrole" | "CREATEROLE" | "nocreaterole" | "NOCREATEROLE" | "inherit" | "INHERIT" | "noinherit" | "NOINHERIT" | "login" | "LOGIN" | "nologin" | "NOLOGIN" | "replication" | "REPLICATION" | "noreplication" | "NOREPLICATION" | "superuser" | "SUPERUSER" | "nosuperuser" | "NOSUPERUSER")[]> | undefined;
        pod_priority_class_name?: string | undefined;
        patroni?: {
            failsafe_mode?: boolean | undefined;
            initdb?: Record<string, string> | undefined;
            loop_wait?: number | undefined;
            maximum_lag_on_failover?: number | undefined;
            pg_hba?: string[] | undefined;
            retry_timeout?: number | undefined;
            slots?: Record<string, Record<string, string>> | undefined;
            synchronous_mode?: boolean | undefined;
            synchronous_mode_strict?: boolean | undefined;
            synchronous_node_count?: number | undefined;
            ttl?: number | undefined;
        } | undefined;
        additionalVolumes?: {
            name: string;
            mountPath: string;
            volumeSource: {};
            targetContainers?: string[] | undefined;
            subPath?: string | undefined;
        }[] | undefined;
        allowedSourceRanges?: string[] | undefined;
        clone?: {
            cluster: string;
            s3_wal_path?: string | undefined;
            s3_endpoint?: string | undefined;
            s3_access_key_id?: string | undefined;
            s3_secret_access_key?: string | undefined;
            s3_force_path_style?: boolean | undefined;
            timestamp?: string | undefined;
            uid?: string | undefined;
        } | undefined;
        dockerImage?: string | undefined;
        connectionPooler?: {
            resources?: {
                requests?: {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                } | undefined;
                limits?: {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                } | undefined;
            } | undefined;
            numberOfInstances?: number | undefined;
            dockerImage?: string | undefined;
            maxDBConnections?: number | undefined;
            mode?: "session" | "transaction" | undefined;
            schema?: string | undefined;
            user?: string | undefined;
        } | undefined;
        databases?: Record<string, string> | undefined;
        enableConnectionPooler?: boolean | undefined;
        enableReplicaConnectionPooler?: boolean | undefined;
        enableLogicalBackup?: boolean | undefined;
        enableMasterLoadBalancer?: boolean | undefined;
        enableMasterPoolerLoadBalancer?: boolean | undefined;
        enableReplicaLoadBalancer?: boolean | undefined;
        enableReplicaPoolerLoadBalancer?: boolean | undefined;
        enableShmVolume?: boolean | undefined;
        env?: {}[] | undefined;
        init_containers?: {}[] | undefined;
        initContainers?: {}[] | undefined;
        logicalBackupSchedule?: string | undefined;
        maintenanceWindows?: string[] | undefined;
        masterServiceAnnotations?: Record<string, string> | undefined;
        nodeAffinity?: {
            preferredDuringSchedulingIgnoredDuringExecution?: {
                preference: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                };
                weight: number;
            }[] | undefined;
            requiredDuringSchedulingIgnoredDuringExecution?: {
                nodeSelectorTerms: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                }[];
            } | undefined;
        } | undefined;
        podAnnotations?: Record<string, string> | undefined;
        podPriorityClassName?: string | undefined;
        preparedDatabases?: Record<string, {
            defaultUsers?: boolean | undefined;
            extensions?: Record<string, string> | undefined;
            schemas?: Record<string, {
                defaultUsers?: boolean | undefined;
                defaultRoles?: boolean | undefined;
            }> | undefined;
            secretNamespace?: string | undefined;
        }> | undefined;
        replicaLoadBalancer?: boolean | undefined;
        replicaServiceAnnotations?: Record<string, string> | undefined;
        schedulerName?: string | undefined;
        serviceAnnotations?: Record<string, string> | undefined;
        spiloRunAsUser?: number | undefined;
        spiloRunAsGroup?: number | undefined;
        spiloFSGroup?: number | undefined;
        streams?: {
            applicationId: string;
            database: string;
            tables: Record<string, {
                eventType: string;
                idColumn?: string | undefined;
                payloadColumn?: string | undefined;
                recoveryEventType?: string | undefined;
            }>;
            filter?: Record<string, string> | undefined;
            batchSize?: number | undefined;
            enableRecovery?: boolean | undefined;
        }[] | undefined;
        tls?: {
            secretName: string;
            certificateFile?: string | undefined;
            privateKeyFile?: string | undefined;
            caFile?: string | undefined;
            caSecretName?: string | undefined;
        } | undefined;
        tolerations?: {
            key?: string | undefined;
            operator?: "Equal" | "Exists" | undefined;
            value?: string | undefined;
            effect?: "NoExecute" | "NoSchedule" | "PreferNoSchedule" | undefined;
            tolerationSeconds?: number | undefined;
        }[] | undefined;
        useLoadBalancer?: boolean | undefined;
        usersIgnoringSecretRotation?: string[] | undefined;
        usersWithInPlaceSecretRotation?: string[] | undefined;
        usersWithSecretRotation?: string[] | undefined;
    }>;
    status: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    metadata: z.ZodOptional<z.ZodObject<{
        annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        creationTimestamp: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        deletionGracePeriodSeconds: z.ZodOptional<z.ZodNumber>;
        deletionTimestamp: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        finalizers: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        generateName: z.ZodOptional<z.ZodString>;
        generation: z.ZodOptional<z.ZodNumber>;
        labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        managedFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
            apiVersion: z.ZodOptional<z.ZodString>;
            fieldsType: z.ZodOptional<z.ZodString>;
            fieldsV1: z.ZodOptional<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
            manager: z.ZodOptional<z.ZodString>;
            operation: z.ZodOptional<z.ZodString>;
            subresource: z.ZodOptional<z.ZodString>;
            time: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }, {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }>, "many">>;
        name: z.ZodOptional<z.ZodString>;
        namespace: z.ZodOptional<z.ZodString>;
        ownerReferences: z.ZodOptional<z.ZodArray<z.ZodObject<{
            apiVersion: z.ZodString;
            blockOwnerDeletion: z.ZodOptional<z.ZodBoolean>;
            controller: z.ZodOptional<z.ZodBoolean>;
            kind: z.ZodString;
            name: z.ZodString;
            uid: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }, {
            apiVersion: string; /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }>, "many">>;
        resourceVersion: z.ZodOptional<z.ZodString>;
        selfLink: z.ZodOptional<z.ZodString>;
        uid: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    }, {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    kind: "postgresql";
    apiVersion: "acid.zalan.do/v1";
    spec: {
        postgresql: {
            version: "11" | "12" | "13" | "14" | "15" | "16";
            parameters?: Record<string, string> | undefined;
        };
        numberOfInstances: number;
        teamId: string;
        volume: {
            size: string;
            subPath?: string | undefined;
            iops?: number | undefined;
            selector?: {
                matchExpressions?: {
                    key: string;
                    operator: "Exists" | "DoesNotExist" | "In" | "NotIn";
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: {} | undefined;
            } | undefined;
            storageClass?: string | undefined;
            throughput?: number | undefined;
        };
        resources?: {
            requests?: {
                cpu?: string | undefined;
                memory?: string | undefined;
                "hugepages-2Mi"?: string | undefined;
                "hugepages-1Gi"?: string | undefined;
            } | undefined;
            limits?: {
                cpu?: string | undefined;
                memory?: string | undefined;
                "hugepages-2Mi"?: string | undefined;
                "hugepages-1Gi"?: string | undefined;
            } | undefined;
        } | undefined;
        standby?: ({
            s3_wal_path?: string | undefined;
            gs_wal_path?: string | undefined;
            standby_host?: string | undefined;
            standby_port?: string | undefined;
        } & ({
            s3_wal_path: string;
            gs_wal_path?: string | undefined;
            standby_host?: string | undefined;
            standby_port?: string | undefined;
        } | {
            gs_wal_path: string;
            s3_wal_path?: string | undefined;
            standby_host?: string | undefined;
            standby_port?: string | undefined;
        } | {
            standby_host: string;
            s3_wal_path?: string | undefined;
            gs_wal_path?: string | undefined;
            standby_port?: string | undefined;
        })) | undefined;
        sidecars?: {}[] | undefined;
        users?: Record<string, ("bypassrls" | "BYPASSRLS" | "nobypassrls" | "NOBYPASSRLS" | "createdb" | "CREATEDB" | "nocreatedb" | "NOCREATEDB" | "createrole" | "CREATEROLE" | "nocreaterole" | "NOCREATEROLE" | "inherit" | "INHERIT" | "noinherit" | "NOINHERIT" | "login" | "LOGIN" | "nologin" | "NOLOGIN" | "replication" | "REPLICATION" | "noreplication" | "NOREPLICATION" | "superuser" | "SUPERUSER" | "nosuperuser" | "NOSUPERUSER")[]> | undefined;
        pod_priority_class_name?: string | undefined;
        patroni?: {
            failsafe_mode?: boolean | undefined;
            initdb?: Record<string, string> | undefined;
            loop_wait?: number | undefined;
            maximum_lag_on_failover?: number | undefined;
            pg_hba?: string[] | undefined;
            retry_timeout?: number | undefined;
            slots?: Record<string, Record<string, string>> | undefined;
            synchronous_mode?: boolean | undefined;
            synchronous_mode_strict?: boolean | undefined;
            synchronous_node_count?: number | undefined;
            ttl?: number | undefined;
        } | undefined;
        additionalVolumes?: {
            name: string;
            mountPath: string;
            volumeSource: {};
            targetContainers?: string[] | undefined;
            subPath?: string | undefined;
        }[] | undefined;
        allowedSourceRanges?: string[] | undefined;
        clone?: {
            cluster: string;
            s3_wal_path?: string | undefined;
            s3_endpoint?: string | undefined;
            s3_access_key_id?: string | undefined;
            s3_secret_access_key?: string | undefined;
            s3_force_path_style?: boolean | undefined;
            timestamp?: string | undefined;
            uid?: string | undefined;
        } | undefined;
        dockerImage?: string | undefined;
        connectionPooler?: {
            resources?: {
                requests?: {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                } | undefined;
                limits?: {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                } | undefined;
            } | undefined;
            numberOfInstances?: number | undefined;
            dockerImage?: string | undefined;
            maxDBConnections?: number | undefined;
            mode?: "session" | "transaction" | undefined;
            schema?: string | undefined;
            user?: string | undefined;
        } | undefined;
        databases?: Record<string, string> | undefined;
        enableConnectionPooler?: boolean | undefined;
        enableReplicaConnectionPooler?: boolean | undefined;
        enableLogicalBackup?: boolean | undefined;
        enableMasterLoadBalancer?: boolean | undefined;
        enableMasterPoolerLoadBalancer?: boolean | undefined;
        enableReplicaLoadBalancer?: boolean | undefined;
        enableReplicaPoolerLoadBalancer?: boolean | undefined;
        enableShmVolume?: boolean | undefined;
        env?: {}[] | undefined;
        init_containers?: {}[] | undefined;
        initContainers?: {}[] | undefined;
        logicalBackupSchedule?: string | undefined;
        maintenanceWindows?: string[] | undefined;
        masterServiceAnnotations?: Record<string, string> | undefined;
        nodeAffinity?: {
            preferredDuringSchedulingIgnoredDuringExecution?: {
                preference: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                };
                weight: number;
            }[] | undefined;
            requiredDuringSchedulingIgnoredDuringExecution?: {
                nodeSelectorTerms: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                }[];
            } | undefined;
        } | undefined;
        podAnnotations?: Record<string, string> | undefined;
        podPriorityClassName?: string | undefined;
        preparedDatabases?: Record<string, {
            defaultUsers?: boolean | undefined;
            extensions?: Record<string, string> | undefined;
            schemas?: Record<string, {
                defaultUsers?: boolean | undefined;
                defaultRoles?: boolean | undefined;
            }> | undefined;
            secretNamespace?: string | undefined;
        }> | undefined;
        replicaLoadBalancer?: boolean | undefined;
        replicaServiceAnnotations?: Record<string, string> | undefined;
        schedulerName?: string | undefined;
        serviceAnnotations?: Record<string, string> | undefined;
        spiloRunAsUser?: number | undefined;
        spiloRunAsGroup?: number | undefined;
        spiloFSGroup?: number | undefined;
        streams?: {
            applicationId: string;
            database: string;
            tables: Record<string, {
                eventType: string;
                idColumn?: string | undefined;
                payloadColumn?: string | undefined;
                recoveryEventType?: string | undefined;
            }>;
            filter?: Record<string, string> | undefined;
            batchSize?: number | undefined;
            enableRecovery?: boolean | undefined;
        }[] | undefined;
        tls?: {
            secretName: string;
            certificateFile?: string | undefined;
            privateKeyFile?: string | undefined;
            caFile?: string | undefined;
            caSecretName?: string | undefined;
        } | undefined;
        tolerations?: {
            key?: string | undefined;
            operator?: "Equal" | "Exists" | undefined;
            value?: string | undefined;
            effect?: "NoExecute" | "NoSchedule" | "PreferNoSchedule" | undefined;
            tolerationSeconds?: number | undefined;
        }[] | undefined;
        useLoadBalancer?: boolean | undefined;
        usersIgnoringSecretRotation?: string[] | undefined;
        usersWithInPlaceSecretRotation?: string[] | undefined;
        usersWithSecretRotation?: string[] | undefined;
    };
    status?: Record<string, string> | undefined;
    metadata?: {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    } | undefined;
}, {
    kind: "postgresql";
    apiVersion: "acid.zalan.do/v1";
    spec: {
        postgresql: {
            version: "11" | "12" | "13" | "14" | "15" | "16";
            parameters?: Record<string, string> | undefined;
        };
        numberOfInstances: number;
        teamId: string;
        volume: {
            size: string;
            subPath?: string | undefined;
            iops?: number | undefined;
            selector?: {
                matchExpressions?: {
                    key: string;
                    operator: "Exists" | "DoesNotExist" | "In" | "NotIn";
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: {} | undefined;
            } | undefined;
            storageClass?: string | undefined;
            throughput?: number | undefined;
        };
        resources?: {
            requests?: {
                cpu?: string | undefined;
                memory?: string | undefined;
                "hugepages-2Mi"?: string | undefined;
                "hugepages-1Gi"?: string | undefined;
            } | undefined;
            limits?: {
                cpu?: string | undefined;
                memory?: string | undefined;
                "hugepages-2Mi"?: string | undefined;
                "hugepages-1Gi"?: string | undefined;
            } | undefined;
        } | undefined;
        standby?: ({
            s3_wal_path?: string | undefined;
            gs_wal_path?: string | undefined;
            standby_host?: string | undefined;
            standby_port?: string | undefined;
        } & ({
            s3_wal_path: string;
            gs_wal_path?: string | undefined;
            standby_host?: string | undefined;
            standby_port?: string | undefined;
        } | {
            gs_wal_path: string;
            s3_wal_path?: string | undefined;
            standby_host?: string | undefined;
            standby_port?: string | undefined;
        } | {
            standby_host: string;
            s3_wal_path?: string | undefined;
            gs_wal_path?: string | undefined;
            standby_port?: string | undefined;
        })) | undefined;
        sidecars?: {}[] | undefined;
        users?: Record<string, ("bypassrls" | "BYPASSRLS" | "nobypassrls" | "NOBYPASSRLS" | "createdb" | "CREATEDB" | "nocreatedb" | "NOCREATEDB" | "createrole" | "CREATEROLE" | "nocreaterole" | "NOCREATEROLE" | "inherit" | "INHERIT" | "noinherit" | "NOINHERIT" | "login" | "LOGIN" | "nologin" | "NOLOGIN" | "replication" | "REPLICATION" | "noreplication" | "NOREPLICATION" | "superuser" | "SUPERUSER" | "nosuperuser" | "NOSUPERUSER")[]> | undefined;
        pod_priority_class_name?: string | undefined;
        patroni?: {
            failsafe_mode?: boolean | undefined;
            initdb?: Record<string, string> | undefined;
            loop_wait?: number | undefined;
            maximum_lag_on_failover?: number | undefined;
            pg_hba?: string[] | undefined;
            retry_timeout?: number | undefined;
            slots?: Record<string, Record<string, string>> | undefined;
            synchronous_mode?: boolean | undefined;
            synchronous_mode_strict?: boolean | undefined;
            synchronous_node_count?: number | undefined;
            ttl?: number | undefined;
        } | undefined;
        additionalVolumes?: {
            name: string;
            mountPath: string;
            volumeSource: {};
            targetContainers?: string[] | undefined;
            subPath?: string | undefined;
        }[] | undefined;
        allowedSourceRanges?: string[] | undefined;
        clone?: {
            cluster: string;
            s3_wal_path?: string | undefined;
            s3_endpoint?: string | undefined;
            s3_access_key_id?: string | undefined;
            s3_secret_access_key?: string | undefined;
            s3_force_path_style?: boolean | undefined;
            timestamp?: string | undefined;
            uid?: string | undefined;
        } | undefined;
        dockerImage?: string | undefined;
        connectionPooler?: {
            resources?: {
                requests?: {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                } | undefined;
                limits?: {
                    cpu?: string | undefined;
                    memory?: string | undefined;
                } | undefined;
            } | undefined;
            numberOfInstances?: number | undefined;
            dockerImage?: string | undefined;
            maxDBConnections?: number | undefined;
            mode?: "session" | "transaction" | undefined;
            schema?: string | undefined;
            user?: string | undefined;
        } | undefined;
        databases?: Record<string, string> | undefined;
        enableConnectionPooler?: boolean | undefined;
        enableReplicaConnectionPooler?: boolean | undefined;
        enableLogicalBackup?: boolean | undefined;
        enableMasterLoadBalancer?: boolean | undefined;
        enableMasterPoolerLoadBalancer?: boolean | undefined;
        enableReplicaLoadBalancer?: boolean | undefined;
        enableReplicaPoolerLoadBalancer?: boolean | undefined;
        enableShmVolume?: boolean | undefined;
        env?: {}[] | undefined;
        init_containers?: {}[] | undefined;
        initContainers?: {}[] | undefined;
        logicalBackupSchedule?: string | undefined;
        maintenanceWindows?: string[] | undefined;
        masterServiceAnnotations?: Record<string, string> | undefined;
        nodeAffinity?: {
            preferredDuringSchedulingIgnoredDuringExecution?: {
                preference: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                };
                weight: number;
            }[] | undefined;
            requiredDuringSchedulingIgnoredDuringExecution?: {
                nodeSelectorTerms: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchFields?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                }[];
            } | undefined;
        } | undefined;
        podAnnotations?: Record<string, string> | undefined;
        podPriorityClassName?: string | undefined;
        preparedDatabases?: Record<string, {
            defaultUsers?: boolean | undefined;
            extensions?: Record<string, string> | undefined;
            schemas?: Record<string, {
                defaultUsers?: boolean | undefined;
                defaultRoles?: boolean | undefined;
            }> | undefined;
            secretNamespace?: string | undefined;
        }> | undefined;
        replicaLoadBalancer?: boolean | undefined;
        replicaServiceAnnotations?: Record<string, string> | undefined;
        schedulerName?: string | undefined;
        serviceAnnotations?: Record<string, string> | undefined;
        spiloRunAsUser?: number | undefined;
        spiloRunAsGroup?: number | undefined;
        spiloFSGroup?: number | undefined;
        streams?: {
            applicationId: string;
            database: string;
            tables: Record<string, {
                eventType: string;
                idColumn?: string | undefined;
                payloadColumn?: string | undefined;
                recoveryEventType?: string | undefined;
            }>;
            filter?: Record<string, string> | undefined;
            batchSize?: number | undefined;
            enableRecovery?: boolean | undefined;
        }[] | undefined;
        tls?: {
            secretName: string;
            certificateFile?: string | undefined;
            privateKeyFile?: string | undefined;
            caFile?: string | undefined;
            caSecretName?: string | undefined;
        } | undefined;
        tolerations?: {
            key?: string | undefined;
            operator?: "Equal" | "Exists" | undefined;
            value?: string | undefined;
            effect?: "NoExecute" | "NoSchedule" | "PreferNoSchedule" | undefined;
            tolerationSeconds?: number | undefined;
        }[] | undefined;
        useLoadBalancer?: boolean | undefined;
        usersIgnoringSecretRotation?: string[] | undefined;
        usersWithInPlaceSecretRotation?: string[] | undefined;
        usersWithSecretRotation?: string[] | undefined;
    };
    status?: Record<string, string> | undefined;
    metadata?: {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    } | undefined;
}>;
