import { z } from "zod";
import { iObjectMetaSchema } from "@soft-stech/apimachinery/apis/meta/v1/ObjectMeta.schema";
export const IpostgresqlSchema = z.object({
    "kind": z.literal("postgresql"),
    "apiVersion": z.literal("acid.zalan.do/v1"),
    "spec": z.object({
        "additionalVolumes": z.array(z.object({
            "name": z.string(),
            "mountPath": z.string(),
            "targetContainers": z.array(z.string()).optional(),
            "volumeSource": z.object({}),
            "subPath": z.string().optional()
        })).optional(),
        "allowedSourceRanges": z.array(z.string()).optional(),
        "clone": z.object({
            "cluster": z.string(),
            "s3_endpoint": z.string().optional(),
            "s3_access_key_id": z.string().optional(),
            "s3_secret_access_key": z.string().optional(),
            "s3_force_path_style": z.boolean().optional(),
            "s3_wal_path": z.string().optional(),
            /**
             *
             * @pattern ^([0-9]+)-(0[1-9]|1[012])-(0[1-9]|[12][0-9]|3[01])[Tt]([01][0-9]|2[0-3]):([0-5][0-9]):([0-5][0-9]|60)(\.[0-9]+)?(([+-]([01][0-9]|2[0-3]):[0-5][0-9]))$
             */
            "timestamp": z.string().regex(/^([0-9]+)-(0[1-9]|1[012])-(0[1-9]|[12][0-9]|3[01])[Tt]([01][0-9]|2[0-3]):([0-5][0-9]):([0-5][0-9]|60)(\.[0-9]+)?(([+-]([01][0-9]|2[0-3]):[0-5][0-9]))$/).optional(),
            /**
             *
             * @format uuid
             */
            "uid": z.string().uuid().optional()
        }).optional(),
        "connectionPooler": z.object({
            "dockerImage": z.string().optional(),
            "maxDBConnections": z.number().optional(),
            "mode": z.union([z.literal("session"), z.literal("transaction")]).optional(),
            /**
             *
             * @minimum 1
             */
            "numberOfInstances": z.number().min(1).optional(),
            "resources": z.object({
                "limits": z.object({
                    /**
                     *
                     * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
                     */
                    "cpu": z.string().regex(/^(\d+m|\d+(\.\d{1,3})?)$/).optional(),
                    /**
                     *
                     * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
                     */
                    "memory": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/).optional()
                }).optional(),
                "requests": z.object({
                    /**
                     *
                     * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
                     */
                    "cpu": z.string().regex(/^(\d+m|\d+(\.\d{1,3})?)$/).optional(),
                    /**
                     *
                     * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
                     */
                    "memory": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/).optional()
                }).optional()
            }).optional(),
            "schema": z.string().optional(),
            "user": z.string().optional()
        }).optional(),
        "databases": z.record(z.string()).optional(),
        "dockerImage": z.string().optional(),
        "enableConnectionPooler": z.boolean().optional(),
        "enableReplicaConnectionPooler": z.boolean().optional(),
        "enableLogicalBackup": z.boolean().optional(),
        "enableMasterLoadBalancer": z.boolean().optional(),
        "enableMasterPoolerLoadBalancer": z.boolean().optional(),
        "enableReplicaLoadBalancer": z.boolean().optional(),
        "enableReplicaPoolerLoadBalancer": z.boolean().optional(),
        "enableShmVolume": z.boolean().optional(),
        "env": z.array(z.object({})).optional(),
        /**
         * deprecated
         */
        "init_containers": z.array(z.object({})).optional(),
        "initContainers": z.array(z.object({})).optional(),
        /**
         *
         * @pattern ^(\d+|\*)(\/\d+)?(\s+(\d+|\*)(\/\d+)?){4}$
         */
        "logicalBackupSchedule": z.string().regex(/^(\d+|\*)(\/\d+)?(\s+(\d+|\*)(\/\d+)?){4}$/).optional(),
        "maintenanceWindows": z.array(z.string()).optional(),
        "masterServiceAnnotations": z.record(z.string()).optional(),
        "nodeAffinity": z.object({
            "preferredDuringSchedulingIgnoredDuringExecution": z.array(z.object({
                "preference": z.object({
                    "matchExpressions": z.array(z.object({
                        "key": z.string(),
                        "operator": z.string(),
                        "values": z.array(z.string()).optional()
                    })).optional(),
                    "matchFields": z.array(z.object({
                        "key": z.string(),
                        "operator": z.string(),
                        "values": z.array(z.string()).optional()
                    })).optional()
                }),
                /**
                 *
                 * @format int32
                 */
                "weight": z.number()
            })).optional(),
            "requiredDuringSchedulingIgnoredDuringExecution": z.object({
                "nodeSelectorTerms": z.array(z.object({
                    "matchExpressions": z.array(z.object({
                        "key": z.string(),
                        "operator": z.string(),
                        "values": z.array(z.string()).optional()
                    })).optional(),
                    "matchFields": z.array(z.object({
                        "key": z.string(),
                        "operator": z.string(),
                        "values": z.array(z.string()).optional()
                    })).optional()
                }))
            }).optional()
        }).optional(),
        "numberOfInstances": z.number(),
        "patroni": z.object({
            "failsafe_mode": z.boolean().optional(),
            "initdb": z.record(z.string()).optional(),
            "loop_wait": z.number().optional(),
            "maximum_lag_on_failover": z.number().optional(),
            "pg_hba": z.array(z.string()).optional(),
            "retry_timeout": z.number().optional(),
            "slots": z.record(z.record(z.string())).optional(),
            "synchronous_mode": z.boolean().optional(),
            "synchronous_mode_strict": z.boolean().optional(),
            "synchronous_node_count": z.number().optional(),
            "ttl": z.number().optional()
        }).optional(),
        "podAnnotations": z.record(z.string()).optional(),
        /**
         * deprecated
         */
        "pod_priority_class_name": z.string().optional(),
        "podPriorityClassName": z.string().optional(),
        "postgresql": z.object({
            "version": z.union([z.literal("11"), z.literal("12"), z.literal("13"), z.literal("14"), z.literal("15"), z.literal("16")]),
            "parameters": z.record(z.string()).optional()
        }),
        "preparedDatabases": z.record(z.object({
            "defaultUsers": z.boolean().optional(),
            "extensions": z.record(z.string()).optional(),
            "schemas": z.record(z.object({
                "defaultUsers": z.boolean().optional(),
                "defaultRoles": z.boolean().optional()
            })).optional(),
            "secretNamespace": z.string().optional()
        })).optional(),
        /**
         * deprecated
         */
        "replicaLoadBalancer": z.boolean().optional(),
        "replicaServiceAnnotations": z.record(z.string()).optional(),
        "resources": z.object({
            "limits": z.object({
                /**
                 *
                 * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
                 */
                "cpu": z.string().regex(/^(\d+m|\d+(\.\d{1,3})?)$/).optional(),
                /**
                 *
                 * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
                 */
                "memory": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/).optional(),
                /**
                 *
                 * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
                 */
                "hugepages-2Mi": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/).optional(),
                /**
                 *
                 * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
                 */
                "hugepages-1Gi": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/).optional()
            }).optional(),
            "requests": z.object({
                /**
                 *
                 * @pattern ^(\d+m|\d+(\.\d{1,3})?)$
                 */
                "cpu": z.string().regex(/^(\d+m|\d+(\.\d{1,3})?)$/).optional(),
                /**
                 *
                 * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
                 */
                "memory": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/).optional(),
                /**
                 *
                 * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
                 */
                "hugepages-2Mi": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/).optional(),
                /**
                 *
                 * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
                 */
                "hugepages-1Gi": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/).optional()
            }).optional()
        }).optional(),
        "schedulerName": z.string().optional(),
        "serviceAnnotations": z.record(z.string()).optional(),
        "sidecars": z.array(z.object({})).optional(),
        "spiloRunAsUser": z.number().optional(),
        "spiloRunAsGroup": z.number().optional(),
        "spiloFSGroup": z.number().optional(),
        "standby": z.object({
            "s3_wal_path": z.string().optional(),
            "gs_wal_path": z.string().optional(),
            "standby_host": z.string().optional(),
            "standby_port": z.string().optional()
        }).and(z.union([z.object({
                "s3_wal_path": z.string(),
                "gs_wal_path": z.string().optional(),
                "standby_host": z.string().optional(),
                "standby_port": z.string().optional()
            }), z.object({
                "s3_wal_path": z.string().optional(),
                "gs_wal_path": z.string(),
                "standby_host": z.string().optional(),
                "standby_port": z.string().optional()
            }), z.object({
                "s3_wal_path": z.string().optional(),
                "gs_wal_path": z.string().optional(),
                "standby_host": z.string(),
                "standby_port": z.string().optional()
            })])).optional(),
        "streams": z.array(z.object({
            "applicationId": z.string(),
            "batchSize": z.number().optional(),
            "database": z.string(),
            "enableRecovery": z.boolean().optional(),
            "filter": z.record(z.string()).optional(),
            "tables": z.record(z.object({
                "eventType": z.string(),
                "idColumn": z.string().optional(),
                "payloadColumn": z.string().optional(),
                "recoveryEventType": z.string().optional()
            }))
        })).optional(),
        "teamId": z.string(),
        "tls": z.object({
            "secretName": z.string(),
            "certificateFile": z.string().optional(),
            "privateKeyFile": z.string().optional(),
            "caFile": z.string().optional(),
            "caSecretName": z.string().optional()
        }).optional(),
        "tolerations": z.array(z.object({
            "key": z.string().optional(),
            "operator": z.union([z.literal("Equal"), z.literal("Exists")]).optional(),
            "value": z.string().optional(),
            "effect": z.union([z.literal("NoExecute"), z.literal("NoSchedule"), z.literal("PreferNoSchedule")]).optional(),
            "tolerationSeconds": z.number().optional()
        })).optional(),
        /**
         * deprecated
         */
        "useLoadBalancer": z.boolean().optional(),
        "users": z.record(z.array(z.union([z.literal("bypassrls"), z.literal("BYPASSRLS"), z.literal("nobypassrls"), z.literal("NOBYPASSRLS"), z.literal("createdb"), z.literal("CREATEDB"), z.literal("nocreatedb"), z.literal("NOCREATEDB"), z.literal("createrole"), z.literal("CREATEROLE"), z.literal("nocreaterole"), z.literal("NOCREATEROLE"), z.literal("inherit"), z.literal("INHERIT"), z.literal("noinherit"), z.literal("NOINHERIT"), z.literal("login"), z.literal("LOGIN"), z.literal("nologin"), z.literal("NOLOGIN"), z.literal("replication"), z.literal("REPLICATION"), z.literal("noreplication"), z.literal("NOREPLICATION"), z.literal("superuser"), z.literal("SUPERUSER"), z.literal("nosuperuser"), z.literal("NOSUPERUSER")]))).optional(),
        "usersIgnoringSecretRotation": z.array(z.string()).optional(),
        "usersWithInPlaceSecretRotation": z.array(z.string()).optional(),
        "usersWithSecretRotation": z.array(z.string()).optional(),
        "volume": z.object({
            "iops": z.number().optional(),
            "selector": z.object({
                "matchExpressions": z.array(z.object({
                    "key": z.string(),
                    "operator": z.union([z.literal("DoesNotExist"), z.literal("Exists"), z.literal("In"), z.literal("NotIn")]),
                    "values": z.array(z.string()).optional()
                })).optional(),
                "matchLabels": z.object({}).optional()
            }).optional(),
            /**
             *
             * @pattern ^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$
             */
            "size": z.string().regex(/^(\d+(e\d+)?|\d+(\.\d+)?(e\d+)?[EPTGMK]i?)$/),
            "storageClass": z.string().optional(),
            "subPath": z.string().optional(),
            "throughput": z.number().optional()
        })
    }),
    "status": z.record(z.string()).optional(),
    "metadata": iObjectMetaSchema.optional()
});
