import { z } from "zod";
/**
 * PGAdmin is the Schema for the pgadmins API
 */
export declare const IPGAdminSchema: z.ZodObject<{
    /**
     * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
     */
    apiVersion: z.ZodLiteral<"postgres-operator.crunchydata.com/v1beta1">;
    /**
     * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
     */
    kind: z.ZodLiteral<"PGAdmin">;
    metadata: z.ZodOptional<z.ZodObject<{
        annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        creationTimestamp: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        deletionGracePeriodSeconds: z.ZodOptional<z.ZodNumber>;
        deletionTimestamp: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        finalizers: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        generateName: z.ZodOptional<z.ZodString>;
        generation: z.ZodOptional<z.ZodNumber>;
        labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        managedFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
            apiVersion: z.ZodOptional<z.ZodString>;
            fieldsType: z.ZodOptional<z.ZodString>;
            fieldsV1: z.ZodOptional<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
            manager: z.ZodOptional<z.ZodString>;
            operation: z.ZodOptional<z.ZodString>;
            subresource: z.ZodOptional<z.ZodString>;
            time: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined; /**
             * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
             */
            subresource?: string | undefined;
            time?: string | null | undefined;
        }, {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined; /**
             * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
             */
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }>, "many">>;
        name: z.ZodOptional<z.ZodString>;
        namespace: z.ZodOptional<z.ZodString>;
        ownerReferences: z.ZodOptional<z.ZodArray<z.ZodObject<{
            apiVersion: z.ZodString;
            blockOwnerDeletion: z.ZodOptional<z.ZodBoolean>;
            controller: z.ZodOptional<z.ZodBoolean>;
            kind: z.ZodString;
            name: z.ZodString;
            uid: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }, {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string; /**
             * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
             */
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }>, "many">>;
        resourceVersion: z.ZodOptional<z.ZodString>;
        selfLink: z.ZodOptional<z.ZodString>; /**
         * A label query over a set of resources, in this case pods.
         */
        uid: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name?: string | undefined; /**
         * key is the label key that the selector applies to.
         */
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined; /**
         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
         */
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined; /**
         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
         */
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string; /**
             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
             */
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    }, {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined; /**
             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
             */
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined; /**
             * key is the label key that the selector applies to.
             */
            controller?: boolean | undefined;
        }[] | undefined;
    }>>;
    /**
     * PGAdminSpec defines the desired state of PGAdmin
     */
    spec: z.ZodOptional<z.ZodObject<{
        /**
         * Scheduling constraints of the PGAdmin pod. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/assign-pod-node
         */
        affinity: z.ZodOptional<z.ZodObject<{
            /**
             * Describes node affinity scheduling rules for the pod.
             */
            nodeAffinity: z.ZodOptional<z.ZodObject<{
                /**
                 * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node matches the corresponding matchExpressions; the node(s) with the highest sum are the most preferred.
                 */
                preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * A node selector term, associated with the corresponding weight.
                     */
                    preference: z.ZodObject<{
                        /**
                         * A list of node selector requirements by node's labels.
                         */
                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * The label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                             */
                            operator: z.ZodString;
                            /**
                             * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                        /**
                         * A list of node selector requirements by node's fields.
                         */
                        matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * The label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                             */
                            operator: z.ZodString;
                            /**
                             * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }>;
                    /**
                     * Weight associated with matching the corresponding nodeSelectorTerm, in the range 1-100.
                     * @format int32
                     */
                    weight: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }, {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }>, "many">>;
                /**
                 * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to an update), the system may or may not try to eventually evict the pod from its node.
                 */
                requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodObject<{
                    /**
                     * Required. A list of node selector terms. The terms are ORed.
                     */
                    nodeSelectorTerms: z.ZodArray<z.ZodObject<{
                        /**
                         * A list of node selector requirements by node's labels.
                         */
                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * The label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                             */
                            operator: z.ZodString;
                            /**
                             * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                        /**
                         * A list of node selector requirements by node's fields.
                         */
                        matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * The label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                             */
                            operator: z.ZodString;
                            /**
                             * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                }, {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                }>>;
            }, "strip", z.ZodTypeAny, {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                } | undefined;
            }, {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                } | undefined;
            }>>;
            /**
             * Describes pod affinity scheduling rules (e.g. co-locate this pod in the same node, zone, etc. as some other pod(s)).
             */
            podAffinity: z.ZodOptional<z.ZodObject<{
                /**
                 * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                 */
                preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * Required. A pod affinity term, associated with the corresponding weight.
                     */
                    podAffinityTerm: z.ZodObject<{
                        /**
                         * A label query over a set of resources, in this case pods.
                         */
                        labelSelector: z.ZodOptional<z.ZodObject<{
                            /**
                             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                             */
                            matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the label key that the selector applies to.
                                 */
                                key: z.ZodString;
                                /**
                                 * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                 */
                                operator: z.ZodString;
                                /**
                                 * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                 */
                                values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }>, "many">>;
                            /**
                             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                             */
                            matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                        }, "strip", z.ZodTypeAny, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }>>;
                        /**
                         * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                         */
                        namespaceSelector: z.ZodOptional<z.ZodObject<{
                            /**
                             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                             */
                            matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the label key that the selector applies to.
                                 */
                                key: z.ZodString;
                                /**
                                 * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                 */
                                operator: z.ZodString;
                                /**
                                 * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                 */
                                values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }>, "many">>;
                            /**
                             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                             */
                            matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                        }, "strip", z.ZodTypeAny, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }>>;
                        /**
                         * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                         */
                        namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        /**
                         * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                         */
                        topologyKey: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }, {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }>;
                    /**
                     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                     * @format int32
                     */
                    weight: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }, {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }>, "many">>;
                /**
                 * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                 */
                requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * A label query over a set of resources, in this case pods.
                     */
                    labelSelector: z.ZodOptional<z.ZodObject<{
                        /**
                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                         */
                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                             */
                            operator: z.ZodString;
                            /**
                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                        /**
                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                         */
                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    }, "strip", z.ZodTypeAny, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }>>;
                    /**
                     * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                     */
                    namespaceSelector: z.ZodOptional<z.ZodObject<{
                        /**
                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                         */
                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                             */
                            operator: z.ZodString;
                            /**
                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                        /**
                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                         */
                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    }, "strip", z.ZodTypeAny, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }>>;
                    /**
                     * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                     */
                    namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    /**
                     * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                     */
                    topologyKey: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }, {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            }, {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            }>>;
            /**
             * Describes pod anti-affinity scheduling rules (e.g. avoid putting this pod in the same node, zone, etc. as some other pod(s)).
             */
            podAntiAffinity: z.ZodOptional<z.ZodObject<{
                /**
                 * The scheduler will prefer to schedule pods to nodes that satisfy the anti-affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling anti-affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                 */
                preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * Required. A pod affinity term, associated with the corresponding weight.
                     */
                    podAffinityTerm: z.ZodObject<{
                        /**
                         * A label query over a set of resources, in this case pods.
                         */
                        labelSelector: z.ZodOptional<z.ZodObject<{
                            /**
                             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                             */
                            matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the label key that the selector applies to.
                                 */
                                key: z.ZodString;
                                /**
                                 * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                 */
                                operator: z.ZodString;
                                /**
                                 * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                 */
                                values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }>, "many">>;
                            /**
                             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                             */
                            matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                        }, "strip", z.ZodTypeAny, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }>>;
                        /**
                         * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                         */
                        namespaceSelector: z.ZodOptional<z.ZodObject<{
                            /**
                             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                             */
                            matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the label key that the selector applies to.
                                 */
                                key: z.ZodString;
                                /**
                                 * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                 */
                                operator: z.ZodString;
                                /**
                                 * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                 */
                                values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }>, "many">>;
                            /**
                             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                             */
                            matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                        }, "strip", z.ZodTypeAny, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }>>;
                        /**
                         * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                         */
                        namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        /**
                         * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                         */
                        topologyKey: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }, {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }>;
                    /**
                     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                     * @format int32
                     */
                    weight: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }, {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }>, "many">>;
                /**
                 * If the anti-affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the anti-affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                 */
                requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * A label query over a set of resources, in this case pods.
                     */
                    labelSelector: z.ZodOptional<z.ZodObject<{
                        /**
                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                         */
                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                             */
                            operator: z.ZodString;
                            /**
                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                        /**
                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                         */
                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    }, "strip", z.ZodTypeAny, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }>>;
                    /**
                     * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                     */
                    namespaceSelector: z.ZodOptional<z.ZodObject<{
                        /**
                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                         */
                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                             */
                            operator: z.ZodString;
                            /**
                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                        /**
                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                         */
                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    }, "strip", z.ZodTypeAny, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }>>;
                    /**
                     * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                     */
                    namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    /**
                     * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                     */
                    topologyKey: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }, {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            }, {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            nodeAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                } | undefined;
            } | undefined;
            podAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
            podAntiAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
        }, {
            nodeAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                } | undefined;
            } | undefined;
            podAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
            podAntiAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
        }>>;
        /**
         * Configuration settings for the pgAdmin process. Changes to any of these values will be loaded without validation. Be careful, as you may put pgAdmin into an unusable state.
         */
        config: z.ZodOptional<z.ZodObject<{
            /**
             * Files allows the user to mount projected volumes into the pgAdmin container so that files can be referenced by pgAdmin as needed.
             */
            files: z.ZodOptional<z.ZodArray<z.ZodObject<{
                /**
                 * configMap information about the configMap data to project
                 */
                configMap: z.ZodOptional<z.ZodObject<{
                    /**
                     * items if unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
                     */
                    items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * key is the key to project.
                         */
                        key: z.ZodString;
                        /**
                         * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                         * @format int32
                         */
                        mode: z.ZodOptional<z.ZodNumber>;
                        /**
                         * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                         */
                        path: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }, {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }>, "many">>;
                    /**
                     * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                     */
                    name: z.ZodOptional<z.ZodString>;
                    /**
                     * optional specify whether the ConfigMap or its keys must be defined
                     */
                    optional: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                }, {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                }>>;
                /**
                 * downwardAPI information about the downwardAPI data to project
                 */
                downwardAPI: z.ZodOptional<z.ZodObject<{
                    /**
                     * Items is a list of DownwardAPIVolume file
                     */
                    items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * Required: Selects a field of the pod: only annotations, labels, name and namespace are supported.
                         */
                        fieldRef: z.ZodOptional<z.ZodObject<{
                            /**
                             * Version of the schema the FieldPath is written in terms of, defaults to "v1".
                             */
                            apiVersion: z.ZodOptional<z.ZodString>;
                            /**
                             * Path of the field to select in the specified API version.
                             */
                            fieldPath: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        }, {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        }>>;
                        /**
                         * Optional: mode bits used to set permissions on this file, must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                         * @format int32
                         */
                        mode: z.ZodOptional<z.ZodNumber>;
                        /**
                         * Required: Path is  the relative path name of the file to be created. Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
                         */
                        path: z.ZodString;
                        /**
                         * Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, requests.cpu and requests.memory) are currently supported.
                         */
                        resourceFieldRef: z.ZodOptional<z.ZodObject<{
                            /**
                             * Container name: required for volumes, optional for env vars
                             */
                            containerName: z.ZodOptional<z.ZodString>;
                            /**
                             * Specifies the output format of the exposed resources, defaults to "1"
                             * @schema union([z.number(), z.string().regex(/^(\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))(([KMGTPE]i)|[numkMGTPE]|([eE](\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))))?$/)]).optional()
                             */
                            divisor: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString]>>;
                            /**
                             * Required: resource to select
                             */
                            resource: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        }, {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }, {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }>, "many">>;
                }, "strip", z.ZodTypeAny, {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                }, {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                }>>;
                /**
                 * secret information about the secret data to project
                 */
                secret: z.ZodOptional<z.ZodObject<{
                    /**
                     * items if unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
                     */
                    items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * key is the key to project.
                         */
                        key: z.ZodString;
                        /**
                         * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                         * @format int32
                         */
                        mode: z.ZodOptional<z.ZodNumber>;
                        /**
                         * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                         */
                        path: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }, {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }>, "many">>;
                    /**
                     * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                     */
                    name: z.ZodOptional<z.ZodString>;
                    /**
                     * optional field specify whether the Secret or its key must be defined
                     */
                    optional: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                }, {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                }>>;
                /**
                 * serviceAccountToken is information about the serviceAccountToken data to project
                 */
                serviceAccountToken: z.ZodOptional<z.ZodObject<{
                    /**
                     * audience is the intended audience of the token. A recipient of a token must identify itself with an identifier specified in the audience of the token, and otherwise should reject the token. The audience defaults to the identifier of the apiserver.
                     */
                    audience: z.ZodOptional<z.ZodString>;
                    /**
                     * expirationSeconds is the requested duration of validity of the service account token. As the token approaches expiration, the kubelet volume plugin will proactively rotate the service account token. The kubelet will start trying to rotate the token if the token is older than 80 percent of its time to live or if the token is older than 24 hours.Defaults to 1 hour and must be at least 10 minutes.
                     * @format int64
                     */
                    expirationSeconds: z.ZodOptional<z.ZodNumber>;
                    /**
                     * path is the path relative to the mount point of the file to project the token into.
                     */
                    path: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                }, {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                configMap?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                downwardAPI?: {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                } | undefined;
                secret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                serviceAccountToken?: {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                } | undefined;
            }, {
                configMap?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                downwardAPI?: {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                } | undefined;
                secret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                serviceAccountToken?: {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                } | undefined;
            }>, "many">>;
            /**
             * A Secret containing the value for the LDAP_BIND_PASSWORD setting. More info: https://www.pgadmin.org/docs/pgadmin4/latest/ldap.html
             */
            ldapBindPassword: z.ZodOptional<z.ZodObject<{
                /**
                 * The key of the secret to select from.  Must be a valid secret key.
                 */
                key: z.ZodString;
                /**
                 * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                 */
                name: z.ZodOptional<z.ZodString>;
                /**
                 * Specify whether the Secret or its key must be defined
                 */
                optional: z.ZodOptional<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                key: string;
                name?: string | undefined;
                optional?: boolean | undefined;
            }, {
                key: string;
                name?: string | undefined;
                optional?: boolean | undefined;
            }>>;
            /**
             * Settings for the pgAdmin server process. Keys should be uppercase and values must be constants. More info: https://www.pgadmin.org/docs/pgadmin4/latest/config_py.html
             */
            settings: z.ZodOptional<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
        }, "strip", z.ZodTypeAny, {
            files?: {
                configMap?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                downwardAPI?: {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                } | undefined;
                secret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                serviceAccountToken?: {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                } | undefined;
            }[] | undefined;
            ldapBindPassword?: {
                key: string;
                name?: string | undefined;
                optional?: boolean | undefined;
            } | undefined;
            settings?: {} | undefined;
        }, {
            files?: {
                configMap?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                downwardAPI?: {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                } | undefined;
                secret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                serviceAccountToken?: {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                } | undefined;
            }[] | undefined;
            ldapBindPassword?: {
                key: string;
                name?: string | undefined;
                optional?: boolean | undefined;
            } | undefined;
            settings?: {} | undefined;
        }>>;
        /**
         * Defines a PersistentVolumeClaim for pgAdmin data. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes
         */
        dataVolumeClaimSpec: z.ZodObject<{
            /**
             * accessModes contains the desired access modes the volume should have. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes-1
             */
            accessModes: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            /**
             * dataSource field can be used to specify either: \* An existing VolumeSnapshot object (snapshot.storage.k8s.io/VolumeSnapshot) \* An existing PVC (PersistentVolumeClaim) If the provisioner or an external controller can support the specified data source, it will create a new volume based on the contents of the specified data source. If the AnyVolumeDataSource feature gate is enabled, this field will always have the same contents as the DataSourceRef field.
             */
            dataSource: z.ZodOptional<z.ZodObject<{
                /**
                 * APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
                 */
                apiGroup: z.ZodOptional<z.ZodString>;
                /**
                 * Kind is the type of resource being referenced
                 */
                kind: z.ZodString;
                /**
                 * Name is the name of resource being referenced
                 */
                name: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                kind: string;
                name: string;
                apiGroup?: string | undefined;
            }, {
                kind: string;
                name: string;
                apiGroup?: string | undefined;
            }>>;
            /**
             * dataSourceRef specifies the object from which to populate the volume with data, if a non-empty volume is desired. This may be any local object from a non-empty API group (non core object) or a PersistentVolumeClaim object. When this field is specified, volume binding will only succeed if the type of the specified object matches some installed volume populator or dynamic provisioner. This field will replace the functionality of the DataSource field and as such if both fields are non-empty, they must have the same value. For backwards compatibility, both fields (DataSource and DataSourceRef) will be set to the same value automatically if one of them is empty and the other is non-empty. There are two important differences between DataSource and DataSourceRef: \* While DataSource only allows two specific types of objects, DataSourceRef allows any non-core object, as well as PersistentVolumeClaim objects. \* While DataSource ignores disallowed values (dropping them), DataSourceRef preserves all values, and generates an error if a disallowed value is specified. (Beta) Using this field requires the AnyVolumeDataSource feature gate to be enabled.
             */
            dataSourceRef: z.ZodOptional<z.ZodObject<{
                /**
                 * APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
                 */
                apiGroup: z.ZodOptional<z.ZodString>;
                /**
                 * Kind is the type of resource being referenced
                 */
                kind: z.ZodString;
                /**
                 * Name is the name of resource being referenced
                 */
                name: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                kind: string;
                name: string;
                apiGroup?: string | undefined;
            }, {
                kind: string;
                name: string;
                apiGroup?: string | undefined;
            }>>;
            /**
             * resources represents the minimum resources the volume should have. If RecoverVolumeExpansionFailure feature is enabled users are allowed to specify resource requirements that are lower than previous value but must still be higher than capacity recorded in the status field of the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#resources
             */
            resources: z.ZodOptional<z.ZodObject<{
                /**
                 * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                 */
                limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                /**
                 * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                 */
                requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
            }, "strip", z.ZodTypeAny, {
                requests?: Record<string, string | number> | undefined;
                limits?: Record<string, string | number> | undefined;
            }, {
                requests?: Record<string, string | number> | undefined;
                limits?: Record<string, string | number> | undefined;
            }>>;
            /**
             * selector is a label query over volumes to consider for binding.
             */
            selector: z.ZodOptional<z.ZodObject<{
                /**
                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                 */
                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * key is the label key that the selector applies to.
                     */
                    key: z.ZodString;
                    /**
                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                     */
                    operator: z.ZodString;
                    /**
                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                     */
                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                }, "strip", z.ZodTypeAny, {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }, {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }>, "many">>;
                /**
                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                 */
                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
            }, "strip", z.ZodTypeAny, {
                matchExpressions?: {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: Record<string, string> | undefined;
            }, {
                matchExpressions?: {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: Record<string, string> | undefined;
            }>>;
            /**
             * storageClassName is the name of the StorageClass required by the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#class-1
             */
            storageClassName: z.ZodOptional<z.ZodString>;
            /**
             * volumeMode defines what type of volume is required by the claim. Value of Filesystem is implied when not included in claim spec.
             */
            volumeMode: z.ZodOptional<z.ZodString>;
            /**
             * volumeName is the binding reference to the PersistentVolume backing this claim.
             */
            volumeName: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            accessModes?: string[] | undefined;
            resources?: {
                requests?: Record<string, string | number> | undefined;
                limits?: Record<string, string | number> | undefined;
            } | undefined;
            selector?: {
                matchExpressions?: {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: Record<string, string> | undefined;
            } | undefined;
            dataSource?: {
                kind: string;
                name: string;
                apiGroup?: string | undefined;
            } | undefined;
            dataSourceRef?: {
                kind: string;
                name: string;
                apiGroup?: string | undefined;
            } | undefined;
            storageClassName?: string | undefined;
            volumeMode?: string | undefined;
            volumeName?: string | undefined;
        }, {
            accessModes?: string[] | undefined;
            resources?: {
                requests?: Record<string, string | number> | undefined;
                limits?: Record<string, string | number> | undefined;
            } | undefined;
            selector?: {
                matchExpressions?: {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: Record<string, string> | undefined;
            } | undefined;
            dataSource?: {
                kind: string;
                name: string;
                apiGroup?: string | undefined;
            } | undefined;
            dataSourceRef?: {
                kind: string;
                name: string;
                apiGroup?: string | undefined;
            } | undefined;
            storageClassName?: string | undefined;
            volumeMode?: string | undefined;
            volumeName?: string | undefined;
        }>;
        /**
         * The image name to use for pgAdmin instance.
         */
        image: z.ZodOptional<z.ZodString>;
        /**
         * ImagePullPolicy is used to determine when Kubernetes will attempt to pull (download) container images. More info: https://kubernetes.io/docs/concepts/containers/images/#image-pull-policy
         */
        imagePullPolicy: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"Always">, z.ZodLiteral<"Never">, z.ZodLiteral<"IfNotPresent">]>>;
        /**
         * The image pull secrets used to pull from a private registry. Changing this value causes all running PGAdmin pods to restart. https://k8s.io/docs/tasks/configure-pod-container/pull-image-private-registry/
         */
        imagePullSecrets: z.ZodOptional<z.ZodArray<z.ZodObject<{
            /**
             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            name?: string | undefined;
        }, {
            name?: string | undefined;
        }>, "many">>;
        /**
         * Metadata contains metadata for custom resources
         */
        metadata: z.ZodOptional<z.ZodObject<{
            annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
            labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            annotations?: Record<string, string> | undefined;
            labels?: Record<string, string> | undefined;
        }, {
            annotations?: Record<string, string> | undefined;
            labels?: Record<string, string> | undefined;
        }>>;
        /**
         * Priority class name for the PGAdmin pod. Changing this value causes PGAdmin pod to restart. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/pod-priority-preemption/
         */
        priorityClassName: z.ZodOptional<z.ZodString>;
        /**
         * Resource requirements for the PGAdmin container.
         */
        resources: z.ZodOptional<z.ZodObject<{
            /**
             * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
             */
            limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
            /**
             * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
             */
            requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
        }, "strip", z.ZodTypeAny, {
            requests?: Record<string, string | number> | undefined;
            limits?: Record<string, string | number> | undefined;
        }, {
            requests?: Record<string, string | number> | undefined;
            limits?: Record<string, string | number> | undefined;
        }>>;
        /**
         * ServerGroups for importing PostgresClusters to pgAdmin. To create a pgAdmin with no selectors, leave this field empty. A pgAdmin created with no `ServerGroups` will not automatically add any servers through discovery. PostgresClusters can still be added manually.
         */
        serverGroups: z.ZodOptional<z.ZodArray<z.ZodObject<{
            /**
             * The name for the ServerGroup in pgAdmin. Must be unique in the pgAdmin's ServerGroups since it becomes the ServerGroup name in pgAdmin.
             */
            name: z.ZodString;
            /**
             * PostgresClusterSelector selects clusters to dynamically add to pgAdmin by matching labels. An empty selector like `{}` will select ALL clusters in the namespace.
             */
            postgresClusterSelector: z.ZodObject<{
                /**
                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                 */
                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * key is the label key that the selector applies to.
                     */
                    key: z.ZodString;
                    /**
                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                     */
                    operator: z.ZodString;
                    /**
                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                     */
                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                }, "strip", z.ZodTypeAny, {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }, {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }>, "many">>;
                /**
                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                 */
                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
            }, "strip", z.ZodTypeAny, {
                matchExpressions?: {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: Record<string, string> | undefined;
            }, {
                matchExpressions?: {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: Record<string, string> | undefined;
            }>;
        }, "strip", z.ZodTypeAny, {
            name: string;
            postgresClusterSelector: {
                matchExpressions?: {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: Record<string, string> | undefined;
            };
        }, {
            name: string;
            postgresClusterSelector: {
                matchExpressions?: {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: Record<string, string> | undefined;
            };
        }>, "many">>;
        /**
         * Tolerations of the PGAdmin pod. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/taint-and-toleration
         */
        tolerations: z.ZodOptional<z.ZodArray<z.ZodObject<{
            /**
             * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
             */
            effect: z.ZodOptional<z.ZodString>;
            /**
             * Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
             */
            key: z.ZodOptional<z.ZodString>;
            /**
             * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
             */
            operator: z.ZodOptional<z.ZodString>;
            /**
             * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
             * @format int64
             */
            tolerationSeconds: z.ZodOptional<z.ZodNumber>;
            /**
             * Value is the taint value the toleration matches to. If the operator is Exists, the value should be empty, otherwise just a regular string.
             */
            value: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            key?: string | undefined;
            operator?: string | undefined;
            value?: string | undefined;
            effect?: string | undefined;
            tolerationSeconds?: number | undefined;
        }, {
            key?: string | undefined;
            operator?: string | undefined;
            value?: string | undefined;
            effect?: string | undefined;
            tolerationSeconds?: number | undefined;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        dataVolumeClaimSpec: {
            accessModes?: string[] | undefined;
            resources?: {
                requests?: Record<string, string | number> | undefined;
                limits?: Record<string, string | number> | undefined;
            } | undefined;
            selector?: {
                matchExpressions?: {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: Record<string, string> | undefined;
            } | undefined;
            dataSource?: {
                kind: string;
                name: string;
                apiGroup?: string | undefined;
            } | undefined;
            dataSourceRef?: {
                kind: string;
                name: string;
                apiGroup?: string | undefined;
            } | undefined;
            storageClassName?: string | undefined;
            volumeMode?: string | undefined;
            volumeName?: string | undefined;
        };
        resources?: {
            requests?: Record<string, string | number> | undefined;
            limits?: Record<string, string | number> | undefined;
        } | undefined;
        metadata?: {
            annotations?: Record<string, string> | undefined;
            labels?: Record<string, string> | undefined;
        } | undefined;
        tolerations?: {
            key?: string | undefined;
            operator?: string | undefined;
            value?: string | undefined;
            effect?: string | undefined;
            tolerationSeconds?: number | undefined;
        }[] | undefined;
        affinity?: {
            nodeAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                } | undefined;
            } | undefined;
            podAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
            podAntiAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
        } | undefined;
        config?: {
            files?: {
                configMap?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                downwardAPI?: {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                } | undefined;
                secret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                serviceAccountToken?: {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                } | undefined;
            }[] | undefined;
            ldapBindPassword?: {
                key: string;
                name?: string | undefined;
                optional?: boolean | undefined;
            } | undefined;
            settings?: {} | undefined;
        } | undefined;
        image?: string | undefined;
        imagePullPolicy?: "Always" | "Never" | "IfNotPresent" | undefined;
        imagePullSecrets?: {
            name?: string | undefined;
        }[] | undefined;
        priorityClassName?: string | undefined;
        serverGroups?: {
            name: string;
            postgresClusterSelector: {
                matchExpressions?: {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: Record<string, string> | undefined;
            };
        }[] | undefined;
    }, {
        dataVolumeClaimSpec: {
            accessModes?: string[] | undefined;
            resources?: {
                requests?: Record<string, string | number> | undefined;
                limits?: Record<string, string | number> | undefined;
            } | undefined;
            selector?: {
                matchExpressions?: {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: Record<string, string> | undefined;
            } | undefined;
            dataSource?: {
                kind: string;
                name: string;
                apiGroup?: string | undefined;
            } | undefined;
            dataSourceRef?: {
                kind: string;
                name: string;
                apiGroup?: string | undefined;
            } | undefined;
            storageClassName?: string | undefined;
            volumeMode?: string | undefined;
            volumeName?: string | undefined;
        };
        resources?: {
            requests?: Record<string, string | number> | undefined;
            limits?: Record<string, string | number> | undefined;
        } | undefined;
        metadata?: {
            annotations?: Record<string, string> | undefined;
            labels?: Record<string, string> | undefined;
        } | undefined;
        tolerations?: {
            key?: string | undefined;
            operator?: string | undefined;
            value?: string | undefined;
            effect?: string | undefined;
            tolerationSeconds?: number | undefined;
        }[] | undefined;
        affinity?: {
            nodeAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                } | undefined;
            } | undefined;
            podAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
            podAntiAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
        } | undefined;
        config?: {
            files?: {
                configMap?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                downwardAPI?: {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                } | undefined;
                secret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                serviceAccountToken?: {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                } | undefined;
            }[] | undefined;
            ldapBindPassword?: {
                key: string;
                name?: string | undefined;
                optional?: boolean | undefined;
            } | undefined;
            settings?: {} | undefined;
        } | undefined;
        image?: string | undefined;
        imagePullPolicy?: "Always" | "Never" | "IfNotPresent" | undefined;
        imagePullSecrets?: {
            name?: string | undefined;
        }[] | undefined;
        priorityClassName?: string | undefined;
        serverGroups?: {
            name: string;
            postgresClusterSelector: {
                matchExpressions?: {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: Record<string, string> | undefined;
            };
        }[] | undefined;
    }>>;
    /**
     * PGAdminStatus defines the observed state of PGAdmin
     */
    status: z.ZodOptional<z.ZodObject<{
        /**
         * conditions represent the observations of pgadmin's current state. Known .status.conditions.type are: "PersistentVolumeResizing", "Progressing", "ProxyAvailable"
         */
        conditions: z.ZodOptional<z.ZodArray<z.ZodObject<{
            /**
             * lastTransitionTime is the last time the condition transitioned from one status to another. This should be when the underlying condition changed.  If that is not known, then using the time when the API field changed is acceptable.
             * @format date-time
             */
            lastTransitionTime: z.ZodNullable<z.ZodString>;
            /**
             * message is a human readable message indicating details about the transition. This may be an empty string.
             * @maxLength 32768
             */
            message: z.ZodString;
            /**
             * observedGeneration represents the .metadata.generation that the condition was set based upon. For instance, if .metadata.generation is currently 12, but the .status.conditions[x].observedGeneration is 9, the condition is out of date with respect to the current state of the instance.
             * @format int64
             */
            observedGeneration: z.ZodOptional<z.ZodNumber>;
            /**
             * reason contains a programmatic identifier indicating the reason for the condition's last transition. Producers of specific condition types may define expected values and meanings for this field, and whether the values are considered a guaranteed API. The value should be a CamelCase string. This field may not be empty.
             * @minLength 1
             * @maxLength 1024
             * @pattern ^[A-Za-z]([A-Za-z0-9_,:]*[A-Za-z0-9_])?$
             */
            reason: z.ZodString;
            /**
             * status of the condition, one of True, False, Unknown.
             */
            status: z.ZodUnion<[z.ZodLiteral<"True">, z.ZodLiteral<"False">, z.ZodLiteral<"Unknown">]>;
            /**
             * type of condition in CamelCase or in foo.example.com/CamelCase. --- Many .condition.type values are consistent across resources like Available, but because arbitrary conditions can be useful (see .node.status.conditions), the ability to deconflict is important. The regex it matches is (dns1123SubdomainFmt/)?(qualifiedNameFmt)
             * @maxLength 316
             */
            type: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            type: string;
            lastTransitionTime: string | null;
            message: string;
            reason: string;
            status: "True" | "False" | "Unknown";
            observedGeneration?: number | undefined;
        }, {
            type: string;
            lastTransitionTime: string | null;
            message: string;
            reason: string;
            status: "True" | "False" | "Unknown";
            observedGeneration?: number | undefined;
        }>, "many">>;
        /**
         * observedGeneration represents the .metadata.generation on which the status was based.
         * @format int64
         */
        observedGeneration: z.ZodOptional<z.ZodNumber>;
    }, "strip", z.ZodTypeAny, {
        observedGeneration?: number | undefined;
        conditions?: {
            type: string;
            lastTransitionTime: string | null;
            message: string;
            reason: string;
            status: "True" | "False" | "Unknown";
            observedGeneration?: number | undefined;
        }[] | undefined;
    }, {
        observedGeneration?: number | undefined;
        conditions?: {
            type: string;
            lastTransitionTime: string | null;
            message: string;
            reason: string;
            status: "True" | "False" | "Unknown";
            observedGeneration?: number | undefined;
        }[] | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    kind: "PGAdmin";
    apiVersion: "postgres-operator.crunchydata.com/v1beta1";
    status?: {
        observedGeneration?: number | undefined;
        conditions?: {
            type: string;
            lastTransitionTime: string | null;
            message: string;
            reason: string;
            status: "True" | "False" | "Unknown";
            observedGeneration?: number | undefined;
        }[] | undefined;
    } | undefined;
    metadata?: {
        name?: string | undefined; /**
         * key is the label key that the selector applies to.
         */
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined; /**
         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
         */
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined; /**
         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
         */
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string; /**
             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
             */
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    } | undefined;
    spec?: {
        dataVolumeClaimSpec: {
            accessModes?: string[] | undefined;
            resources?: {
                requests?: Record<string, string | number> | undefined;
                limits?: Record<string, string | number> | undefined;
            } | undefined;
            selector?: {
                matchExpressions?: {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: Record<string, string> | undefined;
            } | undefined;
            dataSource?: {
                kind: string;
                name: string;
                apiGroup?: string | undefined;
            } | undefined;
            dataSourceRef?: {
                kind: string;
                name: string;
                apiGroup?: string | undefined;
            } | undefined;
            storageClassName?: string | undefined;
            volumeMode?: string | undefined;
            volumeName?: string | undefined;
        };
        resources?: {
            requests?: Record<string, string | number> | undefined;
            limits?: Record<string, string | number> | undefined;
        } | undefined;
        metadata?: {
            annotations?: Record<string, string> | undefined;
            labels?: Record<string, string> | undefined;
        } | undefined;
        tolerations?: {
            key?: string | undefined;
            operator?: string | undefined;
            value?: string | undefined;
            effect?: string | undefined;
            tolerationSeconds?: number | undefined;
        }[] | undefined;
        affinity?: {
            nodeAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                } | undefined;
            } | undefined;
            podAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
            podAntiAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
        } | undefined;
        config?: {
            files?: {
                configMap?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                downwardAPI?: {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                } | undefined;
                secret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                serviceAccountToken?: {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                } | undefined;
            }[] | undefined;
            ldapBindPassword?: {
                key: string;
                name?: string | undefined;
                optional?: boolean | undefined;
            } | undefined;
            settings?: {} | undefined;
        } | undefined;
        image?: string | undefined;
        imagePullPolicy?: "Always" | "Never" | "IfNotPresent" | undefined;
        imagePullSecrets?: {
            name?: string | undefined;
        }[] | undefined;
        priorityClassName?: string | undefined;
        serverGroups?: {
            name: string;
            postgresClusterSelector: {
                matchExpressions?: {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: Record<string, string> | undefined;
            };
        }[] | undefined;
    } | undefined;
}, {
    kind: "PGAdmin";
    apiVersion: "postgres-operator.crunchydata.com/v1beta1";
    status?: {
        observedGeneration?: number | undefined;
        conditions?: {
            type: string;
            lastTransitionTime: string | null;
            message: string;
            reason: string;
            status: "True" | "False" | "Unknown";
            observedGeneration?: number | undefined;
        }[] | undefined;
    } | undefined;
    metadata?: {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined; /**
             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
             */
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined; /**
             * key is the label key that the selector applies to.
             */
            controller?: boolean | undefined;
        }[] | undefined;
    } | undefined;
    spec?: {
        dataVolumeClaimSpec: {
            accessModes?: string[] | undefined;
            resources?: {
                requests?: Record<string, string | number> | undefined;
                limits?: Record<string, string | number> | undefined;
            } | undefined;
            selector?: {
                matchExpressions?: {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: Record<string, string> | undefined;
            } | undefined;
            dataSource?: {
                kind: string;
                name: string;
                apiGroup?: string | undefined;
            } | undefined;
            dataSourceRef?: {
                kind: string;
                name: string;
                apiGroup?: string | undefined;
            } | undefined;
            storageClassName?: string | undefined;
            volumeMode?: string | undefined;
            volumeName?: string | undefined;
        };
        resources?: {
            requests?: Record<string, string | number> | undefined;
            limits?: Record<string, string | number> | undefined;
        } | undefined;
        metadata?: {
            annotations?: Record<string, string> | undefined;
            labels?: Record<string, string> | undefined;
        } | undefined;
        tolerations?: {
            key?: string | undefined;
            operator?: string | undefined;
            value?: string | undefined;
            effect?: string | undefined;
            tolerationSeconds?: number | undefined;
        }[] | undefined;
        affinity?: {
            nodeAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                } | undefined;
            } | undefined;
            podAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
            podAntiAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
        } | undefined;
        config?: {
            files?: {
                configMap?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                downwardAPI?: {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                } | undefined;
                secret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                serviceAccountToken?: {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                } | undefined;
            }[] | undefined;
            ldapBindPassword?: {
                key: string;
                name?: string | undefined;
                optional?: boolean | undefined;
            } | undefined;
            settings?: {} | undefined;
        } | undefined;
        image?: string | undefined;
        imagePullPolicy?: "Always" | "Never" | "IfNotPresent" | undefined;
        imagePullSecrets?: {
            name?: string | undefined;
        }[] | undefined;
        priorityClassName?: string | undefined;
        serverGroups?: {
            name: string;
            postgresClusterSelector: {
                matchExpressions?: {
                    key: string;
                    operator: string;
                    values?: string[] | undefined;
                }[] | undefined;
                matchLabels?: Record<string, string> | undefined;
            };
        }[] | undefined;
    } | undefined;
}>;
