import { z } from "zod";
/**
 * PGUpgrade is the Schema for the pgupgrades API
 */
export declare const IPGUpgradeSchema: z.ZodObject<{
    /**
     * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
     */
    apiVersion: z.ZodLiteral<"postgres-operator.crunchydata.com/v1beta1">;
    /**
     * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
     */
    kind: z.ZodLiteral<"PGUpgrade">;
    metadata: z.ZodOptional<z.ZodObject<{
        annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        creationTimestamp: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        deletionGracePeriodSeconds: z.ZodOptional<z.ZodNumber>;
        deletionTimestamp: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        finalizers: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        generateName: z.ZodOptional<z.ZodString>;
        generation: z.ZodOptional<z.ZodNumber>;
        labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        managedFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
            apiVersion: z.ZodOptional<z.ZodString>;
            fieldsType: z.ZodOptional<z.ZodString>;
            fieldsV1: z.ZodOptional<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
            manager: z.ZodOptional<z.ZodString>; /**
             * A list of node selector requirements by node's labels.
             */
            operation: z.ZodOptional<z.ZodString>;
            subresource: z.ZodOptional<z.ZodString>;
            time: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined; /**
             * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
             */
            subresource?: string | undefined;
            time?: string | null | undefined;
        }, {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }>, "many">>;
        name: z.ZodOptional<z.ZodString>;
        namespace: z.ZodOptional<z.ZodString>;
        ownerReferences: z.ZodOptional<z.ZodArray<z.ZodObject<{
            apiVersion: z.ZodString;
            blockOwnerDeletion: z.ZodOptional<z.ZodBoolean>;
            controller: z.ZodOptional<z.ZodBoolean>;
            kind: z.ZodString;
            name: z.ZodString;
            uid: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string; /**
             * Describes pod affinity scheduling rules (e.g. co-locate this pod in the same node, zone, etc. as some other pod(s)).
             */
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }, {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }>, "many">>;
        resourceVersion: z.ZodOptional<z.ZodString>;
        selfLink: z.ZodOptional<z.ZodString>; /**
         * A label query over a set of resources, in this case pods.
         */
        uid: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name?: string | undefined; /**
         * key is the label key that the selector applies to.
         */
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined; /**
         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
         */
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        /**
         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
         */
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string; /**
             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
             */
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    }, {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined; /**
         * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
         */
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined; /**
             * key is the label key that the selector applies to.
             */
            controller?: boolean | undefined;
        }[] | undefined;
    }>>;
    /**
     * PGUpgradeSpec defines the desired state of PGUpgrade
     */
    spec: z.ZodOptional<z.ZodObject<{
        /**
         * Scheduling constraints of the PGUpgrade pod. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/assign-pod-node
         */
        affinity: z.ZodOptional<z.ZodObject<{
            /**
             * Describes node affinity scheduling rules for the pod.
             */
            nodeAffinity: z.ZodOptional<z.ZodObject<{
                /**
                 * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node matches the corresponding matchExpressions; the node(s) with the highest sum are the most preferred.
                 */
                preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * A node selector term, associated with the corresponding weight.
                     */
                    preference: z.ZodObject<{
                        /**
                         * A list of node selector requirements by node's labels.
                         */
                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * The label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                             */
                            operator: z.ZodString;
                            /**
                             * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                        /**
                         * A list of node selector requirements by node's fields.
                         */
                        matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * The label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                             */
                            operator: z.ZodString;
                            /**
                             * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }>;
                    /**
                     * Weight associated with matching the corresponding nodeSelectorTerm, in the range 1-100.
                     * @format int32
                     */
                    weight: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }, {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }>, "many">>;
                /**
                 * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to an update), the system may or may not try to eventually evict the pod from its node.
                 */
                requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodObject<{
                    /**
                     * Required. A list of node selector terms. The terms are ORed.
                     */
                    nodeSelectorTerms: z.ZodArray<z.ZodObject<{
                        /**
                         * A list of node selector requirements by node's labels.
                         */
                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * The label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                             */
                            operator: z.ZodString;
                            /**
                             * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                        /**
                         * A list of node selector requirements by node's fields.
                         */
                        matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * The label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                             */
                            operator: z.ZodString;
                            /**
                             * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }>, "many">;
                }, "strip", z.ZodTypeAny, {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                }, {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                }>>;
            }, "strip", z.ZodTypeAny, {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                } | undefined;
            }, {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                } | undefined;
            }>>;
            /**
             * Describes pod affinity scheduling rules (e.g. co-locate this pod in the same node, zone, etc. as some other pod(s)).
             */
            podAffinity: z.ZodOptional<z.ZodObject<{
                /**
                 * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                 */
                preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * Required. A pod affinity term, associated with the corresponding weight.
                     */
                    podAffinityTerm: z.ZodObject<{
                        /**
                         * A label query over a set of resources, in this case pods.
                         */
                        labelSelector: z.ZodOptional<z.ZodObject<{
                            /**
                             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                             */
                            matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the label key that the selector applies to.
                                 */
                                key: z.ZodString;
                                /**
                                 * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                 */
                                operator: z.ZodString;
                                /**
                                 * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                 */
                                values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }>, "many">>;
                            /**
                             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                             */
                            matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                        }, "strip", z.ZodTypeAny, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }>>;
                        /**
                         * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                         */
                        namespaceSelector: z.ZodOptional<z.ZodObject<{
                            /**
                             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                             */
                            matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the label key that the selector applies to.
                                 */
                                key: z.ZodString;
                                /**
                                 * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                 */
                                operator: z.ZodString;
                                /**
                                 * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                 */
                                values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }>, "many">>;
                            /**
                             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                             */
                            matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                        }, "strip", z.ZodTypeAny, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }>>;
                        /**
                         * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                         */
                        namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        /**
                         * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                         */
                        topologyKey: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }, {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }>;
                    /**
                     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                     * @format int32
                     */
                    weight: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }, {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }>, "many">>;
                /**
                 * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                 */
                requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * A label query over a set of resources, in this case pods.
                     */
                    labelSelector: z.ZodOptional<z.ZodObject<{
                        /**
                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                         */
                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                             */
                            operator: z.ZodString;
                            /**
                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                        /**
                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                         */
                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    }, "strip", z.ZodTypeAny, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }>>;
                    /**
                     * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                     */
                    namespaceSelector: z.ZodOptional<z.ZodObject<{
                        /**
                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                         */
                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                             */
                            operator: z.ZodString;
                            /**
                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                        /**
                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                         */
                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    }, "strip", z.ZodTypeAny, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }>>;
                    /**
                     * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                     */
                    namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    /**
                     * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                     */
                    topologyKey: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }, {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            }, {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            }>>;
            /**
             * Describes pod anti-affinity scheduling rules (e.g. avoid putting this pod in the same node, zone, etc. as some other pod(s)).
             */
            podAntiAffinity: z.ZodOptional<z.ZodObject<{
                /**
                 * The scheduler will prefer to schedule pods to nodes that satisfy the anti-affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling anti-affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                 */
                preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * Required. A pod affinity term, associated with the corresponding weight.
                     */
                    podAffinityTerm: z.ZodObject<{
                        /**
                         * A label query over a set of resources, in this case pods.
                         */
                        labelSelector: z.ZodOptional<z.ZodObject<{
                            /**
                             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                             */
                            matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the label key that the selector applies to.
                                 */
                                key: z.ZodString;
                                /**
                                 * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                 */
                                operator: z.ZodString;
                                /**
                                 * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                 */
                                values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }>, "many">>;
                            /**
                             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                             */
                            matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                        }, "strip", z.ZodTypeAny, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }>>;
                        /**
                         * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                         */
                        namespaceSelector: z.ZodOptional<z.ZodObject<{
                            /**
                             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                             */
                            matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the label key that the selector applies to.
                                 */
                                key: z.ZodString;
                                /**
                                 * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                 */
                                operator: z.ZodString;
                                /**
                                 * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                 */
                                values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }>, "many">>;
                            /**
                             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                             */
                            matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                        }, "strip", z.ZodTypeAny, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }>>;
                        /**
                         * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                         */
                        namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        /**
                         * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                         */
                        topologyKey: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }, {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }>;
                    /**
                     * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                     * @format int32
                     */
                    weight: z.ZodNumber;
                }, "strip", z.ZodTypeAny, {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }, {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }>, "many">>;
                /**
                 * If the anti-affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the anti-affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                 */
                requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * A label query over a set of resources, in this case pods.
                     */
                    labelSelector: z.ZodOptional<z.ZodObject<{
                        /**
                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                         */
                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                             */
                            operator: z.ZodString;
                            /**
                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                        /**
                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                         */
                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    }, "strip", z.ZodTypeAny, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }>>;
                    /**
                     * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                     */
                    namespaceSelector: z.ZodOptional<z.ZodObject<{
                        /**
                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                         */
                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                             */
                            operator: z.ZodString;
                            /**
                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                        /**
                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                         */
                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    }, "strip", z.ZodTypeAny, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }>>;
                    /**
                     * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                     */
                    namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    /**
                     * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                     */
                    topologyKey: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }, {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            }, {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            nodeAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                } | undefined;
            } | undefined;
            podAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
            podAntiAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
        }, {
            nodeAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                } | undefined;
            } | undefined;
            podAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
            podAntiAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
        }>>;
        /**
         * The major version of PostgreSQL before the upgrade.
         * @minimum 10
         * @maximum 16
         */
        fromPostgresVersion: z.ZodNumber;
        /**
         * The image name to use for major PostgreSQL upgrades.
         */
        image: z.ZodOptional<z.ZodString>;
        /**
         * ImagePullPolicy is used to determine when Kubernetes will attempt to pull (download) container images. More info: https://kubernetes.io/docs/concepts/containers/images/#image-pull-policy
         */
        imagePullPolicy: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"Always">, z.ZodLiteral<"Never">, z.ZodLiteral<"IfNotPresent">]>>;
        /**
         * The image pull secrets used to pull from a private registry. Changing this value causes all running PGUpgrade pods to restart. https://k8s.io/docs/tasks/configure-pod-container/pull-image-private-registry/
         */
        imagePullSecrets: z.ZodOptional<z.ZodArray<z.ZodObject<{
            /**
             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            name?: string | undefined;
        }, {
            name?: string | undefined;
        }>, "many">>;
        /**
         * Metadata contains metadata for custom resources
         */
        metadata: z.ZodOptional<z.ZodObject<{
            annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
            labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            annotations?: Record<string, string> | undefined;
            labels?: Record<string, string> | undefined;
        }, {
            annotations?: Record<string, string> | undefined;
            labels?: Record<string, string> | undefined;
        }>>;
        /**
         * The name of the cluster to be updated
         * @minLength 1
         */
        postgresClusterName: z.ZodString;
        /**
         * Priority class name for the PGUpgrade pod. Changing this value causes PGUpgrade pod to restart. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/pod-priority-preemption/
         */
        priorityClassName: z.ZodOptional<z.ZodString>;
        /**
         * Resource requirements for the PGUpgrade container.
         */
        resources: z.ZodOptional<z.ZodObject<{
            /**
             * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
             */
            limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
            /**
             * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
             */
            requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
        }, "strip", z.ZodTypeAny, {
            requests?: Record<string, string | number> | undefined;
            limits?: Record<string, string | number> | undefined;
        }, {
            requests?: Record<string, string | number> | undefined;
            limits?: Record<string, string | number> | undefined;
        }>>;
        /**
         * The image name to use for PostgreSQL containers after upgrade. When omitted, the value comes from an operator environment variable.
         */
        toPostgresImage: z.ZodOptional<z.ZodString>;
        /**
         * The major version of PostgreSQL to be upgraded to.
         * @minimum 10
         * @maximum 16
         */
        toPostgresVersion: z.ZodNumber;
        /**
         * Tolerations of the PGUpgrade pod. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/taint-and-toleration
         */
        tolerations: z.ZodOptional<z.ZodArray<z.ZodObject<{
            /**
             * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
             */
            effect: z.ZodOptional<z.ZodString>;
            /**
             * Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
             */
            key: z.ZodOptional<z.ZodString>;
            /**
             * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
             */
            operator: z.ZodOptional<z.ZodString>;
            /**
             * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
             * @format int64
             */
            tolerationSeconds: z.ZodOptional<z.ZodNumber>;
            /**
             * Value is the taint value the toleration matches to. If the operator is Exists, the value should be empty, otherwise just a regular string.
             */
            value: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            key?: string | undefined;
            operator?: string | undefined;
            value?: string | undefined;
            effect?: string | undefined;
            tolerationSeconds?: number | undefined;
        }, {
            key?: string | undefined;
            operator?: string | undefined;
            value?: string | undefined;
            effect?: string | undefined;
            tolerationSeconds?: number | undefined;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        fromPostgresVersion: number;
        postgresClusterName: string;
        toPostgresVersion: number;
        resources?: {
            requests?: Record<string, string | number> | undefined;
            limits?: Record<string, string | number> | undefined;
        } | undefined;
        metadata?: {
            annotations?: Record<string, string> | undefined;
            labels?: Record<string, string> | undefined;
        } | undefined;
        tolerations?: {
            key?: string | undefined;
            operator?: string | undefined;
            value?: string | undefined;
            effect?: string | undefined;
            tolerationSeconds?: number | undefined;
        }[] | undefined;
        affinity?: {
            nodeAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                } | undefined;
            } | undefined;
            podAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
            podAntiAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
        } | undefined;
        image?: string | undefined;
        imagePullPolicy?: "Always" | "Never" | "IfNotPresent" | undefined;
        imagePullSecrets?: {
            name?: string | undefined;
        }[] | undefined;
        priorityClassName?: string | undefined;
        toPostgresImage?: string | undefined;
    }, {
        fromPostgresVersion: number;
        postgresClusterName: string;
        toPostgresVersion: number;
        resources?: {
            requests?: Record<string, string | number> | undefined;
            limits?: Record<string, string | number> | undefined;
        } | undefined;
        metadata?: {
            annotations?: Record<string, string> | undefined;
            labels?: Record<string, string> | undefined;
        } | undefined;
        tolerations?: {
            key?: string | undefined;
            operator?: string | undefined;
            value?: string | undefined;
            effect?: string | undefined;
            tolerationSeconds?: number | undefined;
        }[] | undefined;
        affinity?: {
            nodeAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                } | undefined;
            } | undefined;
            podAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
            podAntiAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
        } | undefined;
        image?: string | undefined;
        imagePullPolicy?: "Always" | "Never" | "IfNotPresent" | undefined;
        imagePullSecrets?: {
            name?: string | undefined;
        }[] | undefined;
        priorityClassName?: string | undefined;
        toPostgresImage?: string | undefined;
    }>>;
    /**
     * PGUpgradeStatus defines the observed state of PGUpgrade
     */
    status: z.ZodOptional<z.ZodObject<{
        /**
         * conditions represent the observations of PGUpgrade's current state.
         */
        conditions: z.ZodOptional<z.ZodArray<z.ZodObject<{
            /**
             * lastTransitionTime is the last time the condition transitioned from one status to another. This should be when the underlying condition changed.  If that is not known, then using the time when the API field changed is acceptable.
             * @format date-time
             */
            lastTransitionTime: z.ZodNullable<z.ZodString>;
            /**
             * message is a human readable message indicating details about the transition. This may be an empty string.
             * @maxLength 32768
             */
            message: z.ZodString;
            /**
             * observedGeneration represents the .metadata.generation that the condition was set based upon. For instance, if .metadata.generation is currently 12, but the .status.conditions[x].observedGeneration is 9, the condition is out of date with respect to the current state of the instance.
             * @format int64
             */
            observedGeneration: z.ZodOptional<z.ZodNumber>;
            /**
             * reason contains a programmatic identifier indicating the reason for the condition's last transition. Producers of specific condition types may define expected values and meanings for this field, and whether the values are considered a guaranteed API. The value should be a CamelCase string. This field may not be empty.
             * @minLength 1
             * @maxLength 1024
             * @pattern ^[A-Za-z]([A-Za-z0-9_,:]*[A-Za-z0-9_])?$
             */
            reason: z.ZodString;
            /**
             * status of the condition, one of True, False, Unknown.
             */
            status: z.ZodUnion<[z.ZodLiteral<"True">, z.ZodLiteral<"False">, z.ZodLiteral<"Unknown">]>;
            /**
             * type of condition in CamelCase or in foo.example.com/CamelCase. --- Many .condition.type values are consistent across resources like Available, but because arbitrary conditions can be useful (see .node.status.conditions), the ability to deconflict is important. The regex it matches is (dns1123SubdomainFmt/)?(qualifiedNameFmt)
             * @maxLength 316
             */
            type: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            type: string;
            lastTransitionTime: string | null;
            message: string;
            reason: string;
            status: "True" | "False" | "Unknown";
            observedGeneration?: number | undefined;
        }, {
            type: string;
            lastTransitionTime: string | null;
            message: string;
            reason: string;
            status: "True" | "False" | "Unknown";
            observedGeneration?: number | undefined;
        }>, "many">>;
        /**
         * observedGeneration represents the .metadata.generation on which the status was based.
         * @format int64
         */
        observedGeneration: z.ZodOptional<z.ZodNumber>;
    }, "strip", z.ZodTypeAny, {
        observedGeneration?: number | undefined;
        conditions?: {
            type: string;
            lastTransitionTime: string | null;
            message: string;
            reason: string;
            status: "True" | "False" | "Unknown";
            observedGeneration?: number | undefined;
        }[] | undefined;
    }, {
        observedGeneration?: number | undefined;
        conditions?: {
            type: string;
            lastTransitionTime: string | null;
            message: string;
            reason: string;
            status: "True" | "False" | "Unknown";
            observedGeneration?: number | undefined;
        }[] | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    kind: "PGUpgrade";
    apiVersion: "postgres-operator.crunchydata.com/v1beta1";
    status?: {
        observedGeneration?: number | undefined;
        conditions?: {
            type: string;
            lastTransitionTime: string | null;
            message: string;
            reason: string;
            status: "True" | "False" | "Unknown";
            observedGeneration?: number | undefined;
        }[] | undefined;
    } | undefined;
    metadata?: {
        name?: string | undefined; /**
         * key is the label key that the selector applies to.
         */
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined; /**
         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
         */
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        /**
         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
         */
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string; /**
             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
             */
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    } | undefined;
    spec?: {
        fromPostgresVersion: number;
        postgresClusterName: string;
        toPostgresVersion: number;
        resources?: {
            requests?: Record<string, string | number> | undefined;
            limits?: Record<string, string | number> | undefined;
        } | undefined;
        metadata?: {
            annotations?: Record<string, string> | undefined;
            labels?: Record<string, string> | undefined;
        } | undefined;
        tolerations?: {
            key?: string | undefined;
            operator?: string | undefined;
            value?: string | undefined;
            effect?: string | undefined;
            tolerationSeconds?: number | undefined;
        }[] | undefined;
        affinity?: {
            nodeAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                } | undefined;
            } | undefined;
            podAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
            podAntiAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
        } | undefined;
        image?: string | undefined;
        imagePullPolicy?: "Always" | "Never" | "IfNotPresent" | undefined;
        imagePullSecrets?: {
            name?: string | undefined;
        }[] | undefined;
        priorityClassName?: string | undefined;
        toPostgresImage?: string | undefined;
    } | undefined;
}, {
    kind: "PGUpgrade";
    apiVersion: "postgres-operator.crunchydata.com/v1beta1";
    status?: {
        observedGeneration?: number | undefined;
        conditions?: {
            type: string;
            lastTransitionTime: string | null;
            message: string;
            reason: string;
            status: "True" | "False" | "Unknown";
            observedGeneration?: number | undefined;
        }[] | undefined;
    } | undefined;
    metadata?: {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined; /**
         * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
         */
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined; /**
             * key is the label key that the selector applies to.
             */
            controller?: boolean | undefined;
        }[] | undefined;
    } | undefined;
    spec?: {
        fromPostgresVersion: number;
        postgresClusterName: string;
        toPostgresVersion: number;
        resources?: {
            requests?: Record<string, string | number> | undefined;
            limits?: Record<string, string | number> | undefined;
        } | undefined;
        metadata?: {
            annotations?: Record<string, string> | undefined;
            labels?: Record<string, string> | undefined;
        } | undefined;
        tolerations?: {
            key?: string | undefined;
            operator?: string | undefined;
            value?: string | undefined;
            effect?: string | undefined;
            tolerationSeconds?: number | undefined;
        }[] | undefined;
        affinity?: {
            nodeAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    preference: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    };
                    weight: number;
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    nodeSelectorTerms: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchFields?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                    }[];
                } | undefined;
            } | undefined;
            podAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
            podAntiAffinity?: {
                preferredDuringSchedulingIgnoredDuringExecution?: {
                    weight: number;
                    podAffinityTerm: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    };
                }[] | undefined;
                requiredDuringSchedulingIgnoredDuringExecution?: {
                    topologyKey: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaceSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    namespaces?: string[] | undefined;
                }[] | undefined;
            } | undefined;
        } | undefined;
        image?: string | undefined;
        imagePullPolicy?: "Always" | "Never" | "IfNotPresent" | undefined;
        imagePullSecrets?: {
            name?: string | undefined;
        }[] | undefined;
        priorityClassName?: string | undefined;
        toPostgresImage?: string | undefined;
    } | undefined;
}>;
