import { z } from "zod";
/**
 * PostgresCluster is the Schema for the postgresclusters API
 */
export declare const IPostgresClusterSchema: z.ZodObject<{
    /**
     * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
     */
    apiVersion: z.ZodLiteral<"postgres-operator.crunchydata.com/v1beta1">;
    /**
     * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
     */
    kind: z.ZodLiteral<"PostgresCluster">;
    metadata: z.ZodOptional<z.ZodObject<{
        annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        creationTimestamp: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        deletionGracePeriodSeconds: z.ZodOptional<z.ZodNumber>; /**
         * pgBackRest archive configuration
         */
        deletionTimestamp: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        finalizers: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        generateName: z.ZodOptional<z.ZodString>;
        generation: z.ZodOptional<z.ZodNumber>;
        labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        managedFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
            apiVersion: z.ZodOptional<z.ZodString>;
            fieldsType: z.ZodOptional<z.ZodString>;
            fieldsV1: z.ZodOptional<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
            manager: z.ZodOptional<z.ZodString>;
            operation: z.ZodOptional<z.ZodString>;
            subresource: z.ZodOptional<z.ZodString>;
            time: z.ZodOptional<z.ZodNullable<z.ZodString>>; /**
             * Required: Path is  the relative path name of the file to be created. Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
             */
        }, "strip", z.ZodTypeAny, {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }, {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }>, "many">>;
        name: z.ZodOptional<z.ZodString>;
        namespace: z.ZodOptional<z.ZodString>;
        ownerReferences: z.ZodOptional<z.ZodArray<z.ZodObject<{
            apiVersion: z.ZodString;
            blockOwnerDeletion: z.ZodOptional<z.ZodBoolean>;
            controller: z.ZodOptional<z.ZodBoolean>;
            kind: z.ZodString;
            name: z.ZodString;
            uid: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }, {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined; /**
             * key is the key to project.
             */
        }>, "many">>;
        resourceVersion: z.ZodOptional<z.ZodString>;
        selfLink: z.ZodOptional<z.ZodString>;
        uid: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string; /**
             * expirationSeconds is the requested duration of validity of the service account token. As the token approaches expiration, the kubelet volume plugin will proactively rotate the service account token. The kubelet will start trying to rotate the token if the token is older than 80 percent of its time to live or if the token is older than 24 hours.Defaults to 1 hour and must be at least 10 minutes.
             * @format int64
             */
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    }, {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    }>>;
    /**
     * PostgresClusterSpec defines the desired state of PostgresCluster
     */
    spec: z.ZodOptional<z.ZodObject<{
        /**
         * PostgreSQL backup configuration
         */
        backups: z.ZodObject<{
            /**
             * pgBackRest archive configuration
             */
            pgbackrest: z.ZodObject<{
                /**
                 * Projected volumes containing custom pgBackRest configuration.  These files are mounted under "/etc/pgbackrest/conf.d" alongside any pgBackRest configuration generated by the PostgreSQL Operator: https://pgbackrest.org/configuration.html
                 */
                configuration: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * configMap information about the configMap data to project
                     */
                    configMap: z.ZodOptional<z.ZodObject<{
                        /**
                         * items if unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
                         */
                        items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the key to project.
                             */
                            key: z.ZodString;
                            /**
                             * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                             * @format int32
                             */
                            mode: z.ZodOptional<z.ZodNumber>;
                            /**
                             * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                             */
                            path: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }, {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }>, "many">>;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                         */
                        name: z.ZodOptional<z.ZodString>;
                        /**
                         * optional specify whether the ConfigMap or its keys must be defined
                         */
                        optional: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    }, {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    }>>;
                    /**
                     * downwardAPI information about the downwardAPI data to project
                     */
                    downwardAPI: z.ZodOptional<z.ZodObject<{
                        /**
                         * Items is a list of DownwardAPIVolume file
                         */
                        items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * Required: Selects a field of the pod: only annotations, labels, name and namespace are supported.
                             */
                            fieldRef: z.ZodOptional<z.ZodObject<{
                                /**
                                 * Version of the schema the FieldPath is written in terms of, defaults to "v1".
                                 */
                                apiVersion: z.ZodOptional<z.ZodString>;
                                /**
                                 * Path of the field to select in the specified API version.
                                 */
                                fieldPath: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            }, {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            }>>;
                            /**
                             * Optional: mode bits used to set permissions on this file, must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                             * @format int32
                             */
                            mode: z.ZodOptional<z.ZodNumber>;
                            /**
                             * Required: Path is  the relative path name of the file to be created. Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
                             */
                            path: z.ZodString;
                            /**
                             * Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, requests.cpu and requests.memory) are currently supported.
                             */
                            resourceFieldRef: z.ZodOptional<z.ZodObject<{
                                /**
                                 * Container name: required for volumes, optional for env vars
                                 */
                                containerName: z.ZodOptional<z.ZodString>;
                                /**
                                 * Specifies the output format of the exposed resources, defaults to "1"
                                 * @schema union([z.number(), z.string().regex(/^(\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))(([KMGTPE]i)|[numkMGTPE]|([eE](\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))))?$/)]).optional()
                                 */
                                divisor: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString]>>;
                                /**
                                 * Required: resource to select
                                 */
                                resource: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            }, {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }, {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    }, {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    }>>;
                    /**
                     * secret information about the secret data to project
                     */
                    secret: z.ZodOptional<z.ZodObject<{
                        /**
                         * items if unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
                         */
                        items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the key to project.
                             */
                            key: z.ZodString;
                            /**
                             * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                             * @format int32
                             */
                            mode: z.ZodOptional<z.ZodNumber>;
                            /**
                             * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                             */
                            path: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }, {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }>, "many">>;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                         */
                        name: z.ZodOptional<z.ZodString>;
                        /**
                         * optional field specify whether the Secret or its key must be defined
                         */
                        optional: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    }, {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    }>>;
                    /**
                     * serviceAccountToken is information about the serviceAccountToken data to project
                     */
                    serviceAccountToken: z.ZodOptional<z.ZodObject<{
                        /**
                         * audience is the intended audience of the token. A recipient of a token must identify itself with an identifier specified in the audience of the token, and otherwise should reject the token. The audience defaults to the identifier of the apiserver.
                         */
                        audience: z.ZodOptional<z.ZodString>;
                        /**
                         * expirationSeconds is the requested duration of validity of the service account token. As the token approaches expiration, the kubelet volume plugin will proactively rotate the service account token. The kubelet will start trying to rotate the token if the token is older than 80 percent of its time to live or if the token is older than 24 hours.Defaults to 1 hour and must be at least 10 minutes.
                         * @format int64
                         */
                        expirationSeconds: z.ZodOptional<z.ZodNumber>;
                        /**
                         * path is the path relative to the mount point of the file to project the token into.
                         */
                        path: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    }, {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }, {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }>, "many">>;
                /**
                 * Global pgBackRest configuration settings.  These settings are included in the "global" section of the pgBackRest configuration generated by the PostgreSQL Operator, and then mounted under "/etc/pgbackrest/conf.d": https://pgbackrest.org/configuration.html
                 */
                global: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                /**
                 * The image name to use for pgBackRest containers.  Utilized to run pgBackRest repository hosts and backups. The image may also be set using the RELATED_IMAGE_PGBACKREST environment variable
                 */
                image: z.ZodOptional<z.ZodString>;
                /**
                 * Jobs field allows configuration for all backup jobs
                 */
                jobs: z.ZodOptional<z.ZodObject<{
                    /**
                     * Scheduling constraints of pgBackRest backup Job pods. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/assign-pod-node
                     */
                    affinity: z.ZodOptional<z.ZodObject<{
                        /**
                         * Describes node affinity scheduling rules for the pod.
                         */
                        nodeAffinity: z.ZodOptional<z.ZodObject<{
                            /**
                             * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node matches the corresponding matchExpressions; the node(s) with the highest sum are the most preferred.
                             */
                            preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * A node selector term, associated with the corresponding weight.
                                 */
                                preference: z.ZodObject<{
                                    /**
                                     * A list of node selector requirements by node's labels.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * The label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * A list of node selector requirements by node's fields.
                                     */
                                    matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * The label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }>;
                                /**
                                 * Weight associated with matching the corresponding nodeSelectorTerm, in the range 1-100.
                                 * @format int32
                                 */
                                weight: z.ZodNumber;
                            }, "strip", z.ZodTypeAny, {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }, {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }>, "many">>;
                            /**
                             * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to an update), the system may or may not try to eventually evict the pod from its node.
                             */
                            requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodObject<{
                                /**
                                 * Required. A list of node selector terms. The terms are ORed.
                                 */
                                nodeSelectorTerms: z.ZodArray<z.ZodObject<{
                                    /**
                                     * A list of node selector requirements by node's labels.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * The label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * A list of node selector requirements by node's fields.
                                     */
                                    matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * The label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }>, "many">;
                            }, "strip", z.ZodTypeAny, {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            }, {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        }, {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        }>>;
                        /**
                         * Describes pod affinity scheduling rules (e.g. co-locate this pod in the same node, zone, etc. as some other pod(s)).
                         */
                        podAffinity: z.ZodOptional<z.ZodObject<{
                            /**
                             * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                             */
                            preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * Required. A pod affinity term, associated with the corresponding weight.
                                 */
                                podAffinityTerm: z.ZodObject<{
                                    /**
                                     * A label query over a set of resources, in this case pods.
                                     */
                                    labelSelector: z.ZodOptional<z.ZodObject<{
                                        /**
                                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                         */
                                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                            /**
                                             * key is the label key that the selector applies to.
                                             */
                                            key: z.ZodString;
                                            /**
                                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                             */
                                            operator: z.ZodString;
                                            /**
                                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                             */
                                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                        }, "strip", z.ZodTypeAny, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }>, "many">>;
                                        /**
                                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                         */
                                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                    }, "strip", z.ZodTypeAny, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }>>;
                                    /**
                                     * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                     */
                                    namespaceSelector: z.ZodOptional<z.ZodObject<{
                                        /**
                                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                         */
                                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                            /**
                                             * key is the label key that the selector applies to.
                                             */
                                            key: z.ZodString;
                                            /**
                                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                             */
                                            operator: z.ZodString;
                                            /**
                                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                             */
                                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                        }, "strip", z.ZodTypeAny, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }>, "many">>;
                                        /**
                                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                         */
                                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                    }, "strip", z.ZodTypeAny, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }>>;
                                    /**
                                     * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                     */
                                    namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    /**
                                     * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                     */
                                    topologyKey: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                }, {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                }>;
                                /**
                                 * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                                 * @format int32
                                 */
                                weight: z.ZodNumber;
                            }, "strip", z.ZodTypeAny, {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }, {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }>, "many">>;
                            /**
                             * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                             */
                            requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * A label query over a set of resources, in this case pods.
                                 */
                                labelSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                 */
                                namespaceSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                 */
                                namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                /**
                                 * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                 */
                                topologyKey: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }>, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        }, {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        }>>;
                        /**
                         * Describes pod anti-affinity scheduling rules (e.g. avoid putting this pod in the same node, zone, etc. as some other pod(s)).
                         */
                        podAntiAffinity: z.ZodOptional<z.ZodObject<{
                            /**
                             * The scheduler will prefer to schedule pods to nodes that satisfy the anti-affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling anti-affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                             */
                            preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * Required. A pod affinity term, associated with the corresponding weight.
                                 */
                                podAffinityTerm: z.ZodObject<{
                                    /**
                                     * A label query over a set of resources, in this case pods.
                                     */
                                    labelSelector: z.ZodOptional<z.ZodObject<{
                                        /**
                                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                         */
                                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                            /**
                                             * key is the label key that the selector applies to.
                                             */
                                            key: z.ZodString;
                                            /**
                                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                             */
                                            operator: z.ZodString;
                                            /**
                                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                             */
                                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                        }, "strip", z.ZodTypeAny, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }>, "many">>;
                                        /**
                                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                         */
                                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                    }, "strip", z.ZodTypeAny, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }>>;
                                    /**
                                     * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                     */
                                    namespaceSelector: z.ZodOptional<z.ZodObject<{
                                        /**
                                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                         */
                                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                            /**
                                             * key is the label key that the selector applies to.
                                             */
                                            key: z.ZodString;
                                            /**
                                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                             */
                                            operator: z.ZodString;
                                            /**
                                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                             */
                                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                        }, "strip", z.ZodTypeAny, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }>, "many">>;
                                        /**
                                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                         */
                                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                    }, "strip", z.ZodTypeAny, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }>>;
                                    /**
                                     * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                     */
                                    namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    /**
                                     * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                     */
                                    topologyKey: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                }, {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                }>;
                                /**
                                 * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                                 * @format int32
                                 */
                                weight: z.ZodNumber;
                            }, "strip", z.ZodTypeAny, {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }, {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }>, "many">>;
                            /**
                             * If the anti-affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the anti-affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                             */
                            requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * A label query over a set of resources, in this case pods.
                                 */
                                labelSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                 */
                                namespaceSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                 */
                                namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                /**
                                 * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                 */
                                topologyKey: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }>, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        }, {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    }, {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    }>>;
                    /**
                     * Priority class name for the pgBackRest backup Job pods. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/pod-priority-preemption/
                     */
                    priorityClassName: z.ZodOptional<z.ZodString>;
                    /**
                     * Resource limits for backup jobs. Includes manual, scheduled and replica create backups
                     */
                    resources: z.ZodOptional<z.ZodObject<{
                        /**
                         * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                         */
                        limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                        /**
                         * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                         */
                        requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                    }, "strip", z.ZodTypeAny, {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    }, {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    }>>;
                    /**
                     * Tolerations of pgBackRest backup Job pods. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/taint-and-toleration
                     */
                    tolerations: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
                         */
                        effect: z.ZodOptional<z.ZodString>;
                        /**
                         * Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
                         */
                        key: z.ZodOptional<z.ZodString>;
                        /**
                         * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
                         */
                        operator: z.ZodOptional<z.ZodString>;
                        /**
                         * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
                         * @format int64
                         */
                        tolerationSeconds: z.ZodOptional<z.ZodNumber>;
                        /**
                         * Value is the taint value the toleration matches to. If the operator is Exists, the value should be empty, otherwise just a regular string.
                         */
                        value: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }, {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }>, "many">>;
                    /**
                     * Limit the lifetime of a Job that has finished. More info: https://kubernetes.io/docs/concepts/workloads/controllers/job
                     * @minimum 60
                     * @format int32
                     */
                    ttlSecondsAfterFinished: z.ZodOptional<z.ZodNumber>;
                }, "strip", z.ZodTypeAny, {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    ttlSecondsAfterFinished?: number | undefined;
                }, {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    ttlSecondsAfterFinished?: number | undefined;
                }>>;
                /**
                 * Defines details for manual pgBackRest backup Jobs
                 */
                manual: z.ZodOptional<z.ZodObject<{
                    /**
                     * Command line options to include when running the pgBackRest backup command. https://pgbackrest.org/command.html#command-backup
                     */
                    options: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    /**
                     * The name of the pgBackRest repo to run the backup command against.
                     * @pattern ^repo[1-4]
                     */
                    repoName: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    repoName: string;
                    options?: string[] | undefined;
                }, {
                    repoName: string;
                    options?: string[] | undefined;
                }>>;
                /**
                 * Metadata contains metadata for custom resources
                 */
                metadata: z.ZodOptional<z.ZodObject<{
                    annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                }, "strip", z.ZodTypeAny, {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                }, {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                }>>;
                /**
                 * Defines configuration for a pgBackRest dedicated repository host.  This section is only applicable if at least one "volume" (i.e. PVC-based) repository is defined in the "repos" section, therefore enabling a dedicated repository host Deployment.
                 */
                repoHost: z.ZodOptional<z.ZodObject<{
                    /**
                     * Scheduling constraints of the Dedicated repo host pod. Changing this value causes repo host to restart. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/assign-pod-node
                     */
                    affinity: z.ZodOptional<z.ZodObject<{
                        /**
                         * Describes node affinity scheduling rules for the pod.
                         */
                        nodeAffinity: z.ZodOptional<z.ZodObject<{
                            /**
                             * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node matches the corresponding matchExpressions; the node(s) with the highest sum are the most preferred.
                             */
                            preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * A node selector term, associated with the corresponding weight.
                                 */
                                preference: z.ZodObject<{
                                    /**
                                     * A list of node selector requirements by node's labels.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * The label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * A list of node selector requirements by node's fields.
                                     */
                                    matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * The label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }>;
                                /**
                                 * Weight associated with matching the corresponding nodeSelectorTerm, in the range 1-100.
                                 * @format int32
                                 */
                                weight: z.ZodNumber;
                            }, "strip", z.ZodTypeAny, {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }, {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }>, "many">>;
                            /**
                             * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to an update), the system may or may not try to eventually evict the pod from its node.
                             */
                            requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodObject<{
                                /**
                                 * Required. A list of node selector terms. The terms are ORed.
                                 */
                                nodeSelectorTerms: z.ZodArray<z.ZodObject<{
                                    /**
                                     * A list of node selector requirements by node's labels.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * The label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * A list of node selector requirements by node's fields.
                                     */
                                    matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * The label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }>, "many">;
                            }, "strip", z.ZodTypeAny, {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            }, {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        }, {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        }>>;
                        /**
                         * Describes pod affinity scheduling rules (e.g. co-locate this pod in the same node, zone, etc. as some other pod(s)).
                         */
                        podAffinity: z.ZodOptional<z.ZodObject<{
                            /**
                             * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                             */
                            preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * Required. A pod affinity term, associated with the corresponding weight.
                                 */
                                podAffinityTerm: z.ZodObject<{
                                    /**
                                     * A label query over a set of resources, in this case pods.
                                     */
                                    labelSelector: z.ZodOptional<z.ZodObject<{
                                        /**
                                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                         */
                                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                            /**
                                             * key is the label key that the selector applies to.
                                             */
                                            key: z.ZodString;
                                            /**
                                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                             */
                                            operator: z.ZodString;
                                            /**
                                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                             */
                                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                        }, "strip", z.ZodTypeAny, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }>, "many">>;
                                        /**
                                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                         */
                                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                    }, "strip", z.ZodTypeAny, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }>>;
                                    /**
                                     * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                     */
                                    namespaceSelector: z.ZodOptional<z.ZodObject<{
                                        /**
                                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                         */
                                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                            /**
                                             * key is the label key that the selector applies to.
                                             */
                                            key: z.ZodString;
                                            /**
                                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                             */
                                            operator: z.ZodString;
                                            /**
                                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                             */
                                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                        }, "strip", z.ZodTypeAny, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }>, "many">>;
                                        /**
                                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                         */
                                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                    }, "strip", z.ZodTypeAny, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }>>;
                                    /**
                                     * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                     */
                                    namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    /**
                                     * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                     */
                                    topologyKey: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                }, {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                }>;
                                /**
                                 * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                                 * @format int32
                                 */
                                weight: z.ZodNumber;
                            }, "strip", z.ZodTypeAny, {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }, {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }>, "many">>;
                            /**
                             * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                             */
                            requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * A label query over a set of resources, in this case pods.
                                 */
                                labelSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                 */
                                namespaceSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                 */
                                namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                /**
                                 * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                 */
                                topologyKey: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }>, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        }, {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        }>>;
                        /**
                         * Describes pod anti-affinity scheduling rules (e.g. avoid putting this pod in the same node, zone, etc. as some other pod(s)).
                         */
                        podAntiAffinity: z.ZodOptional<z.ZodObject<{
                            /**
                             * The scheduler will prefer to schedule pods to nodes that satisfy the anti-affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling anti-affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                             */
                            preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * Required. A pod affinity term, associated with the corresponding weight.
                                 */
                                podAffinityTerm: z.ZodObject<{
                                    /**
                                     * A label query over a set of resources, in this case pods.
                                     */
                                    labelSelector: z.ZodOptional<z.ZodObject<{
                                        /**
                                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                         */
                                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                            /**
                                             * key is the label key that the selector applies to.
                                             */
                                            key: z.ZodString;
                                            /**
                                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                             */
                                            operator: z.ZodString;
                                            /**
                                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                             */
                                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                        }, "strip", z.ZodTypeAny, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }>, "many">>;
                                        /**
                                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                         */
                                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                    }, "strip", z.ZodTypeAny, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }>>;
                                    /**
                                     * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                     */
                                    namespaceSelector: z.ZodOptional<z.ZodObject<{
                                        /**
                                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                         */
                                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                            /**
                                             * key is the label key that the selector applies to.
                                             */
                                            key: z.ZodString;
                                            /**
                                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                             */
                                            operator: z.ZodString;
                                            /**
                                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                             */
                                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                        }, "strip", z.ZodTypeAny, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }>, "many">>;
                                        /**
                                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                         */
                                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                    }, "strip", z.ZodTypeAny, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }>>;
                                    /**
                                     * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                     */
                                    namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    /**
                                     * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                     */
                                    topologyKey: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                }, {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                }>;
                                /**
                                 * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                                 * @format int32
                                 */
                                weight: z.ZodNumber;
                            }, "strip", z.ZodTypeAny, {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }, {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }>, "many">>;
                            /**
                             * If the anti-affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the anti-affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                             */
                            requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * A label query over a set of resources, in this case pods.
                                 */
                                labelSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                 */
                                namespaceSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                 */
                                namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                /**
                                 * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                 */
                                topologyKey: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }>, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        }, {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    }, {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    }>>;
                    /**
                     * Priority class name for the pgBackRest repo host pod. Changing this value causes PostgreSQL to restart. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/pod-priority-preemption/
                     */
                    priorityClassName: z.ZodOptional<z.ZodString>;
                    /**
                     * Resource requirements for a pgBackRest repository host
                     */
                    resources: z.ZodOptional<z.ZodObject<{
                        /**
                         * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                         */
                        limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                        /**
                         * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                         */
                        requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                    }, "strip", z.ZodTypeAny, {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    }, {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    }>>;
                    /**
                     * ConfigMap containing custom SSH configuration. Deprecated: Repository hosts use mTLS for encryption, authentication, and authorization.
                     */
                    sshConfigMap: z.ZodOptional<z.ZodObject<{
                        /**
                         * items if unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
                         */
                        items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the key to project.
                             */
                            key: z.ZodString;
                            /**
                             * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                             * @format int32
                             */
                            mode: z.ZodOptional<z.ZodNumber>;
                            /**
                             * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                             */
                            path: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }, {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }>, "many">>;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                         */
                        name: z.ZodOptional<z.ZodString>;
                        /**
                         * optional specify whether the ConfigMap or its keys must be defined
                         */
                        optional: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    }, {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    }>>;
                    /**
                     * Secret containing custom SSH keys. Deprecated: Repository hosts use mTLS for encryption, authentication, and authorization.
                     */
                    sshSecret: z.ZodOptional<z.ZodObject<{
                        /**
                         * items if unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
                         */
                        items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the key to project.
                             */
                            key: z.ZodString;
                            /**
                             * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                             * @format int32
                             */
                            mode: z.ZodOptional<z.ZodNumber>;
                            /**
                             * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                             */
                            path: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }, {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }>, "many">>;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                         */
                        name: z.ZodOptional<z.ZodString>;
                        /**
                         * optional field specify whether the Secret or its key must be defined
                         */
                        optional: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    }, {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    }>>;
                    /**
                     * Tolerations of a PgBackRest repo host pod. Changing this value causes a restart. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/taint-and-toleration
                     */
                    tolerations: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
                         */
                        effect: z.ZodOptional<z.ZodString>;
                        /**
                         * Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
                         */
                        key: z.ZodOptional<z.ZodString>;
                        /**
                         * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
                         */
                        operator: z.ZodOptional<z.ZodString>;
                        /**
                         * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
                         * @format int64
                         */
                        tolerationSeconds: z.ZodOptional<z.ZodNumber>;
                        /**
                         * Value is the taint value the toleration matches to. If the operator is Exists, the value should be empty, otherwise just a regular string.
                         */
                        value: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }, {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }>, "many">>;
                    /**
                     * Topology spread constraints of a Dedicated repo host pod. Changing this value causes the repo host to restart. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-topology-spread-constraints/
                     */
                    topologySpreadConstraints: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * LabelSelector is used to find matching pods. Pods that match this label selector are counted to determine the number of pods in their corresponding topology domain.
                         */
                        labelSelector: z.ZodOptional<z.ZodObject<{
                            /**
                             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                             */
                            matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the label key that the selector applies to.
                                 */
                                key: z.ZodString;
                                /**
                                 * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                 */
                                operator: z.ZodString;
                                /**
                                 * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                 */
                                values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }>, "many">>;
                            /**
                             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                             */
                            matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                        }, "strip", z.ZodTypeAny, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }>>;
                        /**
                         * MaxSkew describes the degree to which pods may be unevenly distributed. When `whenUnsatisfiable=DoNotSchedule`, it is the maximum permitted difference between the number of matching pods in the target topology and the global minimum. The global minimum is the minimum number of matching pods in an eligible domain or zero if the number of eligible domains is less than MinDomains. For example, in a 3-zone cluster, MaxSkew is set to 1, and pods with the same labelSelector spread as 2/2/1: In this case, the global minimum is 1. | zone1 | zone2 | zone3 | |  P P  |  P P  |   P   | - if MaxSkew is 1, incoming pod can only be scheduled to zone3 to become 2/2/2; scheduling it onto zone1(zone2) would make the ActualSkew(3-1) on zone1(zone2) violate MaxSkew(1). - if MaxSkew is 2, incoming pod can be scheduled onto any zone. When `whenUnsatisfiable=ScheduleAnyway`, it is used to give higher precedence to topologies that satisfy it. It's a required field. Default value is 1 and 0 is not allowed.
                         * @format int32
                         */
                        maxSkew: z.ZodNumber;
                        /**
                         * MinDomains indicates a minimum number of eligible domains. When the number of eligible domains with matching topology keys is less than minDomains, Pod Topology Spread treats "global minimum" as 0, and then the calculation of Skew is performed. And when the number of eligible domains with matching topology keys equals or greater than minDomains, this value has no effect on scheduling. As a result, when the number of eligible domains is less than minDomains, scheduler won't schedule more than maxSkew Pods to those domains. If value is nil, the constraint behaves as if MinDomains is equal to 1. Valid values are integers greater than 0. When value is not nil, WhenUnsatisfiable must be DoNotSchedule.
                         *  For example, in a 3-zone cluster, MaxSkew is set to 2, MinDomains is set to 5 and pods with the same labelSelector spread as 2/2/2: | zone1 | zone2 | zone3 | |  P P  |  P P  |  P P  | The number of domains is less than 5(MinDomains), so "global minimum" is treated as 0. In this situation, new pod with the same labelSelector cannot be scheduled, because computed skew will be 3(3 - 0) if new Pod is scheduled to any of the three zones, it will violate MaxSkew.
                         *  This is an alpha field and requires enabling MinDomainsInPodTopologySpread feature gate.
                         * @format int32
                         */
                        minDomains: z.ZodOptional<z.ZodNumber>;
                        /**
                         * TopologyKey is the key of node labels. Nodes that have a label with this key and identical values are considered to be in the same topology. We consider each <key, value> as a "bucket", and try to put balanced number of pods into each bucket. We define a domain as a particular instance of a topology. Also, we define an eligible domain as a domain whose nodes match the node selector. e.g. If TopologyKey is "kubernetes.io/hostname", each Node is a domain of that topology. And, if TopologyKey is "topology.kubernetes.io/zone", each zone is a domain of that topology. It's a required field.
                         */
                        topologyKey: z.ZodString;
                        /**
                         * WhenUnsatisfiable indicates how to deal with a pod if it doesn't satisfy the spread constraint. - DoNotSchedule (default) tells the scheduler not to schedule it. - ScheduleAnyway tells the scheduler to schedule the pod in any location, but giving higher precedence to topologies that would help reduce the skew. A constraint is considered "Unsatisfiable" for an incoming pod if and only if every possible node assignment for that pod would violate "MaxSkew" on some topology. For example, in a 3-zone cluster, MaxSkew is set to 1, and pods with the same labelSelector spread as 3/1/1: | zone1 | zone2 | zone3 | | P P P |   P   |   P   | If WhenUnsatisfiable is set to DoNotSchedule, incoming pod can only be scheduled to zone2(zone3) to become 3/2/1(3/1/2) as ActualSkew(2-1) on zone2(zone3) satisfies MaxSkew(1). In other words, the cluster can still be imbalanced, but scheduler won't make it \*more\* imbalanced. It's a required field.
                         */
                        whenUnsatisfiable: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        topologyKey: string;
                        maxSkew: number;
                        whenUnsatisfiable: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        minDomains?: number | undefined;
                    }, {
                        topologyKey: string;
                        maxSkew: number;
                        whenUnsatisfiable: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        minDomains?: number | undefined;
                    }>, "many">>;
                }, "strip", z.ZodTypeAny, {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    sshConfigMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    sshSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    topologySpreadConstraints?: {
                        topologyKey: string;
                        maxSkew: number;
                        whenUnsatisfiable: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        minDomains?: number | undefined;
                    }[] | undefined;
                }, {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    sshConfigMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    sshSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    topologySpreadConstraints?: {
                        topologyKey: string;
                        maxSkew: number;
                        whenUnsatisfiable: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        minDomains?: number | undefined;
                    }[] | undefined;
                }>>;
                /**
                 * Defines a pgBackRest repository
                 */
                repos: z.ZodArray<z.ZodObject<{
                    /**
                     * Represents a pgBackRest repository that is created using Azure storage
                     */
                    azure: z.ZodOptional<z.ZodObject<{
                        /**
                         * The Azure container utilized for the repository
                         */
                        container: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        container: string;
                    }, {
                        container: string;
                    }>>;
                    /**
                     * Represents a pgBackRest repository that is created using Google Cloud Storage
                     */
                    gcs: z.ZodOptional<z.ZodObject<{
                        /**
                         * The GCS bucket utilized for the repository
                         */
                        bucket: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        bucket: string;
                    }, {
                        bucket: string;
                    }>>;
                    /**
                     * The name of the the repository
                     * @pattern ^repo[1-4]
                     */
                    name: z.ZodString;
                    /**
                     * RepoS3 represents a pgBackRest repository that is created using AWS S3 (or S3-compatible) storage
                     */
                    s3: z.ZodOptional<z.ZodObject<{
                        /**
                         * The S3 bucket utilized for the repository
                         */
                        bucket: z.ZodString;
                        /**
                         * A valid endpoint corresponding to the specified region
                         */
                        endpoint: z.ZodString;
                        /**
                         * The region corresponding to the S3 bucket
                         */
                        region: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    }, {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    }>>;
                    /**
                     * Defines the schedules for the pgBackRest backups Full, Differential and Incremental backup types are supported: https://pgbackrest.org/user-guide.html#concept/backup
                     */
                    schedules: z.ZodOptional<z.ZodObject<{
                        /**
                         * Defines the Cron schedule for a differential pgBackRest backup. Follows the standard Cron schedule syntax: https://k8s.io/docs/concepts/workloads/controllers/cron-jobs/#cron-schedule-syntax
                         * @minLength 6
                         */
                        differential: z.ZodOptional<z.ZodString>;
                        /**
                         * Defines the Cron schedule for a full pgBackRest backup. Follows the standard Cron schedule syntax: https://k8s.io/docs/concepts/workloads/controllers/cron-jobs/#cron-schedule-syntax
                         * @minLength 6
                         */
                        full: z.ZodOptional<z.ZodString>;
                        /**
                         * Defines the Cron schedule for an incremental pgBackRest backup. Follows the standard Cron schedule syntax: https://k8s.io/docs/concepts/workloads/controllers/cron-jobs/#cron-schedule-syntax
                         * @minLength 6
                         */
                        incremental: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    }, {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    }>>;
                    /**
                     * Represents a pgBackRest repository that is created using a PersistentVolumeClaim
                     */
                    volume: z.ZodOptional<z.ZodObject<{
                        /**
                         * Defines a PersistentVolumeClaim spec used to create and/or bind a volume
                         */
                        volumeClaimSpec: z.ZodObject<{
                            /**
                             * accessModes contains the desired access modes the volume should have. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes-1
                             */
                            accessModes: z.ZodArray<z.ZodString, "many">;
                            /**
                             * dataSource field can be used to specify either: \* An existing VolumeSnapshot object (snapshot.storage.k8s.io/VolumeSnapshot) \* An existing PVC (PersistentVolumeClaim) If the provisioner or an external controller can support the specified data source, it will create a new volume based on the contents of the specified data source. If the AnyVolumeDataSource feature gate is enabled, this field will always have the same contents as the DataSourceRef field.
                             */
                            dataSource: z.ZodOptional<z.ZodObject<{
                                /**
                                 * APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
                                 */
                                apiGroup: z.ZodOptional<z.ZodString>;
                                /**
                                 * Kind is the type of resource being referenced
                                 */
                                kind: z.ZodString;
                                /**
                                 * Name is the name of resource being referenced
                                 */
                                name: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            }, {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            }>>;
                            /**
                             * dataSourceRef specifies the object from which to populate the volume with data, if a non-empty volume is desired. This may be any local object from a non-empty API group (non core object) or a PersistentVolumeClaim object. When this field is specified, volume binding will only succeed if the type of the specified object matches some installed volume populator or dynamic provisioner. This field will replace the functionality of the DataSource field and as such if both fields are non-empty, they must have the same value. For backwards compatibility, both fields (DataSource and DataSourceRef) will be set to the same value automatically if one of them is empty and the other is non-empty. There are two important differences between DataSource and DataSourceRef: \* While DataSource only allows two specific types of objects, DataSourceRef allows any non-core object, as well as PersistentVolumeClaim objects. \* While DataSource ignores disallowed values (dropping them), DataSourceRef preserves all values, and generates an error if a disallowed value is specified. (Beta) Using this field requires the AnyVolumeDataSource feature gate to be enabled.
                             */
                            dataSourceRef: z.ZodOptional<z.ZodObject<{
                                /**
                                 * APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
                                 */
                                apiGroup: z.ZodOptional<z.ZodString>;
                                /**
                                 * Kind is the type of resource being referenced
                                 */
                                kind: z.ZodString;
                                /**
                                 * Name is the name of resource being referenced
                                 */
                                name: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            }, {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            }>>;
                            /**
                             * resources represents the minimum resources the volume should have. If RecoverVolumeExpansionFailure feature is enabled users are allowed to specify resource requirements that are lower than previous value but must still be higher than capacity recorded in the status field of the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#resources
                             */
                            resources: z.ZodObject<{
                                /**
                                 * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                                 */
                                limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                                /**
                                 * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                                 */
                                requests: z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>;
                            }, "strip", z.ZodTypeAny, {
                                requests: Record<string, string | number>;
                                limits?: Record<string, string | number> | undefined;
                            }, {
                                requests: Record<string, string | number>;
                                limits?: Record<string, string | number> | undefined;
                            }>;
                            /**
                             * selector is a label query over volumes to consider for binding.
                             */
                            selector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * storageClassName is the name of the StorageClass required by the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#class-1
                             */
                            storageClassName: z.ZodOptional<z.ZodString>;
                            /**
                             * volumeMode defines what type of volume is required by the claim. Value of Filesystem is implied when not included in claim spec.
                             */
                            volumeMode: z.ZodOptional<z.ZodString>;
                            /**
                             * volumeName is the binding reference to the PersistentVolume backing this claim.
                             */
                            volumeName: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            accessModes: string[];
                            resources: {
                                requests: Record<string, string | number>;
                                limits?: Record<string, string | number> | undefined;
                            };
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        }, {
                            accessModes: string[];
                            resources: {
                                requests: Record<string, string | number>;
                                limits?: Record<string, string | number> | undefined;
                            };
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        }>;
                    }, "strip", z.ZodTypeAny, {
                        volumeClaimSpec: {
                            accessModes: string[];
                            resources: {
                                requests: Record<string, string | number>;
                                limits?: Record<string, string | number> | undefined;
                            };
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    }, {
                        volumeClaimSpec: {
                            accessModes: string[];
                            resources: {
                                requests: Record<string, string | number>;
                                limits?: Record<string, string | number> | undefined;
                            };
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes: string[];
                            resources: {
                                requests: Record<string, string | number>;
                                limits?: Record<string, string | number> | undefined;
                            };
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                }, {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes: string[];
                            resources: {
                                requests: Record<string, string | number>;
                                limits?: Record<string, string | number> | undefined;
                            };
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                }>, "many">;
                /**
                 * Defines details for performing an in-place restore using pgBackRest
                 */
                restore: z.ZodOptional<z.ZodObject<{
                    /**
                     * Scheduling constraints of the pgBackRest restore Job. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/assign-pod-node
                     */
                    affinity: z.ZodOptional<z.ZodObject<{
                        /**
                         * Describes node affinity scheduling rules for the pod.
                         */
                        nodeAffinity: z.ZodOptional<z.ZodObject<{
                            /**
                             * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node matches the corresponding matchExpressions; the node(s) with the highest sum are the most preferred.
                             */
                            preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * A node selector term, associated with the corresponding weight.
                                 */
                                preference: z.ZodObject<{
                                    /**
                                     * A list of node selector requirements by node's labels.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * The label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * A list of node selector requirements by node's fields.
                                     */
                                    matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * The label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }>;
                                /**
                                 * Weight associated with matching the corresponding nodeSelectorTerm, in the range 1-100.
                                 * @format int32
                                 */
                                weight: z.ZodNumber;
                            }, "strip", z.ZodTypeAny, {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }, {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }>, "many">>;
                            /**
                             * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to an update), the system may or may not try to eventually evict the pod from its node.
                             */
                            requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodObject<{
                                /**
                                 * Required. A list of node selector terms. The terms are ORed.
                                 */
                                nodeSelectorTerms: z.ZodArray<z.ZodObject<{
                                    /**
                                     * A list of node selector requirements by node's labels.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * The label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * A list of node selector requirements by node's fields.
                                     */
                                    matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * The label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }>, "many">;
                            }, "strip", z.ZodTypeAny, {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            }, {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        }, {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        }>>;
                        /**
                         * Describes pod affinity scheduling rules (e.g. co-locate this pod in the same node, zone, etc. as some other pod(s)).
                         */
                        podAffinity: z.ZodOptional<z.ZodObject<{
                            /**
                             * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                             */
                            preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * Required. A pod affinity term, associated with the corresponding weight.
                                 */
                                podAffinityTerm: z.ZodObject<{
                                    /**
                                     * A label query over a set of resources, in this case pods.
                                     */
                                    labelSelector: z.ZodOptional<z.ZodObject<{
                                        /**
                                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                         */
                                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                            /**
                                             * key is the label key that the selector applies to.
                                             */
                                            key: z.ZodString;
                                            /**
                                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                             */
                                            operator: z.ZodString;
                                            /**
                                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                             */
                                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                        }, "strip", z.ZodTypeAny, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }>, "many">>;
                                        /**
                                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                         */
                                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                    }, "strip", z.ZodTypeAny, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }>>;
                                    /**
                                     * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                     */
                                    namespaceSelector: z.ZodOptional<z.ZodObject<{
                                        /**
                                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                         */
                                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                            /**
                                             * key is the label key that the selector applies to.
                                             */
                                            key: z.ZodString;
                                            /**
                                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                             */
                                            operator: z.ZodString;
                                            /**
                                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                             */
                                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                        }, "strip", z.ZodTypeAny, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }>, "many">>;
                                        /**
                                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                         */
                                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                    }, "strip", z.ZodTypeAny, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }>>;
                                    /**
                                     * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                     */
                                    namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    /**
                                     * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                     */
                                    topologyKey: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                }, {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                }>;
                                /**
                                 * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                                 * @format int32
                                 */
                                weight: z.ZodNumber;
                            }, "strip", z.ZodTypeAny, {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }, {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }>, "many">>;
                            /**
                             * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                             */
                            requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * A label query over a set of resources, in this case pods.
                                 */
                                labelSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                 */
                                namespaceSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                 */
                                namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                /**
                                 * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                 */
                                topologyKey: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }>, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        }, {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        }>>;
                        /**
                         * Describes pod anti-affinity scheduling rules (e.g. avoid putting this pod in the same node, zone, etc. as some other pod(s)).
                         */
                        podAntiAffinity: z.ZodOptional<z.ZodObject<{
                            /**
                             * The scheduler will prefer to schedule pods to nodes that satisfy the anti-affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling anti-affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                             */
                            preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * Required. A pod affinity term, associated with the corresponding weight.
                                 */
                                podAffinityTerm: z.ZodObject<{
                                    /**
                                     * A label query over a set of resources, in this case pods.
                                     */
                                    labelSelector: z.ZodOptional<z.ZodObject<{
                                        /**
                                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                         */
                                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                            /**
                                             * key is the label key that the selector applies to.
                                             */
                                            key: z.ZodString;
                                            /**
                                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                             */
                                            operator: z.ZodString;
                                            /**
                                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                             */
                                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                        }, "strip", z.ZodTypeAny, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }>, "many">>;
                                        /**
                                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                         */
                                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                    }, "strip", z.ZodTypeAny, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }>>;
                                    /**
                                     * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                     */
                                    namespaceSelector: z.ZodOptional<z.ZodObject<{
                                        /**
                                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                         */
                                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                            /**
                                             * key is the label key that the selector applies to.
                                             */
                                            key: z.ZodString;
                                            /**
                                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                             */
                                            operator: z.ZodString;
                                            /**
                                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                             */
                                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                        }, "strip", z.ZodTypeAny, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }, {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }>, "many">>;
                                        /**
                                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                         */
                                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                    }, "strip", z.ZodTypeAny, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }, {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    }>>;
                                    /**
                                     * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                     */
                                    namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    /**
                                     * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                     */
                                    topologyKey: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                }, {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                }>;
                                /**
                                 * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                                 * @format int32
                                 */
                                weight: z.ZodNumber;
                            }, "strip", z.ZodTypeAny, {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }, {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }>, "many">>;
                            /**
                             * If the anti-affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the anti-affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                             */
                            requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * A label query over a set of resources, in this case pods.
                                 */
                                labelSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                 */
                                namespaceSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                 */
                                namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                /**
                                 * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                 */
                                topologyKey: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }>, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        }, {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    }, {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    }>>;
                    /**
                     * The name of an existing PostgresCluster to use as the data source for the new PostgresCluster. Defaults to the name of the PostgresCluster being created if not provided.
                     */
                    clusterName: z.ZodOptional<z.ZodString>;
                    /**
                     * The namespace of the cluster specified as the data source using the clusterName field. Defaults to the namespace of the PostgresCluster being created if not provided.
                     */
                    clusterNamespace: z.ZodOptional<z.ZodString>;
                    /**
                     * Whether or not in-place pgBackRest restores are enabled for this PostgresCluster.
                     */
                    enabled: z.ZodBoolean;
                    /**
                     * Command line options to include when running the pgBackRest restore command. https://pgbackrest.org/command.html#command-restore
                     */
                    options: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    /**
                     * Priority class name for the pgBackRest restore Job pod. Changing this value causes PostgreSQL to restart. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/pod-priority-preemption/
                     */
                    priorityClassName: z.ZodOptional<z.ZodString>;
                    /**
                     * The name of the pgBackRest repo within the source PostgresCluster that contains the backups that should be utilized to perform a pgBackRest restore when initializing the data source for the new PostgresCluster.
                     * @pattern ^repo[1-4]
                     */
                    repoName: z.ZodString;
                    /**
                     * Resource requirements for the pgBackRest restore Job.
                     */
                    resources: z.ZodOptional<z.ZodObject<{
                        /**
                         * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                         */
                        limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                        /**
                         * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                         */
                        requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                    }, "strip", z.ZodTypeAny, {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    }, {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    }>>;
                    /**
                     * Tolerations of the pgBackRest restore Job. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/taint-and-toleration
                     */
                    tolerations: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
                         */
                        effect: z.ZodOptional<z.ZodString>;
                        /**
                         * Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
                         */
                        key: z.ZodOptional<z.ZodString>;
                        /**
                         * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
                         */
                        operator: z.ZodOptional<z.ZodString>;
                        /**
                         * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
                         * @format int64
                         */
                        tolerationSeconds: z.ZodOptional<z.ZodNumber>;
                        /**
                         * Value is the taint value the toleration matches to. If the operator is Exists, the value should be empty, otherwise just a regular string.
                         */
                        value: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }, {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }>, "many">>;
                }, "strip", z.ZodTypeAny, {
                    repoName: string;
                    enabled: boolean;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    options?: string[] | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    clusterName?: string | undefined;
                    clusterNamespace?: string | undefined;
                }, {
                    repoName: string;
                    enabled: boolean;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    options?: string[] | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    clusterName?: string | undefined;
                    clusterNamespace?: string | undefined;
                }>>;
                /**
                 * Configuration for pgBackRest sidecar containers
                 */
                sidecars: z.ZodOptional<z.ZodObject<{
                    /**
                     * Defines the configuration for the pgBackRest sidecar container
                     */
                    pgbackrest: z.ZodOptional<z.ZodObject<{
                        /**
                         * Resource requirements for a sidecar container
                         */
                        resources: z.ZodOptional<z.ZodObject<{
                            /**
                             * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                             */
                            limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                            /**
                             * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                             */
                            requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                        }, "strip", z.ZodTypeAny, {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        }, {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    }, {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    }>>;
                    /**
                     * Defines the configuration for the pgBackRest config sidecar container
                     */
                    pgbackrestConfig: z.ZodOptional<z.ZodObject<{
                        /**
                         * Resource requirements for a sidecar container
                         */
                        resources: z.ZodOptional<z.ZodObject<{
                            /**
                             * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                             */
                            limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                            /**
                             * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                             */
                            requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                        }, "strip", z.ZodTypeAny, {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        }, {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    }, {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    pgbackrest?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                    pgbackrestConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                }, {
                    pgbackrest?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                    pgbackrestConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                repos: {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes: string[];
                            resources: {
                                requests: Record<string, string | number>;
                                limits?: Record<string, string | number> | undefined;
                            };
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                }[];
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                configuration?: {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }[] | undefined;
                sidecars?: {
                    pgbackrest?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                    pgbackrestConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                image?: string | undefined;
                global?: Record<string, string> | undefined;
                jobs?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    ttlSecondsAfterFinished?: number | undefined;
                } | undefined;
                manual?: {
                    repoName: string;
                    options?: string[] | undefined;
                } | undefined;
                repoHost?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    sshConfigMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    sshSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    topologySpreadConstraints?: {
                        topologyKey: string;
                        maxSkew: number;
                        whenUnsatisfiable: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        minDomains?: number | undefined;
                    }[] | undefined;
                } | undefined;
                restore?: {
                    repoName: string;
                    enabled: boolean;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    options?: string[] | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    clusterName?: string | undefined;
                    clusterNamespace?: string | undefined;
                } | undefined;
            }, {
                repos: {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes: string[];
                            resources: {
                                requests: Record<string, string | number>;
                                limits?: Record<string, string | number> | undefined;
                            };
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                }[];
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                configuration?: {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }[] | undefined;
                sidecars?: {
                    pgbackrest?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                    pgbackrestConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                image?: string | undefined;
                global?: Record<string, string> | undefined;
                jobs?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    ttlSecondsAfterFinished?: number | undefined;
                } | undefined;
                manual?: {
                    repoName: string;
                    options?: string[] | undefined;
                } | undefined;
                repoHost?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    sshConfigMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    sshSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    topologySpreadConstraints?: {
                        topologyKey: string;
                        maxSkew: number;
                        whenUnsatisfiable: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        minDomains?: number | undefined;
                    }[] | undefined;
                } | undefined;
                restore?: {
                    repoName: string;
                    enabled: boolean;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    options?: string[] | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    clusterName?: string | undefined;
                    clusterNamespace?: string | undefined;
                } | undefined;
            }>;
        }, "strip", z.ZodTypeAny, {
            pgbackrest: {
                repos: {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes: string[];
                            resources: {
                                requests: Record<string, string | number>;
                                limits?: Record<string, string | number> | undefined;
                            };
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                }[];
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                configuration?: {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }[] | undefined;
                sidecars?: {
                    pgbackrest?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                    pgbackrestConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                image?: string | undefined;
                global?: Record<string, string> | undefined;
                jobs?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    ttlSecondsAfterFinished?: number | undefined;
                } | undefined;
                manual?: {
                    repoName: string;
                    options?: string[] | undefined;
                } | undefined;
                repoHost?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    sshConfigMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    sshSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    topologySpreadConstraints?: {
                        topologyKey: string;
                        maxSkew: number;
                        whenUnsatisfiable: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        minDomains?: number | undefined;
                    }[] | undefined;
                } | undefined;
                restore?: {
                    repoName: string;
                    enabled: boolean;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    options?: string[] | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    clusterName?: string | undefined;
                    clusterNamespace?: string | undefined;
                } | undefined;
            };
        }, {
            pgbackrest: {
                repos: {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes: string[];
                            resources: {
                                requests: Record<string, string | number>;
                                limits?: Record<string, string | number> | undefined;
                            };
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                }[];
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                configuration?: {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }[] | undefined;
                sidecars?: {
                    pgbackrest?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                    pgbackrestConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                image?: string | undefined;
                global?: Record<string, string> | undefined;
                jobs?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    ttlSecondsAfterFinished?: number | undefined;
                } | undefined;
                manual?: {
                    repoName: string;
                    options?: string[] | undefined;
                } | undefined;
                repoHost?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    sshConfigMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    sshSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    topologySpreadConstraints?: {
                        topologyKey: string;
                        maxSkew: number;
                        whenUnsatisfiable: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        minDomains?: number | undefined;
                    }[] | undefined;
                } | undefined;
                restore?: {
                    repoName: string;
                    enabled: boolean;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    options?: string[] | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    clusterName?: string | undefined;
                    clusterNamespace?: string | undefined;
                } | undefined;
            };
        }>;
        config: z.ZodOptional<z.ZodObject<{
            files: z.ZodOptional<z.ZodArray<z.ZodObject<{
                /**
                 * configMap information about the configMap data to project
                 */
                configMap: z.ZodOptional<z.ZodObject<{
                    /**
                     * items if unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
                     */
                    items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * key is the key to project.
                         */
                        key: z.ZodString;
                        /**
                         * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                         * @format int32
                         */
                        mode: z.ZodOptional<z.ZodNumber>;
                        /**
                         * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                         */
                        path: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }, {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }>, "many">>;
                    /**
                     * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                     */
                    name: z.ZodOptional<z.ZodString>;
                    /**
                     * optional specify whether the ConfigMap or its keys must be defined
                     */
                    optional: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                }, {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                }>>;
                /**
                 * downwardAPI information about the downwardAPI data to project
                 */
                downwardAPI: z.ZodOptional<z.ZodObject<{
                    /**
                     * Items is a list of DownwardAPIVolume file
                     */
                    items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * Required: Selects a field of the pod: only annotations, labels, name and namespace are supported.
                         */
                        fieldRef: z.ZodOptional<z.ZodObject<{
                            /**
                             * Version of the schema the FieldPath is written in terms of, defaults to "v1".
                             */
                            apiVersion: z.ZodOptional<z.ZodString>;
                            /**
                             * Path of the field to select in the specified API version.
                             */
                            fieldPath: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        }, {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        }>>;
                        /**
                         * Optional: mode bits used to set permissions on this file, must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                         * @format int32
                         */
                        mode: z.ZodOptional<z.ZodNumber>;
                        /**
                         * Required: Path is  the relative path name of the file to be created. Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
                         */
                        path: z.ZodString;
                        /**
                         * Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, requests.cpu and requests.memory) are currently supported.
                         */
                        resourceFieldRef: z.ZodOptional<z.ZodObject<{
                            /**
                             * Container name: required for volumes, optional for env vars
                             */
                            containerName: z.ZodOptional<z.ZodString>;
                            /**
                             * Specifies the output format of the exposed resources, defaults to "1"
                             * @schema union([z.number(), z.string().regex(/^(\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))(([KMGTPE]i)|[numkMGTPE]|([eE](\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))))?$/)]).optional()
                             */
                            divisor: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString]>>;
                            /**
                             * Required: resource to select
                             */
                            resource: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        }, {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }, {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }>, "many">>;
                }, "strip", z.ZodTypeAny, {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                }, {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                }>>;
                /**
                 * secret information about the secret data to project
                 */
                secret: z.ZodOptional<z.ZodObject<{
                    /**
                     * items if unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
                     */
                    items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * key is the key to project.
                         */
                        key: z.ZodString;
                        /**
                         * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                         * @format int32
                         */
                        mode: z.ZodOptional<z.ZodNumber>;
                        /**
                         * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                         */
                        path: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }, {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }>, "many">>;
                    /**
                     * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                     */
                    name: z.ZodOptional<z.ZodString>;
                    /**
                     * optional field specify whether the Secret or its key must be defined
                     */
                    optional: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                }, {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                }>>;
                /**
                 * serviceAccountToken is information about the serviceAccountToken data to project
                 */
                serviceAccountToken: z.ZodOptional<z.ZodObject<{
                    /**
                     * audience is the intended audience of the token. A recipient of a token must identify itself with an identifier specified in the audience of the token, and otherwise should reject the token. The audience defaults to the identifier of the apiserver.
                     */
                    audience: z.ZodOptional<z.ZodString>;
                    /**
                     * expirationSeconds is the requested duration of validity of the service account token. As the token approaches expiration, the kubelet volume plugin will proactively rotate the service account token. The kubelet will start trying to rotate the token if the token is older than 80 percent of its time to live or if the token is older than 24 hours.Defaults to 1 hour and must be at least 10 minutes.
                     * @format int64
                     */
                    expirationSeconds: z.ZodOptional<z.ZodNumber>;
                    /**
                     * path is the path relative to the mount point of the file to project the token into.
                     */
                    path: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                }, {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                configMap?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                downwardAPI?: {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                } | undefined;
                secret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                serviceAccountToken?: {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                } | undefined;
            }, {
                configMap?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                downwardAPI?: {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                } | undefined;
                secret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                serviceAccountToken?: {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                } | undefined;
            }>, "many">>;
        }, "strip", z.ZodTypeAny, {
            files?: {
                configMap?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                downwardAPI?: {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                } | undefined;
                secret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                serviceAccountToken?: {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                } | undefined;
            }[] | undefined;
        }, {
            files?: {
                configMap?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                downwardAPI?: {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                } | undefined;
                secret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                serviceAccountToken?: {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                } | undefined;
            }[] | undefined;
        }>>;
        /**
         * The secret containing the replication client certificates and keys for secure connections to the PostgreSQL server. It will need to contain the client TLS certificate, TLS key and the Certificate Authority certificate with the data keys set to tls.crt, tls.key and ca.crt, respectively. NOTE: If CustomReplicationClientTLSSecret is provided, CustomTLSSecret MUST be provided and the ca.crt provided must be the same.
         */
        customReplicationTLSSecret: z.ZodOptional<z.ZodObject<{
            /**
             * items if unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
             */
            items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                /**
                 * key is the key to project.
                 */
                key: z.ZodString;
                /**
                 * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                 * @format int32
                 */
                mode: z.ZodOptional<z.ZodNumber>;
                /**
                 * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                 */
                path: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                key: string;
                path: string;
                mode?: number | undefined;
            }, {
                key: string;
                path: string;
                mode?: number | undefined;
            }>, "many">>;
            /**
             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name: z.ZodOptional<z.ZodString>;
            /**
             * optional field specify whether the Secret or its key must be defined
             */
            optional: z.ZodOptional<z.ZodBoolean>;
        }, "strip", z.ZodTypeAny, {
            name?: string | undefined;
            items?: {
                key: string;
                path: string;
                mode?: number | undefined;
            }[] | undefined;
            optional?: boolean | undefined;
        }, {
            name?: string | undefined;
            items?: {
                key: string;
                path: string;
                mode?: number | undefined;
            }[] | undefined;
            optional?: boolean | undefined;
        }>>;
        /**
         * The secret containing the Certificates and Keys to encrypt PostgreSQL traffic will need to contain the server TLS certificate, TLS key and the Certificate Authority certificate with the data keys set to tls.crt, tls.key and ca.crt, respectively. It will then be mounted as a volume projection to the '/pgconf/tls' directory. For more information on Kubernetes secret projections, please see https://k8s.io/docs/concepts/configuration/secret/#projection-of-secret-keys-to-specific-paths NOTE: If CustomTLSSecret is provided, CustomReplicationClientTLSSecret MUST be provided and the ca.crt provided must be the same.
         */
        customTLSSecret: z.ZodOptional<z.ZodObject<{
            /**
             * items if unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
             */
            items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                /**
                 * key is the key to project.
                 */
                key: z.ZodString;
                /**
                 * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                 * @format int32
                 */
                mode: z.ZodOptional<z.ZodNumber>;
                /**
                 * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                 */
                path: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                key: string;
                path: string;
                mode?: number | undefined;
            }, {
                key: string;
                path: string;
                mode?: number | undefined;
            }>, "many">>;
            /**
             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name: z.ZodOptional<z.ZodString>;
            /**
             * optional field specify whether the Secret or its key must be defined
             */
            optional: z.ZodOptional<z.ZodBoolean>;
        }, "strip", z.ZodTypeAny, {
            name?: string | undefined;
            items?: {
                key: string;
                path: string;
                mode?: number | undefined;
            }[] | undefined;
            optional?: boolean | undefined;
        }, {
            name?: string | undefined;
            items?: {
                key: string;
                path: string;
                mode?: number | undefined;
            }[] | undefined;
            optional?: boolean | undefined;
        }>>;
        /**
         * Specifies a data source for bootstrapping the PostgreSQL cluster.
         */
        dataSource: z.ZodOptional<z.ZodObject<{
            /**
             * Defines a pgBackRest cloud-based data source that can be used to pre-populate the the PostgreSQL data directory for a new PostgreSQL cluster using a pgBackRest restore. The PGBackRest field is incompatible with the PostgresCluster field: only one data source can be used for pre-populating a new PostgreSQL cluster
             */
            pgbackrest: z.ZodOptional<z.ZodObject<{
                /**
                 * Scheduling constraints of the pgBackRest restore Job. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/assign-pod-node
                 */
                affinity: z.ZodOptional<z.ZodObject<{
                    /**
                     * Describes node affinity scheduling rules for the pod.
                     */
                    nodeAffinity: z.ZodOptional<z.ZodObject<{
                        /**
                         * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node matches the corresponding matchExpressions; the node(s) with the highest sum are the most preferred.
                         */
                        preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * A node selector term, associated with the corresponding weight.
                             */
                            preference: z.ZodObject<{
                                /**
                                 * A list of node selector requirements by node's labels.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * The label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * A list of node selector requirements by node's fields.
                                 */
                                matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * The label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }>;
                            /**
                             * Weight associated with matching the corresponding nodeSelectorTerm, in the range 1-100.
                             * @format int32
                             */
                            weight: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }, {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }>, "many">>;
                        /**
                         * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to an update), the system may or may not try to eventually evict the pod from its node.
                         */
                        requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodObject<{
                            /**
                             * Required. A list of node selector terms. The terms are ORed.
                             */
                            nodeSelectorTerms: z.ZodArray<z.ZodObject<{
                                /**
                                 * A list of node selector requirements by node's labels.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * The label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * A list of node selector requirements by node's fields.
                                 */
                                matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * The label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        }, {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    }, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    }>>;
                    /**
                     * Describes pod affinity scheduling rules (e.g. co-locate this pod in the same node, zone, etc. as some other pod(s)).
                     */
                    podAffinity: z.ZodOptional<z.ZodObject<{
                        /**
                         * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                         */
                        preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * Required. A pod affinity term, associated with the corresponding weight.
                             */
                            podAffinityTerm: z.ZodObject<{
                                /**
                                 * A label query over a set of resources, in this case pods.
                                 */
                                labelSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                 */
                                namespaceSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                 */
                                namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                /**
                                 * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                 */
                                topologyKey: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }>;
                            /**
                             * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                             * @format int32
                             */
                            weight: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }, {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }>, "many">>;
                        /**
                         * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                         */
                        requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * A label query over a set of resources, in this case pods.
                             */
                            labelSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                             */
                            namespaceSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                             */
                            namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            /**
                             * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                             */
                            topologyKey: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    }, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    }>>;
                    /**
                     * Describes pod anti-affinity scheduling rules (e.g. avoid putting this pod in the same node, zone, etc. as some other pod(s)).
                     */
                    podAntiAffinity: z.ZodOptional<z.ZodObject<{
                        /**
                         * The scheduler will prefer to schedule pods to nodes that satisfy the anti-affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling anti-affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                         */
                        preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * Required. A pod affinity term, associated with the corresponding weight.
                             */
                            podAffinityTerm: z.ZodObject<{
                                /**
                                 * A label query over a set of resources, in this case pods.
                                 */
                                labelSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                 */
                                namespaceSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                 */
                                namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                /**
                                 * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                 */
                                topologyKey: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }>;
                            /**
                             * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                             * @format int32
                             */
                            weight: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }, {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }>, "many">>;
                        /**
                         * If the anti-affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the anti-affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                         */
                        requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * A label query over a set of resources, in this case pods.
                             */
                            labelSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                             */
                            namespaceSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                             */
                            namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            /**
                             * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                             */
                            topologyKey: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    }, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                }, {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                }>>;
                /**
                 * Projected volumes containing custom pgBackRest configuration.  These files are mounted under "/etc/pgbackrest/conf.d" alongside any pgBackRest configuration generated by the PostgreSQL Operator: https://pgbackrest.org/configuration.html
                 */
                configuration: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * configMap information about the configMap data to project
                     */
                    configMap: z.ZodOptional<z.ZodObject<{
                        /**
                         * items if unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
                         */
                        items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the key to project.
                             */
                            key: z.ZodString;
                            /**
                             * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                             * @format int32
                             */
                            mode: z.ZodOptional<z.ZodNumber>;
                            /**
                             * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                             */
                            path: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }, {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }>, "many">>;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                         */
                        name: z.ZodOptional<z.ZodString>;
                        /**
                         * optional specify whether the ConfigMap or its keys must be defined
                         */
                        optional: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    }, {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    }>>;
                    /**
                     * downwardAPI information about the downwardAPI data to project
                     */
                    downwardAPI: z.ZodOptional<z.ZodObject<{
                        /**
                         * Items is a list of DownwardAPIVolume file
                         */
                        items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * Required: Selects a field of the pod: only annotations, labels, name and namespace are supported.
                             */
                            fieldRef: z.ZodOptional<z.ZodObject<{
                                /**
                                 * Version of the schema the FieldPath is written in terms of, defaults to "v1".
                                 */
                                apiVersion: z.ZodOptional<z.ZodString>;
                                /**
                                 * Path of the field to select in the specified API version.
                                 */
                                fieldPath: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            }, {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            }>>;
                            /**
                             * Optional: mode bits used to set permissions on this file, must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                             * @format int32
                             */
                            mode: z.ZodOptional<z.ZodNumber>;
                            /**
                             * Required: Path is  the relative path name of the file to be created. Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
                             */
                            path: z.ZodString;
                            /**
                             * Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, requests.cpu and requests.memory) are currently supported.
                             */
                            resourceFieldRef: z.ZodOptional<z.ZodObject<{
                                /**
                                 * Container name: required for volumes, optional for env vars
                                 */
                                containerName: z.ZodOptional<z.ZodString>;
                                /**
                                 * Specifies the output format of the exposed resources, defaults to "1"
                                 * @schema union([z.number(), z.string().regex(/^(\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))(([KMGTPE]i)|[numkMGTPE]|([eE](\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))))?$/)]).optional()
                                 */
                                divisor: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString]>>;
                                /**
                                 * Required: resource to select
                                 */
                                resource: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            }, {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }, {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    }, {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    }>>;
                    /**
                     * secret information about the secret data to project
                     */
                    secret: z.ZodOptional<z.ZodObject<{
                        /**
                         * items if unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
                         */
                        items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the key to project.
                             */
                            key: z.ZodString;
                            /**
                             * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                             * @format int32
                             */
                            mode: z.ZodOptional<z.ZodNumber>;
                            /**
                             * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                             */
                            path: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }, {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }>, "many">>;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                         */
                        name: z.ZodOptional<z.ZodString>;
                        /**
                         * optional field specify whether the Secret or its key must be defined
                         */
                        optional: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    }, {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    }>>;
                    /**
                     * serviceAccountToken is information about the serviceAccountToken data to project
                     */
                    serviceAccountToken: z.ZodOptional<z.ZodObject<{
                        /**
                         * audience is the intended audience of the token. A recipient of a token must identify itself with an identifier specified in the audience of the token, and otherwise should reject the token. The audience defaults to the identifier of the apiserver.
                         */
                        audience: z.ZodOptional<z.ZodString>;
                        /**
                         * expirationSeconds is the requested duration of validity of the service account token. As the token approaches expiration, the kubelet volume plugin will proactively rotate the service account token. The kubelet will start trying to rotate the token if the token is older than 80 percent of its time to live or if the token is older than 24 hours.Defaults to 1 hour and must be at least 10 minutes.
                         * @format int64
                         */
                        expirationSeconds: z.ZodOptional<z.ZodNumber>;
                        /**
                         * path is the path relative to the mount point of the file to project the token into.
                         */
                        path: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    }, {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }, {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }>, "many">>;
                /**
                 * Global pgBackRest configuration settings.  These settings are included in the "global" section of the pgBackRest configuration generated by the PostgreSQL Operator, and then mounted under "/etc/pgbackrest/conf.d": https://pgbackrest.org/configuration.html
                 */
                global: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                /**
                 * Command line options to include when running the pgBackRest restore command. https://pgbackrest.org/command.html#command-restore
                 */
                options: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                /**
                 * Priority class name for the pgBackRest restore Job pod. Changing this value causes PostgreSQL to restart. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/pod-priority-preemption/
                 */
                priorityClassName: z.ZodOptional<z.ZodString>;
                /**
                 * Defines a pgBackRest repository
                 */
                repo: z.ZodObject<{
                    /**
                     * Represents a pgBackRest repository that is created using Azure storage
                     */
                    azure: z.ZodOptional<z.ZodObject<{
                        /**
                         * The Azure container utilized for the repository
                         */
                        container: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        container: string;
                    }, {
                        container: string;
                    }>>;
                    /**
                     * Represents a pgBackRest repository that is created using Google Cloud Storage
                     */
                    gcs: z.ZodOptional<z.ZodObject<{
                        /**
                         * The GCS bucket utilized for the repository
                         */
                        bucket: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        bucket: string;
                    }, {
                        bucket: string;
                    }>>;
                    /**
                     * The name of the the repository
                     * @pattern ^repo[1-4]
                     */
                    name: z.ZodString;
                    /**
                     * RepoS3 represents a pgBackRest repository that is created using AWS S3 (or S3-compatible) storage
                     */
                    s3: z.ZodOptional<z.ZodObject<{
                        /**
                         * The S3 bucket utilized for the repository
                         */
                        bucket: z.ZodString;
                        /**
                         * A valid endpoint corresponding to the specified region
                         */
                        endpoint: z.ZodString;
                        /**
                         * The region corresponding to the S3 bucket
                         */
                        region: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    }, {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    }>>;
                    /**
                     * Defines the schedules for the pgBackRest backups Full, Differential and Incremental backup types are supported: https://pgbackrest.org/user-guide.html#concept/backup
                     */
                    schedules: z.ZodOptional<z.ZodObject<{
                        /**
                         * Defines the Cron schedule for a differential pgBackRest backup. Follows the standard Cron schedule syntax: https://k8s.io/docs/concepts/workloads/controllers/cron-jobs/#cron-schedule-syntax
                         * @minLength 6
                         */
                        differential: z.ZodOptional<z.ZodString>;
                        /**
                         * Defines the Cron schedule for a full pgBackRest backup. Follows the standard Cron schedule syntax: https://k8s.io/docs/concepts/workloads/controllers/cron-jobs/#cron-schedule-syntax
                         * @minLength 6
                         */
                        full: z.ZodOptional<z.ZodString>;
                        /**
                         * Defines the Cron schedule for an incremental pgBackRest backup. Follows the standard Cron schedule syntax: https://k8s.io/docs/concepts/workloads/controllers/cron-jobs/#cron-schedule-syntax
                         * @minLength 6
                         */
                        incremental: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    }, {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    }>>;
                    /**
                     * Represents a pgBackRest repository that is created using a PersistentVolumeClaim
                     */
                    volume: z.ZodOptional<z.ZodObject<{
                        /**
                         * Defines a PersistentVolumeClaim spec used to create and/or bind a volume
                         */
                        volumeClaimSpec: z.ZodObject<{
                            /**
                             * accessModes contains the desired access modes the volume should have. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes-1
                             */
                            accessModes: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            /**
                             * dataSource field can be used to specify either: \* An existing VolumeSnapshot object (snapshot.storage.k8s.io/VolumeSnapshot) \* An existing PVC (PersistentVolumeClaim) If the provisioner or an external controller can support the specified data source, it will create a new volume based on the contents of the specified data source. If the AnyVolumeDataSource feature gate is enabled, this field will always have the same contents as the DataSourceRef field.
                             */
                            dataSource: z.ZodOptional<z.ZodObject<{
                                /**
                                 * APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
                                 */
                                apiGroup: z.ZodOptional<z.ZodString>;
                                /**
                                 * Kind is the type of resource being referenced
                                 */
                                kind: z.ZodString;
                                /**
                                 * Name is the name of resource being referenced
                                 */
                                name: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            }, {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            }>>;
                            /**
                             * dataSourceRef specifies the object from which to populate the volume with data, if a non-empty volume is desired. This may be any local object from a non-empty API group (non core object) or a PersistentVolumeClaim object. When this field is specified, volume binding will only succeed if the type of the specified object matches some installed volume populator or dynamic provisioner. This field will replace the functionality of the DataSource field and as such if both fields are non-empty, they must have the same value. For backwards compatibility, both fields (DataSource and DataSourceRef) will be set to the same value automatically if one of them is empty and the other is non-empty. There are two important differences between DataSource and DataSourceRef: \* While DataSource only allows two specific types of objects, DataSourceRef allows any non-core object, as well as PersistentVolumeClaim objects. \* While DataSource ignores disallowed values (dropping them), DataSourceRef preserves all values, and generates an error if a disallowed value is specified. (Beta) Using this field requires the AnyVolumeDataSource feature gate to be enabled.
                             */
                            dataSourceRef: z.ZodOptional<z.ZodObject<{
                                /**
                                 * APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
                                 */
                                apiGroup: z.ZodOptional<z.ZodString>;
                                /**
                                 * Kind is the type of resource being referenced
                                 */
                                kind: z.ZodString;
                                /**
                                 * Name is the name of resource being referenced
                                 */
                                name: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            }, {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            }>>;
                            /**
                             * resources represents the minimum resources the volume should have. If RecoverVolumeExpansionFailure feature is enabled users are allowed to specify resource requirements that are lower than previous value but must still be higher than capacity recorded in the status field of the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#resources
                             */
                            resources: z.ZodOptional<z.ZodObject<{
                                /**
                                 * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                                 */
                                limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                                /**
                                 * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                                 */
                                requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                            }, "strip", z.ZodTypeAny, {
                                requests?: Record<string, string | number> | undefined;
                                limits?: Record<string, string | number> | undefined;
                            }, {
                                requests?: Record<string, string | number> | undefined;
                                limits?: Record<string, string | number> | undefined;
                            }>>;
                            /**
                             * selector is a label query over volumes to consider for binding.
                             */
                            selector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * storageClassName is the name of the StorageClass required by the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#class-1
                             */
                            storageClassName: z.ZodOptional<z.ZodString>;
                            /**
                             * volumeMode defines what type of volume is required by the claim. Value of Filesystem is implied when not included in claim spec.
                             */
                            volumeMode: z.ZodOptional<z.ZodString>;
                            /**
                             * volumeName is the binding reference to the PersistentVolume backing this claim.
                             */
                            volumeName: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            accessModes?: string[] | undefined;
                            resources?: {
                                requests?: Record<string, string | number> | undefined;
                                limits?: Record<string, string | number> | undefined;
                            } | undefined;
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        }, {
                            accessModes?: string[] | undefined;
                            resources?: {
                                requests?: Record<string, string | number> | undefined;
                                limits?: Record<string, string | number> | undefined;
                            } | undefined;
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        }>;
                    }, "strip", z.ZodTypeAny, {
                        volumeClaimSpec: {
                            accessModes?: string[] | undefined;
                            resources?: {
                                requests?: Record<string, string | number> | undefined;
                                limits?: Record<string, string | number> | undefined;
                            } | undefined;
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    }, {
                        volumeClaimSpec: {
                            accessModes?: string[] | undefined;
                            resources?: {
                                requests?: Record<string, string | number> | undefined;
                                limits?: Record<string, string | number> | undefined;
                            } | undefined;
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes?: string[] | undefined;
                            resources?: {
                                requests?: Record<string, string | number> | undefined;
                                limits?: Record<string, string | number> | undefined;
                            } | undefined;
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                }, {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes?: string[] | undefined;
                            resources?: {
                                requests?: Record<string, string | number> | undefined;
                                limits?: Record<string, string | number> | undefined;
                            } | undefined;
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                }>;
                /**
                 * Resource requirements for the pgBackRest restore Job.
                 */
                resources: z.ZodOptional<z.ZodObject<{
                    /**
                     * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                     */
                    limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                    /**
                     * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                     */
                    requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                }, "strip", z.ZodTypeAny, {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                }, {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                }>>;
                /**
                 * The name of an existing pgBackRest stanza to use as the data source for the new PostgresCluster. Defaults to `db` if not provided.
                 * @default "db"
                 */
                stanza: z.ZodDefault<z.ZodString>;
                /**
                 * Tolerations of the pgBackRest restore Job. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/taint-and-toleration
                 */
                tolerations: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
                     */
                    effect: z.ZodOptional<z.ZodString>;
                    /**
                     * Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
                     */
                    key: z.ZodOptional<z.ZodString>;
                    /**
                     * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
                     */
                    operator: z.ZodOptional<z.ZodString>;
                    /**
                     * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
                     * @format int64
                     */
                    tolerationSeconds: z.ZodOptional<z.ZodNumber>;
                    /**
                     * Value is the taint value the toleration matches to. If the operator is Exists, the value should be empty, otherwise just a regular string.
                     */
                    value: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }, {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                repo: {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes?: string[] | undefined;
                            resources?: {
                                requests?: Record<string, string | number> | undefined;
                                limits?: Record<string, string | number> | undefined;
                            } | undefined;
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                };
                stanza: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                configuration?: {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }[] | undefined;
                options?: string[] | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                priorityClassName?: string | undefined;
                global?: Record<string, string> | undefined;
            }, {
                repo: {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes?: string[] | undefined;
                            resources?: {
                                requests?: Record<string, string | number> | undefined;
                                limits?: Record<string, string | number> | undefined;
                            } | undefined;
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                };
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                stanza?: string | undefined;
                configuration?: {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }[] | undefined;
                options?: string[] | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                priorityClassName?: string | undefined;
                global?: Record<string, string> | undefined;
            }>>;
            /**
             * Defines a pgBackRest data source that can be used to pre-populate the PostgreSQL data directory for a new PostgreSQL cluster using a pgBackRest restore. The PGBackRest field is incompatible with the PostgresCluster field: only one data source can be used for pre-populating a new PostgreSQL cluster
             */
            postgresCluster: z.ZodOptional<z.ZodObject<{
                /**
                 * Scheduling constraints of the pgBackRest restore Job. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/assign-pod-node
                 */
                affinity: z.ZodOptional<z.ZodObject<{
                    /**
                     * Describes node affinity scheduling rules for the pod.
                     */
                    nodeAffinity: z.ZodOptional<z.ZodObject<{
                        /**
                         * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node matches the corresponding matchExpressions; the node(s) with the highest sum are the most preferred.
                         */
                        preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * A node selector term, associated with the corresponding weight.
                             */
                            preference: z.ZodObject<{
                                /**
                                 * A list of node selector requirements by node's labels.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * The label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * A list of node selector requirements by node's fields.
                                 */
                                matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * The label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }>;
                            /**
                             * Weight associated with matching the corresponding nodeSelectorTerm, in the range 1-100.
                             * @format int32
                             */
                            weight: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }, {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }>, "many">>;
                        /**
                         * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to an update), the system may or may not try to eventually evict the pod from its node.
                         */
                        requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodObject<{
                            /**
                             * Required. A list of node selector terms. The terms are ORed.
                             */
                            nodeSelectorTerms: z.ZodArray<z.ZodObject<{
                                /**
                                 * A list of node selector requirements by node's labels.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * The label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * A list of node selector requirements by node's fields.
                                 */
                                matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * The label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        }, {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    }, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    }>>;
                    /**
                     * Describes pod affinity scheduling rules (e.g. co-locate this pod in the same node, zone, etc. as some other pod(s)).
                     */
                    podAffinity: z.ZodOptional<z.ZodObject<{
                        /**
                         * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                         */
                        preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * Required. A pod affinity term, associated with the corresponding weight.
                             */
                            podAffinityTerm: z.ZodObject<{
                                /**
                                 * A label query over a set of resources, in this case pods.
                                 */
                                labelSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                 */
                                namespaceSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                 */
                                namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                /**
                                 * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                 */
                                topologyKey: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }>;
                            /**
                             * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                             * @format int32
                             */
                            weight: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }, {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }>, "many">>;
                        /**
                         * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                         */
                        requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * A label query over a set of resources, in this case pods.
                             */
                            labelSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                             */
                            namespaceSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                             */
                            namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            /**
                             * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                             */
                            topologyKey: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    }, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    }>>;
                    /**
                     * Describes pod anti-affinity scheduling rules (e.g. avoid putting this pod in the same node, zone, etc. as some other pod(s)).
                     */
                    podAntiAffinity: z.ZodOptional<z.ZodObject<{
                        /**
                         * The scheduler will prefer to schedule pods to nodes that satisfy the anti-affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling anti-affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                         */
                        preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * Required. A pod affinity term, associated with the corresponding weight.
                             */
                            podAffinityTerm: z.ZodObject<{
                                /**
                                 * A label query over a set of resources, in this case pods.
                                 */
                                labelSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                 */
                                namespaceSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                 */
                                namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                /**
                                 * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                 */
                                topologyKey: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }>;
                            /**
                             * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                             * @format int32
                             */
                            weight: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }, {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }>, "many">>;
                        /**
                         * If the anti-affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the anti-affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                         */
                        requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * A label query over a set of resources, in this case pods.
                             */
                            labelSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                             */
                            namespaceSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                             */
                            namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            /**
                             * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                             */
                            topologyKey: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    }, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                }, {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                }>>;
                /**
                 * The name of an existing PostgresCluster to use as the data source for the new PostgresCluster. Defaults to the name of the PostgresCluster being created if not provided.
                 */
                clusterName: z.ZodOptional<z.ZodString>;
                /**
                 * The namespace of the cluster specified as the data source using the clusterName field. Defaults to the namespace of the PostgresCluster being created if not provided.
                 */
                clusterNamespace: z.ZodOptional<z.ZodString>;
                /**
                 * Command line options to include when running the pgBackRest restore command. https://pgbackrest.org/command.html#command-restore
                 */
                options: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                /**
                 * Priority class name for the pgBackRest restore Job pod. Changing this value causes PostgreSQL to restart. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/pod-priority-preemption/
                 */
                priorityClassName: z.ZodOptional<z.ZodString>;
                /**
                 * The name of the pgBackRest repo within the source PostgresCluster that contains the backups that should be utilized to perform a pgBackRest restore when initializing the data source for the new PostgresCluster.
                 * @pattern ^repo[1-4]
                 */
                repoName: z.ZodString;
                /**
                 * Resource requirements for the pgBackRest restore Job.
                 */
                resources: z.ZodOptional<z.ZodObject<{
                    /**
                     * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                     */
                    limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                    /**
                     * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                     */
                    requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                }, "strip", z.ZodTypeAny, {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                }, {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                }>>;
                /**
                 * Tolerations of the pgBackRest restore Job. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/taint-and-toleration
                 */
                tolerations: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
                     */
                    effect: z.ZodOptional<z.ZodString>;
                    /**
                     * Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
                     */
                    key: z.ZodOptional<z.ZodString>;
                    /**
                     * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
                     */
                    operator: z.ZodOptional<z.ZodString>;
                    /**
                     * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
                     * @format int64
                     */
                    tolerationSeconds: z.ZodOptional<z.ZodNumber>;
                    /**
                     * Value is the taint value the toleration matches to. If the operator is Exists, the value should be empty, otherwise just a regular string.
                     */
                    value: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }, {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                repoName: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                options?: string[] | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                priorityClassName?: string | undefined;
                clusterName?: string | undefined;
                clusterNamespace?: string | undefined;
            }, {
                repoName: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                options?: string[] | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                priorityClassName?: string | undefined;
                clusterName?: string | undefined;
                clusterNamespace?: string | undefined;
            }>>;
            /**
             * Defines any existing volumes to reuse for this PostgresCluster.
             */
            volumes: z.ZodOptional<z.ZodObject<{
                /**
                 * Defines the existing pgBackRest repo volume and directory to use in the current PostgresCluster.
                 */
                pgBackRestVolume: z.ZodOptional<z.ZodObject<{
                    /**
                     * The existing directory. When not set, a move Job is not created for the associated volume.
                     */
                    directory: z.ZodOptional<z.ZodString>;
                    /**
                     * The existing PVC name.
                     */
                    pvcName: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    pvcName: string;
                    directory?: string | undefined;
                }, {
                    pvcName: string;
                    directory?: string | undefined;
                }>>;
                /**
                 * Defines the existing pgData volume and directory to use in the current PostgresCluster.
                 */
                pgDataVolume: z.ZodOptional<z.ZodObject<{
                    /**
                     * The existing directory. When not set, a move Job is not created for the associated volume.
                     */
                    directory: z.ZodOptional<z.ZodString>;
                    /**
                     * The existing PVC name.
                     */
                    pvcName: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    pvcName: string;
                    directory?: string | undefined;
                }, {
                    pvcName: string;
                    directory?: string | undefined;
                }>>;
                /**
                 * Defines the existing pg_wal volume and directory to use in the current PostgresCluster. Note that a defined pg_wal volume MUST be accompanied by a pgData volume.
                 */
                pgWALVolume: z.ZodOptional<z.ZodObject<{
                    /**
                     * The existing directory. When not set, a move Job is not created for the associated volume.
                     */
                    directory: z.ZodOptional<z.ZodString>;
                    /**
                     * The existing PVC name.
                     */
                    pvcName: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    pvcName: string;
                    directory?: string | undefined;
                }, {
                    pvcName: string;
                    directory?: string | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                pgBackRestVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
                pgDataVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
                pgWALVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
            }, {
                pgBackRestVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
                pgDataVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
                pgWALVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            pgbackrest?: {
                repo: {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes?: string[] | undefined;
                            resources?: {
                                requests?: Record<string, string | number> | undefined;
                                limits?: Record<string, string | number> | undefined;
                            } | undefined;
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                };
                stanza: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                configuration?: {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }[] | undefined;
                options?: string[] | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                priorityClassName?: string | undefined;
                global?: Record<string, string> | undefined;
            } | undefined;
            postgresCluster?: {
                repoName: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                options?: string[] | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                priorityClassName?: string | undefined;
                clusterName?: string | undefined;
                clusterNamespace?: string | undefined;
            } | undefined;
            volumes?: {
                pgBackRestVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
                pgDataVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
                pgWALVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
            } | undefined;
        }, {
            pgbackrest?: {
                repo: {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes?: string[] | undefined;
                            resources?: {
                                requests?: Record<string, string | number> | undefined;
                                limits?: Record<string, string | number> | undefined;
                            } | undefined;
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                };
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                stanza?: string | undefined;
                configuration?: {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }[] | undefined;
                options?: string[] | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                priorityClassName?: string | undefined;
                global?: Record<string, string> | undefined;
            } | undefined;
            postgresCluster?: {
                repoName: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                options?: string[] | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                priorityClassName?: string | undefined;
                clusterName?: string | undefined;
                clusterNamespace?: string | undefined;
            } | undefined;
            volumes?: {
                pgBackRestVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
                pgDataVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
                pgWALVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
            } | undefined;
        }>>;
        /**
         * DatabaseInitSQL defines a ConfigMap containing custom SQL that will be run after the cluster is initialized. This ConfigMap must be in the same namespace as the cluster.
         */
        databaseInitSQL: z.ZodOptional<z.ZodObject<{
            /**
             * Key is the ConfigMap data key that points to a SQL string
             */
            key: z.ZodString;
            /**
             * Name is the name of a ConfigMap
             */
            name: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            key: string;
            name: string;
        }, {
            key: string;
            name: string;
        }>>;
        /**
         * Whether or not the PostgreSQL cluster should use the defined default scheduling constraints. If the field is unset or false, the default scheduling constraints will be used in addition to any custom constraints provided.
         */
        disableDefaultPodScheduling: z.ZodOptional<z.ZodBoolean>;
        /**
         * The image name to use for PostgreSQL containers. When omitted, the value comes from an operator environment variable. For standard PostgreSQL images, the format is RELATED_IMAGE_POSTGRES_{postgresVersion}, e.g. RELATED_IMAGE_POSTGRES_13. For PostGIS enabled PostgreSQL images, the format is RELATED_IMAGE_POSTGRES_{postgresVersion}_GIS_{postGISVersion}, e.g. RELATED_IMAGE_POSTGRES_13_GIS_3.1.
         */
        image: z.ZodOptional<z.ZodString>;
        /**
         * ImagePullPolicy is used to determine when Kubernetes will attempt to pull (download) container images. More info: https://kubernetes.io/docs/concepts/containers/images/#image-pull-policy
         */
        imagePullPolicy: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"Always">, z.ZodLiteral<"Never">, z.ZodLiteral<"IfNotPresent">]>>;
        /**
         * The image pull secrets used to pull from a private registry Changing this value causes all running pods to restart. https://k8s.io/docs/tasks/configure-pod-container/pull-image-private-registry/
         */
        imagePullSecrets: z.ZodOptional<z.ZodArray<z.ZodObject<{
            /**
             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
             */
            name: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            name?: string | undefined;
        }, {
            name?: string | undefined;
        }>, "many">>;
        /**
         * Specifies one or more sets of PostgreSQL pods that replicate data for this cluster.
         */
        instances: z.ZodArray<z.ZodObject<{
            /**
             * Scheduling constraints of a PostgreSQL pod. Changing this value causes PostgreSQL to restart. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/assign-pod-node
             */
            affinity: z.ZodOptional<z.ZodObject<{
                /**
                 * Describes node affinity scheduling rules for the pod.
                 */
                nodeAffinity: z.ZodOptional<z.ZodObject<{
                    /**
                     * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node matches the corresponding matchExpressions; the node(s) with the highest sum are the most preferred.
                     */
                    preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * A node selector term, associated with the corresponding weight.
                         */
                        preference: z.ZodObject<{
                            /**
                             * A list of node selector requirements by node's labels.
                             */
                            matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * The label key that the selector applies to.
                                 */
                                key: z.ZodString;
                                /**
                                 * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                 */
                                operator: z.ZodString;
                                /**
                                 * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                 */
                                values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }>, "many">>;
                            /**
                             * A list of node selector requirements by node's fields.
                             */
                            matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * The label key that the selector applies to.
                                 */
                                key: z.ZodString;
                                /**
                                 * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                 */
                                operator: z.ZodString;
                                /**
                                 * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                 */
                                values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }>, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        }, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        }>;
                        /**
                         * Weight associated with matching the corresponding nodeSelectorTerm, in the range 1-100.
                         * @format int32
                         */
                        weight: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        preference: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        };
                        weight: number;
                    }, {
                        preference: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        };
                        weight: number;
                    }>, "many">>;
                    /**
                     * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to an update), the system may or may not try to eventually evict the pod from its node.
                     */
                    requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodObject<{
                        /**
                         * Required. A list of node selector terms. The terms are ORed.
                         */
                        nodeSelectorTerms: z.ZodArray<z.ZodObject<{
                            /**
                             * A list of node selector requirements by node's labels.
                             */
                            matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * The label key that the selector applies to.
                                 */
                                key: z.ZodString;
                                /**
                                 * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                 */
                                operator: z.ZodString;
                                /**
                                 * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                 */
                                values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }>, "many">>;
                            /**
                             * A list of node selector requirements by node's fields.
                             */
                            matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * The label key that the selector applies to.
                                 */
                                key: z.ZodString;
                                /**
                                 * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                 */
                                operator: z.ZodString;
                                /**
                                 * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                 */
                                values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }>, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        }, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        }>, "many">;
                    }, "strip", z.ZodTypeAny, {
                        nodeSelectorTerms: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        }[];
                    }, {
                        nodeSelectorTerms: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        }[];
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        preference: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        };
                        weight: number;
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        nodeSelectorTerms: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        }[];
                    } | undefined;
                }, {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        preference: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        };
                        weight: number;
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        nodeSelectorTerms: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        }[];
                    } | undefined;
                }>>;
                /**
                 * Describes pod affinity scheduling rules (e.g. co-locate this pod in the same node, zone, etc. as some other pod(s)).
                 */
                podAffinity: z.ZodOptional<z.ZodObject<{
                    /**
                     * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                     */
                    preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * Required. A pod affinity term, associated with the corresponding weight.
                         */
                        podAffinityTerm: z.ZodObject<{
                            /**
                             * A label query over a set of resources, in this case pods.
                             */
                            labelSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                             */
                            namespaceSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                             */
                            namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            /**
                             * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                             */
                            topologyKey: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }>;
                        /**
                         * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                         * @format int32
                         */
                        weight: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }, {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }>, "many">>;
                    /**
                     * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                     */
                    requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * A label query over a set of resources, in this case pods.
                         */
                        labelSelector: z.ZodOptional<z.ZodObject<{
                            /**
                             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                             */
                            matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the label key that the selector applies to.
                                 */
                                key: z.ZodString;
                                /**
                                 * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                 */
                                operator: z.ZodString;
                                /**
                                 * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                 */
                                values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }>, "many">>;
                            /**
                             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                             */
                            matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                        }, "strip", z.ZodTypeAny, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }>>;
                        /**
                         * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                         */
                        namespaceSelector: z.ZodOptional<z.ZodObject<{
                            /**
                             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                             */
                            matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the label key that the selector applies to.
                                 */
                                key: z.ZodString;
                                /**
                                 * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                 */
                                operator: z.ZodString;
                                /**
                                 * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                 */
                                values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }>, "many">>;
                            /**
                             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                             */
                            matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                        }, "strip", z.ZodTypeAny, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }>>;
                        /**
                         * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                         */
                        namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        /**
                         * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                         */
                        topologyKey: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }, {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }>, "many">>;
                }, "strip", z.ZodTypeAny, {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                }, {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                }>>;
                /**
                 * Describes pod anti-affinity scheduling rules (e.g. avoid putting this pod in the same node, zone, etc. as some other pod(s)).
                 */
                podAntiAffinity: z.ZodOptional<z.ZodObject<{
                    /**
                     * The scheduler will prefer to schedule pods to nodes that satisfy the anti-affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling anti-affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                     */
                    preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * Required. A pod affinity term, associated with the corresponding weight.
                         */
                        podAffinityTerm: z.ZodObject<{
                            /**
                             * A label query over a set of resources, in this case pods.
                             */
                            labelSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                             */
                            namespaceSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                             */
                            namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            /**
                             * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                             */
                            topologyKey: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }>;
                        /**
                         * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                         * @format int32
                         */
                        weight: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }, {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }>, "many">>;
                    /**
                     * If the anti-affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the anti-affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                     */
                    requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * A label query over a set of resources, in this case pods.
                         */
                        labelSelector: z.ZodOptional<z.ZodObject<{
                            /**
                             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                             */
                            matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the label key that the selector applies to.
                                 */
                                key: z.ZodString;
                                /**
                                 * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                 */
                                operator: z.ZodString;
                                /**
                                 * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                 */
                                values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }>, "many">>;
                            /**
                             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                             */
                            matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                        }, "strip", z.ZodTypeAny, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }>>;
                        /**
                         * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                         */
                        namespaceSelector: z.ZodOptional<z.ZodObject<{
                            /**
                             * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                             */
                            matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the label key that the selector applies to.
                                 */
                                key: z.ZodString;
                                /**
                                 * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                 */
                                operator: z.ZodString;
                                /**
                                 * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                 */
                                values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }, {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }>, "many">>;
                            /**
                             * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                             */
                            matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                        }, "strip", z.ZodTypeAny, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }, {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        }>>;
                        /**
                         * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                         */
                        namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        /**
                         * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                         */
                        topologyKey: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }, {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }>, "many">>;
                }, "strip", z.ZodTypeAny, {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                }, {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                nodeAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        preference: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        };
                        weight: number;
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        nodeSelectorTerms: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        }[];
                    } | undefined;
                } | undefined;
                podAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                } | undefined;
                podAntiAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                } | undefined;
            }, {
                nodeAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        preference: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        };
                        weight: number;
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        nodeSelectorTerms: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        }[];
                    } | undefined;
                } | undefined;
                podAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                } | undefined;
                podAntiAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                } | undefined;
            }>>;
            /**
             * Custom sidecars for PostgreSQL instance pods. Changing this value causes PostgreSQL to restart.
             */
            containers: z.ZodOptional<z.ZodArray<z.ZodObject<{
                /**
                 * Arguments to the entrypoint. The container image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell
                 */
                args: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                /**
                 * Entrypoint array. Not executed within a shell. The container image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell
                 */
                command: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                /**
                 * List of environment variables to set in the container. Cannot be updated.
                 */
                env: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * Name of the environment variable. Must be a C_IDENTIFIER.
                     */
                    name: z.ZodString;
                    /**
                     * Variable references $(VAR_NAME) are expanded using the previously defined environment variables in the container and any service environment variables. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
                     */
                    value: z.ZodOptional<z.ZodString>;
                    /**
                     * Source for the environment variable's value. Cannot be used if value is not empty.
                     */
                    valueFrom: z.ZodOptional<z.ZodObject<{
                        /**
                         * Selects a key of a ConfigMap.
                         */
                        configMapKeyRef: z.ZodOptional<z.ZodObject<{
                            /**
                             * The key to select.
                             */
                            key: z.ZodString;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                             */
                            name: z.ZodOptional<z.ZodString>;
                            /**
                             * Specify whether the ConfigMap or its key must be defined
                             */
                            optional: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        }, {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        }>>;
                        /**
                         * Selects a field of the pod: supports metadata.name, metadata.namespace, `metadata.labels['<KEY>']`, `metadata.annotations['<KEY>']`, spec.nodeName, spec.serviceAccountName, status.hostIP, status.podIP, status.podIPs.
                         */
                        fieldRef: z.ZodOptional<z.ZodObject<{
                            /**
                             * Version of the schema the FieldPath is written in terms of, defaults to "v1".
                             */
                            apiVersion: z.ZodOptional<z.ZodString>;
                            /**
                             * Path of the field to select in the specified API version.
                             */
                            fieldPath: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        }, {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        }>>;
                        /**
                         * Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, limits.ephemeral-storage, requests.cpu, requests.memory and requests.ephemeral-storage) are currently supported.
                         */
                        resourceFieldRef: z.ZodOptional<z.ZodObject<{
                            /**
                             * Container name: required for volumes, optional for env vars
                             */
                            containerName: z.ZodOptional<z.ZodString>;
                            /**
                             * Specifies the output format of the exposed resources, defaults to "1"
                             * @schema union([z.number(), z.string().regex(/^(\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))(([KMGTPE]i)|[numkMGTPE]|([eE](\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))))?$/)]).optional()
                             */
                            divisor: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString]>>;
                            /**
                             * Required: resource to select
                             */
                            resource: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        }, {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        }>>;
                        /**
                         * Selects a key of a secret in the pod's namespace
                         */
                        secretKeyRef: z.ZodOptional<z.ZodObject<{
                            /**
                             * The key of the secret to select from.  Must be a valid secret key.
                             */
                            key: z.ZodString;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                             */
                            name: z.ZodOptional<z.ZodString>;
                            /**
                             * Specify whether the Secret or its key must be defined
                             */
                            optional: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        }, {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                        configMapKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        secretKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    }, {
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                        configMapKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        secretKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    name: string;
                    value?: string | undefined;
                    valueFrom?: {
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                        configMapKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        secretKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    } | undefined;
                }, {
                    name: string;
                    value?: string | undefined;
                    valueFrom?: {
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                        configMapKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        secretKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    } | undefined;
                }>, "many">>;
                /**
                 * List of sources to populate environment variables in the container. The keys defined within a source must be a C_IDENTIFIER. All invalid keys will be reported as an event when the container is starting. When a key exists in multiple sources, the value associated with the last source will take precedence. Values defined by an Env with a duplicate key will take precedence. Cannot be updated.
                 */
                envFrom: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * The ConfigMap to select from
                     */
                    configMapRef: z.ZodOptional<z.ZodObject<{
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                         */
                        name: z.ZodOptional<z.ZodString>;
                        /**
                         * Specify whether the ConfigMap must be defined
                         */
                        optional: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    }, {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    }>>;
                    /**
                     * An optional identifier to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER.
                     */
                    prefix: z.ZodOptional<z.ZodString>;
                    /**
                     * The Secret to select from
                     */
                    secretRef: z.ZodOptional<z.ZodObject<{
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                         */
                        name: z.ZodOptional<z.ZodString>;
                        /**
                         * Specify whether the Secret must be defined
                         */
                        optional: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    }, {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    configMapRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    prefix?: string | undefined;
                    secretRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                }, {
                    configMapRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    prefix?: string | undefined;
                    secretRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                }>, "many">>;
                /**
                 * Container image name. More info: https://kubernetes.io/docs/concepts/containers/images This field is optional to allow higher level config management to default or override container images in workload controllers like Deployments and StatefulSets.
                 */
                image: z.ZodOptional<z.ZodString>;
                /**
                 * Image pull policy. One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: https://kubernetes.io/docs/concepts/containers/images#updating-images
                 */
                imagePullPolicy: z.ZodOptional<z.ZodString>;
                /**
                 * Actions that the management system should take in response to container lifecycle events. Cannot be updated.
                 */
                lifecycle: z.ZodOptional<z.ZodObject<{
                    /**
                     * PostStart is called immediately after a container is created. If the handler fails, the container is terminated and restarted according to its restart policy. Other management of the container blocks until the hook completes. More info: https://kubernetes.io/docs/concepts/containers/container-lifecycle-hooks/#container-hooks
                     */
                    postStart: z.ZodOptional<z.ZodObject<{
                        /**
                         * Exec specifies the action to take.
                         */
                        exec: z.ZodOptional<z.ZodObject<{
                            /**
                             * Command is the command line to execute inside the container, the working directory for the command  is root ('/') in the container's filesystem. The command is simply exec'd, it is not run inside a shell, so traditional shell instructions ('|', etc) won't work. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
                             */
                            command: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            command?: string[] | undefined;
                        }, {
                            command?: string[] | undefined;
                        }>>;
                        /**
                         * HTTPGet specifies the http request to perform.
                         */
                        httpGet: z.ZodOptional<z.ZodObject<{
                            /**
                             * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
                             */
                            host: z.ZodOptional<z.ZodString>;
                            /**
                             * Custom headers to set in the request. HTTP allows repeated headers.
                             */
                            httpHeaders: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * The header field name
                                 */
                                name: z.ZodString;
                                /**
                                 * The header field value
                                 */
                                value: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                name: string;
                                value: string;
                            }, {
                                name: string;
                                value: string;
                            }>, "many">>;
                            /**
                             * Path to access on the HTTP server.
                             */
                            path: z.ZodOptional<z.ZodString>;
                            /**
                             * Name or number of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                             */
                            port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                            /**
                             * Scheme to use for connecting to the host. Defaults to HTTP.
                             */
                            scheme: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        }, {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        }>>;
                        /**
                         * Deprecated. TCPSocket is NOT supported as a LifecycleHandler and kept for the backward compatibility. There are no validation of this field and lifecycle hooks will fail in runtime when tcp handler is specified.
                         */
                        tcpSocket: z.ZodOptional<z.ZodObject<{
                            /**
                             * Optional: Host name to connect to, defaults to the pod IP.
                             */
                            host: z.ZodOptional<z.ZodString>;
                            /**
                             * Number or name of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                             */
                            port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                        }, "strip", z.ZodTypeAny, {
                            port: string | number;
                            host?: string | undefined;
                        }, {
                            port: string | number;
                            host?: string | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    }, {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    }>>;
                    /**
                     * PreStop is called immediately before a container is terminated due to an API request or management event such as liveness/startup probe failure, preemption, resource contention, etc. The handler is not called if the container crashes or exits. The Pod's termination grace period countdown begins before the PreStop hook is executed. Regardless of the outcome of the handler, the container will eventually terminate within the Pod's termination grace period (unless delayed by finalizers). Other management of the container blocks until the hook completes or until the termination grace period is reached. More info: https://kubernetes.io/docs/concepts/containers/container-lifecycle-hooks/#container-hooks
                     */
                    preStop: z.ZodOptional<z.ZodObject<{
                        /**
                         * Exec specifies the action to take.
                         */
                        exec: z.ZodOptional<z.ZodObject<{
                            /**
                             * Command is the command line to execute inside the container, the working directory for the command  is root ('/') in the container's filesystem. The command is simply exec'd, it is not run inside a shell, so traditional shell instructions ('|', etc) won't work. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
                             */
                            command: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            command?: string[] | undefined;
                        }, {
                            command?: string[] | undefined;
                        }>>;
                        /**
                         * HTTPGet specifies the http request to perform.
                         */
                        httpGet: z.ZodOptional<z.ZodObject<{
                            /**
                             * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
                             */
                            host: z.ZodOptional<z.ZodString>;
                            /**
                             * Custom headers to set in the request. HTTP allows repeated headers.
                             */
                            httpHeaders: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * The header field name
                                 */
                                name: z.ZodString;
                                /**
                                 * The header field value
                                 */
                                value: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                name: string;
                                value: string;
                            }, {
                                name: string;
                                value: string;
                            }>, "many">>;
                            /**
                             * Path to access on the HTTP server.
                             */
                            path: z.ZodOptional<z.ZodString>;
                            /**
                             * Name or number of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                             */
                            port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                            /**
                             * Scheme to use for connecting to the host. Defaults to HTTP.
                             */
                            scheme: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        }, {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        }>>;
                        /**
                         * Deprecated. TCPSocket is NOT supported as a LifecycleHandler and kept for the backward compatibility. There are no validation of this field and lifecycle hooks will fail in runtime when tcp handler is specified.
                         */
                        tcpSocket: z.ZodOptional<z.ZodObject<{
                            /**
                             * Optional: Host name to connect to, defaults to the pod IP.
                             */
                            host: z.ZodOptional<z.ZodString>;
                            /**
                             * Number or name of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                             */
                            port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                        }, "strip", z.ZodTypeAny, {
                            port: string | number;
                            host?: string | undefined;
                        }, {
                            port: string | number;
                            host?: string | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    }, {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    postStart?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                    preStop?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                }, {
                    postStart?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                    preStop?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                }>>;
                /**
                 * Periodic probe of container liveness. Container will be restarted if the probe fails. Cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
                 */
                livenessProbe: z.ZodOptional<z.ZodObject<{
                    /**
                     * Exec specifies the action to take.
                     */
                    exec: z.ZodOptional<z.ZodObject<{
                        /**
                         * Command is the command line to execute inside the container, the working directory for the command  is root ('/') in the container's filesystem. The command is simply exec'd, it is not run inside a shell, so traditional shell instructions ('|', etc) won't work. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
                         */
                        command: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        command?: string[] | undefined;
                    }, {
                        command?: string[] | undefined;
                    }>>;
                    /**
                     * Minimum consecutive failures for the probe to be considered failed after having succeeded. Defaults to 3. Minimum value is 1.
                     * @format int32
                     */
                    failureThreshold: z.ZodOptional<z.ZodNumber>;
                    /**
                     * GRPC specifies an action involving a GRPC port. This is a beta field and requires enabling GRPCContainerProbe feature gate.
                     */
                    grpc: z.ZodOptional<z.ZodObject<{
                        /**
                         * Port number of the gRPC service. Number must be in the range 1 to 65535.
                         * @format int32
                         */
                        port: z.ZodNumber;
                        /**
                         * Service is the name of the service to place in the gRPC HealthCheckRequest (see https://github.com/grpc/grpc/blob/master/doc/health-checking.md).
                         *  If this is not specified, the default behavior is defined by gRPC.
                         */
                        service: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        port: number;
                        service?: string | undefined;
                    }, {
                        port: number;
                        service?: string | undefined;
                    }>>;
                    /**
                     * HTTPGet specifies the http request to perform.
                     */
                    httpGet: z.ZodOptional<z.ZodObject<{
                        /**
                         * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
                         */
                        host: z.ZodOptional<z.ZodString>;
                        /**
                         * Custom headers to set in the request. HTTP allows repeated headers.
                         */
                        httpHeaders: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * The header field name
                             */
                            name: z.ZodString;
                            /**
                             * The header field value
                             */
                            value: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            name: string;
                            value: string;
                        }, {
                            name: string;
                            value: string;
                        }>, "many">>;
                        /**
                         * Path to access on the HTTP server.
                         */
                        path: z.ZodOptional<z.ZodString>;
                        /**
                         * Name or number of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                         */
                        port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                        /**
                         * Scheme to use for connecting to the host. Defaults to HTTP.
                         */
                        scheme: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    }, {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    }>>;
                    /**
                     * Number of seconds after the container has started before liveness probes are initiated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
                     * @format int32
                     */
                    initialDelaySeconds: z.ZodOptional<z.ZodNumber>;
                    /**
                     * How often (in seconds) to perform the probe. Default to 10 seconds. Minimum value is 1.
                     * @format int32
                     */
                    periodSeconds: z.ZodOptional<z.ZodNumber>;
                    /**
                     * Minimum consecutive successes for the probe to be considered successful after having failed. Defaults to 1. Must be 1 for liveness and startup. Minimum value is 1.
                     * @format int32
                     */
                    successThreshold: z.ZodOptional<z.ZodNumber>;
                    /**
                     * TCPSocket specifies an action involving a TCP port.
                     */
                    tcpSocket: z.ZodOptional<z.ZodObject<{
                        /**
                         * Optional: Host name to connect to, defaults to the pod IP.
                         */
                        host: z.ZodOptional<z.ZodString>;
                        /**
                         * Number or name of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                         */
                        port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                    }, "strip", z.ZodTypeAny, {
                        port: string | number;
                        host?: string | undefined;
                    }, {
                        port: string | number;
                        host?: string | undefined;
                    }>>;
                    /**
                     * Optional duration in seconds the pod needs to terminate gracefully upon probe failure. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process. If this value is nil, the pod's terminationGracePeriodSeconds will be used. Otherwise, this value overrides the value provided by the pod spec. Value must be non-negative integer. The value zero indicates stop immediately via the kill signal (no opportunity to shut down). This is a beta field and requires enabling ProbeTerminationGracePeriod feature gate. Minimum value is 1. spec.terminationGracePeriodSeconds is used if unset.
                     * @format int64
                     */
                    terminationGracePeriodSeconds: z.ZodOptional<z.ZodNumber>;
                    /**
                     * Number of seconds after which the probe times out. Defaults to 1 second. Minimum value is 1. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
                     * @format int32
                     */
                    timeoutSeconds: z.ZodOptional<z.ZodNumber>;
                }, "strip", z.ZodTypeAny, {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                }, {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                }>>;
                /**
                 * Name of the container specified as a DNS_LABEL. Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
                 */
                name: z.ZodString;
                /**
                 * List of ports to expose from the container. Exposing a port here gives the system additional information about the network connections a container uses, but is primarily informational. Not specifying a port here DOES NOT prevent that port from being exposed. Any port which is listening on the default "0.0.0.0" address inside a container will be accessible from the network. Cannot be updated.
                 */
                ports: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * Number of port to expose on the pod's IP address. This must be a valid port number, 0 < x < 65536.
                     * @format int32
                     */
                    containerPort: z.ZodNumber;
                    /**
                     * What host IP to bind the external port to.
                     */
                    hostIP: z.ZodOptional<z.ZodString>;
                    /**
                     * Number of port to expose on the host. If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
                     * @format int32
                     */
                    hostPort: z.ZodOptional<z.ZodNumber>;
                    /**
                     * If specified, this must be an IANA_SVC_NAME and unique within the pod. Each named port in a pod must have a unique name. Name for the port that can be referred to by services.
                     */
                    name: z.ZodOptional<z.ZodString>;
                    /**
                     * Protocol for port. Must be UDP, TCP, or SCTP. Defaults to "TCP".
                     * @default "TCP"
                     */
                    protocol: z.ZodDefault<z.ZodOptional<z.ZodString>>;
                }, "strip", z.ZodTypeAny, {
                    containerPort: number;
                    protocol: string;
                    name?: string | undefined;
                    hostIP?: string | undefined;
                    hostPort?: number | undefined;
                }, {
                    containerPort: number;
                    name?: string | undefined;
                    hostIP?: string | undefined;
                    hostPort?: number | undefined;
                    protocol?: string | undefined;
                }>, "many">>;
                /**
                 * Periodic probe of container service readiness. Container will be removed from service endpoints if the probe fails. Cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
                 */
                readinessProbe: z.ZodOptional<z.ZodObject<{
                    /**
                     * Exec specifies the action to take.
                     */
                    exec: z.ZodOptional<z.ZodObject<{
                        /**
                         * Command is the command line to execute inside the container, the working directory for the command  is root ('/') in the container's filesystem. The command is simply exec'd, it is not run inside a shell, so traditional shell instructions ('|', etc) won't work. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
                         */
                        command: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        command?: string[] | undefined;
                    }, {
                        command?: string[] | undefined;
                    }>>;
                    /**
                     * Minimum consecutive failures for the probe to be considered failed after having succeeded. Defaults to 3. Minimum value is 1.
                     * @format int32
                     */
                    failureThreshold: z.ZodOptional<z.ZodNumber>;
                    /**
                     * GRPC specifies an action involving a GRPC port. This is a beta field and requires enabling GRPCContainerProbe feature gate.
                     */
                    grpc: z.ZodOptional<z.ZodObject<{
                        /**
                         * Port number of the gRPC service. Number must be in the range 1 to 65535.
                         * @format int32
                         */
                        port: z.ZodNumber;
                        /**
                         * Service is the name of the service to place in the gRPC HealthCheckRequest (see https://github.com/grpc/grpc/blob/master/doc/health-checking.md).
                         *  If this is not specified, the default behavior is defined by gRPC.
                         */
                        service: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        port: number;
                        service?: string | undefined;
                    }, {
                        port: number;
                        service?: string | undefined;
                    }>>;
                    /**
                     * HTTPGet specifies the http request to perform.
                     */
                    httpGet: z.ZodOptional<z.ZodObject<{
                        /**
                         * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
                         */
                        host: z.ZodOptional<z.ZodString>;
                        /**
                         * Custom headers to set in the request. HTTP allows repeated headers.
                         */
                        httpHeaders: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * The header field name
                             */
                            name: z.ZodString;
                            /**
                             * The header field value
                             */
                            value: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            name: string;
                            value: string;
                        }, {
                            name: string;
                            value: string;
                        }>, "many">>;
                        /**
                         * Path to access on the HTTP server.
                         */
                        path: z.ZodOptional<z.ZodString>;
                        /**
                         * Name or number of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                         */
                        port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                        /**
                         * Scheme to use for connecting to the host. Defaults to HTTP.
                         */
                        scheme: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    }, {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    }>>;
                    /**
                     * Number of seconds after the container has started before liveness probes are initiated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
                     * @format int32
                     */
                    initialDelaySeconds: z.ZodOptional<z.ZodNumber>;
                    /**
                     * How often (in seconds) to perform the probe. Default to 10 seconds. Minimum value is 1.
                     * @format int32
                     */
                    periodSeconds: z.ZodOptional<z.ZodNumber>;
                    /**
                     * Minimum consecutive successes for the probe to be considered successful after having failed. Defaults to 1. Must be 1 for liveness and startup. Minimum value is 1.
                     * @format int32
                     */
                    successThreshold: z.ZodOptional<z.ZodNumber>;
                    /**
                     * TCPSocket specifies an action involving a TCP port.
                     */
                    tcpSocket: z.ZodOptional<z.ZodObject<{
                        /**
                         * Optional: Host name to connect to, defaults to the pod IP.
                         */
                        host: z.ZodOptional<z.ZodString>;
                        /**
                         * Number or name of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                         */
                        port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                    }, "strip", z.ZodTypeAny, {
                        port: string | number;
                        host?: string | undefined;
                    }, {
                        port: string | number;
                        host?: string | undefined;
                    }>>;
                    /**
                     * Optional duration in seconds the pod needs to terminate gracefully upon probe failure. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process. If this value is nil, the pod's terminationGracePeriodSeconds will be used. Otherwise, this value overrides the value provided by the pod spec. Value must be non-negative integer. The value zero indicates stop immediately via the kill signal (no opportunity to shut down). This is a beta field and requires enabling ProbeTerminationGracePeriod feature gate. Minimum value is 1. spec.terminationGracePeriodSeconds is used if unset.
                     * @format int64
                     */
                    terminationGracePeriodSeconds: z.ZodOptional<z.ZodNumber>;
                    /**
                     * Number of seconds after which the probe times out. Defaults to 1 second. Minimum value is 1. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
                     * @format int32
                     */
                    timeoutSeconds: z.ZodOptional<z.ZodNumber>;
                }, "strip", z.ZodTypeAny, {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                }, {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                }>>;
                /**
                 * Compute Resources required by this container. Cannot be updated. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                 */
                resources: z.ZodOptional<z.ZodObject<{
                    /**
                     * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                     */
                    limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                    /**
                     * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                     */
                    requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                }, "strip", z.ZodTypeAny, {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                }, {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                }>>;
                /**
                 * SecurityContext defines the security options the container should be run with. If set, the fields of SecurityContext override the equivalent fields of PodSecurityContext. More info: https://kubernetes.io/docs/tasks/configure-pod-container/security-context/
                 */
                securityContext: z.ZodOptional<z.ZodObject<{
                    /**
                     * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process. This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN Note that this field cannot be set when spec.os.name is windows.
                     */
                    allowPrivilegeEscalation: z.ZodOptional<z.ZodBoolean>;
                    /**
                     * The capabilities to add/drop when running containers. Defaults to the default set of capabilities granted by the container runtime. Note that this field cannot be set when spec.os.name is windows.
                     */
                    capabilities: z.ZodOptional<z.ZodObject<{
                        /**
                         * Added capabilities
                         */
                        add: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        /**
                         * Removed capabilities
                         */
                        drop: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        add?: string[] | undefined;
                        drop?: string[] | undefined;
                    }, {
                        add?: string[] | undefined;
                        drop?: string[] | undefined;
                    }>>;
                    /**
                     * Run container in privileged mode. Processes in privileged containers are essentially equivalent to root on the host. Defaults to false. Note that this field cannot be set when spec.os.name is windows.
                     */
                    privileged: z.ZodOptional<z.ZodBoolean>;
                    /**
                     * procMount denotes the type of proc mount to use for the containers. The default is DefaultProcMount which uses the container runtime defaults for readonly paths and masked paths. This requires the ProcMountType feature flag to be enabled. Note that this field cannot be set when spec.os.name is windows.
                     */
                    procMount: z.ZodOptional<z.ZodString>;
                    /**
                     * Whether this container has a read-only root filesystem. Default is false. Note that this field cannot be set when spec.os.name is windows.
                     */
                    readOnlyRootFilesystem: z.ZodOptional<z.ZodBoolean>;
                    /**
                     * The GID to run the entrypoint of the container process. Uses runtime default if unset. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows.
                     * @format int64
                     */
                    runAsGroup: z.ZodOptional<z.ZodNumber>;
                    /**
                     * Indicates that the container must run as a non-root user. If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
                     */
                    runAsNonRoot: z.ZodOptional<z.ZodBoolean>;
                    /**
                     * The UID to run the entrypoint of the container process. Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows.
                     * @format int64
                     */
                    runAsUser: z.ZodOptional<z.ZodNumber>;
                    /**
                     * The SELinux context to be applied to the container. If unspecified, the container runtime will allocate a random SELinux context for each container.  May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows.
                     */
                    seLinuxOptions: z.ZodOptional<z.ZodObject<{
                        /**
                         * Level is SELinux level label that applies to the container.
                         */
                        level: z.ZodOptional<z.ZodString>;
                        /**
                         * Role is a SELinux role label that applies to the container.
                         */
                        role: z.ZodOptional<z.ZodString>;
                        /**
                         * Type is a SELinux type label that applies to the container.
                         */
                        type: z.ZodOptional<z.ZodString>;
                        /**
                         * User is a SELinux user label that applies to the container.
                         */
                        user: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        type?: string | undefined;
                        user?: string | undefined;
                        level?: string | undefined;
                        role?: string | undefined;
                    }, {
                        type?: string | undefined;
                        user?: string | undefined;
                        level?: string | undefined;
                        role?: string | undefined;
                    }>>;
                    /**
                     * The seccomp options to use by this container. If seccomp options are provided at both the pod & container level, the container options override the pod options. Note that this field cannot be set when spec.os.name is windows.
                     */
                    seccompProfile: z.ZodOptional<z.ZodObject<{
                        /**
                         * localhostProfile indicates a profile defined in a file on the node should be used. The profile must be preconfigured on the node to work. Must be a descending path, relative to the kubelet's configured seccomp profile location. Must only be set if type is "Localhost".
                         */
                        localhostProfile: z.ZodOptional<z.ZodString>;
                        /**
                         * type indicates which kind of seccomp profile will be applied. Valid options are: Localhost - a profile defined in a file on the node should be used. RuntimeDefault - the container runtime default profile should be used. Unconfined - no profile should be applied.
                         */
                        type: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        type: string;
                        localhostProfile?: string | undefined;
                    }, {
                        type: string;
                        localhostProfile?: string | undefined;
                    }>>;
                    /**
                     * The Windows specific settings applied to all containers. If unspecified, the options from the PodSecurityContext will be used. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is linux.
                     */
                    windowsOptions: z.ZodOptional<z.ZodObject<{
                        /**
                         * GMSACredentialSpec is where the GMSA admission webhook (https://github.com/kubernetes-sigs/windows-gmsa) inlines the contents of the GMSA credential spec named by the GMSACredentialSpecName field.
                         */
                        gmsaCredentialSpec: z.ZodOptional<z.ZodString>;
                        /**
                         * GMSACredentialSpecName is the name of the GMSA credential spec to use.
                         */
                        gmsaCredentialSpecName: z.ZodOptional<z.ZodString>;
                        /**
                         * HostProcess determines if a container should be run as a 'Host Process' container. This field is alpha-level and will only be honored by components that enable the WindowsHostProcessContainers feature flag. Setting this field without the feature flag will result in errors when validating the Pod. All of a Pod's containers must have the same effective HostProcess value (it is not allowed to have a mix of HostProcess containers and non-HostProcess containers).  In addition, if HostProcess is true then HostNetwork must also be set to true.
                         */
                        hostProcess: z.ZodOptional<z.ZodBoolean>;
                        /**
                         * The UserName in Windows to run the entrypoint of the container process. Defaults to the user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
                         */
                        runAsUserName: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        gmsaCredentialSpec?: string | undefined;
                        gmsaCredentialSpecName?: string | undefined;
                        hostProcess?: boolean | undefined;
                        runAsUserName?: string | undefined;
                    }, {
                        gmsaCredentialSpec?: string | undefined;
                        gmsaCredentialSpecName?: string | undefined;
                        hostProcess?: boolean | undefined;
                        runAsUserName?: string | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    allowPrivilegeEscalation?: boolean | undefined;
                    capabilities?: {
                        add?: string[] | undefined;
                        drop?: string[] | undefined;
                    } | undefined;
                    privileged?: boolean | undefined;
                    procMount?: string | undefined;
                    readOnlyRootFilesystem?: boolean | undefined;
                    runAsGroup?: number | undefined;
                    runAsNonRoot?: boolean | undefined;
                    runAsUser?: number | undefined;
                    seLinuxOptions?: {
                        type?: string | undefined;
                        user?: string | undefined;
                        level?: string | undefined;
                        role?: string | undefined;
                    } | undefined;
                    seccompProfile?: {
                        type: string;
                        localhostProfile?: string | undefined;
                    } | undefined;
                    windowsOptions?: {
                        gmsaCredentialSpec?: string | undefined;
                        gmsaCredentialSpecName?: string | undefined;
                        hostProcess?: boolean | undefined;
                        runAsUserName?: string | undefined;
                    } | undefined;
                }, {
                    allowPrivilegeEscalation?: boolean | undefined;
                    capabilities?: {
                        add?: string[] | undefined;
                        drop?: string[] | undefined;
                    } | undefined;
                    privileged?: boolean | undefined;
                    procMount?: string | undefined;
                    readOnlyRootFilesystem?: boolean | undefined;
                    runAsGroup?: number | undefined;
                    runAsNonRoot?: boolean | undefined;
                    runAsUser?: number | undefined;
                    seLinuxOptions?: {
                        type?: string | undefined;
                        user?: string | undefined;
                        level?: string | undefined;
                        role?: string | undefined;
                    } | undefined;
                    seccompProfile?: {
                        type: string;
                        localhostProfile?: string | undefined;
                    } | undefined;
                    windowsOptions?: {
                        gmsaCredentialSpec?: string | undefined;
                        gmsaCredentialSpecName?: string | undefined;
                        hostProcess?: boolean | undefined;
                        runAsUserName?: string | undefined;
                    } | undefined;
                }>>;
                /**
                 * StartupProbe indicates that the Pod has successfully initialized. If specified, no other probes are executed until this completes successfully. If this probe fails, the Pod will be restarted, just as if the livenessProbe failed. This can be used to provide different probe parameters at the beginning of a Pod's lifecycle, when it might take a long time to load data or warm a cache, than during steady-state operation. This cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
                 */
                startupProbe: z.ZodOptional<z.ZodObject<{
                    /**
                     * Exec specifies the action to take.
                     */
                    exec: z.ZodOptional<z.ZodObject<{
                        /**
                         * Command is the command line to execute inside the container, the working directory for the command  is root ('/') in the container's filesystem. The command is simply exec'd, it is not run inside a shell, so traditional shell instructions ('|', etc) won't work. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
                         */
                        command: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        command?: string[] | undefined;
                    }, {
                        command?: string[] | undefined;
                    }>>;
                    /**
                     * Minimum consecutive failures for the probe to be considered failed after having succeeded. Defaults to 3. Minimum value is 1.
                     * @format int32
                     */
                    failureThreshold: z.ZodOptional<z.ZodNumber>;
                    /**
                     * GRPC specifies an action involving a GRPC port. This is a beta field and requires enabling GRPCContainerProbe feature gate.
                     */
                    grpc: z.ZodOptional<z.ZodObject<{
                        /**
                         * Port number of the gRPC service. Number must be in the range 1 to 65535.
                         * @format int32
                         */
                        port: z.ZodNumber;
                        /**
                         * Service is the name of the service to place in the gRPC HealthCheckRequest (see https://github.com/grpc/grpc/blob/master/doc/health-checking.md).
                         *  If this is not specified, the default behavior is defined by gRPC.
                         */
                        service: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        port: number;
                        service?: string | undefined;
                    }, {
                        port: number;
                        service?: string | undefined;
                    }>>;
                    /**
                     * HTTPGet specifies the http request to perform.
                     */
                    httpGet: z.ZodOptional<z.ZodObject<{
                        /**
                         * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
                         */
                        host: z.ZodOptional<z.ZodString>;
                        /**
                         * Custom headers to set in the request. HTTP allows repeated headers.
                         */
                        httpHeaders: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * The header field name
                             */
                            name: z.ZodString;
                            /**
                             * The header field value
                             */
                            value: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            name: string;
                            value: string;
                        }, {
                            name: string;
                            value: string;
                        }>, "many">>;
                        /**
                         * Path to access on the HTTP server.
                         */
                        path: z.ZodOptional<z.ZodString>;
                        /**
                         * Name or number of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                         */
                        port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                        /**
                         * Scheme to use for connecting to the host. Defaults to HTTP.
                         */
                        scheme: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    }, {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    }>>;
                    /**
                     * Number of seconds after the container has started before liveness probes are initiated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
                     * @format int32
                     */
                    initialDelaySeconds: z.ZodOptional<z.ZodNumber>;
                    /**
                     * How often (in seconds) to perform the probe. Default to 10 seconds. Minimum value is 1.
                     * @format int32
                     */
                    periodSeconds: z.ZodOptional<z.ZodNumber>;
                    /**
                     * Minimum consecutive successes for the probe to be considered successful after having failed. Defaults to 1. Must be 1 for liveness and startup. Minimum value is 1.
                     * @format int32
                     */
                    successThreshold: z.ZodOptional<z.ZodNumber>;
                    /**
                     * TCPSocket specifies an action involving a TCP port.
                     */
                    tcpSocket: z.ZodOptional<z.ZodObject<{
                        /**
                         * Optional: Host name to connect to, defaults to the pod IP.
                         */
                        host: z.ZodOptional<z.ZodString>;
                        /**
                         * Number or name of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                         */
                        port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                    }, "strip", z.ZodTypeAny, {
                        port: string | number;
                        host?: string | undefined;
                    }, {
                        port: string | number;
                        host?: string | undefined;
                    }>>;
                    /**
                     * Optional duration in seconds the pod needs to terminate gracefully upon probe failure. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process. If this value is nil, the pod's terminationGracePeriodSeconds will be used. Otherwise, this value overrides the value provided by the pod spec. Value must be non-negative integer. The value zero indicates stop immediately via the kill signal (no opportunity to shut down). This is a beta field and requires enabling ProbeTerminationGracePeriod feature gate. Minimum value is 1. spec.terminationGracePeriodSeconds is used if unset.
                     * @format int64
                     */
                    terminationGracePeriodSeconds: z.ZodOptional<z.ZodNumber>;
                    /**
                     * Number of seconds after which the probe times out. Defaults to 1 second. Minimum value is 1. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
                     * @format int32
                     */
                    timeoutSeconds: z.ZodOptional<z.ZodNumber>;
                }, "strip", z.ZodTypeAny, {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                }, {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                }>>;
                /**
                 * Whether this container should allocate a buffer for stdin in the container runtime. If this is not set, reads from stdin in the container will always result in EOF. Default is false.
                 */
                stdin: z.ZodOptional<z.ZodBoolean>;
                /**
                 * Whether the container runtime should close the stdin channel after it has been opened by a single attach. When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF. Default is false
                 */
                stdinOnce: z.ZodOptional<z.ZodBoolean>;
                /**
                 * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem. Message written is intended to be brief final status, such as an assertion failure message. Will be truncated by the node if greater than 4096 bytes. The total message length across all containers will be limited to 12kb. Defaults to /dev/termination-log. Cannot be updated.
                 */
                terminationMessagePath: z.ZodOptional<z.ZodString>;
                /**
                 * Indicate how the termination message should be populated. File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
                 */
                terminationMessagePolicy: z.ZodOptional<z.ZodString>;
                /**
                 * Whether this container should allocate a TTY for itself, also requires 'stdin' to be true. Default is false.
                 */
                tty: z.ZodOptional<z.ZodBoolean>;
                /**
                 * volumeDevices is the list of block devices to be used by the container.
                 */
                volumeDevices: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * devicePath is the path inside of the container that the device will be mapped to.
                     */
                    devicePath: z.ZodString;
                    /**
                     * name must match the name of a persistentVolumeClaim in the pod
                     */
                    name: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    name: string;
                    devicePath: string;
                }, {
                    name: string;
                    devicePath: string;
                }>, "many">>;
                /**
                 * Pod volumes to mount into the container's filesystem. Cannot be updated.
                 */
                volumeMounts: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * Path within the container at which the volume should be mounted.  Must not contain ':'.
                     */
                    mountPath: z.ZodString;
                    /**
                     * mountPropagation determines how mounts are propagated from the host to container and the other way around. When not set, MountPropagationNone is used. This field is beta in 1.10.
                     */
                    mountPropagation: z.ZodOptional<z.ZodString>;
                    /**
                     * This must match the Name of a Volume.
                     */
                    name: z.ZodString;
                    /**
                     * Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false.
                     */
                    readOnly: z.ZodOptional<z.ZodBoolean>;
                    /**
                     * Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root).
                     */
                    subPath: z.ZodOptional<z.ZodString>;
                    /**
                     * Expanded path within the volume from which the container's volume should be mounted. Behaves similarly to SubPath but environment variable references $(VAR_NAME) are expanded using the container's environment. Defaults to "" (volume's root). SubPathExpr and SubPath are mutually exclusive.
                     */
                    subPathExpr: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    name: string;
                    mountPath: string;
                    subPath?: string | undefined;
                    mountPropagation?: string | undefined;
                    readOnly?: boolean | undefined;
                    subPathExpr?: string | undefined;
                }, {
                    name: string;
                    mountPath: string;
                    subPath?: string | undefined;
                    mountPropagation?: string | undefined;
                    readOnly?: boolean | undefined;
                    subPathExpr?: string | undefined;
                }>, "many">>;
                /**
                 * Container's working directory. If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
                 */
                workingDir: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                name: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                env?: {
                    name: string;
                    value?: string | undefined;
                    valueFrom?: {
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                        configMapKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        secretKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    } | undefined;
                }[] | undefined;
                image?: string | undefined;
                imagePullPolicy?: string | undefined;
                args?: string[] | undefined;
                command?: string[] | undefined;
                envFrom?: {
                    configMapRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    prefix?: string | undefined;
                    secretRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                lifecycle?: {
                    postStart?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                    preStop?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                livenessProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                ports?: {
                    containerPort: number;
                    protocol: string;
                    name?: string | undefined;
                    hostIP?: string | undefined;
                    hostPort?: number | undefined;
                }[] | undefined;
                readinessProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                securityContext?: {
                    allowPrivilegeEscalation?: boolean | undefined;
                    capabilities?: {
                        add?: string[] | undefined;
                        drop?: string[] | undefined;
                    } | undefined;
                    privileged?: boolean | undefined;
                    procMount?: string | undefined;
                    readOnlyRootFilesystem?: boolean | undefined;
                    runAsGroup?: number | undefined;
                    runAsNonRoot?: boolean | undefined;
                    runAsUser?: number | undefined;
                    seLinuxOptions?: {
                        type?: string | undefined;
                        user?: string | undefined;
                        level?: string | undefined;
                        role?: string | undefined;
                    } | undefined;
                    seccompProfile?: {
                        type: string;
                        localhostProfile?: string | undefined;
                    } | undefined;
                    windowsOptions?: {
                        gmsaCredentialSpec?: string | undefined;
                        gmsaCredentialSpecName?: string | undefined;
                        hostProcess?: boolean | undefined;
                        runAsUserName?: string | undefined;
                    } | undefined;
                } | undefined;
                startupProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                stdin?: boolean | undefined;
                stdinOnce?: boolean | undefined;
                terminationMessagePath?: string | undefined;
                terminationMessagePolicy?: string | undefined;
                tty?: boolean | undefined;
                volumeDevices?: {
                    name: string;
                    devicePath: string;
                }[] | undefined;
                volumeMounts?: {
                    name: string;
                    mountPath: string;
                    subPath?: string | undefined;
                    mountPropagation?: string | undefined;
                    readOnly?: boolean | undefined;
                    subPathExpr?: string | undefined;
                }[] | undefined;
                workingDir?: string | undefined;
            }, {
                name: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                env?: {
                    name: string;
                    value?: string | undefined;
                    valueFrom?: {
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                        configMapKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        secretKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    } | undefined;
                }[] | undefined;
                image?: string | undefined;
                imagePullPolicy?: string | undefined;
                args?: string[] | undefined;
                command?: string[] | undefined;
                envFrom?: {
                    configMapRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    prefix?: string | undefined;
                    secretRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                lifecycle?: {
                    postStart?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                    preStop?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                livenessProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                ports?: {
                    containerPort: number;
                    name?: string | undefined;
                    hostIP?: string | undefined;
                    hostPort?: number | undefined;
                    protocol?: string | undefined;
                }[] | undefined;
                readinessProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                securityContext?: {
                    allowPrivilegeEscalation?: boolean | undefined;
                    capabilities?: {
                        add?: string[] | undefined;
                        drop?: string[] | undefined;
                    } | undefined;
                    privileged?: boolean | undefined;
                    procMount?: string | undefined;
                    readOnlyRootFilesystem?: boolean | undefined;
                    runAsGroup?: number | undefined;
                    runAsNonRoot?: boolean | undefined;
                    runAsUser?: number | undefined;
                    seLinuxOptions?: {
                        type?: string | undefined;
                        user?: string | undefined;
                        level?: string | undefined;
                        role?: string | undefined;
                    } | undefined;
                    seccompProfile?: {
                        type: string;
                        localhostProfile?: string | undefined;
                    } | undefined;
                    windowsOptions?: {
                        gmsaCredentialSpec?: string | undefined;
                        gmsaCredentialSpecName?: string | undefined;
                        hostProcess?: boolean | undefined;
                        runAsUserName?: string | undefined;
                    } | undefined;
                } | undefined;
                startupProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                stdin?: boolean | undefined;
                stdinOnce?: boolean | undefined;
                terminationMessagePath?: string | undefined;
                terminationMessagePolicy?: string | undefined;
                tty?: boolean | undefined;
                volumeDevices?: {
                    name: string;
                    devicePath: string;
                }[] | undefined;
                volumeMounts?: {
                    name: string;
                    mountPath: string;
                    subPath?: string | undefined;
                    mountPropagation?: string | undefined;
                    readOnly?: boolean | undefined;
                    subPathExpr?: string | undefined;
                }[] | undefined;
                workingDir?: string | undefined;
            }>, "many">>;
            /**
             * Defines a PersistentVolumeClaim for PostgreSQL data. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes
             */
            dataVolumeClaimSpec: z.ZodObject<{
                /**
                 * accessModes contains the desired access modes the volume should have. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes-1
                 */
                accessModes: z.ZodArray<z.ZodString, "many">;
                /**
                 * dataSource field can be used to specify either: \* An existing VolumeSnapshot object (snapshot.storage.k8s.io/VolumeSnapshot) \* An existing PVC (PersistentVolumeClaim) If the provisioner or an external controller can support the specified data source, it will create a new volume based on the contents of the specified data source. If the AnyVolumeDataSource feature gate is enabled, this field will always have the same contents as the DataSourceRef field.
                 */
                dataSource: z.ZodOptional<z.ZodObject<{
                    /**
                     * APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
                     */
                    apiGroup: z.ZodOptional<z.ZodString>;
                    /**
                     * Kind is the type of resource being referenced
                     */
                    kind: z.ZodString;
                    /**
                     * Name is the name of resource being referenced
                     */
                    name: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                }, {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                }>>;
                /**
                 * dataSourceRef specifies the object from which to populate the volume with data, if a non-empty volume is desired. This may be any local object from a non-empty API group (non core object) or a PersistentVolumeClaim object. When this field is specified, volume binding will only succeed if the type of the specified object matches some installed volume populator or dynamic provisioner. This field will replace the functionality of the DataSource field and as such if both fields are non-empty, they must have the same value. For backwards compatibility, both fields (DataSource and DataSourceRef) will be set to the same value automatically if one of them is empty and the other is non-empty. There are two important differences between DataSource and DataSourceRef: \* While DataSource only allows two specific types of objects, DataSourceRef allows any non-core object, as well as PersistentVolumeClaim objects. \* While DataSource ignores disallowed values (dropping them), DataSourceRef preserves all values, and generates an error if a disallowed value is specified. (Beta) Using this field requires the AnyVolumeDataSource feature gate to be enabled.
                 */
                dataSourceRef: z.ZodOptional<z.ZodObject<{
                    /**
                     * APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
                     */
                    apiGroup: z.ZodOptional<z.ZodString>;
                    /**
                     * Kind is the type of resource being referenced
                     */
                    kind: z.ZodString;
                    /**
                     * Name is the name of resource being referenced
                     */
                    name: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                }, {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                }>>;
                /**
                 * resources represents the minimum resources the volume should have. If RecoverVolumeExpansionFailure feature is enabled users are allowed to specify resource requirements that are lower than previous value but must still be higher than capacity recorded in the status field of the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#resources
                 */
                resources: z.ZodObject<{
                    /**
                     * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                     */
                    limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                    /**
                     * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                     */
                    requests: z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>;
                }, "strip", z.ZodTypeAny, {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                }, {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                }>;
                /**
                 * selector is a label query over volumes to consider for binding.
                 */
                selector: z.ZodOptional<z.ZodObject<{
                    /**
                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                     */
                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * key is the label key that the selector applies to.
                         */
                        key: z.ZodString;
                        /**
                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                         */
                        operator: z.ZodString;
                        /**
                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                         */
                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }, {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }>, "many">>;
                    /**
                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                     */
                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                }, "strip", z.ZodTypeAny, {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                }, {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                }>>;
                /**
                 * storageClassName is the name of the StorageClass required by the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#class-1
                 */
                storageClassName: z.ZodOptional<z.ZodString>;
                /**
                 * volumeMode defines what type of volume is required by the claim. Value of Filesystem is implied when not included in claim spec.
                 */
                volumeMode: z.ZodOptional<z.ZodString>;
                /**
                 * volumeName is the binding reference to the PersistentVolume backing this claim.
                 */
                volumeName: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                accessModes: string[];
                resources: {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                };
                selector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                dataSource?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                dataSourceRef?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                storageClassName?: string | undefined;
                volumeMode?: string | undefined;
                volumeName?: string | undefined;
            }, {
                accessModes: string[];
                resources: {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                };
                selector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                dataSource?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                dataSourceRef?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                storageClassName?: string | undefined;
                volumeMode?: string | undefined;
                volumeName?: string | undefined;
            }>;
            /**
             * Metadata contains metadata for custom resources
             */
            metadata: z.ZodOptional<z.ZodObject<{
                annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
            }, "strip", z.ZodTypeAny, {
                annotations?: Record<string, string> | undefined;
                labels?: Record<string, string> | undefined;
            }, {
                annotations?: Record<string, string> | undefined;
                labels?: Record<string, string> | undefined;
            }>>;
            /**
             * Minimum number of pods that should be available at a time. Defaults to one when the replicas field is greater than one.
             */
            minAvailable: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString]>>;
            /**
             * Name that associates this set of PostgreSQL pods. This field is optional when only one instance set is defined. Each instance set in a cluster must have a unique name. The combined length of this and the cluster name must be 46 characters or less.
             * @pattern ^([a-z0-9]([-a-z0-9]*[a-z0-9])?)?$
             */
            name: z.ZodOptional<z.ZodString>;
            /**
             * Priority class name for the PostgreSQL pod. Changing this value causes PostgreSQL to restart. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/pod-priority-preemption/
             */
            priorityClassName: z.ZodOptional<z.ZodString>;
            /**
             * Number of desired PostgreSQL pods.
             * @default 1
             * @minimum 1
             * @format int32
             */
            replicas: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
            /**
             * Compute resources of a PostgreSQL container.
             */
            resources: z.ZodOptional<z.ZodObject<{
                /**
                 * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                 */
                limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                /**
                 * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                 */
                requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
            }, "strip", z.ZodTypeAny, {
                requests?: Record<string, string | number> | undefined;
                limits?: Record<string, string | number> | undefined;
            }, {
                requests?: Record<string, string | number> | undefined;
                limits?: Record<string, string | number> | undefined;
            }>>;
            /**
             * Configuration for instance sidecar containers
             */
            sidecars: z.ZodOptional<z.ZodObject<{
                /**
                 * Defines the configuration for the replica cert copy sidecar container
                 */
                replicaCertCopy: z.ZodOptional<z.ZodObject<{
                    /**
                     * Resource requirements for a sidecar container
                     */
                    resources: z.ZodOptional<z.ZodObject<{
                        /**
                         * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                         */
                        limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                        /**
                         * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                         */
                        requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                    }, "strip", z.ZodTypeAny, {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    }, {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                }, {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                replicaCertCopy?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                } | undefined;
            }, {
                replicaCertCopy?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                } | undefined;
            }>>;
            /**
             * The list of tablespaces volumes to mount for this postgrescluster This field requires enabling TablespaceVolumes feature gate
             */
            tablespaceVolumes: z.ZodOptional<z.ZodArray<z.ZodObject<{
                /**
                 * Defines a PersistentVolumeClaim for a tablespace. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes
                 */
                dataVolumeClaimSpec: z.ZodObject<{
                    /**
                     * accessModes contains the desired access modes the volume should have. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes-1
                     */
                    accessModes: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    /**
                     * dataSource field can be used to specify either: \* An existing VolumeSnapshot object (snapshot.storage.k8s.io/VolumeSnapshot) \* An existing PVC (PersistentVolumeClaim) If the provisioner or an external controller can support the specified data source, it will create a new volume based on the contents of the specified data source. If the AnyVolumeDataSource feature gate is enabled, this field will always have the same contents as the DataSourceRef field.
                     */
                    dataSource: z.ZodOptional<z.ZodObject<{
                        /**
                         * APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
                         */
                        apiGroup: z.ZodOptional<z.ZodString>;
                        /**
                         * Kind is the type of resource being referenced
                         */
                        kind: z.ZodString;
                        /**
                         * Name is the name of resource being referenced
                         */
                        name: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    }, {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    }>>;
                    /**
                     * dataSourceRef specifies the object from which to populate the volume with data, if a non-empty volume is desired. This may be any local object from a non-empty API group (non core object) or a PersistentVolumeClaim object. When this field is specified, volume binding will only succeed if the type of the specified object matches some installed volume populator or dynamic provisioner. This field will replace the functionality of the DataSource field and as such if both fields are non-empty, they must have the same value. For backwards compatibility, both fields (DataSource and DataSourceRef) will be set to the same value automatically if one of them is empty and the other is non-empty. There are two important differences between DataSource and DataSourceRef: \* While DataSource only allows two specific types of objects, DataSourceRef allows any non-core object, as well as PersistentVolumeClaim objects. \* While DataSource ignores disallowed values (dropping them), DataSourceRef preserves all values, and generates an error if a disallowed value is specified. (Beta) Using this field requires the AnyVolumeDataSource feature gate to be enabled.
                     */
                    dataSourceRef: z.ZodOptional<z.ZodObject<{
                        /**
                         * APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
                         */
                        apiGroup: z.ZodOptional<z.ZodString>;
                        /**
                         * Kind is the type of resource being referenced
                         */
                        kind: z.ZodString;
                        /**
                         * Name is the name of resource being referenced
                         */
                        name: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    }, {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    }>>;
                    /**
                     * resources represents the minimum resources the volume should have. If RecoverVolumeExpansionFailure feature is enabled users are allowed to specify resource requirements that are lower than previous value but must still be higher than capacity recorded in the status field of the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#resources
                     */
                    resources: z.ZodOptional<z.ZodObject<{
                        /**
                         * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                         */
                        limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                        /**
                         * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                         */
                        requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                    }, "strip", z.ZodTypeAny, {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    }, {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    }>>;
                    /**
                     * selector is a label query over volumes to consider for binding.
                     */
                    selector: z.ZodOptional<z.ZodObject<{
                        /**
                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                         */
                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                             */
                            operator: z.ZodString;
                            /**
                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                        /**
                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                         */
                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    }, "strip", z.ZodTypeAny, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }>>;
                    /**
                     * storageClassName is the name of the StorageClass required by the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#class-1
                     */
                    storageClassName: z.ZodOptional<z.ZodString>;
                    /**
                     * volumeMode defines what type of volume is required by the claim. Value of Filesystem is implied when not included in claim spec.
                     */
                    volumeMode: z.ZodOptional<z.ZodString>;
                    /**
                     * volumeName is the binding reference to the PersistentVolume backing this claim.
                     */
                    volumeName: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                }, {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                }>;
                /**
                 * The name for the tablespace, used as the path name for the volume. Must be unique in the instance set since they become the directory names.
                 * @minLength 1
                 * @pattern ^[a-z][a-z0-9]*$
                 */
                name: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                name: string;
                dataVolumeClaimSpec: {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                };
            }, {
                name: string;
                dataVolumeClaimSpec: {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                };
            }>, "many">>;
            /**
             * Tolerations of a PostgreSQL pod. Changing this value causes PostgreSQL to restart. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/taint-and-toleration
             */
            tolerations: z.ZodOptional<z.ZodArray<z.ZodObject<{
                /**
                 * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
                 */
                effect: z.ZodOptional<z.ZodString>;
                /**
                 * Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
                 */
                key: z.ZodOptional<z.ZodString>;
                /**
                 * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
                 */
                operator: z.ZodOptional<z.ZodString>;
                /**
                 * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
                 * @format int64
                 */
                tolerationSeconds: z.ZodOptional<z.ZodNumber>;
                /**
                 * Value is the taint value the toleration matches to. If the operator is Exists, the value should be empty, otherwise just a regular string.
                 */
                value: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                key?: string | undefined;
                operator?: string | undefined;
                value?: string | undefined;
                effect?: string | undefined;
                tolerationSeconds?: number | undefined;
            }, {
                key?: string | undefined;
                operator?: string | undefined;
                value?: string | undefined;
                effect?: string | undefined;
                tolerationSeconds?: number | undefined;
            }>, "many">>;
            /**
             * Topology spread constraints of a PostgreSQL pod. Changing this value causes PostgreSQL to restart. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-topology-spread-constraints/
             */
            topologySpreadConstraints: z.ZodOptional<z.ZodArray<z.ZodObject<{
                /**
                 * LabelSelector is used to find matching pods. Pods that match this label selector are counted to determine the number of pods in their corresponding topology domain.
                 */
                labelSelector: z.ZodOptional<z.ZodObject<{
                    /**
                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                     */
                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * key is the label key that the selector applies to.
                         */
                        key: z.ZodString;
                        /**
                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                         */
                        operator: z.ZodString;
                        /**
                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                         */
                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }, {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }>, "many">>;
                    /**
                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                     */
                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                }, "strip", z.ZodTypeAny, {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                }, {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                }>>;
                /**
                 * MaxSkew describes the degree to which pods may be unevenly distributed. When `whenUnsatisfiable=DoNotSchedule`, it is the maximum permitted difference between the number of matching pods in the target topology and the global minimum. The global minimum is the minimum number of matching pods in an eligible domain or zero if the number of eligible domains is less than MinDomains. For example, in a 3-zone cluster, MaxSkew is set to 1, and pods with the same labelSelector spread as 2/2/1: In this case, the global minimum is 1. | zone1 | zone2 | zone3 | |  P P  |  P P  |   P   | - if MaxSkew is 1, incoming pod can only be scheduled to zone3 to become 2/2/2; scheduling it onto zone1(zone2) would make the ActualSkew(3-1) on zone1(zone2) violate MaxSkew(1). - if MaxSkew is 2, incoming pod can be scheduled onto any zone. When `whenUnsatisfiable=ScheduleAnyway`, it is used to give higher precedence to topologies that satisfy it. It's a required field. Default value is 1 and 0 is not allowed.
                 * @format int32
                 */
                maxSkew: z.ZodNumber;
                /**
                 * MinDomains indicates a minimum number of eligible domains. When the number of eligible domains with matching topology keys is less than minDomains, Pod Topology Spread treats "global minimum" as 0, and then the calculation of Skew is performed. And when the number of eligible domains with matching topology keys equals or greater than minDomains, this value has no effect on scheduling. As a result, when the number of eligible domains is less than minDomains, scheduler won't schedule more than maxSkew Pods to those domains. If value is nil, the constraint behaves as if MinDomains is equal to 1. Valid values are integers greater than 0. When value is not nil, WhenUnsatisfiable must be DoNotSchedule.
                 *  For example, in a 3-zone cluster, MaxSkew is set to 2, MinDomains is set to 5 and pods with the same labelSelector spread as 2/2/2: | zone1 | zone2 | zone3 | |  P P  |  P P  |  P P  | The number of domains is less than 5(MinDomains), so "global minimum" is treated as 0. In this situation, new pod with the same labelSelector cannot be scheduled, because computed skew will be 3(3 - 0) if new Pod is scheduled to any of the three zones, it will violate MaxSkew.
                 *  This is an alpha field and requires enabling MinDomainsInPodTopologySpread feature gate.
                 * @format int32
                 */
                minDomains: z.ZodOptional<z.ZodNumber>;
                /**
                 * TopologyKey is the key of node labels. Nodes that have a label with this key and identical values are considered to be in the same topology. We consider each <key, value> as a "bucket", and try to put balanced number of pods into each bucket. We define a domain as a particular instance of a topology. Also, we define an eligible domain as a domain whose nodes match the node selector. e.g. If TopologyKey is "kubernetes.io/hostname", each Node is a domain of that topology. And, if TopologyKey is "topology.kubernetes.io/zone", each zone is a domain of that topology. It's a required field.
                 */
                topologyKey: z.ZodString;
                /**
                 * WhenUnsatisfiable indicates how to deal with a pod if it doesn't satisfy the spread constraint. - DoNotSchedule (default) tells the scheduler not to schedule it. - ScheduleAnyway tells the scheduler to schedule the pod in any location, but giving higher precedence to topologies that would help reduce the skew. A constraint is considered "Unsatisfiable" for an incoming pod if and only if every possible node assignment for that pod would violate "MaxSkew" on some topology. For example, in a 3-zone cluster, MaxSkew is set to 1, and pods with the same labelSelector spread as 3/1/1: | zone1 | zone2 | zone3 | | P P P |   P   |   P   | If WhenUnsatisfiable is set to DoNotSchedule, incoming pod can only be scheduled to zone2(zone3) to become 3/2/1(3/1/2) as ActualSkew(2-1) on zone2(zone3) satisfies MaxSkew(1). In other words, the cluster can still be imbalanced, but scheduler won't make it \*more\* imbalanced. It's a required field.
                 */
                whenUnsatisfiable: z.ZodString;
            }, "strip", z.ZodTypeAny, {
                topologyKey: string;
                maxSkew: number;
                whenUnsatisfiable: string;
                labelSelector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                minDomains?: number | undefined;
            }, {
                topologyKey: string;
                maxSkew: number;
                whenUnsatisfiable: string;
                labelSelector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                minDomains?: number | undefined;
            }>, "many">>;
            /**
             * Defines a separate PersistentVolumeClaim for PostgreSQL's write-ahead log. More info: https://www.postgresql.org/docs/current/wal.html
             */
            walVolumeClaimSpec: z.ZodOptional<z.ZodObject<{
                /**
                 * accessModes contains the desired access modes the volume should have. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes-1
                 */
                accessModes: z.ZodArray<z.ZodString, "many">;
                /**
                 * dataSource field can be used to specify either: \* An existing VolumeSnapshot object (snapshot.storage.k8s.io/VolumeSnapshot) \* An existing PVC (PersistentVolumeClaim) If the provisioner or an external controller can support the specified data source, it will create a new volume based on the contents of the specified data source. If the AnyVolumeDataSource feature gate is enabled, this field will always have the same contents as the DataSourceRef field.
                 */
                dataSource: z.ZodOptional<z.ZodObject<{
                    /**
                     * APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
                     */
                    apiGroup: z.ZodOptional<z.ZodString>;
                    /**
                     * Kind is the type of resource being referenced
                     */
                    kind: z.ZodString;
                    /**
                     * Name is the name of resource being referenced
                     */
                    name: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                }, {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                }>>;
                /**
                 * dataSourceRef specifies the object from which to populate the volume with data, if a non-empty volume is desired. This may be any local object from a non-empty API group (non core object) or a PersistentVolumeClaim object. When this field is specified, volume binding will only succeed if the type of the specified object matches some installed volume populator or dynamic provisioner. This field will replace the functionality of the DataSource field and as such if both fields are non-empty, they must have the same value. For backwards compatibility, both fields (DataSource and DataSourceRef) will be set to the same value automatically if one of them is empty and the other is non-empty. There are two important differences between DataSource and DataSourceRef: \* While DataSource only allows two specific types of objects, DataSourceRef allows any non-core object, as well as PersistentVolumeClaim objects. \* While DataSource ignores disallowed values (dropping them), DataSourceRef preserves all values, and generates an error if a disallowed value is specified. (Beta) Using this field requires the AnyVolumeDataSource feature gate to be enabled.
                 */
                dataSourceRef: z.ZodOptional<z.ZodObject<{
                    /**
                     * APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
                     */
                    apiGroup: z.ZodOptional<z.ZodString>;
                    /**
                     * Kind is the type of resource being referenced
                     */
                    kind: z.ZodString;
                    /**
                     * Name is the name of resource being referenced
                     */
                    name: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                }, {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                }>>;
                /**
                 * resources represents the minimum resources the volume should have. If RecoverVolumeExpansionFailure feature is enabled users are allowed to specify resource requirements that are lower than previous value but must still be higher than capacity recorded in the status field of the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#resources
                 */
                resources: z.ZodObject<{
                    /**
                     * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                     */
                    limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                    /**
                     * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                     */
                    requests: z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>;
                }, "strip", z.ZodTypeAny, {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                }, {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                }>;
                /**
                 * selector is a label query over volumes to consider for binding.
                 */
                selector: z.ZodOptional<z.ZodObject<{
                    /**
                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                     */
                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * key is the label key that the selector applies to.
                         */
                        key: z.ZodString;
                        /**
                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                         */
                        operator: z.ZodString;
                        /**
                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                         */
                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }, {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }>, "many">>;
                    /**
                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                     */
                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                }, "strip", z.ZodTypeAny, {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                }, {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                }>>;
                /**
                 * storageClassName is the name of the StorageClass required by the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#class-1
                 */
                storageClassName: z.ZodOptional<z.ZodString>;
                /**
                 * volumeMode defines what type of volume is required by the claim. Value of Filesystem is implied when not included in claim spec.
                 */
                volumeMode: z.ZodOptional<z.ZodString>;
                /**
                 * volumeName is the binding reference to the PersistentVolume backing this claim.
                 */
                volumeName: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                accessModes: string[];
                resources: {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                };
                selector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                dataSource?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                dataSourceRef?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                storageClassName?: string | undefined;
                volumeMode?: string | undefined;
                volumeName?: string | undefined;
            }, {
                accessModes: string[];
                resources: {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                };
                selector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                dataSource?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                dataSourceRef?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                storageClassName?: string | undefined;
                volumeMode?: string | undefined;
                volumeName?: string | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            dataVolumeClaimSpec: {
                accessModes: string[];
                resources: {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                };
                selector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                dataSource?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                dataSourceRef?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                storageClassName?: string | undefined;
                volumeMode?: string | undefined;
                volumeName?: string | undefined;
            };
            replicas: number;
            name?: string | undefined;
            resources?: {
                requests?: Record<string, string | number> | undefined;
                limits?: Record<string, string | number> | undefined;
            } | undefined;
            metadata?: {
                annotations?: Record<string, string> | undefined;
                labels?: Record<string, string> | undefined;
            } | undefined;
            sidecars?: {
                replicaCertCopy?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
            tolerations?: {
                key?: string | undefined;
                operator?: string | undefined;
                value?: string | undefined;
                effect?: string | undefined;
                tolerationSeconds?: number | undefined;
            }[] | undefined;
            affinity?: {
                nodeAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        preference: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        };
                        weight: number;
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        nodeSelectorTerms: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        }[];
                    } | undefined;
                } | undefined;
                podAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                } | undefined;
                podAntiAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                } | undefined;
            } | undefined;
            priorityClassName?: string | undefined;
            topologySpreadConstraints?: {
                topologyKey: string;
                maxSkew: number;
                whenUnsatisfiable: string;
                labelSelector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                minDomains?: number | undefined;
            }[] | undefined;
            containers?: {
                name: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                env?: {
                    name: string;
                    value?: string | undefined;
                    valueFrom?: {
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                        configMapKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        secretKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    } | undefined;
                }[] | undefined;
                image?: string | undefined;
                imagePullPolicy?: string | undefined;
                args?: string[] | undefined;
                command?: string[] | undefined;
                envFrom?: {
                    configMapRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    prefix?: string | undefined;
                    secretRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                lifecycle?: {
                    postStart?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                    preStop?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                livenessProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                ports?: {
                    containerPort: number;
                    protocol: string;
                    name?: string | undefined;
                    hostIP?: string | undefined;
                    hostPort?: number | undefined;
                }[] | undefined;
                readinessProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                securityContext?: {
                    allowPrivilegeEscalation?: boolean | undefined;
                    capabilities?: {
                        add?: string[] | undefined;
                        drop?: string[] | undefined;
                    } | undefined;
                    privileged?: boolean | undefined;
                    procMount?: string | undefined;
                    readOnlyRootFilesystem?: boolean | undefined;
                    runAsGroup?: number | undefined;
                    runAsNonRoot?: boolean | undefined;
                    runAsUser?: number | undefined;
                    seLinuxOptions?: {
                        type?: string | undefined;
                        user?: string | undefined;
                        level?: string | undefined;
                        role?: string | undefined;
                    } | undefined;
                    seccompProfile?: {
                        type: string;
                        localhostProfile?: string | undefined;
                    } | undefined;
                    windowsOptions?: {
                        gmsaCredentialSpec?: string | undefined;
                        gmsaCredentialSpecName?: string | undefined;
                        hostProcess?: boolean | undefined;
                        runAsUserName?: string | undefined;
                    } | undefined;
                } | undefined;
                startupProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                stdin?: boolean | undefined;
                stdinOnce?: boolean | undefined;
                terminationMessagePath?: string | undefined;
                terminationMessagePolicy?: string | undefined;
                tty?: boolean | undefined;
                volumeDevices?: {
                    name: string;
                    devicePath: string;
                }[] | undefined;
                volumeMounts?: {
                    name: string;
                    mountPath: string;
                    subPath?: string | undefined;
                    mountPropagation?: string | undefined;
                    readOnly?: boolean | undefined;
                    subPathExpr?: string | undefined;
                }[] | undefined;
                workingDir?: string | undefined;
            }[] | undefined;
            minAvailable?: string | number | undefined;
            tablespaceVolumes?: {
                name: string;
                dataVolumeClaimSpec: {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                };
            }[] | undefined;
            walVolumeClaimSpec?: {
                accessModes: string[];
                resources: {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                };
                selector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                dataSource?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                dataSourceRef?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                storageClassName?: string | undefined;
                volumeMode?: string | undefined;
                volumeName?: string | undefined;
            } | undefined;
        }, {
            dataVolumeClaimSpec: {
                accessModes: string[];
                resources: {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                };
                selector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                dataSource?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                dataSourceRef?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                storageClassName?: string | undefined;
                volumeMode?: string | undefined;
                volumeName?: string | undefined;
            };
            name?: string | undefined;
            resources?: {
                requests?: Record<string, string | number> | undefined;
                limits?: Record<string, string | number> | undefined;
            } | undefined;
            metadata?: {
                annotations?: Record<string, string> | undefined;
                labels?: Record<string, string> | undefined;
            } | undefined;
            sidecars?: {
                replicaCertCopy?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
            tolerations?: {
                key?: string | undefined;
                operator?: string | undefined;
                value?: string | undefined;
                effect?: string | undefined;
                tolerationSeconds?: number | undefined;
            }[] | undefined;
            affinity?: {
                nodeAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        preference: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        };
                        weight: number;
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        nodeSelectorTerms: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        }[];
                    } | undefined;
                } | undefined;
                podAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                } | undefined;
                podAntiAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                } | undefined;
            } | undefined;
            priorityClassName?: string | undefined;
            topologySpreadConstraints?: {
                topologyKey: string;
                maxSkew: number;
                whenUnsatisfiable: string;
                labelSelector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                minDomains?: number | undefined;
            }[] | undefined;
            containers?: {
                name: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                env?: {
                    name: string;
                    value?: string | undefined;
                    valueFrom?: {
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                        configMapKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        secretKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    } | undefined;
                }[] | undefined;
                image?: string | undefined;
                imagePullPolicy?: string | undefined;
                args?: string[] | undefined;
                command?: string[] | undefined;
                envFrom?: {
                    configMapRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    prefix?: string | undefined;
                    secretRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                lifecycle?: {
                    postStart?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                    preStop?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                livenessProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                ports?: {
                    containerPort: number;
                    name?: string | undefined;
                    hostIP?: string | undefined;
                    hostPort?: number | undefined;
                    protocol?: string | undefined;
                }[] | undefined;
                readinessProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                securityContext?: {
                    allowPrivilegeEscalation?: boolean | undefined;
                    capabilities?: {
                        add?: string[] | undefined;
                        drop?: string[] | undefined;
                    } | undefined;
                    privileged?: boolean | undefined;
                    procMount?: string | undefined;
                    readOnlyRootFilesystem?: boolean | undefined;
                    runAsGroup?: number | undefined;
                    runAsNonRoot?: boolean | undefined;
                    runAsUser?: number | undefined;
                    seLinuxOptions?: {
                        type?: string | undefined;
                        user?: string | undefined;
                        level?: string | undefined;
                        role?: string | undefined;
                    } | undefined;
                    seccompProfile?: {
                        type: string;
                        localhostProfile?: string | undefined;
                    } | undefined;
                    windowsOptions?: {
                        gmsaCredentialSpec?: string | undefined;
                        gmsaCredentialSpecName?: string | undefined;
                        hostProcess?: boolean | undefined;
                        runAsUserName?: string | undefined;
                    } | undefined;
                } | undefined;
                startupProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                stdin?: boolean | undefined;
                stdinOnce?: boolean | undefined;
                terminationMessagePath?: string | undefined;
                terminationMessagePolicy?: string | undefined;
                tty?: boolean | undefined;
                volumeDevices?: {
                    name: string;
                    devicePath: string;
                }[] | undefined;
                volumeMounts?: {
                    name: string;
                    mountPath: string;
                    subPath?: string | undefined;
                    mountPropagation?: string | undefined;
                    readOnly?: boolean | undefined;
                    subPathExpr?: string | undefined;
                }[] | undefined;
                workingDir?: string | undefined;
            }[] | undefined;
            minAvailable?: string | number | undefined;
            replicas?: number | undefined;
            tablespaceVolumes?: {
                name: string;
                dataVolumeClaimSpec: {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                };
            }[] | undefined;
            walVolumeClaimSpec?: {
                accessModes: string[];
                resources: {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                };
                selector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                dataSource?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                dataSourceRef?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                storageClassName?: string | undefined;
                volumeMode?: string | undefined;
                volumeName?: string | undefined;
            } | undefined;
        }>, "many">;
        /**
         * Metadata contains metadata for custom resources
         */
        metadata: z.ZodOptional<z.ZodObject<{
            annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
            labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            annotations?: Record<string, string> | undefined;
            labels?: Record<string, string> | undefined;
        }, {
            annotations?: Record<string, string> | undefined;
            labels?: Record<string, string> | undefined;
        }>>;
        /**
         * The specification of monitoring tools that connect to PostgreSQL
         */
        monitoring: z.ZodOptional<z.ZodObject<{
            /**
             * PGMonitorSpec defines the desired state of the pgMonitor tool suite
             */
            pgmonitor: z.ZodOptional<z.ZodObject<{
                exporter: z.ZodOptional<z.ZodObject<{
                    /**
                     * Projected volumes containing custom PostgreSQL Exporter configuration.  Currently supports the customization of PostgreSQL Exporter queries. If a "queries.yml" file is detected in any volume projected using this field, it will be loaded using the "extend.query-path" flag: https://github.com/prometheus-community/postgres_exporter#flags Changing the values of field causes PostgreSQL and the exporter to restart.
                     */
                    configuration: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * configMap information about the configMap data to project
                         */
                        configMap: z.ZodOptional<z.ZodObject<{
                            /**
                             * items if unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
                             */
                            items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the key to project.
                                 */
                                key: z.ZodString;
                                /**
                                 * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                                 * @format int32
                                 */
                                mode: z.ZodOptional<z.ZodNumber>;
                                /**
                                 * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                                 */
                                path: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }, {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }>, "many">>;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                             */
                            name: z.ZodOptional<z.ZodString>;
                            /**
                             * optional specify whether the ConfigMap or its keys must be defined
                             */
                            optional: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        }, {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        }>>;
                        /**
                         * downwardAPI information about the downwardAPI data to project
                         */
                        downwardAPI: z.ZodOptional<z.ZodObject<{
                            /**
                             * Items is a list of DownwardAPIVolume file
                             */
                            items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * Required: Selects a field of the pod: only annotations, labels, name and namespace are supported.
                                 */
                                fieldRef: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
                                     */
                                    apiVersion: z.ZodOptional<z.ZodString>;
                                    /**
                                     * Path of the field to select in the specified API version.
                                     */
                                    fieldPath: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                }, {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                }>>;
                                /**
                                 * Optional: mode bits used to set permissions on this file, must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                                 * @format int32
                                 */
                                mode: z.ZodOptional<z.ZodNumber>;
                                /**
                                 * Required: Path is  the relative path name of the file to be created. Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
                                 */
                                path: z.ZodString;
                                /**
                                 * Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, requests.cpu and requests.memory) are currently supported.
                                 */
                                resourceFieldRef: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * Container name: required for volumes, optional for env vars
                                     */
                                    containerName: z.ZodOptional<z.ZodString>;
                                    /**
                                     * Specifies the output format of the exposed resources, defaults to "1"
                                     * @schema union([z.number(), z.string().regex(/^(\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))(([KMGTPE]i)|[numkMGTPE]|([eE](\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))))?$/)]).optional()
                                     */
                                    divisor: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString]>>;
                                    /**
                                     * Required: resource to select
                                     */
                                    resource: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                }, {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                }>>;
                            }, "strip", z.ZodTypeAny, {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }, {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }>, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        }, {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        }>>;
                        /**
                         * secret information about the secret data to project
                         */
                        secret: z.ZodOptional<z.ZodObject<{
                            /**
                             * items if unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
                             */
                            items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the key to project.
                                 */
                                key: z.ZodString;
                                /**
                                 * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                                 * @format int32
                                 */
                                mode: z.ZodOptional<z.ZodNumber>;
                                /**
                                 * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                                 */
                                path: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }, {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }>, "many">>;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                             */
                            name: z.ZodOptional<z.ZodString>;
                            /**
                             * optional field specify whether the Secret or its key must be defined
                             */
                            optional: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        }, {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        }>>;
                        /**
                         * serviceAccountToken is information about the serviceAccountToken data to project
                         */
                        serviceAccountToken: z.ZodOptional<z.ZodObject<{
                            /**
                             * audience is the intended audience of the token. A recipient of a token must identify itself with an identifier specified in the audience of the token, and otherwise should reject the token. The audience defaults to the identifier of the apiserver.
                             */
                            audience: z.ZodOptional<z.ZodString>;
                            /**
                             * expirationSeconds is the requested duration of validity of the service account token. As the token approaches expiration, the kubelet volume plugin will proactively rotate the service account token. The kubelet will start trying to rotate the token if the token is older than 80 percent of its time to live or if the token is older than 24 hours.Defaults to 1 hour and must be at least 10 minutes.
                             * @format int64
                             */
                            expirationSeconds: z.ZodOptional<z.ZodNumber>;
                            /**
                             * path is the path relative to the mount point of the file to project the token into.
                             */
                            path: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        }, {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }, {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }>, "many">>;
                    /**
                     * Projected secret containing custom TLS certificates to encrypt output from the exporter web server
                     */
                    customTLSSecret: z.ZodOptional<z.ZodObject<{
                        /**
                         * items if unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
                         */
                        items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the key to project.
                             */
                            key: z.ZodString;
                            /**
                             * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                             * @format int32
                             */
                            mode: z.ZodOptional<z.ZodNumber>;
                            /**
                             * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                             */
                            path: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }, {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }>, "many">>;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                         */
                        name: z.ZodOptional<z.ZodString>;
                        /**
                         * optional field specify whether the Secret or its key must be defined
                         */
                        optional: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    }, {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    }>>;
                    /**
                     * The image name to use for crunchy-postgres-exporter containers. The image may also be set using the RELATED_IMAGE_PGEXPORTER environment variable.
                     */
                    image: z.ZodOptional<z.ZodString>;
                    /**
                     * Changing this value causes PostgreSQL and the exporter to restart. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers
                     */
                    resources: z.ZodOptional<z.ZodObject<{
                        /**
                         * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                         */
                        limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                        /**
                         * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                         */
                        requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                    }, "strip", z.ZodTypeAny, {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    }, {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    configuration?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    customTLSSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                }, {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    configuration?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    customTLSSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                exporter?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    configuration?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    customTLSSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                } | undefined;
            }, {
                exporter?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    configuration?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    customTLSSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                } | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            pgmonitor?: {
                exporter?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    configuration?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    customTLSSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
        }, {
            pgmonitor?: {
                exporter?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    configuration?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    customTLSSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
        }>>;
        /**
         * Whether or not the PostgreSQL cluster is being deployed to an OpenShift environment. If the field is unset, the operator will automatically detect the environment.
         */
        openshift: z.ZodOptional<z.ZodBoolean>;
        patroni: z.ZodOptional<z.ZodObject<{
            /**
             * Patroni dynamic configuration settings. Changes to this value will be automatically reloaded without validation. Changes to certain PostgreSQL parameters cause PostgreSQL to restart. More info: https://patroni.readthedocs.io/en/latest/SETTINGS.html
             */
            dynamicConfiguration: z.ZodOptional<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
            /**
             * TTL of the cluster leader lock. "Think of it as the length of time before initiation of the automatic failover process." Changing this value causes PostgreSQL to restart.
             * @default 30
             * @minimum 3
             * @format int32
             */
            leaderLeaseDurationSeconds: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
            /**
             * The port on which Patroni should listen. Changing this value causes PostgreSQL to restart.
             * @default 8008
             * @minimum 1024
             * @format int32
             */
            port: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
            /**
             * Switchover gives options to perform ad hoc switchovers in a PostgresCluster.
             */
            switchover: z.ZodOptional<z.ZodObject<{
                /**
                 * Whether or not the operator should allow switchovers in a PostgresCluster
                 */
                enabled: z.ZodBoolean;
                /**
                 * The instance that should become primary during a switchover. This field is optional when Type is "Switchover" and required when Type is "Failover". When it is not specified, a healthy replica is automatically selected.
                 */
                targetInstance: z.ZodOptional<z.ZodString>;
                /**
                 * Type of switchover to perform. Valid options are Switchover and Failover. "Switchover" changes the primary instance of a healthy PostgresCluster. "Failover" forces a particular instance to be primary, regardless of other factors. A TargetInstance must be specified to failover. NOTE: The Failover type is reserved as the "last resort" case.
                 * @default "Switchover"
                 */
                type: z.ZodDefault<z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"Switchover">, z.ZodLiteral<"Failover">]>>>;
            }, "strip", z.ZodTypeAny, {
                type: "Switchover" | "Failover";
                enabled: boolean;
                targetInstance?: string | undefined;
            }, {
                enabled: boolean;
                type?: "Switchover" | "Failover" | undefined;
                targetInstance?: string | undefined;
            }>>;
            /**
             * The interval for refreshing the leader lock and applying dynamicConfiguration. Must be less than leaderLeaseDurationSeconds. Changing this value causes PostgreSQL to restart.
             * @default 10
             * @minimum 1
             * @format int32
             */
            syncPeriodSeconds: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        }, "strip", z.ZodTypeAny, {
            port: number;
            leaderLeaseDurationSeconds: number;
            syncPeriodSeconds: number;
            dynamicConfiguration?: {} | undefined;
            switchover?: {
                type: "Switchover" | "Failover";
                enabled: boolean;
                targetInstance?: string | undefined;
            } | undefined;
        }, {
            port?: number | undefined;
            dynamicConfiguration?: {} | undefined;
            leaderLeaseDurationSeconds?: number | undefined;
            switchover?: {
                enabled: boolean;
                type?: "Switchover" | "Failover" | undefined;
                targetInstance?: string | undefined;
            } | undefined;
            syncPeriodSeconds?: number | undefined;
        }>>;
        /**
         * Suspends the rollout and reconciliation of changes made to the PostgresCluster spec.
         */
        paused: z.ZodOptional<z.ZodBoolean>;
        /**
         * The port on which PostgreSQL should listen.
         * @default 5432
         * @minimum 1024
         * @format int32
         */
        port: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        /**
         * The PostGIS extension version installed in the PostgreSQL image. When image is not set, indicates a PostGIS enabled image will be used.
         */
        postGISVersion: z.ZodOptional<z.ZodString>;
        /**
         * The major version of PostgreSQL installed in the PostgreSQL image
         * @minimum 10
         * @maximum 16
         */
        postgresVersion: z.ZodNumber;
        /**
         * The specification of a proxy that connects to PostgreSQL.
         */
        proxy: z.ZodOptional<z.ZodObject<{
            /**
             * Defines a PgBouncer proxy and connection pooler.
             */
            pgBouncer: z.ZodObject<{
                /**
                 * Scheduling constraints of a PgBouncer pod. Changing this value causes PgBouncer to restart. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/assign-pod-node
                 */
                affinity: z.ZodOptional<z.ZodObject<{
                    /**
                     * Describes node affinity scheduling rules for the pod.
                     */
                    nodeAffinity: z.ZodOptional<z.ZodObject<{
                        /**
                         * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node matches the corresponding matchExpressions; the node(s) with the highest sum are the most preferred.
                         */
                        preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * A node selector term, associated with the corresponding weight.
                             */
                            preference: z.ZodObject<{
                                /**
                                 * A list of node selector requirements by node's labels.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * The label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * A list of node selector requirements by node's fields.
                                 */
                                matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * The label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }>;
                            /**
                             * Weight associated with matching the corresponding nodeSelectorTerm, in the range 1-100.
                             * @format int32
                             */
                            weight: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }, {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }>, "many">>;
                        /**
                         * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to an update), the system may or may not try to eventually evict the pod from its node.
                         */
                        requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodObject<{
                            /**
                             * Required. A list of node selector terms. The terms are ORed.
                             */
                            nodeSelectorTerms: z.ZodArray<z.ZodObject<{
                                /**
                                 * A list of node selector requirements by node's labels.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * The label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * A list of node selector requirements by node's fields.
                                 */
                                matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * The label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        }, {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    }, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    }>>;
                    /**
                     * Describes pod affinity scheduling rules (e.g. co-locate this pod in the same node, zone, etc. as some other pod(s)).
                     */
                    podAffinity: z.ZodOptional<z.ZodObject<{
                        /**
                         * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                         */
                        preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * Required. A pod affinity term, associated with the corresponding weight.
                             */
                            podAffinityTerm: z.ZodObject<{
                                /**
                                 * A label query over a set of resources, in this case pods.
                                 */
                                labelSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                 */
                                namespaceSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                 */
                                namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                /**
                                 * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                 */
                                topologyKey: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }>;
                            /**
                             * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                             * @format int32
                             */
                            weight: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }, {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }>, "many">>;
                        /**
                         * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                         */
                        requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * A label query over a set of resources, in this case pods.
                             */
                            labelSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                             */
                            namespaceSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                             */
                            namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            /**
                             * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                             */
                            topologyKey: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    }, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    }>>;
                    /**
                     * Describes pod anti-affinity scheduling rules (e.g. avoid putting this pod in the same node, zone, etc. as some other pod(s)).
                     */
                    podAntiAffinity: z.ZodOptional<z.ZodObject<{
                        /**
                         * The scheduler will prefer to schedule pods to nodes that satisfy the anti-affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling anti-affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                         */
                        preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * Required. A pod affinity term, associated with the corresponding weight.
                             */
                            podAffinityTerm: z.ZodObject<{
                                /**
                                 * A label query over a set of resources, in this case pods.
                                 */
                                labelSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                 */
                                namespaceSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                 */
                                namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                /**
                                 * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                 */
                                topologyKey: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }>;
                            /**
                             * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                             * @format int32
                             */
                            weight: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }, {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }>, "many">>;
                        /**
                         * If the anti-affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the anti-affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                         */
                        requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * A label query over a set of resources, in this case pods.
                             */
                            labelSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                             */
                            namespaceSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                             */
                            namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            /**
                             * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                             */
                            topologyKey: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    }, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                }, {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                }>>;
                /**
                 * Configuration settings for the PgBouncer process. Changes to any of these values will be automatically reloaded without validation. Be careful, as you may put PgBouncer into an unusable state. More info: https://www.pgbouncer.org/usage.html#reload
                 */
                config: z.ZodOptional<z.ZodObject<{
                    /**
                     * PgBouncer database definitions. The key is the database requested by a client while the value is a libpq-styled connection string. The special key "\*" acts as a fallback. When this field is empty, PgBouncer is configured with a single "\*" entry that connects to the primary PostgreSQL instance. More info: https://www.pgbouncer.org/config.html#section-databases
                     */
                    databases: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    /**
                     * Files to mount under "/etc/pgbouncer". When specified, settings in the "pgbouncer.ini" file are loaded before all others. From there, other files may be included by absolute path. Changing these references causes PgBouncer to restart, but changes to the file contents are automatically reloaded. More info: https://www.pgbouncer.org/config.html#include-directive
                     */
                    files: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * configMap information about the configMap data to project
                         */
                        configMap: z.ZodOptional<z.ZodObject<{
                            /**
                             * items if unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
                             */
                            items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the key to project.
                                 */
                                key: z.ZodString;
                                /**
                                 * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                                 * @format int32
                                 */
                                mode: z.ZodOptional<z.ZodNumber>;
                                /**
                                 * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                                 */
                                path: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }, {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }>, "many">>;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                             */
                            name: z.ZodOptional<z.ZodString>;
                            /**
                             * optional specify whether the ConfigMap or its keys must be defined
                             */
                            optional: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        }, {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        }>>;
                        /**
                         * downwardAPI information about the downwardAPI data to project
                         */
                        downwardAPI: z.ZodOptional<z.ZodObject<{
                            /**
                             * Items is a list of DownwardAPIVolume file
                             */
                            items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * Required: Selects a field of the pod: only annotations, labels, name and namespace are supported.
                                 */
                                fieldRef: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
                                     */
                                    apiVersion: z.ZodOptional<z.ZodString>;
                                    /**
                                     * Path of the field to select in the specified API version.
                                     */
                                    fieldPath: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                }, {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                }>>;
                                /**
                                 * Optional: mode bits used to set permissions on this file, must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                                 * @format int32
                                 */
                                mode: z.ZodOptional<z.ZodNumber>;
                                /**
                                 * Required: Path is  the relative path name of the file to be created. Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
                                 */
                                path: z.ZodString;
                                /**
                                 * Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, requests.cpu and requests.memory) are currently supported.
                                 */
                                resourceFieldRef: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * Container name: required for volumes, optional for env vars
                                     */
                                    containerName: z.ZodOptional<z.ZodString>;
                                    /**
                                     * Specifies the output format of the exposed resources, defaults to "1"
                                     * @schema union([z.number(), z.string().regex(/^(\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))(([KMGTPE]i)|[numkMGTPE]|([eE](\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))))?$/)]).optional()
                                     */
                                    divisor: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString]>>;
                                    /**
                                     * Required: resource to select
                                     */
                                    resource: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                }, {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                }>>;
                            }, "strip", z.ZodTypeAny, {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }, {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }>, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        }, {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        }>>;
                        /**
                         * secret information about the secret data to project
                         */
                        secret: z.ZodOptional<z.ZodObject<{
                            /**
                             * items if unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
                             */
                            items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the key to project.
                                 */
                                key: z.ZodString;
                                /**
                                 * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                                 * @format int32
                                 */
                                mode: z.ZodOptional<z.ZodNumber>;
                                /**
                                 * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                                 */
                                path: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }, {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }>, "many">>;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                             */
                            name: z.ZodOptional<z.ZodString>;
                            /**
                             * optional field specify whether the Secret or its key must be defined
                             */
                            optional: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        }, {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        }>>;
                        /**
                         * serviceAccountToken is information about the serviceAccountToken data to project
                         */
                        serviceAccountToken: z.ZodOptional<z.ZodObject<{
                            /**
                             * audience is the intended audience of the token. A recipient of a token must identify itself with an identifier specified in the audience of the token, and otherwise should reject the token. The audience defaults to the identifier of the apiserver.
                             */
                            audience: z.ZodOptional<z.ZodString>;
                            /**
                             * expirationSeconds is the requested duration of validity of the service account token. As the token approaches expiration, the kubelet volume plugin will proactively rotate the service account token. The kubelet will start trying to rotate the token if the token is older than 80 percent of its time to live or if the token is older than 24 hours.Defaults to 1 hour and must be at least 10 minutes.
                             * @format int64
                             */
                            expirationSeconds: z.ZodOptional<z.ZodNumber>;
                            /**
                             * path is the path relative to the mount point of the file to project the token into.
                             */
                            path: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        }, {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }, {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }>, "many">>;
                    /**
                     * Settings that apply to the entire PgBouncer process. More info: https://www.pgbouncer.org/config.html
                     */
                    global: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    /**
                     * Connection settings specific to particular users. More info: https://www.pgbouncer.org/config.html#section-users
                     */
                    users: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                }, "strip", z.ZodTypeAny, {
                    users?: Record<string, string> | undefined;
                    databases?: Record<string, string> | undefined;
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    global?: Record<string, string> | undefined;
                }, {
                    users?: Record<string, string> | undefined;
                    databases?: Record<string, string> | undefined;
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    global?: Record<string, string> | undefined;
                }>>;
                /**
                 * Custom sidecars for a PgBouncer pod. Changing this value causes PgBouncer to restart.
                 */
                containers: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * Arguments to the entrypoint. The container image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell
                     */
                    args: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    /**
                     * Entrypoint array. Not executed within a shell. The container image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell
                     */
                    command: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    /**
                     * List of environment variables to set in the container. Cannot be updated.
                     */
                    env: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * Name of the environment variable. Must be a C_IDENTIFIER.
                         */
                        name: z.ZodString;
                        /**
                         * Variable references $(VAR_NAME) are expanded using the previously defined environment variables in the container and any service environment variables. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "".
                         */
                        value: z.ZodOptional<z.ZodString>;
                        /**
                         * Source for the environment variable's value. Cannot be used if value is not empty.
                         */
                        valueFrom: z.ZodOptional<z.ZodObject<{
                            /**
                             * Selects a key of a ConfigMap.
                             */
                            configMapKeyRef: z.ZodOptional<z.ZodObject<{
                                /**
                                 * The key to select.
                                 */
                                key: z.ZodString;
                                /**
                                 * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                                 */
                                name: z.ZodOptional<z.ZodString>;
                                /**
                                 * Specify whether the ConfigMap or its key must be defined
                                 */
                                optional: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            }, {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            }>>;
                            /**
                             * Selects a field of the pod: supports metadata.name, metadata.namespace, `metadata.labels['<KEY>']`, `metadata.annotations['<KEY>']`, spec.nodeName, spec.serviceAccountName, status.hostIP, status.podIP, status.podIPs.
                             */
                            fieldRef: z.ZodOptional<z.ZodObject<{
                                /**
                                 * Version of the schema the FieldPath is written in terms of, defaults to "v1".
                                 */
                                apiVersion: z.ZodOptional<z.ZodString>;
                                /**
                                 * Path of the field to select in the specified API version.
                                 */
                                fieldPath: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            }, {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            }>>;
                            /**
                             * Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, limits.ephemeral-storage, requests.cpu, requests.memory and requests.ephemeral-storage) are currently supported.
                             */
                            resourceFieldRef: z.ZodOptional<z.ZodObject<{
                                /**
                                 * Container name: required for volumes, optional for env vars
                                 */
                                containerName: z.ZodOptional<z.ZodString>;
                                /**
                                 * Specifies the output format of the exposed resources, defaults to "1"
                                 * @schema union([z.number(), z.string().regex(/^(\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))(([KMGTPE]i)|[numkMGTPE]|([eE](\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))))?$/)]).optional()
                                 */
                                divisor: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString]>>;
                                /**
                                 * Required: resource to select
                                 */
                                resource: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            }, {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            }>>;
                            /**
                             * Selects a key of a secret in the pod's namespace
                             */
                            secretKeyRef: z.ZodOptional<z.ZodObject<{
                                /**
                                 * The key of the secret to select from.  Must be a valid secret key.
                                 */
                                key: z.ZodString;
                                /**
                                 * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                                 */
                                name: z.ZodOptional<z.ZodString>;
                                /**
                                 * Specify whether the Secret or its key must be defined
                                 */
                                optional: z.ZodOptional<z.ZodBoolean>;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            }, {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                            configMapKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                            secretKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                        }, {
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                            configMapKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                            secretKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        name: string;
                        value?: string | undefined;
                        valueFrom?: {
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                            configMapKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                            secretKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                        } | undefined;
                    }, {
                        name: string;
                        value?: string | undefined;
                        valueFrom?: {
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                            configMapKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                            secretKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                        } | undefined;
                    }>, "many">>;
                    /**
                     * List of sources to populate environment variables in the container. The keys defined within a source must be a C_IDENTIFIER. All invalid keys will be reported as an event when the container is starting. When a key exists in multiple sources, the value associated with the last source will take precedence. Values defined by an Env with a duplicate key will take precedence. Cannot be updated.
                     */
                    envFrom: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * The ConfigMap to select from
                         */
                        configMapRef: z.ZodOptional<z.ZodObject<{
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                             */
                            name: z.ZodOptional<z.ZodString>;
                            /**
                             * Specify whether the ConfigMap must be defined
                             */
                            optional: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        }, {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        }>>;
                        /**
                         * An optional identifier to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER.
                         */
                        prefix: z.ZodOptional<z.ZodString>;
                        /**
                         * The Secret to select from
                         */
                        secretRef: z.ZodOptional<z.ZodObject<{
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                             */
                            name: z.ZodOptional<z.ZodString>;
                            /**
                             * Specify whether the Secret must be defined
                             */
                            optional: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        }, {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        configMapRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        prefix?: string | undefined;
                        secretRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    }, {
                        configMapRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        prefix?: string | undefined;
                        secretRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    }>, "many">>;
                    /**
                     * Container image name. More info: https://kubernetes.io/docs/concepts/containers/images This field is optional to allow higher level config management to default or override container images in workload controllers like Deployments and StatefulSets.
                     */
                    image: z.ZodOptional<z.ZodString>;
                    /**
                     * Image pull policy. One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: https://kubernetes.io/docs/concepts/containers/images#updating-images
                     */
                    imagePullPolicy: z.ZodOptional<z.ZodString>;
                    /**
                     * Actions that the management system should take in response to container lifecycle events. Cannot be updated.
                     */
                    lifecycle: z.ZodOptional<z.ZodObject<{
                        /**
                         * PostStart is called immediately after a container is created. If the handler fails, the container is terminated and restarted according to its restart policy. Other management of the container blocks until the hook completes. More info: https://kubernetes.io/docs/concepts/containers/container-lifecycle-hooks/#container-hooks
                         */
                        postStart: z.ZodOptional<z.ZodObject<{
                            /**
                             * Exec specifies the action to take.
                             */
                            exec: z.ZodOptional<z.ZodObject<{
                                /**
                                 * Command is the command line to execute inside the container, the working directory for the command  is root ('/') in the container's filesystem. The command is simply exec'd, it is not run inside a shell, so traditional shell instructions ('|', etc) won't work. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
                                 */
                                command: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                command?: string[] | undefined;
                            }, {
                                command?: string[] | undefined;
                            }>>;
                            /**
                             * HTTPGet specifies the http request to perform.
                             */
                            httpGet: z.ZodOptional<z.ZodObject<{
                                /**
                                 * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
                                 */
                                host: z.ZodOptional<z.ZodString>;
                                /**
                                 * Custom headers to set in the request. HTTP allows repeated headers.
                                 */
                                httpHeaders: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * The header field name
                                     */
                                    name: z.ZodString;
                                    /**
                                     * The header field value
                                     */
                                    value: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    name: string;
                                    value: string;
                                }, {
                                    name: string;
                                    value: string;
                                }>, "many">>;
                                /**
                                 * Path to access on the HTTP server.
                                 */
                                path: z.ZodOptional<z.ZodString>;
                                /**
                                 * Name or number of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                                 */
                                port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                                /**
                                 * Scheme to use for connecting to the host. Defaults to HTTP.
                                 */
                                scheme: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            }, {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            }>>;
                            /**
                             * Deprecated. TCPSocket is NOT supported as a LifecycleHandler and kept for the backward compatibility. There are no validation of this field and lifecycle hooks will fail in runtime when tcp handler is specified.
                             */
                            tcpSocket: z.ZodOptional<z.ZodObject<{
                                /**
                                 * Optional: Host name to connect to, defaults to the pod IP.
                                 */
                                host: z.ZodOptional<z.ZodString>;
                                /**
                                 * Number or name of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                                 */
                                port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                            }, "strip", z.ZodTypeAny, {
                                port: string | number;
                                host?: string | undefined;
                            }, {
                                port: string | number;
                                host?: string | undefined;
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        }, {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        }>>;
                        /**
                         * PreStop is called immediately before a container is terminated due to an API request or management event such as liveness/startup probe failure, preemption, resource contention, etc. The handler is not called if the container crashes or exits. The Pod's termination grace period countdown begins before the PreStop hook is executed. Regardless of the outcome of the handler, the container will eventually terminate within the Pod's termination grace period (unless delayed by finalizers). Other management of the container blocks until the hook completes or until the termination grace period is reached. More info: https://kubernetes.io/docs/concepts/containers/container-lifecycle-hooks/#container-hooks
                         */
                        preStop: z.ZodOptional<z.ZodObject<{
                            /**
                             * Exec specifies the action to take.
                             */
                            exec: z.ZodOptional<z.ZodObject<{
                                /**
                                 * Command is the command line to execute inside the container, the working directory for the command  is root ('/') in the container's filesystem. The command is simply exec'd, it is not run inside a shell, so traditional shell instructions ('|', etc) won't work. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
                                 */
                                command: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                command?: string[] | undefined;
                            }, {
                                command?: string[] | undefined;
                            }>>;
                            /**
                             * HTTPGet specifies the http request to perform.
                             */
                            httpGet: z.ZodOptional<z.ZodObject<{
                                /**
                                 * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
                                 */
                                host: z.ZodOptional<z.ZodString>;
                                /**
                                 * Custom headers to set in the request. HTTP allows repeated headers.
                                 */
                                httpHeaders: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * The header field name
                                     */
                                    name: z.ZodString;
                                    /**
                                     * The header field value
                                     */
                                    value: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    name: string;
                                    value: string;
                                }, {
                                    name: string;
                                    value: string;
                                }>, "many">>;
                                /**
                                 * Path to access on the HTTP server.
                                 */
                                path: z.ZodOptional<z.ZodString>;
                                /**
                                 * Name or number of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                                 */
                                port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                                /**
                                 * Scheme to use for connecting to the host. Defaults to HTTP.
                                 */
                                scheme: z.ZodOptional<z.ZodString>;
                            }, "strip", z.ZodTypeAny, {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            }, {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            }>>;
                            /**
                             * Deprecated. TCPSocket is NOT supported as a LifecycleHandler and kept for the backward compatibility. There are no validation of this field and lifecycle hooks will fail in runtime when tcp handler is specified.
                             */
                            tcpSocket: z.ZodOptional<z.ZodObject<{
                                /**
                                 * Optional: Host name to connect to, defaults to the pod IP.
                                 */
                                host: z.ZodOptional<z.ZodString>;
                                /**
                                 * Number or name of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                                 */
                                port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                            }, "strip", z.ZodTypeAny, {
                                port: string | number;
                                host?: string | undefined;
                            }, {
                                port: string | number;
                                host?: string | undefined;
                            }>>;
                        }, "strip", z.ZodTypeAny, {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        }, {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        postStart?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                        preStop?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                    }, {
                        postStart?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                        preStop?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                    }>>;
                    /**
                     * Periodic probe of container liveness. Container will be restarted if the probe fails. Cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
                     */
                    livenessProbe: z.ZodOptional<z.ZodObject<{
                        /**
                         * Exec specifies the action to take.
                         */
                        exec: z.ZodOptional<z.ZodObject<{
                            /**
                             * Command is the command line to execute inside the container, the working directory for the command  is root ('/') in the container's filesystem. The command is simply exec'd, it is not run inside a shell, so traditional shell instructions ('|', etc) won't work. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
                             */
                            command: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            command?: string[] | undefined;
                        }, {
                            command?: string[] | undefined;
                        }>>;
                        /**
                         * Minimum consecutive failures for the probe to be considered failed after having succeeded. Defaults to 3. Minimum value is 1.
                         * @format int32
                         */
                        failureThreshold: z.ZodOptional<z.ZodNumber>;
                        /**
                         * GRPC specifies an action involving a GRPC port. This is a beta field and requires enabling GRPCContainerProbe feature gate.
                         */
                        grpc: z.ZodOptional<z.ZodObject<{
                            /**
                             * Port number of the gRPC service. Number must be in the range 1 to 65535.
                             * @format int32
                             */
                            port: z.ZodNumber;
                            /**
                             * Service is the name of the service to place in the gRPC HealthCheckRequest (see https://github.com/grpc/grpc/blob/master/doc/health-checking.md).
                             *  If this is not specified, the default behavior is defined by gRPC.
                             */
                            service: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            port: number;
                            service?: string | undefined;
                        }, {
                            port: number;
                            service?: string | undefined;
                        }>>;
                        /**
                         * HTTPGet specifies the http request to perform.
                         */
                        httpGet: z.ZodOptional<z.ZodObject<{
                            /**
                             * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
                             */
                            host: z.ZodOptional<z.ZodString>;
                            /**
                             * Custom headers to set in the request. HTTP allows repeated headers.
                             */
                            httpHeaders: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * The header field name
                                 */
                                name: z.ZodString;
                                /**
                                 * The header field value
                                 */
                                value: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                name: string;
                                value: string;
                            }, {
                                name: string;
                                value: string;
                            }>, "many">>;
                            /**
                             * Path to access on the HTTP server.
                             */
                            path: z.ZodOptional<z.ZodString>;
                            /**
                             * Name or number of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                             */
                            port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                            /**
                             * Scheme to use for connecting to the host. Defaults to HTTP.
                             */
                            scheme: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        }, {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        }>>;
                        /**
                         * Number of seconds after the container has started before liveness probes are initiated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
                         * @format int32
                         */
                        initialDelaySeconds: z.ZodOptional<z.ZodNumber>;
                        /**
                         * How often (in seconds) to perform the probe. Default to 10 seconds. Minimum value is 1.
                         * @format int32
                         */
                        periodSeconds: z.ZodOptional<z.ZodNumber>;
                        /**
                         * Minimum consecutive successes for the probe to be considered successful after having failed. Defaults to 1. Must be 1 for liveness and startup. Minimum value is 1.
                         * @format int32
                         */
                        successThreshold: z.ZodOptional<z.ZodNumber>;
                        /**
                         * TCPSocket specifies an action involving a TCP port.
                         */
                        tcpSocket: z.ZodOptional<z.ZodObject<{
                            /**
                             * Optional: Host name to connect to, defaults to the pod IP.
                             */
                            host: z.ZodOptional<z.ZodString>;
                            /**
                             * Number or name of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                             */
                            port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                        }, "strip", z.ZodTypeAny, {
                            port: string | number;
                            host?: string | undefined;
                        }, {
                            port: string | number;
                            host?: string | undefined;
                        }>>;
                        /**
                         * Optional duration in seconds the pod needs to terminate gracefully upon probe failure. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process. If this value is nil, the pod's terminationGracePeriodSeconds will be used. Otherwise, this value overrides the value provided by the pod spec. Value must be non-negative integer. The value zero indicates stop immediately via the kill signal (no opportunity to shut down). This is a beta field and requires enabling ProbeTerminationGracePeriod feature gate. Minimum value is 1. spec.terminationGracePeriodSeconds is used if unset.
                         * @format int64
                         */
                        terminationGracePeriodSeconds: z.ZodOptional<z.ZodNumber>;
                        /**
                         * Number of seconds after which the probe times out. Defaults to 1 second. Minimum value is 1. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
                         * @format int32
                         */
                        timeoutSeconds: z.ZodOptional<z.ZodNumber>;
                    }, "strip", z.ZodTypeAny, {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    }, {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    }>>;
                    /**
                     * Name of the container specified as a DNS_LABEL. Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
                     */
                    name: z.ZodString;
                    /**
                     * List of ports to expose from the container. Exposing a port here gives the system additional information about the network connections a container uses, but is primarily informational. Not specifying a port here DOES NOT prevent that port from being exposed. Any port which is listening on the default "0.0.0.0" address inside a container will be accessible from the network. Cannot be updated.
                     */
                    ports: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * Number of port to expose on the pod's IP address. This must be a valid port number, 0 < x < 65536.
                         * @format int32
                         */
                        containerPort: z.ZodNumber;
                        /**
                         * What host IP to bind the external port to.
                         */
                        hostIP: z.ZodOptional<z.ZodString>;
                        /**
                         * Number of port to expose on the host. If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this.
                         * @format int32
                         */
                        hostPort: z.ZodOptional<z.ZodNumber>;
                        /**
                         * If specified, this must be an IANA_SVC_NAME and unique within the pod. Each named port in a pod must have a unique name. Name for the port that can be referred to by services.
                         */
                        name: z.ZodOptional<z.ZodString>;
                        /**
                         * Protocol for port. Must be UDP, TCP, or SCTP. Defaults to "TCP".
                         * @default "TCP"
                         */
                        protocol: z.ZodDefault<z.ZodOptional<z.ZodString>>;
                    }, "strip", z.ZodTypeAny, {
                        containerPort: number;
                        protocol: string;
                        name?: string | undefined;
                        hostIP?: string | undefined;
                        hostPort?: number | undefined;
                    }, {
                        containerPort: number;
                        name?: string | undefined;
                        hostIP?: string | undefined;
                        hostPort?: number | undefined;
                        protocol?: string | undefined;
                    }>, "many">>;
                    /**
                     * Periodic probe of container service readiness. Container will be removed from service endpoints if the probe fails. Cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
                     */
                    readinessProbe: z.ZodOptional<z.ZodObject<{
                        /**
                         * Exec specifies the action to take.
                         */
                        exec: z.ZodOptional<z.ZodObject<{
                            /**
                             * Command is the command line to execute inside the container, the working directory for the command  is root ('/') in the container's filesystem. The command is simply exec'd, it is not run inside a shell, so traditional shell instructions ('|', etc) won't work. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
                             */
                            command: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            command?: string[] | undefined;
                        }, {
                            command?: string[] | undefined;
                        }>>;
                        /**
                         * Minimum consecutive failures for the probe to be considered failed after having succeeded. Defaults to 3. Minimum value is 1.
                         * @format int32
                         */
                        failureThreshold: z.ZodOptional<z.ZodNumber>;
                        /**
                         * GRPC specifies an action involving a GRPC port. This is a beta field and requires enabling GRPCContainerProbe feature gate.
                         */
                        grpc: z.ZodOptional<z.ZodObject<{
                            /**
                             * Port number of the gRPC service. Number must be in the range 1 to 65535.
                             * @format int32
                             */
                            port: z.ZodNumber;
                            /**
                             * Service is the name of the service to place in the gRPC HealthCheckRequest (see https://github.com/grpc/grpc/blob/master/doc/health-checking.md).
                             *  If this is not specified, the default behavior is defined by gRPC.
                             */
                            service: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            port: number;
                            service?: string | undefined;
                        }, {
                            port: number;
                            service?: string | undefined;
                        }>>;
                        /**
                         * HTTPGet specifies the http request to perform.
                         */
                        httpGet: z.ZodOptional<z.ZodObject<{
                            /**
                             * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
                             */
                            host: z.ZodOptional<z.ZodString>;
                            /**
                             * Custom headers to set in the request. HTTP allows repeated headers.
                             */
                            httpHeaders: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * The header field name
                                 */
                                name: z.ZodString;
                                /**
                                 * The header field value
                                 */
                                value: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                name: string;
                                value: string;
                            }, {
                                name: string;
                                value: string;
                            }>, "many">>;
                            /**
                             * Path to access on the HTTP server.
                             */
                            path: z.ZodOptional<z.ZodString>;
                            /**
                             * Name or number of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                             */
                            port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                            /**
                             * Scheme to use for connecting to the host. Defaults to HTTP.
                             */
                            scheme: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        }, {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        }>>;
                        /**
                         * Number of seconds after the container has started before liveness probes are initiated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
                         * @format int32
                         */
                        initialDelaySeconds: z.ZodOptional<z.ZodNumber>;
                        /**
                         * How often (in seconds) to perform the probe. Default to 10 seconds. Minimum value is 1.
                         * @format int32
                         */
                        periodSeconds: z.ZodOptional<z.ZodNumber>;
                        /**
                         * Minimum consecutive successes for the probe to be considered successful after having failed. Defaults to 1. Must be 1 for liveness and startup. Minimum value is 1.
                         * @format int32
                         */
                        successThreshold: z.ZodOptional<z.ZodNumber>;
                        /**
                         * TCPSocket specifies an action involving a TCP port.
                         */
                        tcpSocket: z.ZodOptional<z.ZodObject<{
                            /**
                             * Optional: Host name to connect to, defaults to the pod IP.
                             */
                            host: z.ZodOptional<z.ZodString>;
                            /**
                             * Number or name of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                             */
                            port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                        }, "strip", z.ZodTypeAny, {
                            port: string | number;
                            host?: string | undefined;
                        }, {
                            port: string | number;
                            host?: string | undefined;
                        }>>;
                        /**
                         * Optional duration in seconds the pod needs to terminate gracefully upon probe failure. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process. If this value is nil, the pod's terminationGracePeriodSeconds will be used. Otherwise, this value overrides the value provided by the pod spec. Value must be non-negative integer. The value zero indicates stop immediately via the kill signal (no opportunity to shut down). This is a beta field and requires enabling ProbeTerminationGracePeriod feature gate. Minimum value is 1. spec.terminationGracePeriodSeconds is used if unset.
                         * @format int64
                         */
                        terminationGracePeriodSeconds: z.ZodOptional<z.ZodNumber>;
                        /**
                         * Number of seconds after which the probe times out. Defaults to 1 second. Minimum value is 1. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
                         * @format int32
                         */
                        timeoutSeconds: z.ZodOptional<z.ZodNumber>;
                    }, "strip", z.ZodTypeAny, {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    }, {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    }>>;
                    /**
                     * Compute Resources required by this container. Cannot be updated. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                     */
                    resources: z.ZodOptional<z.ZodObject<{
                        /**
                         * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                         */
                        limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                        /**
                         * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                         */
                        requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                    }, "strip", z.ZodTypeAny, {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    }, {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    }>>;
                    /**
                     * SecurityContext defines the security options the container should be run with. If set, the fields of SecurityContext override the equivalent fields of PodSecurityContext. More info: https://kubernetes.io/docs/tasks/configure-pod-container/security-context/
                     */
                    securityContext: z.ZodOptional<z.ZodObject<{
                        /**
                         * AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process. This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN Note that this field cannot be set when spec.os.name is windows.
                         */
                        allowPrivilegeEscalation: z.ZodOptional<z.ZodBoolean>;
                        /**
                         * The capabilities to add/drop when running containers. Defaults to the default set of capabilities granted by the container runtime. Note that this field cannot be set when spec.os.name is windows.
                         */
                        capabilities: z.ZodOptional<z.ZodObject<{
                            /**
                             * Added capabilities
                             */
                            add: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            /**
                             * Removed capabilities
                             */
                            drop: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            add?: string[] | undefined;
                            drop?: string[] | undefined;
                        }, {
                            add?: string[] | undefined;
                            drop?: string[] | undefined;
                        }>>;
                        /**
                         * Run container in privileged mode. Processes in privileged containers are essentially equivalent to root on the host. Defaults to false. Note that this field cannot be set when spec.os.name is windows.
                         */
                        privileged: z.ZodOptional<z.ZodBoolean>;
                        /**
                         * procMount denotes the type of proc mount to use for the containers. The default is DefaultProcMount which uses the container runtime defaults for readonly paths and masked paths. This requires the ProcMountType feature flag to be enabled. Note that this field cannot be set when spec.os.name is windows.
                         */
                        procMount: z.ZodOptional<z.ZodString>;
                        /**
                         * Whether this container has a read-only root filesystem. Default is false. Note that this field cannot be set when spec.os.name is windows.
                         */
                        readOnlyRootFilesystem: z.ZodOptional<z.ZodBoolean>;
                        /**
                         * The GID to run the entrypoint of the container process. Uses runtime default if unset. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows.
                         * @format int64
                         */
                        runAsGroup: z.ZodOptional<z.ZodNumber>;
                        /**
                         * Indicates that the container must run as a non-root user. If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
                         */
                        runAsNonRoot: z.ZodOptional<z.ZodBoolean>;
                        /**
                         * The UID to run the entrypoint of the container process. Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows.
                         * @format int64
                         */
                        runAsUser: z.ZodOptional<z.ZodNumber>;
                        /**
                         * The SELinux context to be applied to the container. If unspecified, the container runtime will allocate a random SELinux context for each container.  May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows.
                         */
                        seLinuxOptions: z.ZodOptional<z.ZodObject<{
                            /**
                             * Level is SELinux level label that applies to the container.
                             */
                            level: z.ZodOptional<z.ZodString>;
                            /**
                             * Role is a SELinux role label that applies to the container.
                             */
                            role: z.ZodOptional<z.ZodString>;
                            /**
                             * Type is a SELinux type label that applies to the container.
                             */
                            type: z.ZodOptional<z.ZodString>;
                            /**
                             * User is a SELinux user label that applies to the container.
                             */
                            user: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            type?: string | undefined;
                            user?: string | undefined;
                            level?: string | undefined;
                            role?: string | undefined;
                        }, {
                            type?: string | undefined;
                            user?: string | undefined;
                            level?: string | undefined;
                            role?: string | undefined;
                        }>>;
                        /**
                         * The seccomp options to use by this container. If seccomp options are provided at both the pod & container level, the container options override the pod options. Note that this field cannot be set when spec.os.name is windows.
                         */
                        seccompProfile: z.ZodOptional<z.ZodObject<{
                            /**
                             * localhostProfile indicates a profile defined in a file on the node should be used. The profile must be preconfigured on the node to work. Must be a descending path, relative to the kubelet's configured seccomp profile location. Must only be set if type is "Localhost".
                             */
                            localhostProfile: z.ZodOptional<z.ZodString>;
                            /**
                             * type indicates which kind of seccomp profile will be applied. Valid options are: Localhost - a profile defined in a file on the node should be used. RuntimeDefault - the container runtime default profile should be used. Unconfined - no profile should be applied.
                             */
                            type: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            type: string;
                            localhostProfile?: string | undefined;
                        }, {
                            type: string;
                            localhostProfile?: string | undefined;
                        }>>;
                        /**
                         * The Windows specific settings applied to all containers. If unspecified, the options from the PodSecurityContext will be used. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is linux.
                         */
                        windowsOptions: z.ZodOptional<z.ZodObject<{
                            /**
                             * GMSACredentialSpec is where the GMSA admission webhook (https://github.com/kubernetes-sigs/windows-gmsa) inlines the contents of the GMSA credential spec named by the GMSACredentialSpecName field.
                             */
                            gmsaCredentialSpec: z.ZodOptional<z.ZodString>;
                            /**
                             * GMSACredentialSpecName is the name of the GMSA credential spec to use.
                             */
                            gmsaCredentialSpecName: z.ZodOptional<z.ZodString>;
                            /**
                             * HostProcess determines if a container should be run as a 'Host Process' container. This field is alpha-level and will only be honored by components that enable the WindowsHostProcessContainers feature flag. Setting this field without the feature flag will result in errors when validating the Pod. All of a Pod's containers must have the same effective HostProcess value (it is not allowed to have a mix of HostProcess containers and non-HostProcess containers).  In addition, if HostProcess is true then HostNetwork must also be set to true.
                             */
                            hostProcess: z.ZodOptional<z.ZodBoolean>;
                            /**
                             * The UserName in Windows to run the entrypoint of the container process. Defaults to the user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.
                             */
                            runAsUserName: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            gmsaCredentialSpec?: string | undefined;
                            gmsaCredentialSpecName?: string | undefined;
                            hostProcess?: boolean | undefined;
                            runAsUserName?: string | undefined;
                        }, {
                            gmsaCredentialSpec?: string | undefined;
                            gmsaCredentialSpecName?: string | undefined;
                            hostProcess?: boolean | undefined;
                            runAsUserName?: string | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        allowPrivilegeEscalation?: boolean | undefined;
                        capabilities?: {
                            add?: string[] | undefined;
                            drop?: string[] | undefined;
                        } | undefined;
                        privileged?: boolean | undefined;
                        procMount?: string | undefined;
                        readOnlyRootFilesystem?: boolean | undefined;
                        runAsGroup?: number | undefined;
                        runAsNonRoot?: boolean | undefined;
                        runAsUser?: number | undefined;
                        seLinuxOptions?: {
                            type?: string | undefined;
                            user?: string | undefined;
                            level?: string | undefined;
                            role?: string | undefined;
                        } | undefined;
                        seccompProfile?: {
                            type: string;
                            localhostProfile?: string | undefined;
                        } | undefined;
                        windowsOptions?: {
                            gmsaCredentialSpec?: string | undefined;
                            gmsaCredentialSpecName?: string | undefined;
                            hostProcess?: boolean | undefined;
                            runAsUserName?: string | undefined;
                        } | undefined;
                    }, {
                        allowPrivilegeEscalation?: boolean | undefined;
                        capabilities?: {
                            add?: string[] | undefined;
                            drop?: string[] | undefined;
                        } | undefined;
                        privileged?: boolean | undefined;
                        procMount?: string | undefined;
                        readOnlyRootFilesystem?: boolean | undefined;
                        runAsGroup?: number | undefined;
                        runAsNonRoot?: boolean | undefined;
                        runAsUser?: number | undefined;
                        seLinuxOptions?: {
                            type?: string | undefined;
                            user?: string | undefined;
                            level?: string | undefined;
                            role?: string | undefined;
                        } | undefined;
                        seccompProfile?: {
                            type: string;
                            localhostProfile?: string | undefined;
                        } | undefined;
                        windowsOptions?: {
                            gmsaCredentialSpec?: string | undefined;
                            gmsaCredentialSpecName?: string | undefined;
                            hostProcess?: boolean | undefined;
                            runAsUserName?: string | undefined;
                        } | undefined;
                    }>>;
                    /**
                     * StartupProbe indicates that the Pod has successfully initialized. If specified, no other probes are executed until this completes successfully. If this probe fails, the Pod will be restarted, just as if the livenessProbe failed. This can be used to provide different probe parameters at the beginning of a Pod's lifecycle, when it might take a long time to load data or warm a cache, than during steady-state operation. This cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
                     */
                    startupProbe: z.ZodOptional<z.ZodObject<{
                        /**
                         * Exec specifies the action to take.
                         */
                        exec: z.ZodOptional<z.ZodObject<{
                            /**
                             * Command is the command line to execute inside the container, the working directory for the command  is root ('/') in the container's filesystem. The command is simply exec'd, it is not run inside a shell, so traditional shell instructions ('|', etc) won't work. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy.
                             */
                            command: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            command?: string[] | undefined;
                        }, {
                            command?: string[] | undefined;
                        }>>;
                        /**
                         * Minimum consecutive failures for the probe to be considered failed after having succeeded. Defaults to 3. Minimum value is 1.
                         * @format int32
                         */
                        failureThreshold: z.ZodOptional<z.ZodNumber>;
                        /**
                         * GRPC specifies an action involving a GRPC port. This is a beta field and requires enabling GRPCContainerProbe feature gate.
                         */
                        grpc: z.ZodOptional<z.ZodObject<{
                            /**
                             * Port number of the gRPC service. Number must be in the range 1 to 65535.
                             * @format int32
                             */
                            port: z.ZodNumber;
                            /**
                             * Service is the name of the service to place in the gRPC HealthCheckRequest (see https://github.com/grpc/grpc/blob/master/doc/health-checking.md).
                             *  If this is not specified, the default behavior is defined by gRPC.
                             */
                            service: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            port: number;
                            service?: string | undefined;
                        }, {
                            port: number;
                            service?: string | undefined;
                        }>>;
                        /**
                         * HTTPGet specifies the http request to perform.
                         */
                        httpGet: z.ZodOptional<z.ZodObject<{
                            /**
                             * Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead.
                             */
                            host: z.ZodOptional<z.ZodString>;
                            /**
                             * Custom headers to set in the request. HTTP allows repeated headers.
                             */
                            httpHeaders: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * The header field name
                                 */
                                name: z.ZodString;
                                /**
                                 * The header field value
                                 */
                                value: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                name: string;
                                value: string;
                            }, {
                                name: string;
                                value: string;
                            }>, "many">>;
                            /**
                             * Path to access on the HTTP server.
                             */
                            path: z.ZodOptional<z.ZodString>;
                            /**
                             * Name or number of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                             */
                            port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                            /**
                             * Scheme to use for connecting to the host. Defaults to HTTP.
                             */
                            scheme: z.ZodOptional<z.ZodString>;
                        }, "strip", z.ZodTypeAny, {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        }, {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        }>>;
                        /**
                         * Number of seconds after the container has started before liveness probes are initiated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
                         * @format int32
                         */
                        initialDelaySeconds: z.ZodOptional<z.ZodNumber>;
                        /**
                         * How often (in seconds) to perform the probe. Default to 10 seconds. Minimum value is 1.
                         * @format int32
                         */
                        periodSeconds: z.ZodOptional<z.ZodNumber>;
                        /**
                         * Minimum consecutive successes for the probe to be considered successful after having failed. Defaults to 1. Must be 1 for liveness and startup. Minimum value is 1.
                         * @format int32
                         */
                        successThreshold: z.ZodOptional<z.ZodNumber>;
                        /**
                         * TCPSocket specifies an action involving a TCP port.
                         */
                        tcpSocket: z.ZodOptional<z.ZodObject<{
                            /**
                             * Optional: Host name to connect to, defaults to the pod IP.
                             */
                            host: z.ZodOptional<z.ZodString>;
                            /**
                             * Number or name of the port to access on the container. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME.
                             */
                            port: z.ZodUnion<[z.ZodNumber, z.ZodString]>;
                        }, "strip", z.ZodTypeAny, {
                            port: string | number;
                            host?: string | undefined;
                        }, {
                            port: string | number;
                            host?: string | undefined;
                        }>>;
                        /**
                         * Optional duration in seconds the pod needs to terminate gracefully upon probe failure. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process. If this value is nil, the pod's terminationGracePeriodSeconds will be used. Otherwise, this value overrides the value provided by the pod spec. Value must be non-negative integer. The value zero indicates stop immediately via the kill signal (no opportunity to shut down). This is a beta field and requires enabling ProbeTerminationGracePeriod feature gate. Minimum value is 1. spec.terminationGracePeriodSeconds is used if unset.
                         * @format int64
                         */
                        terminationGracePeriodSeconds: z.ZodOptional<z.ZodNumber>;
                        /**
                         * Number of seconds after which the probe times out. Defaults to 1 second. Minimum value is 1. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes
                         * @format int32
                         */
                        timeoutSeconds: z.ZodOptional<z.ZodNumber>;
                    }, "strip", z.ZodTypeAny, {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    }, {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    }>>;
                    /**
                     * Whether this container should allocate a buffer for stdin in the container runtime. If this is not set, reads from stdin in the container will always result in EOF. Default is false.
                     */
                    stdin: z.ZodOptional<z.ZodBoolean>;
                    /**
                     * Whether the container runtime should close the stdin channel after it has been opened by a single attach. When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF. Default is false
                     */
                    stdinOnce: z.ZodOptional<z.ZodBoolean>;
                    /**
                     * Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem. Message written is intended to be brief final status, such as an assertion failure message. Will be truncated by the node if greater than 4096 bytes. The total message length across all containers will be limited to 12kb. Defaults to /dev/termination-log. Cannot be updated.
                     */
                    terminationMessagePath: z.ZodOptional<z.ZodString>;
                    /**
                     * Indicate how the termination message should be populated. File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
                     */
                    terminationMessagePolicy: z.ZodOptional<z.ZodString>;
                    /**
                     * Whether this container should allocate a TTY for itself, also requires 'stdin' to be true. Default is false.
                     */
                    tty: z.ZodOptional<z.ZodBoolean>;
                    /**
                     * volumeDevices is the list of block devices to be used by the container.
                     */
                    volumeDevices: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * devicePath is the path inside of the container that the device will be mapped to.
                         */
                        devicePath: z.ZodString;
                        /**
                         * name must match the name of a persistentVolumeClaim in the pod
                         */
                        name: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        name: string;
                        devicePath: string;
                    }, {
                        name: string;
                        devicePath: string;
                    }>, "many">>;
                    /**
                     * Pod volumes to mount into the container's filesystem. Cannot be updated.
                     */
                    volumeMounts: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * Path within the container at which the volume should be mounted.  Must not contain ':'.
                         */
                        mountPath: z.ZodString;
                        /**
                         * mountPropagation determines how mounts are propagated from the host to container and the other way around. When not set, MountPropagationNone is used. This field is beta in 1.10.
                         */
                        mountPropagation: z.ZodOptional<z.ZodString>;
                        /**
                         * This must match the Name of a Volume.
                         */
                        name: z.ZodString;
                        /**
                         * Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false.
                         */
                        readOnly: z.ZodOptional<z.ZodBoolean>;
                        /**
                         * Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root).
                         */
                        subPath: z.ZodOptional<z.ZodString>;
                        /**
                         * Expanded path within the volume from which the container's volume should be mounted. Behaves similarly to SubPath but environment variable references $(VAR_NAME) are expanded using the container's environment. Defaults to "" (volume's root). SubPathExpr and SubPath are mutually exclusive.
                         */
                        subPathExpr: z.ZodOptional<z.ZodString>;
                    }, "strip", z.ZodTypeAny, {
                        name: string;
                        mountPath: string;
                        subPath?: string | undefined;
                        mountPropagation?: string | undefined;
                        readOnly?: boolean | undefined;
                        subPathExpr?: string | undefined;
                    }, {
                        name: string;
                        mountPath: string;
                        subPath?: string | undefined;
                        mountPropagation?: string | undefined;
                        readOnly?: boolean | undefined;
                        subPathExpr?: string | undefined;
                    }>, "many">>;
                    /**
                     * Container's working directory. If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.
                     */
                    workingDir: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    name: string;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    env?: {
                        name: string;
                        value?: string | undefined;
                        valueFrom?: {
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                            configMapKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                            secretKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    imagePullPolicy?: string | undefined;
                    args?: string[] | undefined;
                    command?: string[] | undefined;
                    envFrom?: {
                        configMapRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        prefix?: string | undefined;
                        secretRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                    lifecycle?: {
                        postStart?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                        preStop?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                    } | undefined;
                    livenessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    ports?: {
                        containerPort: number;
                        protocol: string;
                        name?: string | undefined;
                        hostIP?: string | undefined;
                        hostPort?: number | undefined;
                    }[] | undefined;
                    readinessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    securityContext?: {
                        allowPrivilegeEscalation?: boolean | undefined;
                        capabilities?: {
                            add?: string[] | undefined;
                            drop?: string[] | undefined;
                        } | undefined;
                        privileged?: boolean | undefined;
                        procMount?: string | undefined;
                        readOnlyRootFilesystem?: boolean | undefined;
                        runAsGroup?: number | undefined;
                        runAsNonRoot?: boolean | undefined;
                        runAsUser?: number | undefined;
                        seLinuxOptions?: {
                            type?: string | undefined;
                            user?: string | undefined;
                            level?: string | undefined;
                            role?: string | undefined;
                        } | undefined;
                        seccompProfile?: {
                            type: string;
                            localhostProfile?: string | undefined;
                        } | undefined;
                        windowsOptions?: {
                            gmsaCredentialSpec?: string | undefined;
                            gmsaCredentialSpecName?: string | undefined;
                            hostProcess?: boolean | undefined;
                            runAsUserName?: string | undefined;
                        } | undefined;
                    } | undefined;
                    startupProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    stdin?: boolean | undefined;
                    stdinOnce?: boolean | undefined;
                    terminationMessagePath?: string | undefined;
                    terminationMessagePolicy?: string | undefined;
                    tty?: boolean | undefined;
                    volumeDevices?: {
                        name: string;
                        devicePath: string;
                    }[] | undefined;
                    volumeMounts?: {
                        name: string;
                        mountPath: string;
                        subPath?: string | undefined;
                        mountPropagation?: string | undefined;
                        readOnly?: boolean | undefined;
                        subPathExpr?: string | undefined;
                    }[] | undefined;
                    workingDir?: string | undefined;
                }, {
                    name: string;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    env?: {
                        name: string;
                        value?: string | undefined;
                        valueFrom?: {
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                            configMapKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                            secretKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    imagePullPolicy?: string | undefined;
                    args?: string[] | undefined;
                    command?: string[] | undefined;
                    envFrom?: {
                        configMapRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        prefix?: string | undefined;
                        secretRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                    lifecycle?: {
                        postStart?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                        preStop?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                    } | undefined;
                    livenessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    ports?: {
                        containerPort: number;
                        name?: string | undefined;
                        hostIP?: string | undefined;
                        hostPort?: number | undefined;
                        protocol?: string | undefined;
                    }[] | undefined;
                    readinessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    securityContext?: {
                        allowPrivilegeEscalation?: boolean | undefined;
                        capabilities?: {
                            add?: string[] | undefined;
                            drop?: string[] | undefined;
                        } | undefined;
                        privileged?: boolean | undefined;
                        procMount?: string | undefined;
                        readOnlyRootFilesystem?: boolean | undefined;
                        runAsGroup?: number | undefined;
                        runAsNonRoot?: boolean | undefined;
                        runAsUser?: number | undefined;
                        seLinuxOptions?: {
                            type?: string | undefined;
                            user?: string | undefined;
                            level?: string | undefined;
                            role?: string | undefined;
                        } | undefined;
                        seccompProfile?: {
                            type: string;
                            localhostProfile?: string | undefined;
                        } | undefined;
                        windowsOptions?: {
                            gmsaCredentialSpec?: string | undefined;
                            gmsaCredentialSpecName?: string | undefined;
                            hostProcess?: boolean | undefined;
                            runAsUserName?: string | undefined;
                        } | undefined;
                    } | undefined;
                    startupProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    stdin?: boolean | undefined;
                    stdinOnce?: boolean | undefined;
                    terminationMessagePath?: string | undefined;
                    terminationMessagePolicy?: string | undefined;
                    tty?: boolean | undefined;
                    volumeDevices?: {
                        name: string;
                        devicePath: string;
                    }[] | undefined;
                    volumeMounts?: {
                        name: string;
                        mountPath: string;
                        subPath?: string | undefined;
                        mountPropagation?: string | undefined;
                        readOnly?: boolean | undefined;
                        subPathExpr?: string | undefined;
                    }[] | undefined;
                    workingDir?: string | undefined;
                }>, "many">>;
                /**
                 * A secret projection containing a certificate and key with which to encrypt connections to PgBouncer. The "tls.crt", "tls.key", and "ca.crt" paths must be PEM-encoded certificates and keys. Changing this value causes PgBouncer to restart. More info: https://kubernetes.io/docs/concepts/configuration/secret/#projection-of-secret-keys-to-specific-paths
                 */
                customTLSSecret: z.ZodOptional<z.ZodObject<{
                    /**
                     * items if unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
                     */
                    items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * key is the key to project.
                         */
                        key: z.ZodString;
                        /**
                         * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                         * @format int32
                         */
                        mode: z.ZodOptional<z.ZodNumber>;
                        /**
                         * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                         */
                        path: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }, {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }>, "many">>;
                    /**
                     * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                     */
                    name: z.ZodOptional<z.ZodString>;
                    /**
                     * optional field specify whether the Secret or its key must be defined
                     */
                    optional: z.ZodOptional<z.ZodBoolean>;
                }, "strip", z.ZodTypeAny, {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                }, {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                }>>;
                /**
                 * Name of a container image that can run PgBouncer 1.15 or newer. Changing this value causes PgBouncer to restart. The image may also be set using the RELATED_IMAGE_PGBOUNCER environment variable. More info: https://kubernetes.io/docs/concepts/containers/images
                 */
                image: z.ZodOptional<z.ZodString>;
                /**
                 * Metadata contains metadata for custom resources
                 */
                metadata: z.ZodOptional<z.ZodObject<{
                    annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                }, "strip", z.ZodTypeAny, {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                }, {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                }>>;
                /**
                 * Minimum number of pods that should be available at a time. Defaults to one when the replicas field is greater than one.
                 */
                minAvailable: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString]>>;
                /**
                 * Port on which PgBouncer should listen for client connections. Changing this value causes PgBouncer to restart.
                 * @default 5432
                 * @minimum 1024
                 * @format int32
                 */
                port: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
                /**
                 * Priority class name for the pgBouncer pod. Changing this value causes PostgreSQL to restart. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/pod-priority-preemption/
                 */
                priorityClassName: z.ZodOptional<z.ZodString>;
                /**
                 * Number of desired PgBouncer pods.
                 * @default 1
                 * @format int32
                 */
                replicas: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
                /**
                 * Compute resources of a PgBouncer container. Changing this value causes PgBouncer to restart. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers
                 */
                resources: z.ZodOptional<z.ZodObject<{
                    /**
                     * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                     */
                    limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                    /**
                     * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                     */
                    requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                }, "strip", z.ZodTypeAny, {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                }, {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                }>>;
                /**
                 * Specification of the service that exposes PgBouncer.
                 */
                service: z.ZodOptional<z.ZodObject<{
                    /**
                     * Metadata contains metadata for custom resources
                     */
                    metadata: z.ZodOptional<z.ZodObject<{
                        annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                        labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    }, "strip", z.ZodTypeAny, {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    }, {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    }>>;
                    /**
                     * The port on which this service is exposed when type is NodePort or LoadBalancer. Value must be in-range and not in use or the operation will fail. If unspecified, a port will be allocated if this Service requires one. - https://kubernetes.io/docs/concepts/services-networking/service/#type-nodeport
                     * @format int32
                     */
                    nodePort: z.ZodOptional<z.ZodNumber>;
                    /**
                     * More info: https://kubernetes.io/docs/concepts/services-networking/service/#publishing-services-service-types
                     * @default "ClusterIP"
                     */
                    type: z.ZodDefault<z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"ClusterIP">, z.ZodLiteral<"NodePort">, z.ZodLiteral<"LoadBalancer">]>>>;
                }, "strip", z.ZodTypeAny, {
                    type: "ClusterIP" | "NodePort" | "LoadBalancer";
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                }, {
                    type?: "ClusterIP" | "NodePort" | "LoadBalancer" | undefined;
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                }>>;
                /**
                 * Configuration for pgBouncer sidecar containers
                 */
                sidecars: z.ZodOptional<z.ZodObject<{
                    /**
                     * Defines the configuration for the pgBouncer config sidecar container
                     */
                    pgbouncerConfig: z.ZodOptional<z.ZodObject<{
                        /**
                         * Resource requirements for a sidecar container
                         */
                        resources: z.ZodOptional<z.ZodObject<{
                            /**
                             * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                             */
                            limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                            /**
                             * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                             */
                            requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                        }, "strip", z.ZodTypeAny, {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        }, {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    }, {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    pgbouncerConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                }, {
                    pgbouncerConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                }>>;
                /**
                 * Tolerations of a PgBouncer pod. Changing this value causes PgBouncer to restart. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/taint-and-toleration
                 */
                tolerations: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
                     */
                    effect: z.ZodOptional<z.ZodString>;
                    /**
                     * Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
                     */
                    key: z.ZodOptional<z.ZodString>;
                    /**
                     * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
                     */
                    operator: z.ZodOptional<z.ZodString>;
                    /**
                     * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
                     * @format int64
                     */
                    tolerationSeconds: z.ZodOptional<z.ZodNumber>;
                    /**
                     * Value is the taint value the toleration matches to. If the operator is Exists, the value should be empty, otherwise just a regular string.
                     */
                    value: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }, {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }>, "many">>;
                /**
                 * Topology spread constraints of a PgBouncer pod. Changing this value causes PgBouncer to restart. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-topology-spread-constraints/
                 */
                topologySpreadConstraints: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * LabelSelector is used to find matching pods. Pods that match this label selector are counted to determine the number of pods in their corresponding topology domain.
                     */
                    labelSelector: z.ZodOptional<z.ZodObject<{
                        /**
                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                         */
                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                             */
                            operator: z.ZodString;
                            /**
                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                        /**
                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                         */
                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    }, "strip", z.ZodTypeAny, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }>>;
                    /**
                     * MaxSkew describes the degree to which pods may be unevenly distributed. When `whenUnsatisfiable=DoNotSchedule`, it is the maximum permitted difference between the number of matching pods in the target topology and the global minimum. The global minimum is the minimum number of matching pods in an eligible domain or zero if the number of eligible domains is less than MinDomains. For example, in a 3-zone cluster, MaxSkew is set to 1, and pods with the same labelSelector spread as 2/2/1: In this case, the global minimum is 1. | zone1 | zone2 | zone3 | |  P P  |  P P  |   P   | - if MaxSkew is 1, incoming pod can only be scheduled to zone3 to become 2/2/2; scheduling it onto zone1(zone2) would make the ActualSkew(3-1) on zone1(zone2) violate MaxSkew(1). - if MaxSkew is 2, incoming pod can be scheduled onto any zone. When `whenUnsatisfiable=ScheduleAnyway`, it is used to give higher precedence to topologies that satisfy it. It's a required field. Default value is 1 and 0 is not allowed.
                     * @format int32
                     */
                    maxSkew: z.ZodNumber;
                    /**
                     * MinDomains indicates a minimum number of eligible domains. When the number of eligible domains with matching topology keys is less than minDomains, Pod Topology Spread treats "global minimum" as 0, and then the calculation of Skew is performed. And when the number of eligible domains with matching topology keys equals or greater than minDomains, this value has no effect on scheduling. As a result, when the number of eligible domains is less than minDomains, scheduler won't schedule more than maxSkew Pods to those domains. If value is nil, the constraint behaves as if MinDomains is equal to 1. Valid values are integers greater than 0. When value is not nil, WhenUnsatisfiable must be DoNotSchedule.
                     *  For example, in a 3-zone cluster, MaxSkew is set to 2, MinDomains is set to 5 and pods with the same labelSelector spread as 2/2/2: | zone1 | zone2 | zone3 | |  P P  |  P P  |  P P  | The number of domains is less than 5(MinDomains), so "global minimum" is treated as 0. In this situation, new pod with the same labelSelector cannot be scheduled, because computed skew will be 3(3 - 0) if new Pod is scheduled to any of the three zones, it will violate MaxSkew.
                     *  This is an alpha field and requires enabling MinDomainsInPodTopologySpread feature gate.
                     * @format int32
                     */
                    minDomains: z.ZodOptional<z.ZodNumber>;
                    /**
                     * TopologyKey is the key of node labels. Nodes that have a label with this key and identical values are considered to be in the same topology. We consider each <key, value> as a "bucket", and try to put balanced number of pods into each bucket. We define a domain as a particular instance of a topology. Also, we define an eligible domain as a domain whose nodes match the node selector. e.g. If TopologyKey is "kubernetes.io/hostname", each Node is a domain of that topology. And, if TopologyKey is "topology.kubernetes.io/zone", each zone is a domain of that topology. It's a required field.
                     */
                    topologyKey: z.ZodString;
                    /**
                     * WhenUnsatisfiable indicates how to deal with a pod if it doesn't satisfy the spread constraint. - DoNotSchedule (default) tells the scheduler not to schedule it. - ScheduleAnyway tells the scheduler to schedule the pod in any location, but giving higher precedence to topologies that would help reduce the skew. A constraint is considered "Unsatisfiable" for an incoming pod if and only if every possible node assignment for that pod would violate "MaxSkew" on some topology. For example, in a 3-zone cluster, MaxSkew is set to 1, and pods with the same labelSelector spread as 3/1/1: | zone1 | zone2 | zone3 | | P P P |   P   |   P   | If WhenUnsatisfiable is set to DoNotSchedule, incoming pod can only be scheduled to zone2(zone3) to become 3/2/1(3/1/2) as ActualSkew(2-1) on zone2(zone3) satisfies MaxSkew(1). In other words, the cluster can still be imbalanced, but scheduler won't make it \*more\* imbalanced. It's a required field.
                     */
                    whenUnsatisfiable: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }, {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                port: number;
                replicas: number;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                sidecars?: {
                    pgbouncerConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                config?: {
                    users?: Record<string, string> | undefined;
                    databases?: Record<string, string> | undefined;
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    global?: Record<string, string> | undefined;
                } | undefined;
                image?: string | undefined;
                priorityClassName?: string | undefined;
                topologySpreadConstraints?: {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }[] | undefined;
                customTLSSecret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                service?: {
                    type: "ClusterIP" | "NodePort" | "LoadBalancer";
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                } | undefined;
                containers?: {
                    name: string;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    env?: {
                        name: string;
                        value?: string | undefined;
                        valueFrom?: {
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                            configMapKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                            secretKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    imagePullPolicy?: string | undefined;
                    args?: string[] | undefined;
                    command?: string[] | undefined;
                    envFrom?: {
                        configMapRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        prefix?: string | undefined;
                        secretRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                    lifecycle?: {
                        postStart?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                        preStop?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                    } | undefined;
                    livenessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    ports?: {
                        containerPort: number;
                        protocol: string;
                        name?: string | undefined;
                        hostIP?: string | undefined;
                        hostPort?: number | undefined;
                    }[] | undefined;
                    readinessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    securityContext?: {
                        allowPrivilegeEscalation?: boolean | undefined;
                        capabilities?: {
                            add?: string[] | undefined;
                            drop?: string[] | undefined;
                        } | undefined;
                        privileged?: boolean | undefined;
                        procMount?: string | undefined;
                        readOnlyRootFilesystem?: boolean | undefined;
                        runAsGroup?: number | undefined;
                        runAsNonRoot?: boolean | undefined;
                        runAsUser?: number | undefined;
                        seLinuxOptions?: {
                            type?: string | undefined;
                            user?: string | undefined;
                            level?: string | undefined;
                            role?: string | undefined;
                        } | undefined;
                        seccompProfile?: {
                            type: string;
                            localhostProfile?: string | undefined;
                        } | undefined;
                        windowsOptions?: {
                            gmsaCredentialSpec?: string | undefined;
                            gmsaCredentialSpecName?: string | undefined;
                            hostProcess?: boolean | undefined;
                            runAsUserName?: string | undefined;
                        } | undefined;
                    } | undefined;
                    startupProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    stdin?: boolean | undefined;
                    stdinOnce?: boolean | undefined;
                    terminationMessagePath?: string | undefined;
                    terminationMessagePolicy?: string | undefined;
                    tty?: boolean | undefined;
                    volumeDevices?: {
                        name: string;
                        devicePath: string;
                    }[] | undefined;
                    volumeMounts?: {
                        name: string;
                        mountPath: string;
                        subPath?: string | undefined;
                        mountPropagation?: string | undefined;
                        readOnly?: boolean | undefined;
                        subPathExpr?: string | undefined;
                    }[] | undefined;
                    workingDir?: string | undefined;
                }[] | undefined;
                minAvailable?: string | number | undefined;
            }, {
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                port?: number | undefined;
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                sidecars?: {
                    pgbouncerConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                config?: {
                    users?: Record<string, string> | undefined;
                    databases?: Record<string, string> | undefined;
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    global?: Record<string, string> | undefined;
                } | undefined;
                image?: string | undefined;
                priorityClassName?: string | undefined;
                topologySpreadConstraints?: {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }[] | undefined;
                customTLSSecret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                service?: {
                    type?: "ClusterIP" | "NodePort" | "LoadBalancer" | undefined;
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                } | undefined;
                containers?: {
                    name: string;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    env?: {
                        name: string;
                        value?: string | undefined;
                        valueFrom?: {
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                            configMapKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                            secretKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    imagePullPolicy?: string | undefined;
                    args?: string[] | undefined;
                    command?: string[] | undefined;
                    envFrom?: {
                        configMapRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        prefix?: string | undefined;
                        secretRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                    lifecycle?: {
                        postStart?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                        preStop?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                    } | undefined;
                    livenessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    ports?: {
                        containerPort: number;
                        name?: string | undefined;
                        hostIP?: string | undefined;
                        hostPort?: number | undefined;
                        protocol?: string | undefined;
                    }[] | undefined;
                    readinessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    securityContext?: {
                        allowPrivilegeEscalation?: boolean | undefined;
                        capabilities?: {
                            add?: string[] | undefined;
                            drop?: string[] | undefined;
                        } | undefined;
                        privileged?: boolean | undefined;
                        procMount?: string | undefined;
                        readOnlyRootFilesystem?: boolean | undefined;
                        runAsGroup?: number | undefined;
                        runAsNonRoot?: boolean | undefined;
                        runAsUser?: number | undefined;
                        seLinuxOptions?: {
                            type?: string | undefined;
                            user?: string | undefined;
                            level?: string | undefined;
                            role?: string | undefined;
                        } | undefined;
                        seccompProfile?: {
                            type: string;
                            localhostProfile?: string | undefined;
                        } | undefined;
                        windowsOptions?: {
                            gmsaCredentialSpec?: string | undefined;
                            gmsaCredentialSpecName?: string | undefined;
                            hostProcess?: boolean | undefined;
                            runAsUserName?: string | undefined;
                        } | undefined;
                    } | undefined;
                    startupProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    stdin?: boolean | undefined;
                    stdinOnce?: boolean | undefined;
                    terminationMessagePath?: string | undefined;
                    terminationMessagePolicy?: string | undefined;
                    tty?: boolean | undefined;
                    volumeDevices?: {
                        name: string;
                        devicePath: string;
                    }[] | undefined;
                    volumeMounts?: {
                        name: string;
                        mountPath: string;
                        subPath?: string | undefined;
                        mountPropagation?: string | undefined;
                        readOnly?: boolean | undefined;
                        subPathExpr?: string | undefined;
                    }[] | undefined;
                    workingDir?: string | undefined;
                }[] | undefined;
                minAvailable?: string | number | undefined;
                replicas?: number | undefined;
            }>;
        }, "strip", z.ZodTypeAny, {
            pgBouncer: {
                port: number;
                replicas: number;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                sidecars?: {
                    pgbouncerConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                config?: {
                    users?: Record<string, string> | undefined;
                    databases?: Record<string, string> | undefined;
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    global?: Record<string, string> | undefined;
                } | undefined;
                image?: string | undefined;
                priorityClassName?: string | undefined;
                topologySpreadConstraints?: {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }[] | undefined;
                customTLSSecret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                service?: {
                    type: "ClusterIP" | "NodePort" | "LoadBalancer";
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                } | undefined;
                containers?: {
                    name: string;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    env?: {
                        name: string;
                        value?: string | undefined;
                        valueFrom?: {
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                            configMapKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                            secretKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    imagePullPolicy?: string | undefined;
                    args?: string[] | undefined;
                    command?: string[] | undefined;
                    envFrom?: {
                        configMapRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        prefix?: string | undefined;
                        secretRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                    lifecycle?: {
                        postStart?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                        preStop?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                    } | undefined;
                    livenessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    ports?: {
                        containerPort: number;
                        protocol: string;
                        name?: string | undefined;
                        hostIP?: string | undefined;
                        hostPort?: number | undefined;
                    }[] | undefined;
                    readinessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    securityContext?: {
                        allowPrivilegeEscalation?: boolean | undefined;
                        capabilities?: {
                            add?: string[] | undefined;
                            drop?: string[] | undefined;
                        } | undefined;
                        privileged?: boolean | undefined;
                        procMount?: string | undefined;
                        readOnlyRootFilesystem?: boolean | undefined;
                        runAsGroup?: number | undefined;
                        runAsNonRoot?: boolean | undefined;
                        runAsUser?: number | undefined;
                        seLinuxOptions?: {
                            type?: string | undefined;
                            user?: string | undefined;
                            level?: string | undefined;
                            role?: string | undefined;
                        } | undefined;
                        seccompProfile?: {
                            type: string;
                            localhostProfile?: string | undefined;
                        } | undefined;
                        windowsOptions?: {
                            gmsaCredentialSpec?: string | undefined;
                            gmsaCredentialSpecName?: string | undefined;
                            hostProcess?: boolean | undefined;
                            runAsUserName?: string | undefined;
                        } | undefined;
                    } | undefined;
                    startupProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    stdin?: boolean | undefined;
                    stdinOnce?: boolean | undefined;
                    terminationMessagePath?: string | undefined;
                    terminationMessagePolicy?: string | undefined;
                    tty?: boolean | undefined;
                    volumeDevices?: {
                        name: string;
                        devicePath: string;
                    }[] | undefined;
                    volumeMounts?: {
                        name: string;
                        mountPath: string;
                        subPath?: string | undefined;
                        mountPropagation?: string | undefined;
                        readOnly?: boolean | undefined;
                        subPathExpr?: string | undefined;
                    }[] | undefined;
                    workingDir?: string | undefined;
                }[] | undefined;
                minAvailable?: string | number | undefined;
            };
        }, {
            pgBouncer: {
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                port?: number | undefined;
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                sidecars?: {
                    pgbouncerConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                config?: {
                    users?: Record<string, string> | undefined;
                    databases?: Record<string, string> | undefined;
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    global?: Record<string, string> | undefined;
                } | undefined;
                image?: string | undefined;
                priorityClassName?: string | undefined;
                topologySpreadConstraints?: {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }[] | undefined;
                customTLSSecret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                service?: {
                    type?: "ClusterIP" | "NodePort" | "LoadBalancer" | undefined;
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                } | undefined;
                containers?: {
                    name: string;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    env?: {
                        name: string;
                        value?: string | undefined;
                        valueFrom?: {
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                            configMapKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                            secretKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    imagePullPolicy?: string | undefined;
                    args?: string[] | undefined;
                    command?: string[] | undefined;
                    envFrom?: {
                        configMapRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        prefix?: string | undefined;
                        secretRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                    lifecycle?: {
                        postStart?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                        preStop?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                    } | undefined;
                    livenessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    ports?: {
                        containerPort: number;
                        name?: string | undefined;
                        hostIP?: string | undefined;
                        hostPort?: number | undefined;
                        protocol?: string | undefined;
                    }[] | undefined;
                    readinessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    securityContext?: {
                        allowPrivilegeEscalation?: boolean | undefined;
                        capabilities?: {
                            add?: string[] | undefined;
                            drop?: string[] | undefined;
                        } | undefined;
                        privileged?: boolean | undefined;
                        procMount?: string | undefined;
                        readOnlyRootFilesystem?: boolean | undefined;
                        runAsGroup?: number | undefined;
                        runAsNonRoot?: boolean | undefined;
                        runAsUser?: number | undefined;
                        seLinuxOptions?: {
                            type?: string | undefined;
                            user?: string | undefined;
                            level?: string | undefined;
                            role?: string | undefined;
                        } | undefined;
                        seccompProfile?: {
                            type: string;
                            localhostProfile?: string | undefined;
                        } | undefined;
                        windowsOptions?: {
                            gmsaCredentialSpec?: string | undefined;
                            gmsaCredentialSpecName?: string | undefined;
                            hostProcess?: boolean | undefined;
                            runAsUserName?: string | undefined;
                        } | undefined;
                    } | undefined;
                    startupProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    stdin?: boolean | undefined;
                    stdinOnce?: boolean | undefined;
                    terminationMessagePath?: string | undefined;
                    terminationMessagePolicy?: string | undefined;
                    tty?: boolean | undefined;
                    volumeDevices?: {
                        name: string;
                        devicePath: string;
                    }[] | undefined;
                    volumeMounts?: {
                        name: string;
                        mountPath: string;
                        subPath?: string | undefined;
                        mountPropagation?: string | undefined;
                        readOnly?: boolean | undefined;
                        subPathExpr?: string | undefined;
                    }[] | undefined;
                    workingDir?: string | undefined;
                }[] | undefined;
                minAvailable?: string | number | undefined;
                replicas?: number | undefined;
            };
        }>>;
        /**
         * Specification of the service that exposes the PostgreSQL primary instance.
         */
        service: z.ZodOptional<z.ZodObject<{
            /**
             * Metadata contains metadata for custom resources
             */
            metadata: z.ZodOptional<z.ZodObject<{
                annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
            }, "strip", z.ZodTypeAny, {
                annotations?: Record<string, string> | undefined;
                labels?: Record<string, string> | undefined;
            }, {
                annotations?: Record<string, string> | undefined;
                labels?: Record<string, string> | undefined;
            }>>;
            /**
             * The port on which this service is exposed when type is NodePort or LoadBalancer. Value must be in-range and not in use or the operation will fail. If unspecified, a port will be allocated if this Service requires one. - https://kubernetes.io/docs/concepts/services-networking/service/#type-nodeport
             * @format int32
             */
            nodePort: z.ZodOptional<z.ZodNumber>;
            /**
             * More info: https://kubernetes.io/docs/concepts/services-networking/service/#publishing-services-service-types
             * @default "ClusterIP"
             */
            type: z.ZodDefault<z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"ClusterIP">, z.ZodLiteral<"NodePort">, z.ZodLiteral<"LoadBalancer">]>>>;
        }, "strip", z.ZodTypeAny, {
            type: "ClusterIP" | "NodePort" | "LoadBalancer";
            metadata?: {
                annotations?: Record<string, string> | undefined;
                labels?: Record<string, string> | undefined;
            } | undefined;
            nodePort?: number | undefined;
        }, {
            type?: "ClusterIP" | "NodePort" | "LoadBalancer" | undefined;
            metadata?: {
                annotations?: Record<string, string> | undefined;
                labels?: Record<string, string> | undefined;
            } | undefined;
            nodePort?: number | undefined;
        }>>;
        /**
         * Whether or not the PostgreSQL cluster should be stopped. When this is true, workloads are scaled to zero and CronJobs are suspended. Other resources, such as Services and Volumes, remain in place.
         */
        shutdown: z.ZodOptional<z.ZodBoolean>;
        /**
         * Run this cluster as a read-only copy of an existing cluster or archive.
         */
        standby: z.ZodOptional<z.ZodObject<{
            /**
             * Whether or not the PostgreSQL cluster should be read-only. When this is true, WAL files are applied from a pgBackRest repository or another PostgreSQL server.
             * @default true
             */
            enabled: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
            /**
             * Network address of the PostgreSQL server to follow via streaming replication.
             */
            host: z.ZodOptional<z.ZodString>;
            /**
             * Network port of the PostgreSQL server to follow via streaming replication.
             * @minimum 1024
             * @format int32
             */
            port: z.ZodOptional<z.ZodNumber>;
            /**
             * The name of the pgBackRest repository to follow for WAL files.
             * @pattern ^repo[1-4]
             */
            repoName: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            enabled: boolean;
            repoName?: string | undefined;
            port?: number | undefined;
            host?: string | undefined;
        }, {
            repoName?: string | undefined;
            enabled?: boolean | undefined;
            port?: number | undefined;
            host?: string | undefined;
        }>>;
        /**
         * A list of group IDs applied to the process of a container. These can be useful when accessing shared file systems with constrained permissions. More info: https://kubernetes.io/docs/reference/kubernetes-api/workload-resources/pod-v1/#security-context
         */
        supplementalGroups: z.ZodOptional<z.ZodArray<z.ZodNumber, "many">>;
        /**
         * The specification of a user interface that connects to PostgreSQL.
         */
        userInterface: z.ZodOptional<z.ZodObject<{
            /**
             * Defines a pgAdmin user interface.
             */
            pgAdmin: z.ZodObject<{
                /**
                 * Scheduling constraints of a pgAdmin pod. Changing this value causes pgAdmin to restart. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/assign-pod-node
                 */
                affinity: z.ZodOptional<z.ZodObject<{
                    /**
                     * Describes node affinity scheduling rules for the pod.
                     */
                    nodeAffinity: z.ZodOptional<z.ZodObject<{
                        /**
                         * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node matches the corresponding matchExpressions; the node(s) with the highest sum are the most preferred.
                         */
                        preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * A node selector term, associated with the corresponding weight.
                             */
                            preference: z.ZodObject<{
                                /**
                                 * A list of node selector requirements by node's labels.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * The label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * A list of node selector requirements by node's fields.
                                 */
                                matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * The label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }>;
                            /**
                             * Weight associated with matching the corresponding nodeSelectorTerm, in the range 1-100.
                             * @format int32
                             */
                            weight: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }, {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }>, "many">>;
                        /**
                         * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to an update), the system may or may not try to eventually evict the pod from its node.
                         */
                        requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodObject<{
                            /**
                             * Required. A list of node selector terms. The terms are ORed.
                             */
                            nodeSelectorTerms: z.ZodArray<z.ZodObject<{
                                /**
                                 * A list of node selector requirements by node's labels.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * The label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * A list of node selector requirements by node's fields.
                                 */
                                matchFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * The label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }>, "many">;
                        }, "strip", z.ZodTypeAny, {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        }, {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    }, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    }>>;
                    /**
                     * Describes pod affinity scheduling rules (e.g. co-locate this pod in the same node, zone, etc. as some other pod(s)).
                     */
                    podAffinity: z.ZodOptional<z.ZodObject<{
                        /**
                         * The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                         */
                        preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * Required. A pod affinity term, associated with the corresponding weight.
                             */
                            podAffinityTerm: z.ZodObject<{
                                /**
                                 * A label query over a set of resources, in this case pods.
                                 */
                                labelSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                 */
                                namespaceSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                 */
                                namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                /**
                                 * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                 */
                                topologyKey: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }>;
                            /**
                             * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                             * @format int32
                             */
                            weight: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }, {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }>, "many">>;
                        /**
                         * If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                         */
                        requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * A label query over a set of resources, in this case pods.
                             */
                            labelSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                             */
                            namespaceSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                             */
                            namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            /**
                             * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                             */
                            topologyKey: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    }, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    }>>;
                    /**
                     * Describes pod anti-affinity scheduling rules (e.g. avoid putting this pod in the same node, zone, etc. as some other pod(s)).
                     */
                    podAntiAffinity: z.ZodOptional<z.ZodObject<{
                        /**
                         * The scheduler will prefer to schedule pods to nodes that satisfy the anti-affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling anti-affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred.
                         */
                        preferredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * Required. A pod affinity term, associated with the corresponding weight.
                             */
                            podAffinityTerm: z.ZodObject<{
                                /**
                                 * A label query over a set of resources, in this case pods.
                                 */
                                labelSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                                 */
                                namespaceSelector: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                     */
                                    matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                        /**
                                         * key is the label key that the selector applies to.
                                         */
                                        key: z.ZodString;
                                        /**
                                         * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                         */
                                        operator: z.ZodString;
                                        /**
                                         * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                         */
                                        values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                    }, "strip", z.ZodTypeAny, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }, {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }>, "many">>;
                                    /**
                                     * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                     */
                                    matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                                }, "strip", z.ZodTypeAny, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }, {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                }>>;
                                /**
                                 * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                                 */
                                namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                /**
                                 * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                                 */
                                topologyKey: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }, {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }>;
                            /**
                             * weight associated with matching the corresponding podAffinityTerm, in the range 1-100.
                             * @format int32
                             */
                            weight: z.ZodNumber;
                        }, "strip", z.ZodTypeAny, {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }, {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }>, "many">>;
                        /**
                         * If the anti-affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the anti-affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied.
                         */
                        requiredDuringSchedulingIgnoredDuringExecution: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * A label query over a set of resources, in this case pods.
                             */
                            labelSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * A label query over the set of namespaces that the term applies to. The term is applied to the union of the namespaces selected by this field and the ones listed in the namespaces field. null selector and null or empty namespaces list means "this pod's namespace". An empty selector ({}) matches all namespaces.
                             */
                            namespaceSelector: z.ZodOptional<z.ZodObject<{
                                /**
                                 * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                                 */
                                matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                    /**
                                     * key is the label key that the selector applies to.
                                     */
                                    key: z.ZodString;
                                    /**
                                     * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                                     */
                                    operator: z.ZodString;
                                    /**
                                     * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                                     */
                                    values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                                }, "strip", z.ZodTypeAny, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }, {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }>, "many">>;
                                /**
                                 * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                                 */
                                matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                            }, "strip", z.ZodTypeAny, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }, {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            }>>;
                            /**
                             * namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace".
                             */
                            namespaces: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                            /**
                             * This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed.
                             */
                            topologyKey: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }, {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }>, "many">>;
                    }, "strip", z.ZodTypeAny, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    }, {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                }, {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                }>>;
                /**
                 * Configuration settings for the pgAdmin process. Changes to any of these values will be loaded without validation. Be careful, as you may put pgAdmin into an unusable state.
                 */
                config: z.ZodOptional<z.ZodObject<{
                    /**
                     * Files allows the user to mount projected volumes into the pgAdmin container so that files can be referenced by pgAdmin as needed.
                     */
                    files: z.ZodOptional<z.ZodArray<z.ZodObject<{
                        /**
                         * configMap information about the configMap data to project
                         */
                        configMap: z.ZodOptional<z.ZodObject<{
                            /**
                             * items if unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
                             */
                            items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the key to project.
                                 */
                                key: z.ZodString;
                                /**
                                 * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                                 * @format int32
                                 */
                                mode: z.ZodOptional<z.ZodNumber>;
                                /**
                                 * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                                 */
                                path: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }, {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }>, "many">>;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                             */
                            name: z.ZodOptional<z.ZodString>;
                            /**
                             * optional specify whether the ConfigMap or its keys must be defined
                             */
                            optional: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        }, {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        }>>;
                        /**
                         * downwardAPI information about the downwardAPI data to project
                         */
                        downwardAPI: z.ZodOptional<z.ZodObject<{
                            /**
                             * Items is a list of DownwardAPIVolume file
                             */
                            items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * Required: Selects a field of the pod: only annotations, labels, name and namespace are supported.
                                 */
                                fieldRef: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * Version of the schema the FieldPath is written in terms of, defaults to "v1".
                                     */
                                    apiVersion: z.ZodOptional<z.ZodString>;
                                    /**
                                     * Path of the field to select in the specified API version.
                                     */
                                    fieldPath: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                }, {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                }>>;
                                /**
                                 * Optional: mode bits used to set permissions on this file, must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                                 * @format int32
                                 */
                                mode: z.ZodOptional<z.ZodNumber>;
                                /**
                                 * Required: Path is  the relative path name of the file to be created. Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..'
                                 */
                                path: z.ZodString;
                                /**
                                 * Selects a resource of the container: only resources limits and requests (limits.cpu, limits.memory, requests.cpu and requests.memory) are currently supported.
                                 */
                                resourceFieldRef: z.ZodOptional<z.ZodObject<{
                                    /**
                                     * Container name: required for volumes, optional for env vars
                                     */
                                    containerName: z.ZodOptional<z.ZodString>;
                                    /**
                                     * Specifies the output format of the exposed resources, defaults to "1"
                                     * @schema union([z.number(), z.string().regex(/^(\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))(([KMGTPE]i)|[numkMGTPE]|([eE](\+|-)?(([0-9]+(\.[0-9]*)?)|(\.[0-9]+))))?$/)]).optional()
                                     */
                                    divisor: z.ZodOptional<z.ZodUnion<[z.ZodNumber, z.ZodString]>>;
                                    /**
                                     * Required: resource to select
                                     */
                                    resource: z.ZodString;
                                }, "strip", z.ZodTypeAny, {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                }, {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                }>>;
                            }, "strip", z.ZodTypeAny, {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }, {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }>, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        }, {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        }>>;
                        /**
                         * secret information about the secret data to project
                         */
                        secret: z.ZodOptional<z.ZodObject<{
                            /**
                             * items if unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'.
                             */
                            items: z.ZodOptional<z.ZodArray<z.ZodObject<{
                                /**
                                 * key is the key to project.
                                 */
                                key: z.ZodString;
                                /**
                                 * mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set.
                                 * @format int32
                                 */
                                mode: z.ZodOptional<z.ZodNumber>;
                                /**
                                 * path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'.
                                 */
                                path: z.ZodString;
                            }, "strip", z.ZodTypeAny, {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }, {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }>, "many">>;
                            /**
                             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                             */
                            name: z.ZodOptional<z.ZodString>;
                            /**
                             * optional field specify whether the Secret or its key must be defined
                             */
                            optional: z.ZodOptional<z.ZodBoolean>;
                        }, "strip", z.ZodTypeAny, {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        }, {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        }>>;
                        /**
                         * serviceAccountToken is information about the serviceAccountToken data to project
                         */
                        serviceAccountToken: z.ZodOptional<z.ZodObject<{
                            /**
                             * audience is the intended audience of the token. A recipient of a token must identify itself with an identifier specified in the audience of the token, and otherwise should reject the token. The audience defaults to the identifier of the apiserver.
                             */
                            audience: z.ZodOptional<z.ZodString>;
                            /**
                             * expirationSeconds is the requested duration of validity of the service account token. As the token approaches expiration, the kubelet volume plugin will proactively rotate the service account token. The kubelet will start trying to rotate the token if the token is older than 80 percent of its time to live or if the token is older than 24 hours.Defaults to 1 hour and must be at least 10 minutes.
                             * @format int64
                             */
                            expirationSeconds: z.ZodOptional<z.ZodNumber>;
                            /**
                             * path is the path relative to the mount point of the file to project the token into.
                             */
                            path: z.ZodString;
                        }, "strip", z.ZodTypeAny, {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        }, {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        }>>;
                    }, "strip", z.ZodTypeAny, {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }, {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }>, "many">>;
                    /**
                     * A Secret containing the value for the LDAP_BIND_PASSWORD setting. More info: https://www.pgadmin.org/docs/pgadmin4/latest/ldap.html
                     */
                    ldapBindPassword: z.ZodOptional<z.ZodObject<{
                        /**
                         * The key of the secret to select from.  Must be a valid secret key.
                         */
                        key: z.ZodString;
                        /**
                         * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names
                         */
                        name: z.ZodOptional<z.ZodString>;
                        /**
                         * Specify whether the Secret or its key must be defined
                         */
                        optional: z.ZodOptional<z.ZodBoolean>;
                    }, "strip", z.ZodTypeAny, {
                        key: string;
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    }, {
                        key: string;
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    }>>;
                    /**
                     * Settings for the pgAdmin server process. Keys should be uppercase and values must be constants. More info: https://www.pgadmin.org/docs/pgadmin4/latest/config_py.html
                     */
                    settings: z.ZodOptional<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
                }, "strip", z.ZodTypeAny, {
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    ldapBindPassword?: {
                        key: string;
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    settings?: {} | undefined;
                }, {
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    ldapBindPassword?: {
                        key: string;
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    settings?: {} | undefined;
                }>>;
                /**
                 * Defines a PersistentVolumeClaim for pgAdmin data. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes
                 */
                dataVolumeClaimSpec: z.ZodObject<{
                    /**
                     * accessModes contains the desired access modes the volume should have. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes-1
                     */
                    accessModes: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                    /**
                     * dataSource field can be used to specify either: \* An existing VolumeSnapshot object (snapshot.storage.k8s.io/VolumeSnapshot) \* An existing PVC (PersistentVolumeClaim) If the provisioner or an external controller can support the specified data source, it will create a new volume based on the contents of the specified data source. If the AnyVolumeDataSource feature gate is enabled, this field will always have the same contents as the DataSourceRef field.
                     */
                    dataSource: z.ZodOptional<z.ZodObject<{
                        /**
                         * APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
                         */
                        apiGroup: z.ZodOptional<z.ZodString>;
                        /**
                         * Kind is the type of resource being referenced
                         */
                        kind: z.ZodString;
                        /**
                         * Name is the name of resource being referenced
                         */
                        name: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    }, {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    }>>;
                    /**
                     * dataSourceRef specifies the object from which to populate the volume with data, if a non-empty volume is desired. This may be any local object from a non-empty API group (non core object) or a PersistentVolumeClaim object. When this field is specified, volume binding will only succeed if the type of the specified object matches some installed volume populator or dynamic provisioner. This field will replace the functionality of the DataSource field and as such if both fields are non-empty, they must have the same value. For backwards compatibility, both fields (DataSource and DataSourceRef) will be set to the same value automatically if one of them is empty and the other is non-empty. There are two important differences between DataSource and DataSourceRef: \* While DataSource only allows two specific types of objects, DataSourceRef allows any non-core object, as well as PersistentVolumeClaim objects. \* While DataSource ignores disallowed values (dropping them), DataSourceRef preserves all values, and generates an error if a disallowed value is specified. (Beta) Using this field requires the AnyVolumeDataSource feature gate to be enabled.
                     */
                    dataSourceRef: z.ZodOptional<z.ZodObject<{
                        /**
                         * APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.
                         */
                        apiGroup: z.ZodOptional<z.ZodString>;
                        /**
                         * Kind is the type of resource being referenced
                         */
                        kind: z.ZodString;
                        /**
                         * Name is the name of resource being referenced
                         */
                        name: z.ZodString;
                    }, "strip", z.ZodTypeAny, {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    }, {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    }>>;
                    /**
                     * resources represents the minimum resources the volume should have. If RecoverVolumeExpansionFailure feature is enabled users are allowed to specify resource requirements that are lower than previous value but must still be higher than capacity recorded in the status field of the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#resources
                     */
                    resources: z.ZodOptional<z.ZodObject<{
                        /**
                         * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                         */
                        limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                        /**
                         * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                         */
                        requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                    }, "strip", z.ZodTypeAny, {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    }, {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    }>>;
                    /**
                     * selector is a label query over volumes to consider for binding.
                     */
                    selector: z.ZodOptional<z.ZodObject<{
                        /**
                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                         */
                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                             */
                            operator: z.ZodString;
                            /**
                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                        /**
                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                         */
                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    }, "strip", z.ZodTypeAny, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }>>;
                    /**
                     * storageClassName is the name of the StorageClass required by the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#class-1
                     */
                    storageClassName: z.ZodOptional<z.ZodString>;
                    /**
                     * volumeMode defines what type of volume is required by the claim. Value of Filesystem is implied when not included in claim spec.
                     */
                    volumeMode: z.ZodOptional<z.ZodString>;
                    /**
                     * volumeName is the binding reference to the PersistentVolume backing this claim.
                     */
                    volumeName: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                }, {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                }>;
                /**
                 * Name of a container image that can run pgAdmin 4. Changing this value causes pgAdmin to restart. The image may also be set using the RELATED_IMAGE_PGADMIN environment variable. More info: https://kubernetes.io/docs/concepts/containers/images
                 */
                image: z.ZodOptional<z.ZodString>;
                /**
                 * Metadata contains metadata for custom resources
                 */
                metadata: z.ZodOptional<z.ZodObject<{
                    annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                }, "strip", z.ZodTypeAny, {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                }, {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                }>>;
                /**
                 * Priority class name for the pgAdmin pod. Changing this value causes pgAdmin to restart. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/pod-priority-preemption/
                 */
                priorityClassName: z.ZodOptional<z.ZodString>;
                /**
                 * Number of desired pgAdmin pods.
                 * @default 1
                 * @maximum 1
                 * @format int32
                 */
                replicas: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
                /**
                 * Compute resources of a pgAdmin container. Changing this value causes pgAdmin to restart. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers
                 */
                resources: z.ZodOptional<z.ZodObject<{
                    /**
                     * Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                     */
                    limits: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                    /**
                     * Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/
                     */
                    requests: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodUnion<[z.ZodNumber, z.ZodString]>>>;
                }, "strip", z.ZodTypeAny, {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                }, {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                }>>;
                /**
                 * Specification of the service that exposes pgAdmin.
                 */
                service: z.ZodOptional<z.ZodObject<{
                    /**
                     * Metadata contains metadata for custom resources
                     */
                    metadata: z.ZodOptional<z.ZodObject<{
                        annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                        labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    }, "strip", z.ZodTypeAny, {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    }, {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    }>>;
                    /**
                     * The port on which this service is exposed when type is NodePort or LoadBalancer. Value must be in-range and not in use or the operation will fail. If unspecified, a port will be allocated if this Service requires one. - https://kubernetes.io/docs/concepts/services-networking/service/#type-nodeport
                     * @format int32
                     */
                    nodePort: z.ZodOptional<z.ZodNumber>;
                    /**
                     * More info: https://kubernetes.io/docs/concepts/services-networking/service/#publishing-services-service-types
                     * @default "ClusterIP"
                     */
                    type: z.ZodDefault<z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"ClusterIP">, z.ZodLiteral<"NodePort">, z.ZodLiteral<"LoadBalancer">]>>>;
                }, "strip", z.ZodTypeAny, {
                    type: "ClusterIP" | "NodePort" | "LoadBalancer";
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                }, {
                    type?: "ClusterIP" | "NodePort" | "LoadBalancer" | undefined;
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                }>>;
                /**
                 * Tolerations of a pgAdmin pod. Changing this value causes pgAdmin to restart. More info: https://kubernetes.io/docs/concepts/scheduling-eviction/taint-and-toleration
                 */
                tolerations: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
                     */
                    effect: z.ZodOptional<z.ZodString>;
                    /**
                     * Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys.
                     */
                    key: z.ZodOptional<z.ZodString>;
                    /**
                     * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
                     */
                    operator: z.ZodOptional<z.ZodString>;
                    /**
                     * TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system.
                     * @format int64
                     */
                    tolerationSeconds: z.ZodOptional<z.ZodNumber>;
                    /**
                     * Value is the taint value the toleration matches to. If the operator is Exists, the value should be empty, otherwise just a regular string.
                     */
                    value: z.ZodOptional<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }, {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }>, "many">>;
                /**
                 * Topology spread constraints of a pgAdmin pod. Changing this value causes pgAdmin to restart. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-topology-spread-constraints/
                 */
                topologySpreadConstraints: z.ZodOptional<z.ZodArray<z.ZodObject<{
                    /**
                     * LabelSelector is used to find matching pods. Pods that match this label selector are counted to determine the number of pods in their corresponding topology domain.
                     */
                    labelSelector: z.ZodOptional<z.ZodObject<{
                        /**
                         * matchExpressions is a list of label selector requirements. The requirements are ANDed.
                         */
                        matchExpressions: z.ZodOptional<z.ZodArray<z.ZodObject<{
                            /**
                             * key is the label key that the selector applies to.
                             */
                            key: z.ZodString;
                            /**
                             * operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist.
                             */
                            operator: z.ZodString;
                            /**
                             * values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch.
                             */
                            values: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
                        }, "strip", z.ZodTypeAny, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }, {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }>, "many">>;
                        /**
                         * matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed.
                         */
                        matchLabels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
                    }, "strip", z.ZodTypeAny, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }, {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    }>>;
                    /**
                     * MaxSkew describes the degree to which pods may be unevenly distributed. When `whenUnsatisfiable=DoNotSchedule`, it is the maximum permitted difference between the number of matching pods in the target topology and the global minimum. The global minimum is the minimum number of matching pods in an eligible domain or zero if the number of eligible domains is less than MinDomains. For example, in a 3-zone cluster, MaxSkew is set to 1, and pods with the same labelSelector spread as 2/2/1: In this case, the global minimum is 1. | zone1 | zone2 | zone3 | |  P P  |  P P  |   P   | - if MaxSkew is 1, incoming pod can only be scheduled to zone3 to become 2/2/2; scheduling it onto zone1(zone2) would make the ActualSkew(3-1) on zone1(zone2) violate MaxSkew(1). - if MaxSkew is 2, incoming pod can be scheduled onto any zone. When `whenUnsatisfiable=ScheduleAnyway`, it is used to give higher precedence to topologies that satisfy it. It's a required field. Default value is 1 and 0 is not allowed.
                     * @format int32
                     */
                    maxSkew: z.ZodNumber;
                    /**
                     * MinDomains indicates a minimum number of eligible domains. When the number of eligible domains with matching topology keys is less than minDomains, Pod Topology Spread treats "global minimum" as 0, and then the calculation of Skew is performed. And when the number of eligible domains with matching topology keys equals or greater than minDomains, this value has no effect on scheduling. As a result, when the number of eligible domains is less than minDomains, scheduler won't schedule more than maxSkew Pods to those domains. If value is nil, the constraint behaves as if MinDomains is equal to 1. Valid values are integers greater than 0. When value is not nil, WhenUnsatisfiable must be DoNotSchedule.
                     *  For example, in a 3-zone cluster, MaxSkew is set to 2, MinDomains is set to 5 and pods with the same labelSelector spread as 2/2/2: | zone1 | zone2 | zone3 | |  P P  |  P P  |  P P  | The number of domains is less than 5(MinDomains), so "global minimum" is treated as 0. In this situation, new pod with the same labelSelector cannot be scheduled, because computed skew will be 3(3 - 0) if new Pod is scheduled to any of the three zones, it will violate MaxSkew.
                     *  This is an alpha field and requires enabling MinDomainsInPodTopologySpread feature gate.
                     * @format int32
                     */
                    minDomains: z.ZodOptional<z.ZodNumber>;
                    /**
                     * TopologyKey is the key of node labels. Nodes that have a label with this key and identical values are considered to be in the same topology. We consider each <key, value> as a "bucket", and try to put balanced number of pods into each bucket. We define a domain as a particular instance of a topology. Also, we define an eligible domain as a domain whose nodes match the node selector. e.g. If TopologyKey is "kubernetes.io/hostname", each Node is a domain of that topology. And, if TopologyKey is "topology.kubernetes.io/zone", each zone is a domain of that topology. It's a required field.
                     */
                    topologyKey: z.ZodString;
                    /**
                     * WhenUnsatisfiable indicates how to deal with a pod if it doesn't satisfy the spread constraint. - DoNotSchedule (default) tells the scheduler not to schedule it. - ScheduleAnyway tells the scheduler to schedule the pod in any location, but giving higher precedence to topologies that would help reduce the skew. A constraint is considered "Unsatisfiable" for an incoming pod if and only if every possible node assignment for that pod would violate "MaxSkew" on some topology. For example, in a 3-zone cluster, MaxSkew is set to 1, and pods with the same labelSelector spread as 3/1/1: | zone1 | zone2 | zone3 | | P P P |   P   |   P   | If WhenUnsatisfiable is set to DoNotSchedule, incoming pod can only be scheduled to zone2(zone3) to become 3/2/1(3/1/2) as ActualSkew(2-1) on zone2(zone3) satisfies MaxSkew(1). In other words, the cluster can still be imbalanced, but scheduler won't make it \*more\* imbalanced. It's a required field.
                     */
                    whenUnsatisfiable: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }, {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                dataVolumeClaimSpec: {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                };
                replicas: number;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                config?: {
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    ldapBindPassword?: {
                        key: string;
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    settings?: {} | undefined;
                } | undefined;
                image?: string | undefined;
                priorityClassName?: string | undefined;
                topologySpreadConstraints?: {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }[] | undefined;
                service?: {
                    type: "ClusterIP" | "NodePort" | "LoadBalancer";
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                } | undefined;
            }, {
                dataVolumeClaimSpec: {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                };
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                config?: {
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    ldapBindPassword?: {
                        key: string;
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    settings?: {} | undefined;
                } | undefined;
                image?: string | undefined;
                priorityClassName?: string | undefined;
                topologySpreadConstraints?: {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }[] | undefined;
                service?: {
                    type?: "ClusterIP" | "NodePort" | "LoadBalancer" | undefined;
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                } | undefined;
                replicas?: number | undefined;
            }>;
        }, "strip", z.ZodTypeAny, {
            pgAdmin: {
                dataVolumeClaimSpec: {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                };
                replicas: number;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                config?: {
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    ldapBindPassword?: {
                        key: string;
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    settings?: {} | undefined;
                } | undefined;
                image?: string | undefined;
                priorityClassName?: string | undefined;
                topologySpreadConstraints?: {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }[] | undefined;
                service?: {
                    type: "ClusterIP" | "NodePort" | "LoadBalancer";
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                } | undefined;
            };
        }, {
            pgAdmin: {
                dataVolumeClaimSpec: {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                };
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                config?: {
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    ldapBindPassword?: {
                        key: string;
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    settings?: {} | undefined;
                } | undefined;
                image?: string | undefined;
                priorityClassName?: string | undefined;
                topologySpreadConstraints?: {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }[] | undefined;
                service?: {
                    type?: "ClusterIP" | "NodePort" | "LoadBalancer" | undefined;
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                } | undefined;
                replicas?: number | undefined;
            };
        }>>;
        /**
         * Users to create inside PostgreSQL and the databases they should access. The default creates one user that can access one database matching the PostgresCluster name. An empty list creates no users. Removing a user from this list does NOT drop the user nor revoke their access.
         */
        users: z.ZodOptional<z.ZodArray<z.ZodObject<{
            /**
             * Databases to which this user can connect and create objects. Removing a database from this list does NOT revoke access. This field is ignored for the "postgres" user.
             */
            databases: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            /**
             * The name of this PostgreSQL user. The value may contain only lowercase letters, numbers, and hyphen so that it fits into Kubernetes metadata.
             * @minLength 1
             * @maxLength 63
             * @pattern ^[a-z0-9]([-a-z0-9]*[a-z0-9])?$
             */
            name: z.ZodString;
            /**
             * ALTER ROLE options except for PASSWORD. This field is ignored for the "postgres" user. More info: https://www.postgresql.org/docs/current/role-attributes.html
             * @pattern ^[^;]*$
             */
            options: z.ZodOptional<z.ZodString>;
            /**
             * Properties of the password generated for this user.
             */
            password: z.ZodOptional<z.ZodObject<{
                /**
                 * Type of password to generate. Defaults to ASCII. Valid options are ASCII and AlphaNumeric. "ASCII" passwords contain letters, numbers, and symbols from the US-ASCII character set. "AlphaNumeric" passwords contain letters and numbers from the US-ASCII character set.
                 * @default "ASCII"
                 */
                type: z.ZodDefault<z.ZodUnion<[z.ZodLiteral<"ASCII">, z.ZodLiteral<"AlphaNumeric">]>>;
            }, "strip", z.ZodTypeAny, {
                type: "ASCII" | "AlphaNumeric";
            }, {
                type?: "ASCII" | "AlphaNumeric" | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            name: string;
            options?: string | undefined;
            databases?: string[] | undefined;
            password?: {
                type: "ASCII" | "AlphaNumeric";
            } | undefined;
        }, {
            name: string;
            options?: string | undefined;
            databases?: string[] | undefined;
            password?: {
                type?: "ASCII" | "AlphaNumeric" | undefined;
            } | undefined;
        }>, "many">>;
    }, "strip", z.ZodTypeAny, {
        port: number;
        backups: {
            pgbackrest: {
                repos: {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes: string[];
                            resources: {
                                requests: Record<string, string | number>;
                                limits?: Record<string, string | number> | undefined;
                            };
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                }[];
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                configuration?: {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }[] | undefined;
                sidecars?: {
                    pgbackrest?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                    pgbackrestConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                image?: string | undefined;
                global?: Record<string, string> | undefined;
                jobs?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    ttlSecondsAfterFinished?: number | undefined;
                } | undefined;
                manual?: {
                    repoName: string;
                    options?: string[] | undefined;
                } | undefined;
                repoHost?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    sshConfigMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    sshSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    topologySpreadConstraints?: {
                        topologyKey: string;
                        maxSkew: number;
                        whenUnsatisfiable: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        minDomains?: number | undefined;
                    }[] | undefined;
                } | undefined;
                restore?: {
                    repoName: string;
                    enabled: boolean;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    options?: string[] | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    clusterName?: string | undefined;
                    clusterNamespace?: string | undefined;
                } | undefined;
            };
        };
        instances: {
            dataVolumeClaimSpec: {
                accessModes: string[];
                resources: {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                };
                selector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                dataSource?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                dataSourceRef?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                storageClassName?: string | undefined;
                volumeMode?: string | undefined;
                volumeName?: string | undefined;
            };
            replicas: number;
            name?: string | undefined;
            resources?: {
                requests?: Record<string, string | number> | undefined;
                limits?: Record<string, string | number> | undefined;
            } | undefined;
            metadata?: {
                annotations?: Record<string, string> | undefined;
                labels?: Record<string, string> | undefined;
            } | undefined;
            sidecars?: {
                replicaCertCopy?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
            tolerations?: {
                key?: string | undefined;
                operator?: string | undefined;
                value?: string | undefined;
                effect?: string | undefined;
                tolerationSeconds?: number | undefined;
            }[] | undefined;
            affinity?: {
                nodeAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        preference: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        };
                        weight: number;
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        nodeSelectorTerms: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        }[];
                    } | undefined;
                } | undefined;
                podAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                } | undefined;
                podAntiAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                } | undefined;
            } | undefined;
            priorityClassName?: string | undefined;
            topologySpreadConstraints?: {
                topologyKey: string;
                maxSkew: number;
                whenUnsatisfiable: string;
                labelSelector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                minDomains?: number | undefined;
            }[] | undefined;
            containers?: {
                name: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                env?: {
                    name: string;
                    value?: string | undefined;
                    valueFrom?: {
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                        configMapKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        secretKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    } | undefined;
                }[] | undefined;
                image?: string | undefined;
                imagePullPolicy?: string | undefined;
                args?: string[] | undefined;
                command?: string[] | undefined;
                envFrom?: {
                    configMapRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    prefix?: string | undefined;
                    secretRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                lifecycle?: {
                    postStart?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                    preStop?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                livenessProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                ports?: {
                    containerPort: number;
                    protocol: string;
                    name?: string | undefined;
                    hostIP?: string | undefined;
                    hostPort?: number | undefined;
                }[] | undefined;
                readinessProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                securityContext?: {
                    allowPrivilegeEscalation?: boolean | undefined;
                    capabilities?: {
                        add?: string[] | undefined;
                        drop?: string[] | undefined;
                    } | undefined;
                    privileged?: boolean | undefined;
                    procMount?: string | undefined;
                    readOnlyRootFilesystem?: boolean | undefined;
                    runAsGroup?: number | undefined;
                    runAsNonRoot?: boolean | undefined;
                    runAsUser?: number | undefined;
                    seLinuxOptions?: {
                        type?: string | undefined;
                        user?: string | undefined;
                        level?: string | undefined;
                        role?: string | undefined;
                    } | undefined;
                    seccompProfile?: {
                        type: string;
                        localhostProfile?: string | undefined;
                    } | undefined;
                    windowsOptions?: {
                        gmsaCredentialSpec?: string | undefined;
                        gmsaCredentialSpecName?: string | undefined;
                        hostProcess?: boolean | undefined;
                        runAsUserName?: string | undefined;
                    } | undefined;
                } | undefined;
                startupProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                stdin?: boolean | undefined;
                stdinOnce?: boolean | undefined;
                terminationMessagePath?: string | undefined;
                terminationMessagePolicy?: string | undefined;
                tty?: boolean | undefined;
                volumeDevices?: {
                    name: string;
                    devicePath: string;
                }[] | undefined;
                volumeMounts?: {
                    name: string;
                    mountPath: string;
                    subPath?: string | undefined;
                    mountPropagation?: string | undefined;
                    readOnly?: boolean | undefined;
                    subPathExpr?: string | undefined;
                }[] | undefined;
                workingDir?: string | undefined;
            }[] | undefined;
            minAvailable?: string | number | undefined;
            tablespaceVolumes?: {
                name: string;
                dataVolumeClaimSpec: {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                };
            }[] | undefined;
            walVolumeClaimSpec?: {
                accessModes: string[];
                resources: {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                };
                selector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                dataSource?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                dataSourceRef?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                storageClassName?: string | undefined;
                volumeMode?: string | undefined;
                volumeName?: string | undefined;
            } | undefined;
        }[];
        postgresVersion: number;
        metadata?: {
            annotations?: Record<string, string> | undefined;
            labels?: Record<string, string> | undefined;
        } | undefined;
        standby?: {
            enabled: boolean;
            repoName?: string | undefined;
            port?: number | undefined;
            host?: string | undefined;
        } | undefined;
        users?: {
            name: string;
            options?: string | undefined;
            databases?: string[] | undefined;
            password?: {
                type: "ASCII" | "AlphaNumeric";
            } | undefined;
        }[] | undefined;
        patroni?: {
            port: number;
            leaderLeaseDurationSeconds: number;
            syncPeriodSeconds: number;
            dynamicConfiguration?: {} | undefined;
            switchover?: {
                type: "Switchover" | "Failover";
                enabled: boolean;
                targetInstance?: string | undefined;
            } | undefined;
        } | undefined;
        config?: {
            files?: {
                configMap?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                downwardAPI?: {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                } | undefined;
                secret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                serviceAccountToken?: {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                } | undefined;
            }[] | undefined;
        } | undefined;
        dataSource?: {
            pgbackrest?: {
                repo: {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes?: string[] | undefined;
                            resources?: {
                                requests?: Record<string, string | number> | undefined;
                                limits?: Record<string, string | number> | undefined;
                            } | undefined;
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                };
                stanza: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                configuration?: {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }[] | undefined;
                options?: string[] | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                priorityClassName?: string | undefined;
                global?: Record<string, string> | undefined;
            } | undefined;
            postgresCluster?: {
                repoName: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                options?: string[] | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                priorityClassName?: string | undefined;
                clusterName?: string | undefined;
                clusterNamespace?: string | undefined;
            } | undefined;
            volumes?: {
                pgBackRestVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
                pgDataVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
                pgWALVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
        image?: string | undefined;
        imagePullPolicy?: "Always" | "Never" | "IfNotPresent" | undefined;
        imagePullSecrets?: {
            name?: string | undefined;
        }[] | undefined;
        customReplicationTLSSecret?: {
            name?: string | undefined;
            items?: {
                key: string;
                path: string;
                mode?: number | undefined;
            }[] | undefined;
            optional?: boolean | undefined;
        } | undefined;
        customTLSSecret?: {
            name?: string | undefined;
            items?: {
                key: string;
                path: string;
                mode?: number | undefined;
            }[] | undefined;
            optional?: boolean | undefined;
        } | undefined;
        databaseInitSQL?: {
            key: string;
            name: string;
        } | undefined;
        disableDefaultPodScheduling?: boolean | undefined;
        service?: {
            type: "ClusterIP" | "NodePort" | "LoadBalancer";
            metadata?: {
                annotations?: Record<string, string> | undefined;
                labels?: Record<string, string> | undefined;
            } | undefined;
            nodePort?: number | undefined;
        } | undefined;
        monitoring?: {
            pgmonitor?: {
                exporter?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    configuration?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    customTLSSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
        openshift?: boolean | undefined;
        paused?: boolean | undefined;
        postGISVersion?: string | undefined;
        proxy?: {
            pgBouncer: {
                port: number;
                replicas: number;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                sidecars?: {
                    pgbouncerConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                config?: {
                    users?: Record<string, string> | undefined;
                    databases?: Record<string, string> | undefined;
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    global?: Record<string, string> | undefined;
                } | undefined;
                image?: string | undefined;
                priorityClassName?: string | undefined;
                topologySpreadConstraints?: {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }[] | undefined;
                customTLSSecret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                service?: {
                    type: "ClusterIP" | "NodePort" | "LoadBalancer";
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                } | undefined;
                containers?: {
                    name: string;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    env?: {
                        name: string;
                        value?: string | undefined;
                        valueFrom?: {
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                            configMapKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                            secretKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    imagePullPolicy?: string | undefined;
                    args?: string[] | undefined;
                    command?: string[] | undefined;
                    envFrom?: {
                        configMapRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        prefix?: string | undefined;
                        secretRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                    lifecycle?: {
                        postStart?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                        preStop?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                    } | undefined;
                    livenessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    ports?: {
                        containerPort: number;
                        protocol: string;
                        name?: string | undefined;
                        hostIP?: string | undefined;
                        hostPort?: number | undefined;
                    }[] | undefined;
                    readinessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    securityContext?: {
                        allowPrivilegeEscalation?: boolean | undefined;
                        capabilities?: {
                            add?: string[] | undefined;
                            drop?: string[] | undefined;
                        } | undefined;
                        privileged?: boolean | undefined;
                        procMount?: string | undefined;
                        readOnlyRootFilesystem?: boolean | undefined;
                        runAsGroup?: number | undefined;
                        runAsNonRoot?: boolean | undefined;
                        runAsUser?: number | undefined;
                        seLinuxOptions?: {
                            type?: string | undefined;
                            user?: string | undefined;
                            level?: string | undefined;
                            role?: string | undefined;
                        } | undefined;
                        seccompProfile?: {
                            type: string;
                            localhostProfile?: string | undefined;
                        } | undefined;
                        windowsOptions?: {
                            gmsaCredentialSpec?: string | undefined;
                            gmsaCredentialSpecName?: string | undefined;
                            hostProcess?: boolean | undefined;
                            runAsUserName?: string | undefined;
                        } | undefined;
                    } | undefined;
                    startupProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    stdin?: boolean | undefined;
                    stdinOnce?: boolean | undefined;
                    terminationMessagePath?: string | undefined;
                    terminationMessagePolicy?: string | undefined;
                    tty?: boolean | undefined;
                    volumeDevices?: {
                        name: string;
                        devicePath: string;
                    }[] | undefined;
                    volumeMounts?: {
                        name: string;
                        mountPath: string;
                        subPath?: string | undefined;
                        mountPropagation?: string | undefined;
                        readOnly?: boolean | undefined;
                        subPathExpr?: string | undefined;
                    }[] | undefined;
                    workingDir?: string | undefined;
                }[] | undefined;
                minAvailable?: string | number | undefined;
            };
        } | undefined;
        shutdown?: boolean | undefined;
        supplementalGroups?: number[] | undefined;
        userInterface?: {
            pgAdmin: {
                dataVolumeClaimSpec: {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                };
                replicas: number;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                config?: {
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    ldapBindPassword?: {
                        key: string;
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    settings?: {} | undefined;
                } | undefined;
                image?: string | undefined;
                priorityClassName?: string | undefined;
                topologySpreadConstraints?: {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }[] | undefined;
                service?: {
                    type: "ClusterIP" | "NodePort" | "LoadBalancer";
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                } | undefined;
            };
        } | undefined;
    }, {
        backups: {
            pgbackrest: {
                repos: {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes: string[];
                            resources: {
                                requests: Record<string, string | number>;
                                limits?: Record<string, string | number> | undefined;
                            };
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                }[];
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                configuration?: {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }[] | undefined;
                sidecars?: {
                    pgbackrest?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                    pgbackrestConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                image?: string | undefined;
                global?: Record<string, string> | undefined;
                jobs?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    ttlSecondsAfterFinished?: number | undefined;
                } | undefined;
                manual?: {
                    repoName: string;
                    options?: string[] | undefined;
                } | undefined;
                repoHost?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    sshConfigMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    sshSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    topologySpreadConstraints?: {
                        topologyKey: string;
                        maxSkew: number;
                        whenUnsatisfiable: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        minDomains?: number | undefined;
                    }[] | undefined;
                } | undefined;
                restore?: {
                    repoName: string;
                    enabled: boolean;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    options?: string[] | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    clusterName?: string | undefined;
                    clusterNamespace?: string | undefined;
                } | undefined;
            };
        };
        instances: {
            dataVolumeClaimSpec: {
                accessModes: string[];
                resources: {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                };
                selector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                dataSource?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                dataSourceRef?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                storageClassName?: string | undefined;
                volumeMode?: string | undefined;
                volumeName?: string | undefined;
            };
            name?: string | undefined;
            resources?: {
                requests?: Record<string, string | number> | undefined;
                limits?: Record<string, string | number> | undefined;
            } | undefined;
            metadata?: {
                annotations?: Record<string, string> | undefined;
                labels?: Record<string, string> | undefined;
            } | undefined;
            sidecars?: {
                replicaCertCopy?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
            tolerations?: {
                key?: string | undefined;
                operator?: string | undefined;
                value?: string | undefined;
                effect?: string | undefined;
                tolerationSeconds?: number | undefined;
            }[] | undefined;
            affinity?: {
                nodeAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        preference: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        };
                        weight: number;
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        nodeSelectorTerms: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        }[];
                    } | undefined;
                } | undefined;
                podAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                } | undefined;
                podAntiAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                } | undefined;
            } | undefined;
            priorityClassName?: string | undefined;
            topologySpreadConstraints?: {
                topologyKey: string;
                maxSkew: number;
                whenUnsatisfiable: string;
                labelSelector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                minDomains?: number | undefined;
            }[] | undefined;
            containers?: {
                name: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                env?: {
                    name: string;
                    value?: string | undefined;
                    valueFrom?: {
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                        configMapKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        secretKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    } | undefined;
                }[] | undefined;
                image?: string | undefined;
                imagePullPolicy?: string | undefined;
                args?: string[] | undefined;
                command?: string[] | undefined;
                envFrom?: {
                    configMapRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    prefix?: string | undefined;
                    secretRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                lifecycle?: {
                    postStart?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                    preStop?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                livenessProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                ports?: {
                    containerPort: number;
                    name?: string | undefined;
                    hostIP?: string | undefined;
                    hostPort?: number | undefined;
                    protocol?: string | undefined;
                }[] | undefined;
                readinessProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                securityContext?: {
                    allowPrivilegeEscalation?: boolean | undefined;
                    capabilities?: {
                        add?: string[] | undefined;
                        drop?: string[] | undefined;
                    } | undefined;
                    privileged?: boolean | undefined;
                    procMount?: string | undefined;
                    readOnlyRootFilesystem?: boolean | undefined;
                    runAsGroup?: number | undefined;
                    runAsNonRoot?: boolean | undefined;
                    runAsUser?: number | undefined;
                    seLinuxOptions?: {
                        type?: string | undefined;
                        user?: string | undefined;
                        level?: string | undefined;
                        role?: string | undefined;
                    } | undefined;
                    seccompProfile?: {
                        type: string;
                        localhostProfile?: string | undefined;
                    } | undefined;
                    windowsOptions?: {
                        gmsaCredentialSpec?: string | undefined;
                        gmsaCredentialSpecName?: string | undefined;
                        hostProcess?: boolean | undefined;
                        runAsUserName?: string | undefined;
                    } | undefined;
                } | undefined;
                startupProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                stdin?: boolean | undefined;
                stdinOnce?: boolean | undefined;
                terminationMessagePath?: string | undefined;
                terminationMessagePolicy?: string | undefined;
                tty?: boolean | undefined;
                volumeDevices?: {
                    name: string;
                    devicePath: string;
                }[] | undefined;
                volumeMounts?: {
                    name: string;
                    mountPath: string;
                    subPath?: string | undefined;
                    mountPropagation?: string | undefined;
                    readOnly?: boolean | undefined;
                    subPathExpr?: string | undefined;
                }[] | undefined;
                workingDir?: string | undefined;
            }[] | undefined;
            minAvailable?: string | number | undefined;
            replicas?: number | undefined;
            tablespaceVolumes?: {
                name: string;
                dataVolumeClaimSpec: {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                };
            }[] | undefined;
            walVolumeClaimSpec?: {
                accessModes: string[];
                resources: {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                };
                selector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                dataSource?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                dataSourceRef?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                storageClassName?: string | undefined;
                volumeMode?: string | undefined;
                volumeName?: string | undefined;
            } | undefined;
        }[];
        postgresVersion: number;
        port?: number | undefined;
        metadata?: {
            annotations?: Record<string, string> | undefined;
            labels?: Record<string, string> | undefined;
        } | undefined;
        standby?: {
            repoName?: string | undefined;
            enabled?: boolean | undefined;
            port?: number | undefined;
            host?: string | undefined;
        } | undefined;
        users?: {
            name: string;
            options?: string | undefined;
            databases?: string[] | undefined;
            password?: {
                type?: "ASCII" | "AlphaNumeric" | undefined;
            } | undefined;
        }[] | undefined;
        patroni?: {
            port?: number | undefined;
            dynamicConfiguration?: {} | undefined;
            leaderLeaseDurationSeconds?: number | undefined;
            switchover?: {
                enabled: boolean;
                type?: "Switchover" | "Failover" | undefined;
                targetInstance?: string | undefined;
            } | undefined;
            syncPeriodSeconds?: number | undefined;
        } | undefined;
        config?: {
            files?: {
                configMap?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                downwardAPI?: {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                } | undefined;
                secret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                serviceAccountToken?: {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                } | undefined;
            }[] | undefined;
        } | undefined;
        dataSource?: {
            pgbackrest?: {
                repo: {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes?: string[] | undefined;
                            resources?: {
                                requests?: Record<string, string | number> | undefined;
                                limits?: Record<string, string | number> | undefined;
                            } | undefined;
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                };
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                stanza?: string | undefined;
                configuration?: {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }[] | undefined;
                options?: string[] | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                priorityClassName?: string | undefined;
                global?: Record<string, string> | undefined;
            } | undefined;
            postgresCluster?: {
                repoName: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                options?: string[] | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                priorityClassName?: string | undefined;
                clusterName?: string | undefined;
                clusterNamespace?: string | undefined;
            } | undefined;
            volumes?: {
                pgBackRestVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
                pgDataVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
                pgWALVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
        image?: string | undefined;
        imagePullPolicy?: "Always" | "Never" | "IfNotPresent" | undefined;
        imagePullSecrets?: {
            name?: string | undefined;
        }[] | undefined;
        customReplicationTLSSecret?: {
            name?: string | undefined;
            items?: {
                key: string;
                path: string;
                mode?: number | undefined;
            }[] | undefined;
            optional?: boolean | undefined;
        } | undefined;
        customTLSSecret?: {
            name?: string | undefined;
            items?: {
                key: string;
                path: string;
                mode?: number | undefined;
            }[] | undefined;
            optional?: boolean | undefined;
        } | undefined;
        databaseInitSQL?: {
            key: string;
            name: string;
        } | undefined;
        disableDefaultPodScheduling?: boolean | undefined;
        service?: {
            type?: "ClusterIP" | "NodePort" | "LoadBalancer" | undefined;
            metadata?: {
                annotations?: Record<string, string> | undefined;
                labels?: Record<string, string> | undefined;
            } | undefined;
            nodePort?: number | undefined;
        } | undefined;
        monitoring?: {
            pgmonitor?: {
                exporter?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    configuration?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    customTLSSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
        openshift?: boolean | undefined;
        paused?: boolean | undefined;
        postGISVersion?: string | undefined;
        proxy?: {
            pgBouncer: {
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                port?: number | undefined;
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                sidecars?: {
                    pgbouncerConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                config?: {
                    users?: Record<string, string> | undefined;
                    databases?: Record<string, string> | undefined;
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    global?: Record<string, string> | undefined;
                } | undefined;
                image?: string | undefined;
                priorityClassName?: string | undefined;
                topologySpreadConstraints?: {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }[] | undefined;
                customTLSSecret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                service?: {
                    type?: "ClusterIP" | "NodePort" | "LoadBalancer" | undefined;
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                } | undefined;
                containers?: {
                    name: string;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    env?: {
                        name: string;
                        value?: string | undefined;
                        valueFrom?: {
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                            configMapKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                            secretKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    imagePullPolicy?: string | undefined;
                    args?: string[] | undefined;
                    command?: string[] | undefined;
                    envFrom?: {
                        configMapRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        prefix?: string | undefined;
                        secretRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                    lifecycle?: {
                        postStart?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                        preStop?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                    } | undefined;
                    livenessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    ports?: {
                        containerPort: number;
                        name?: string | undefined;
                        hostIP?: string | undefined;
                        hostPort?: number | undefined;
                        protocol?: string | undefined;
                    }[] | undefined;
                    readinessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    securityContext?: {
                        allowPrivilegeEscalation?: boolean | undefined;
                        capabilities?: {
                            add?: string[] | undefined;
                            drop?: string[] | undefined;
                        } | undefined;
                        privileged?: boolean | undefined;
                        procMount?: string | undefined;
                        readOnlyRootFilesystem?: boolean | undefined;
                        runAsGroup?: number | undefined;
                        runAsNonRoot?: boolean | undefined;
                        runAsUser?: number | undefined;
                        seLinuxOptions?: {
                            type?: string | undefined;
                            user?: string | undefined;
                            level?: string | undefined;
                            role?: string | undefined;
                        } | undefined;
                        seccompProfile?: {
                            type: string;
                            localhostProfile?: string | undefined;
                        } | undefined;
                        windowsOptions?: {
                            gmsaCredentialSpec?: string | undefined;
                            gmsaCredentialSpecName?: string | undefined;
                            hostProcess?: boolean | undefined;
                            runAsUserName?: string | undefined;
                        } | undefined;
                    } | undefined;
                    startupProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    stdin?: boolean | undefined;
                    stdinOnce?: boolean | undefined;
                    terminationMessagePath?: string | undefined;
                    terminationMessagePolicy?: string | undefined;
                    tty?: boolean | undefined;
                    volumeDevices?: {
                        name: string;
                        devicePath: string;
                    }[] | undefined;
                    volumeMounts?: {
                        name: string;
                        mountPath: string;
                        subPath?: string | undefined;
                        mountPropagation?: string | undefined;
                        readOnly?: boolean | undefined;
                        subPathExpr?: string | undefined;
                    }[] | undefined;
                    workingDir?: string | undefined;
                }[] | undefined;
                minAvailable?: string | number | undefined;
                replicas?: number | undefined;
            };
        } | undefined;
        shutdown?: boolean | undefined;
        supplementalGroups?: number[] | undefined;
        userInterface?: {
            pgAdmin: {
                dataVolumeClaimSpec: {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                };
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                config?: {
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    ldapBindPassword?: {
                        key: string;
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    settings?: {} | undefined;
                } | undefined;
                image?: string | undefined;
                priorityClassName?: string | undefined;
                topologySpreadConstraints?: {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }[] | undefined;
                service?: {
                    type?: "ClusterIP" | "NodePort" | "LoadBalancer" | undefined;
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                } | undefined;
                replicas?: number | undefined;
            };
        } | undefined;
    }>>;
    /**
     * PostgresClusterStatus defines the observed state of PostgresCluster
     */
    status: z.ZodOptional<z.ZodObject<{
        /**
         * conditions represent the observations of postgrescluster's current state. Known .status.conditions.type are: "PersistentVolumeResizing", "Progressing", "ProxyAvailable"
         */
        conditions: z.ZodOptional<z.ZodArray<z.ZodObject<{
            /**
             * lastTransitionTime is the last time the condition transitioned from one status to another. This should be when the underlying condition changed.  If that is not known, then using the time when the API field changed is acceptable.
             * @format date-time
             */
            lastTransitionTime: z.ZodNullable<z.ZodString>;
            /**
             * message is a human readable message indicating details about the transition. This may be an empty string.
             * @maxLength 32768
             */
            message: z.ZodString;
            /**
             * observedGeneration represents the .metadata.generation that the condition was set based upon. For instance, if .metadata.generation is currently 12, but the .status.conditions[x].observedGeneration is 9, the condition is out of date with respect to the current state of the instance.
             * @format int64
             */
            observedGeneration: z.ZodOptional<z.ZodNumber>;
            /**
             * reason contains a programmatic identifier indicating the reason for the condition's last transition. Producers of specific condition types may define expected values and meanings for this field, and whether the values are considered a guaranteed API. The value should be a CamelCase string. This field may not be empty.
             * @minLength 1
             * @maxLength 1024
             * @pattern ^[A-Za-z]([A-Za-z0-9_,:]*[A-Za-z0-9_])?$
             */
            reason: z.ZodString;
            /**
             * status of the condition, one of True, False, Unknown.
             */
            status: z.ZodUnion<[z.ZodLiteral<"True">, z.ZodLiteral<"False">, z.ZodLiteral<"Unknown">]>;
            /**
             * type of condition in CamelCase.
             * @maxLength 316
             */
            type: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            type: string;
            lastTransitionTime: string | null;
            message: string;
            reason: string;
            status: "True" | "False" | "Unknown";
            observedGeneration?: number | undefined;
        }, {
            type: string;
            lastTransitionTime: string | null;
            message: string;
            reason: string;
            status: "True" | "False" | "Unknown";
            observedGeneration?: number | undefined;
        }>, "many">>;
        /**
         * DatabaseInitSQL state of custom database initialization in the cluster
         */
        databaseInitSQL: z.ZodOptional<z.ZodString>;
        /**
         * Identifies the databases that have been installed into PostgreSQL.
         */
        databaseRevision: z.ZodOptional<z.ZodString>;
        /**
         * Current state of PostgreSQL instances.
         */
        instances: z.ZodOptional<z.ZodArray<z.ZodObject<{
            name: z.ZodString;
            /**
             * Total number of ready pods.
             * @format int32
             */
            readyReplicas: z.ZodOptional<z.ZodNumber>;
            /**
             * Total number of pods.
             * @format int32
             */
            replicas: z.ZodOptional<z.ZodNumber>;
            /**
             * Total number of pods that have the desired specification.
             * @format int32
             */
            updatedReplicas: z.ZodOptional<z.ZodNumber>;
        }, "strip", z.ZodTypeAny, {
            name: string;
            replicas?: number | undefined;
            readyReplicas?: number | undefined;
            updatedReplicas?: number | undefined;
        }, {
            name: string;
            replicas?: number | undefined;
            readyReplicas?: number | undefined;
            updatedReplicas?: number | undefined;
        }>, "many">>;
        /**
         * Current state of PostgreSQL cluster monitoring tool configuration
         */
        monitoring: z.ZodOptional<z.ZodObject<{
            exporterConfiguration: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            exporterConfiguration?: string | undefined;
        }, {
            exporterConfiguration?: string | undefined;
        }>>;
        /**
         * observedGeneration represents the .metadata.generation on which the status was based.
         * @format int64
         */
        observedGeneration: z.ZodOptional<z.ZodNumber>;
        patroni: z.ZodOptional<z.ZodObject<{
            /**
             * Tracks the execution of the switchover requests.
             */
            switchover: z.ZodOptional<z.ZodString>;
            /**
             * Tracks the current timeline during switchovers
             * @format int64
             */
            switchoverTimeline: z.ZodOptional<z.ZodNumber>;
            /**
             * The PostgreSQL system identifier reported by Patroni.
             */
            systemIdentifier: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            switchover?: string | undefined;
            switchoverTimeline?: number | undefined;
            systemIdentifier?: string | undefined;
        }, {
            switchover?: string | undefined;
            switchoverTimeline?: number | undefined;
            systemIdentifier?: string | undefined;
        }>>;
        /**
         * Status information for pgBackRest
         */
        pgbackrest: z.ZodOptional<z.ZodObject<{
            /**
             * Status information for manual backups
             */
            manualBackup: z.ZodOptional<z.ZodObject<{
                /**
                 * The number of actively running manual backup Pods.
                 * @format int32
                 */
                active: z.ZodOptional<z.ZodNumber>;
                /**
                 * Represents the time the manual backup Job was determined by the Job controller to be completed.  This field is only set if the backup completed successfully. Additionally, it is represented in RFC3339 form and is in UTC.
                 * @format date-time
                 */
                completionTime: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                /**
                 * The number of Pods for the manual backup Job that reached the "Failed" phase.
                 * @format int32
                 */
                failed: z.ZodOptional<z.ZodNumber>;
                /**
                 * Specifies whether or not the Job is finished executing (does not indicate success or failure).
                 */
                finished: z.ZodBoolean;
                /**
                 * A unique identifier for the manual backup as provided using the "pgbackrest-backup" annotation when initiating a backup.
                 */
                id: z.ZodString;
                /**
                 * Represents the time the manual backup Job was acknowledged by the Job controller. It is represented in RFC3339 form and is in UTC.
                 * @format date-time
                 */
                startTime: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                /**
                 * The number of Pods for the manual backup Job that reached the "Succeeded" phase.
                 * @format int32
                 */
                succeeded: z.ZodOptional<z.ZodNumber>;
            }, "strip", z.ZodTypeAny, {
                finished: boolean;
                id: string;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
            }, {
                finished: boolean;
                id: string;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
            }>>;
            /**
             * Status information for the pgBackRest dedicated repository host
             */
            repoHost: z.ZodOptional<z.ZodObject<{
                /**
                 * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
                 */
                apiVersion: z.ZodOptional<z.ZodString>;
                /**
                 * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
                 */
                kind: z.ZodOptional<z.ZodString>;
                /**
                 * Whether or not the pgBackRest repository host is ready for use
                 */
                ready: z.ZodOptional<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                kind?: string | undefined;
                apiVersion?: string | undefined;
                ready?: boolean | undefined;
            }, {
                kind?: string | undefined;
                apiVersion?: string | undefined;
                ready?: boolean | undefined;
            }>>;
            /**
             * Status information for pgBackRest repositories
             */
            repos: z.ZodOptional<z.ZodArray<z.ZodObject<{
                /**
                 * Whether or not the pgBackRest repository PersistentVolumeClaim is bound to a volume
                 */
                bound: z.ZodOptional<z.ZodBoolean>;
                /**
                 * The name of the pgBackRest repository
                 */
                name: z.ZodString;
                /**
                 * ReplicaCreateBackupReady indicates whether a backup exists in the repository as needed to bootstrap replicas.
                 */
                replicaCreateBackupComplete: z.ZodOptional<z.ZodBoolean>;
                /**
                 * A hash of the required fields in the spec for defining an Azure, GCS or S3 repository, Utilizd to detect changes to these fields and then execute pgBackRest stanza-create commands accordingly.
                 */
                repoOptionsHash: z.ZodOptional<z.ZodString>;
                /**
                 * Specifies whether or not a stanza has been successfully created for the repository
                 */
                stanzaCreated: z.ZodOptional<z.ZodBoolean>;
                /**
                 * The name of the volume the containing the pgBackRest repository
                 */
                volume: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                name: string;
                volume?: string | undefined;
                bound?: boolean | undefined;
                replicaCreateBackupComplete?: boolean | undefined;
                repoOptionsHash?: string | undefined;
                stanzaCreated?: boolean | undefined;
            }, {
                name: string;
                volume?: string | undefined;
                bound?: boolean | undefined;
                replicaCreateBackupComplete?: boolean | undefined;
                repoOptionsHash?: string | undefined;
                stanzaCreated?: boolean | undefined;
            }>, "many">>;
            /**
             * Status information for in-place restores
             */
            restore: z.ZodOptional<z.ZodObject<{
                /**
                 * The number of actively running manual backup Pods.
                 * @format int32
                 */
                active: z.ZodOptional<z.ZodNumber>;
                /**
                 * Represents the time the manual backup Job was determined by the Job controller to be completed.  This field is only set if the backup completed successfully. Additionally, it is represented in RFC3339 form and is in UTC.
                 * @format date-time
                 */
                completionTime: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                /**
                 * The number of Pods for the manual backup Job that reached the "Failed" phase.
                 * @format int32
                 */
                failed: z.ZodOptional<z.ZodNumber>;
                /**
                 * Specifies whether or not the Job is finished executing (does not indicate success or failure).
                 */
                finished: z.ZodBoolean;
                /**
                 * A unique identifier for the manual backup as provided using the "pgbackrest-backup" annotation when initiating a backup.
                 */
                id: z.ZodString;
                /**
                 * Represents the time the manual backup Job was acknowledged by the Job controller. It is represented in RFC3339 form and is in UTC.
                 * @format date-time
                 */
                startTime: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                /**
                 * The number of Pods for the manual backup Job that reached the "Succeeded" phase.
                 * @format int32
                 */
                succeeded: z.ZodOptional<z.ZodNumber>;
            }, "strip", z.ZodTypeAny, {
                finished: boolean;
                id: string;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
            }, {
                finished: boolean;
                id: string;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
            }>>;
            /**
             * Status information for scheduled backups
             */
            scheduledBackups: z.ZodOptional<z.ZodArray<z.ZodObject<{
                /**
                 * The number of actively running manual backup Pods.
                 * @format int32
                 */
                active: z.ZodOptional<z.ZodNumber>;
                /**
                 * Represents the time the manual backup Job was determined by the Job controller to be completed.  This field is only set if the backup completed successfully. Additionally, it is represented in RFC3339 form and is in UTC.
                 * @format date-time
                 */
                completionTime: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                /**
                 * The name of the associated pgBackRest scheduled backup CronJob
                 */
                cronJobName: z.ZodOptional<z.ZodString>;
                /**
                 * The number of Pods for the manual backup Job that reached the "Failed" phase.
                 * @format int32
                 */
                failed: z.ZodOptional<z.ZodNumber>;
                /**
                 * The name of the associated pgBackRest repository
                 */
                repo: z.ZodOptional<z.ZodString>;
                /**
                 * Represents the time the manual backup Job was acknowledged by the Job controller. It is represented in RFC3339 form and is in UTC.
                 * @format date-time
                 */
                startTime: z.ZodNullable<z.ZodOptional<z.ZodString>>;
                /**
                 * The number of Pods for the manual backup Job that reached the "Succeeded" phase.
                 * @format int32
                 */
                succeeded: z.ZodOptional<z.ZodNumber>;
                /**
                 * The pgBackRest backup type for this Job
                 */
                type: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                type?: string | undefined;
                repo?: string | undefined;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
                cronJobName?: string | undefined;
            }, {
                type?: string | undefined;
                repo?: string | undefined;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
                cronJobName?: string | undefined;
            }>, "many">>;
        }, "strip", z.ZodTypeAny, {
            repos?: {
                name: string;
                volume?: string | undefined;
                bound?: boolean | undefined;
                replicaCreateBackupComplete?: boolean | undefined;
                repoOptionsHash?: string | undefined;
                stanzaCreated?: boolean | undefined;
            }[] | undefined;
            repoHost?: {
                kind?: string | undefined;
                apiVersion?: string | undefined;
                ready?: boolean | undefined;
            } | undefined;
            restore?: {
                finished: boolean;
                id: string;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
            } | undefined;
            manualBackup?: {
                finished: boolean;
                id: string;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
            } | undefined;
            scheduledBackups?: {
                type?: string | undefined;
                repo?: string | undefined;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
                cronJobName?: string | undefined;
            }[] | undefined;
        }, {
            repos?: {
                name: string;
                volume?: string | undefined;
                bound?: boolean | undefined;
                replicaCreateBackupComplete?: boolean | undefined;
                repoOptionsHash?: string | undefined;
                stanzaCreated?: boolean | undefined;
            }[] | undefined;
            repoHost?: {
                kind?: string | undefined;
                apiVersion?: string | undefined;
                ready?: boolean | undefined;
            } | undefined;
            restore?: {
                finished: boolean;
                id: string;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
            } | undefined;
            manualBackup?: {
                finished: boolean;
                id: string;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
            } | undefined;
            scheduledBackups?: {
                type?: string | undefined;
                repo?: string | undefined;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
                cronJobName?: string | undefined;
            }[] | undefined;
        }>>;
        /**
         * Stores the current PostgreSQL major version following a successful major PostgreSQL upgrade.
         */
        postgresVersion: z.ZodOptional<z.ZodNumber>;
        /**
         * Current state of the PostgreSQL proxy.
         */
        proxy: z.ZodOptional<z.ZodObject<{
            pgBouncer: z.ZodOptional<z.ZodObject<{
                /**
                 * Identifies the revision of PgBouncer assets that have been installed into PostgreSQL.
                 */
                postgresRevision: z.ZodOptional<z.ZodString>;
                /**
                 * Total number of ready pods.
                 * @format int32
                 */
                readyReplicas: z.ZodOptional<z.ZodNumber>;
                /**
                 * Total number of non-terminated pods.
                 * @format int32
                 */
                replicas: z.ZodOptional<z.ZodNumber>;
            }, "strip", z.ZodTypeAny, {
                replicas?: number | undefined;
                readyReplicas?: number | undefined;
                postgresRevision?: string | undefined;
            }, {
                replicas?: number | undefined;
                readyReplicas?: number | undefined;
                postgresRevision?: string | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            pgBouncer?: {
                replicas?: number | undefined;
                readyReplicas?: number | undefined;
                postgresRevision?: string | undefined;
            } | undefined;
        }, {
            pgBouncer?: {
                replicas?: number | undefined;
                readyReplicas?: number | undefined;
                postgresRevision?: string | undefined;
            } | undefined;
        }>>;
        /**
         * Version information for installations with a registration requirement.
         */
        registrationRequired: z.ZodOptional<z.ZodObject<{
            pgoVersion: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            pgoVersion?: string | undefined;
        }, {
            pgoVersion?: string | undefined;
        }>>;
        /**
         * The instance that should be started first when bootstrapping and/or starting a PostgresCluster.
         */
        startupInstance: z.ZodOptional<z.ZodString>;
        /**
         * The instance set associated with the startupInstance
         */
        startupInstanceSet: z.ZodOptional<z.ZodString>;
        /**
         * Signals the need for a token to be applied when registration is required.
         */
        tokenRequired: z.ZodOptional<z.ZodString>;
        /**
         * Current state of the PostgreSQL user interface.
         */
        userInterface: z.ZodOptional<z.ZodObject<{
            /**
             * The state of the pgAdmin user interface.
             */
            pgAdmin: z.ZodOptional<z.ZodObject<{
                /**
                 * Hash that indicates which users have been installed into pgAdmin.
                 */
                usersRevision: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                usersRevision?: string | undefined;
            }, {
                usersRevision?: string | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            pgAdmin?: {
                usersRevision?: string | undefined;
            } | undefined;
        }, {
            pgAdmin?: {
                usersRevision?: string | undefined;
            } | undefined;
        }>>;
        /**
         * Identifies the users that have been installed into PostgreSQL.
         */
        usersRevision: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        pgbackrest?: {
            repos?: {
                name: string;
                volume?: string | undefined;
                bound?: boolean | undefined;
                replicaCreateBackupComplete?: boolean | undefined;
                repoOptionsHash?: string | undefined;
                stanzaCreated?: boolean | undefined;
            }[] | undefined;
            repoHost?: {
                kind?: string | undefined;
                apiVersion?: string | undefined;
                ready?: boolean | undefined;
            } | undefined;
            restore?: {
                finished: boolean;
                id: string;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
            } | undefined;
            manualBackup?: {
                finished: boolean;
                id: string;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
            } | undefined;
            scheduledBackups?: {
                type?: string | undefined;
                repo?: string | undefined;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
                cronJobName?: string | undefined;
            }[] | undefined;
        } | undefined;
        instances?: {
            name: string;
            replicas?: number | undefined;
            readyReplicas?: number | undefined;
            updatedReplicas?: number | undefined;
        }[] | undefined;
        postgresVersion?: number | undefined;
        patroni?: {
            switchover?: string | undefined;
            switchoverTimeline?: number | undefined;
            systemIdentifier?: string | undefined;
        } | undefined;
        observedGeneration?: number | undefined;
        conditions?: {
            type: string;
            lastTransitionTime: string | null;
            message: string;
            reason: string;
            status: "True" | "False" | "Unknown";
            observedGeneration?: number | undefined;
        }[] | undefined;
        databaseInitSQL?: string | undefined;
        monitoring?: {
            exporterConfiguration?: string | undefined;
        } | undefined;
        proxy?: {
            pgBouncer?: {
                replicas?: number | undefined;
                readyReplicas?: number | undefined;
                postgresRevision?: string | undefined;
            } | undefined;
        } | undefined;
        userInterface?: {
            pgAdmin?: {
                usersRevision?: string | undefined;
            } | undefined;
        } | undefined;
        databaseRevision?: string | undefined;
        registrationRequired?: {
            pgoVersion?: string | undefined;
        } | undefined;
        startupInstance?: string | undefined;
        startupInstanceSet?: string | undefined;
        tokenRequired?: string | undefined;
        usersRevision?: string | undefined;
    }, {
        pgbackrest?: {
            repos?: {
                name: string;
                volume?: string | undefined;
                bound?: boolean | undefined;
                replicaCreateBackupComplete?: boolean | undefined;
                repoOptionsHash?: string | undefined;
                stanzaCreated?: boolean | undefined;
            }[] | undefined;
            repoHost?: {
                kind?: string | undefined;
                apiVersion?: string | undefined;
                ready?: boolean | undefined;
            } | undefined;
            restore?: {
                finished: boolean;
                id: string;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
            } | undefined;
            manualBackup?: {
                finished: boolean;
                id: string;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
            } | undefined;
            scheduledBackups?: {
                type?: string | undefined;
                repo?: string | undefined;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
                cronJobName?: string | undefined;
            }[] | undefined;
        } | undefined;
        instances?: {
            name: string;
            replicas?: number | undefined;
            readyReplicas?: number | undefined;
            updatedReplicas?: number | undefined;
        }[] | undefined;
        postgresVersion?: number | undefined;
        patroni?: {
            switchover?: string | undefined;
            switchoverTimeline?: number | undefined;
            systemIdentifier?: string | undefined;
        } | undefined;
        observedGeneration?: number | undefined;
        conditions?: {
            type: string;
            lastTransitionTime: string | null;
            message: string;
            reason: string;
            status: "True" | "False" | "Unknown";
            observedGeneration?: number | undefined;
        }[] | undefined;
        databaseInitSQL?: string | undefined;
        monitoring?: {
            exporterConfiguration?: string | undefined;
        } | undefined;
        proxy?: {
            pgBouncer?: {
                replicas?: number | undefined;
                readyReplicas?: number | undefined;
                postgresRevision?: string | undefined;
            } | undefined;
        } | undefined;
        userInterface?: {
            pgAdmin?: {
                usersRevision?: string | undefined;
            } | undefined;
        } | undefined;
        databaseRevision?: string | undefined;
        registrationRequired?: {
            pgoVersion?: string | undefined;
        } | undefined;
        startupInstance?: string | undefined;
        startupInstanceSet?: string | undefined;
        tokenRequired?: string | undefined;
        usersRevision?: string | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    kind: "PostgresCluster";
    apiVersion: "postgres-operator.crunchydata.com/v1beta1";
    status?: {
        pgbackrest?: {
            repos?: {
                name: string;
                volume?: string | undefined;
                bound?: boolean | undefined;
                replicaCreateBackupComplete?: boolean | undefined;
                repoOptionsHash?: string | undefined;
                stanzaCreated?: boolean | undefined;
            }[] | undefined;
            repoHost?: {
                kind?: string | undefined;
                apiVersion?: string | undefined;
                ready?: boolean | undefined;
            } | undefined;
            restore?: {
                finished: boolean;
                id: string;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
            } | undefined;
            manualBackup?: {
                finished: boolean;
                id: string;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
            } | undefined;
            scheduledBackups?: {
                type?: string | undefined;
                repo?: string | undefined;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
                cronJobName?: string | undefined;
            }[] | undefined;
        } | undefined;
        instances?: {
            name: string;
            replicas?: number | undefined;
            readyReplicas?: number | undefined;
            updatedReplicas?: number | undefined;
        }[] | undefined;
        postgresVersion?: number | undefined;
        patroni?: {
            switchover?: string | undefined;
            switchoverTimeline?: number | undefined;
            systemIdentifier?: string | undefined;
        } | undefined;
        observedGeneration?: number | undefined;
        conditions?: {
            type: string;
            lastTransitionTime: string | null;
            message: string;
            reason: string;
            status: "True" | "False" | "Unknown";
            observedGeneration?: number | undefined;
        }[] | undefined;
        databaseInitSQL?: string | undefined;
        monitoring?: {
            exporterConfiguration?: string | undefined;
        } | undefined;
        proxy?: {
            pgBouncer?: {
                replicas?: number | undefined;
                readyReplicas?: number | undefined;
                postgresRevision?: string | undefined;
            } | undefined;
        } | undefined;
        userInterface?: {
            pgAdmin?: {
                usersRevision?: string | undefined;
            } | undefined;
        } | undefined;
        databaseRevision?: string | undefined;
        registrationRequired?: {
            pgoVersion?: string | undefined;
        } | undefined;
        startupInstance?: string | undefined;
        startupInstanceSet?: string | undefined;
        tokenRequired?: string | undefined;
        usersRevision?: string | undefined;
    } | undefined;
    metadata?: {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string; /**
             * expirationSeconds is the requested duration of validity of the service account token. As the token approaches expiration, the kubelet volume plugin will proactively rotate the service account token. The kubelet will start trying to rotate the token if the token is older than 80 percent of its time to live or if the token is older than 24 hours.Defaults to 1 hour and must be at least 10 minutes.
             * @format int64
             */
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    } | undefined;
    spec?: {
        port: number;
        backups: {
            pgbackrest: {
                repos: {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes: string[];
                            resources: {
                                requests: Record<string, string | number>;
                                limits?: Record<string, string | number> | undefined;
                            };
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                }[];
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                configuration?: {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }[] | undefined;
                sidecars?: {
                    pgbackrest?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                    pgbackrestConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                image?: string | undefined;
                global?: Record<string, string> | undefined;
                jobs?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    ttlSecondsAfterFinished?: number | undefined;
                } | undefined;
                manual?: {
                    repoName: string;
                    options?: string[] | undefined;
                } | undefined;
                repoHost?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    sshConfigMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    sshSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    topologySpreadConstraints?: {
                        topologyKey: string;
                        maxSkew: number;
                        whenUnsatisfiable: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        minDomains?: number | undefined;
                    }[] | undefined;
                } | undefined;
                restore?: {
                    repoName: string;
                    enabled: boolean;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    options?: string[] | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    clusterName?: string | undefined;
                    clusterNamespace?: string | undefined;
                } | undefined;
            };
        };
        instances: {
            dataVolumeClaimSpec: {
                accessModes: string[];
                resources: {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                };
                selector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                dataSource?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                dataSourceRef?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                storageClassName?: string | undefined;
                volumeMode?: string | undefined;
                volumeName?: string | undefined;
            };
            replicas: number;
            name?: string | undefined;
            resources?: {
                requests?: Record<string, string | number> | undefined;
                limits?: Record<string, string | number> | undefined;
            } | undefined;
            metadata?: {
                annotations?: Record<string, string> | undefined;
                labels?: Record<string, string> | undefined;
            } | undefined;
            sidecars?: {
                replicaCertCopy?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
            tolerations?: {
                key?: string | undefined;
                operator?: string | undefined;
                value?: string | undefined;
                effect?: string | undefined;
                tolerationSeconds?: number | undefined;
            }[] | undefined;
            affinity?: {
                nodeAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        preference: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        };
                        weight: number;
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        nodeSelectorTerms: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        }[];
                    } | undefined;
                } | undefined;
                podAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                } | undefined;
                podAntiAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                } | undefined;
            } | undefined;
            priorityClassName?: string | undefined;
            topologySpreadConstraints?: {
                topologyKey: string;
                maxSkew: number;
                whenUnsatisfiable: string;
                labelSelector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                minDomains?: number | undefined;
            }[] | undefined;
            containers?: {
                name: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                env?: {
                    name: string;
                    value?: string | undefined;
                    valueFrom?: {
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                        configMapKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        secretKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    } | undefined;
                }[] | undefined;
                image?: string | undefined;
                imagePullPolicy?: string | undefined;
                args?: string[] | undefined;
                command?: string[] | undefined;
                envFrom?: {
                    configMapRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    prefix?: string | undefined;
                    secretRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                lifecycle?: {
                    postStart?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                    preStop?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                livenessProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                ports?: {
                    containerPort: number;
                    protocol: string;
                    name?: string | undefined;
                    hostIP?: string | undefined;
                    hostPort?: number | undefined;
                }[] | undefined;
                readinessProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                securityContext?: {
                    allowPrivilegeEscalation?: boolean | undefined;
                    capabilities?: {
                        add?: string[] | undefined;
                        drop?: string[] | undefined;
                    } | undefined;
                    privileged?: boolean | undefined;
                    procMount?: string | undefined;
                    readOnlyRootFilesystem?: boolean | undefined;
                    runAsGroup?: number | undefined;
                    runAsNonRoot?: boolean | undefined;
                    runAsUser?: number | undefined;
                    seLinuxOptions?: {
                        type?: string | undefined;
                        user?: string | undefined;
                        level?: string | undefined;
                        role?: string | undefined;
                    } | undefined;
                    seccompProfile?: {
                        type: string;
                        localhostProfile?: string | undefined;
                    } | undefined;
                    windowsOptions?: {
                        gmsaCredentialSpec?: string | undefined;
                        gmsaCredentialSpecName?: string | undefined;
                        hostProcess?: boolean | undefined;
                        runAsUserName?: string | undefined;
                    } | undefined;
                } | undefined;
                startupProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                stdin?: boolean | undefined;
                stdinOnce?: boolean | undefined;
                terminationMessagePath?: string | undefined;
                terminationMessagePolicy?: string | undefined;
                tty?: boolean | undefined;
                volumeDevices?: {
                    name: string;
                    devicePath: string;
                }[] | undefined;
                volumeMounts?: {
                    name: string;
                    mountPath: string;
                    subPath?: string | undefined;
                    mountPropagation?: string | undefined;
                    readOnly?: boolean | undefined;
                    subPathExpr?: string | undefined;
                }[] | undefined;
                workingDir?: string | undefined;
            }[] | undefined;
            minAvailable?: string | number | undefined;
            tablespaceVolumes?: {
                name: string;
                dataVolumeClaimSpec: {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                };
            }[] | undefined;
            walVolumeClaimSpec?: {
                accessModes: string[];
                resources: {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                };
                selector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                dataSource?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                dataSourceRef?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                storageClassName?: string | undefined;
                volumeMode?: string | undefined;
                volumeName?: string | undefined;
            } | undefined;
        }[];
        postgresVersion: number;
        metadata?: {
            annotations?: Record<string, string> | undefined;
            labels?: Record<string, string> | undefined;
        } | undefined;
        standby?: {
            enabled: boolean;
            repoName?: string | undefined;
            port?: number | undefined;
            host?: string | undefined;
        } | undefined;
        users?: {
            name: string;
            options?: string | undefined;
            databases?: string[] | undefined;
            password?: {
                type: "ASCII" | "AlphaNumeric";
            } | undefined;
        }[] | undefined;
        patroni?: {
            port: number;
            leaderLeaseDurationSeconds: number;
            syncPeriodSeconds: number;
            dynamicConfiguration?: {} | undefined;
            switchover?: {
                type: "Switchover" | "Failover";
                enabled: boolean;
                targetInstance?: string | undefined;
            } | undefined;
        } | undefined;
        config?: {
            files?: {
                configMap?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                downwardAPI?: {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                } | undefined;
                secret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                serviceAccountToken?: {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                } | undefined;
            }[] | undefined;
        } | undefined;
        dataSource?: {
            pgbackrest?: {
                repo: {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes?: string[] | undefined;
                            resources?: {
                                requests?: Record<string, string | number> | undefined;
                                limits?: Record<string, string | number> | undefined;
                            } | undefined;
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                };
                stanza: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                configuration?: {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }[] | undefined;
                options?: string[] | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                priorityClassName?: string | undefined;
                global?: Record<string, string> | undefined;
            } | undefined;
            postgresCluster?: {
                repoName: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                options?: string[] | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                priorityClassName?: string | undefined;
                clusterName?: string | undefined;
                clusterNamespace?: string | undefined;
            } | undefined;
            volumes?: {
                pgBackRestVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
                pgDataVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
                pgWALVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
        image?: string | undefined;
        imagePullPolicy?: "Always" | "Never" | "IfNotPresent" | undefined;
        imagePullSecrets?: {
            name?: string | undefined;
        }[] | undefined;
        customReplicationTLSSecret?: {
            name?: string | undefined;
            items?: {
                key: string;
                path: string;
                mode?: number | undefined;
            }[] | undefined;
            optional?: boolean | undefined;
        } | undefined;
        customTLSSecret?: {
            name?: string | undefined;
            items?: {
                key: string;
                path: string;
                mode?: number | undefined;
            }[] | undefined;
            optional?: boolean | undefined;
        } | undefined;
        databaseInitSQL?: {
            key: string;
            name: string;
        } | undefined;
        disableDefaultPodScheduling?: boolean | undefined;
        service?: {
            type: "ClusterIP" | "NodePort" | "LoadBalancer";
            metadata?: {
                annotations?: Record<string, string> | undefined;
                labels?: Record<string, string> | undefined;
            } | undefined;
            nodePort?: number | undefined;
        } | undefined;
        monitoring?: {
            pgmonitor?: {
                exporter?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    configuration?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    customTLSSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
        openshift?: boolean | undefined;
        paused?: boolean | undefined;
        postGISVersion?: string | undefined;
        proxy?: {
            pgBouncer: {
                port: number;
                replicas: number;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                sidecars?: {
                    pgbouncerConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                config?: {
                    users?: Record<string, string> | undefined;
                    databases?: Record<string, string> | undefined;
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    global?: Record<string, string> | undefined;
                } | undefined;
                image?: string | undefined;
                priorityClassName?: string | undefined;
                topologySpreadConstraints?: {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }[] | undefined;
                customTLSSecret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                service?: {
                    type: "ClusterIP" | "NodePort" | "LoadBalancer";
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                } | undefined;
                containers?: {
                    name: string;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    env?: {
                        name: string;
                        value?: string | undefined;
                        valueFrom?: {
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                            configMapKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                            secretKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    imagePullPolicy?: string | undefined;
                    args?: string[] | undefined;
                    command?: string[] | undefined;
                    envFrom?: {
                        configMapRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        prefix?: string | undefined;
                        secretRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                    lifecycle?: {
                        postStart?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                        preStop?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                    } | undefined;
                    livenessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    ports?: {
                        containerPort: number;
                        protocol: string;
                        name?: string | undefined;
                        hostIP?: string | undefined;
                        hostPort?: number | undefined;
                    }[] | undefined;
                    readinessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    securityContext?: {
                        allowPrivilegeEscalation?: boolean | undefined;
                        capabilities?: {
                            add?: string[] | undefined;
                            drop?: string[] | undefined;
                        } | undefined;
                        privileged?: boolean | undefined;
                        procMount?: string | undefined;
                        readOnlyRootFilesystem?: boolean | undefined;
                        runAsGroup?: number | undefined;
                        runAsNonRoot?: boolean | undefined;
                        runAsUser?: number | undefined;
                        seLinuxOptions?: {
                            type?: string | undefined;
                            user?: string | undefined;
                            level?: string | undefined;
                            role?: string | undefined;
                        } | undefined;
                        seccompProfile?: {
                            type: string;
                            localhostProfile?: string | undefined;
                        } | undefined;
                        windowsOptions?: {
                            gmsaCredentialSpec?: string | undefined;
                            gmsaCredentialSpecName?: string | undefined;
                            hostProcess?: boolean | undefined;
                            runAsUserName?: string | undefined;
                        } | undefined;
                    } | undefined;
                    startupProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    stdin?: boolean | undefined;
                    stdinOnce?: boolean | undefined;
                    terminationMessagePath?: string | undefined;
                    terminationMessagePolicy?: string | undefined;
                    tty?: boolean | undefined;
                    volumeDevices?: {
                        name: string;
                        devicePath: string;
                    }[] | undefined;
                    volumeMounts?: {
                        name: string;
                        mountPath: string;
                        subPath?: string | undefined;
                        mountPropagation?: string | undefined;
                        readOnly?: boolean | undefined;
                        subPathExpr?: string | undefined;
                    }[] | undefined;
                    workingDir?: string | undefined;
                }[] | undefined;
                minAvailable?: string | number | undefined;
            };
        } | undefined;
        shutdown?: boolean | undefined;
        supplementalGroups?: number[] | undefined;
        userInterface?: {
            pgAdmin: {
                dataVolumeClaimSpec: {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                };
                replicas: number;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                config?: {
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    ldapBindPassword?: {
                        key: string;
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    settings?: {} | undefined;
                } | undefined;
                image?: string | undefined;
                priorityClassName?: string | undefined;
                topologySpreadConstraints?: {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }[] | undefined;
                service?: {
                    type: "ClusterIP" | "NodePort" | "LoadBalancer";
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                } | undefined;
            };
        } | undefined;
    } | undefined;
}, {
    kind: "PostgresCluster";
    apiVersion: "postgres-operator.crunchydata.com/v1beta1";
    status?: {
        pgbackrest?: {
            repos?: {
                name: string;
                volume?: string | undefined;
                bound?: boolean | undefined;
                replicaCreateBackupComplete?: boolean | undefined;
                repoOptionsHash?: string | undefined;
                stanzaCreated?: boolean | undefined;
            }[] | undefined;
            repoHost?: {
                kind?: string | undefined;
                apiVersion?: string | undefined;
                ready?: boolean | undefined;
            } | undefined;
            restore?: {
                finished: boolean;
                id: string;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
            } | undefined;
            manualBackup?: {
                finished: boolean;
                id: string;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
            } | undefined;
            scheduledBackups?: {
                type?: string | undefined;
                repo?: string | undefined;
                active?: number | undefined;
                completionTime?: string | null | undefined;
                failed?: number | undefined;
                startTime?: string | null | undefined;
                succeeded?: number | undefined;
                cronJobName?: string | undefined;
            }[] | undefined;
        } | undefined;
        instances?: {
            name: string;
            replicas?: number | undefined;
            readyReplicas?: number | undefined;
            updatedReplicas?: number | undefined;
        }[] | undefined;
        postgresVersion?: number | undefined;
        patroni?: {
            switchover?: string | undefined;
            switchoverTimeline?: number | undefined;
            systemIdentifier?: string | undefined;
        } | undefined;
        observedGeneration?: number | undefined;
        conditions?: {
            type: string;
            lastTransitionTime: string | null;
            message: string;
            reason: string;
            status: "True" | "False" | "Unknown";
            observedGeneration?: number | undefined;
        }[] | undefined;
        databaseInitSQL?: string | undefined;
        monitoring?: {
            exporterConfiguration?: string | undefined;
        } | undefined;
        proxy?: {
            pgBouncer?: {
                replicas?: number | undefined;
                readyReplicas?: number | undefined;
                postgresRevision?: string | undefined;
            } | undefined;
        } | undefined;
        userInterface?: {
            pgAdmin?: {
                usersRevision?: string | undefined;
            } | undefined;
        } | undefined;
        databaseRevision?: string | undefined;
        registrationRequired?: {
            pgoVersion?: string | undefined;
        } | undefined;
        startupInstance?: string | undefined;
        startupInstanceSet?: string | undefined;
        tokenRequired?: string | undefined;
        usersRevision?: string | undefined;
    } | undefined;
    metadata?: {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    } | undefined;
    spec?: {
        backups: {
            pgbackrest: {
                repos: {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes: string[];
                            resources: {
                                requests: Record<string, string | number>;
                                limits?: Record<string, string | number> | undefined;
                            };
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                }[];
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                configuration?: {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }[] | undefined;
                sidecars?: {
                    pgbackrest?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                    pgbackrestConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                image?: string | undefined;
                global?: Record<string, string> | undefined;
                jobs?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    ttlSecondsAfterFinished?: number | undefined;
                } | undefined;
                manual?: {
                    repoName: string;
                    options?: string[] | undefined;
                } | undefined;
                repoHost?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    sshConfigMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    sshSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    topologySpreadConstraints?: {
                        topologyKey: string;
                        maxSkew: number;
                        whenUnsatisfiable: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        minDomains?: number | undefined;
                    }[] | undefined;
                } | undefined;
                restore?: {
                    repoName: string;
                    enabled: boolean;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    options?: string[] | undefined;
                    tolerations?: {
                        key?: string | undefined;
                        operator?: string | undefined;
                        value?: string | undefined;
                        effect?: string | undefined;
                        tolerationSeconds?: number | undefined;
                    }[] | undefined;
                    affinity?: {
                        nodeAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                preference: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                };
                                weight: number;
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                nodeSelectorTerms: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchFields?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                }[];
                            } | undefined;
                        } | undefined;
                        podAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                        podAntiAffinity?: {
                            preferredDuringSchedulingIgnoredDuringExecution?: {
                                weight: number;
                                podAffinityTerm: {
                                    topologyKey: string;
                                    labelSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaceSelector?: {
                                        matchExpressions?: {
                                            key: string;
                                            operator: string;
                                            values?: string[] | undefined;
                                        }[] | undefined;
                                        matchLabels?: Record<string, string> | undefined;
                                    } | undefined;
                                    namespaces?: string[] | undefined;
                                };
                            }[] | undefined;
                            requiredDuringSchedulingIgnoredDuringExecution?: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            }[] | undefined;
                        } | undefined;
                    } | undefined;
                    priorityClassName?: string | undefined;
                    clusterName?: string | undefined;
                    clusterNamespace?: string | undefined;
                } | undefined;
            };
        };
        instances: {
            dataVolumeClaimSpec: {
                accessModes: string[];
                resources: {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                };
                selector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                dataSource?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                dataSourceRef?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                storageClassName?: string | undefined;
                volumeMode?: string | undefined;
                volumeName?: string | undefined;
            };
            name?: string | undefined;
            resources?: {
                requests?: Record<string, string | number> | undefined;
                limits?: Record<string, string | number> | undefined;
            } | undefined;
            metadata?: {
                annotations?: Record<string, string> | undefined;
                labels?: Record<string, string> | undefined;
            } | undefined;
            sidecars?: {
                replicaCertCopy?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
            tolerations?: {
                key?: string | undefined;
                operator?: string | undefined;
                value?: string | undefined;
                effect?: string | undefined;
                tolerationSeconds?: number | undefined;
            }[] | undefined;
            affinity?: {
                nodeAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        preference: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        };
                        weight: number;
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        nodeSelectorTerms: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchFields?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                        }[];
                    } | undefined;
                } | undefined;
                podAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                } | undefined;
                podAntiAffinity?: {
                    preferredDuringSchedulingIgnoredDuringExecution?: {
                        weight: number;
                        podAffinityTerm: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        };
                    }[] | undefined;
                    requiredDuringSchedulingIgnoredDuringExecution?: {
                        topologyKey: string;
                        labelSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaceSelector?: {
                            matchExpressions?: {
                                key: string;
                                operator: string;
                                values?: string[] | undefined;
                            }[] | undefined;
                            matchLabels?: Record<string, string> | undefined;
                        } | undefined;
                        namespaces?: string[] | undefined;
                    }[] | undefined;
                } | undefined;
            } | undefined;
            priorityClassName?: string | undefined;
            topologySpreadConstraints?: {
                topologyKey: string;
                maxSkew: number;
                whenUnsatisfiable: string;
                labelSelector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                minDomains?: number | undefined;
            }[] | undefined;
            containers?: {
                name: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                env?: {
                    name: string;
                    value?: string | undefined;
                    valueFrom?: {
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                        configMapKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        secretKeyRef?: {
                            key: string;
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    } | undefined;
                }[] | undefined;
                image?: string | undefined;
                imagePullPolicy?: string | undefined;
                args?: string[] | undefined;
                command?: string[] | undefined;
                envFrom?: {
                    configMapRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    prefix?: string | undefined;
                    secretRef?: {
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                }[] | undefined;
                lifecycle?: {
                    postStart?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                    preStop?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                livenessProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                ports?: {
                    containerPort: number;
                    name?: string | undefined;
                    hostIP?: string | undefined;
                    hostPort?: number | undefined;
                    protocol?: string | undefined;
                }[] | undefined;
                readinessProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                securityContext?: {
                    allowPrivilegeEscalation?: boolean | undefined;
                    capabilities?: {
                        add?: string[] | undefined;
                        drop?: string[] | undefined;
                    } | undefined;
                    privileged?: boolean | undefined;
                    procMount?: string | undefined;
                    readOnlyRootFilesystem?: boolean | undefined;
                    runAsGroup?: number | undefined;
                    runAsNonRoot?: boolean | undefined;
                    runAsUser?: number | undefined;
                    seLinuxOptions?: {
                        type?: string | undefined;
                        user?: string | undefined;
                        level?: string | undefined;
                        role?: string | undefined;
                    } | undefined;
                    seccompProfile?: {
                        type: string;
                        localhostProfile?: string | undefined;
                    } | undefined;
                    windowsOptions?: {
                        gmsaCredentialSpec?: string | undefined;
                        gmsaCredentialSpecName?: string | undefined;
                        hostProcess?: boolean | undefined;
                        runAsUserName?: string | undefined;
                    } | undefined;
                } | undefined;
                startupProbe?: {
                    exec?: {
                        command?: string[] | undefined;
                    } | undefined;
                    httpGet?: {
                        port: string | number;
                        path?: string | undefined;
                        host?: string | undefined;
                        httpHeaders?: {
                            name: string;
                            value: string;
                        }[] | undefined;
                        scheme?: string | undefined;
                    } | undefined;
                    tcpSocket?: {
                        port: string | number;
                        host?: string | undefined;
                    } | undefined;
                    failureThreshold?: number | undefined;
                    grpc?: {
                        port: number;
                        service?: string | undefined;
                    } | undefined;
                    initialDelaySeconds?: number | undefined;
                    periodSeconds?: number | undefined;
                    successThreshold?: number | undefined;
                    terminationGracePeriodSeconds?: number | undefined;
                    timeoutSeconds?: number | undefined;
                } | undefined;
                stdin?: boolean | undefined;
                stdinOnce?: boolean | undefined;
                terminationMessagePath?: string | undefined;
                terminationMessagePolicy?: string | undefined;
                tty?: boolean | undefined;
                volumeDevices?: {
                    name: string;
                    devicePath: string;
                }[] | undefined;
                volumeMounts?: {
                    name: string;
                    mountPath: string;
                    subPath?: string | undefined;
                    mountPropagation?: string | undefined;
                    readOnly?: boolean | undefined;
                    subPathExpr?: string | undefined;
                }[] | undefined;
                workingDir?: string | undefined;
            }[] | undefined;
            minAvailable?: string | number | undefined;
            replicas?: number | undefined;
            tablespaceVolumes?: {
                name: string;
                dataVolumeClaimSpec: {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                };
            }[] | undefined;
            walVolumeClaimSpec?: {
                accessModes: string[];
                resources: {
                    requests: Record<string, string | number>;
                    limits?: Record<string, string | number> | undefined;
                };
                selector?: {
                    matchExpressions?: {
                        key: string;
                        operator: string;
                        values?: string[] | undefined;
                    }[] | undefined;
                    matchLabels?: Record<string, string> | undefined;
                } | undefined;
                dataSource?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                dataSourceRef?: {
                    kind: string;
                    name: string;
                    apiGroup?: string | undefined;
                } | undefined;
                storageClassName?: string | undefined;
                volumeMode?: string | undefined;
                volumeName?: string | undefined;
            } | undefined;
        }[];
        postgresVersion: number;
        port?: number | undefined;
        metadata?: {
            annotations?: Record<string, string> | undefined;
            labels?: Record<string, string> | undefined;
        } | undefined;
        standby?: {
            repoName?: string | undefined;
            enabled?: boolean | undefined;
            port?: number | undefined;
            host?: string | undefined;
        } | undefined;
        users?: {
            name: string;
            options?: string | undefined;
            databases?: string[] | undefined;
            password?: {
                type?: "ASCII" | "AlphaNumeric" | undefined;
            } | undefined;
        }[] | undefined;
        patroni?: {
            port?: number | undefined;
            dynamicConfiguration?: {} | undefined;
            leaderLeaseDurationSeconds?: number | undefined;
            switchover?: {
                enabled: boolean;
                type?: "Switchover" | "Failover" | undefined;
                targetInstance?: string | undefined;
            } | undefined;
            syncPeriodSeconds?: number | undefined;
        } | undefined;
        config?: {
            files?: {
                configMap?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                downwardAPI?: {
                    items?: {
                        path: string;
                        mode?: number | undefined;
                        fieldRef?: {
                            fieldPath: string;
                            apiVersion?: string | undefined;
                        } | undefined;
                        resourceFieldRef?: {
                            resource: string;
                            containerName?: string | undefined;
                            divisor?: string | number | undefined;
                        } | undefined;
                    }[] | undefined;
                } | undefined;
                secret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                serviceAccountToken?: {
                    path: string;
                    audience?: string | undefined;
                    expirationSeconds?: number | undefined;
                } | undefined;
            }[] | undefined;
        } | undefined;
        dataSource?: {
            pgbackrest?: {
                repo: {
                    name: string;
                    volume?: {
                        volumeClaimSpec: {
                            accessModes?: string[] | undefined;
                            resources?: {
                                requests?: Record<string, string | number> | undefined;
                                limits?: Record<string, string | number> | undefined;
                            } | undefined;
                            selector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            dataSource?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            dataSourceRef?: {
                                kind: string;
                                name: string;
                                apiGroup?: string | undefined;
                            } | undefined;
                            storageClassName?: string | undefined;
                            volumeMode?: string | undefined;
                            volumeName?: string | undefined;
                        };
                    } | undefined;
                    gcs?: {
                        bucket: string;
                    } | undefined;
                    s3?: {
                        bucket: string;
                        endpoint: string;
                        region: string;
                    } | undefined;
                    azure?: {
                        container: string;
                    } | undefined;
                    schedules?: {
                        differential?: string | undefined;
                        full?: string | undefined;
                        incremental?: string | undefined;
                    } | undefined;
                };
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                stanza?: string | undefined;
                configuration?: {
                    configMap?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    downwardAPI?: {
                        items?: {
                            path: string;
                            mode?: number | undefined;
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                        }[] | undefined;
                    } | undefined;
                    secret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    serviceAccountToken?: {
                        path: string;
                        audience?: string | undefined;
                        expirationSeconds?: number | undefined;
                    } | undefined;
                }[] | undefined;
                options?: string[] | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                priorityClassName?: string | undefined;
                global?: Record<string, string> | undefined;
            } | undefined;
            postgresCluster?: {
                repoName: string;
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                options?: string[] | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                priorityClassName?: string | undefined;
                clusterName?: string | undefined;
                clusterNamespace?: string | undefined;
            } | undefined;
            volumes?: {
                pgBackRestVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
                pgDataVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
                pgWALVolume?: {
                    pvcName: string;
                    directory?: string | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
        image?: string | undefined;
        imagePullPolicy?: "Always" | "Never" | "IfNotPresent" | undefined;
        imagePullSecrets?: {
            name?: string | undefined;
        }[] | undefined;
        customReplicationTLSSecret?: {
            name?: string | undefined;
            items?: {
                key: string;
                path: string;
                mode?: number | undefined;
            }[] | undefined;
            optional?: boolean | undefined;
        } | undefined;
        customTLSSecret?: {
            name?: string | undefined;
            items?: {
                key: string;
                path: string;
                mode?: number | undefined;
            }[] | undefined;
            optional?: boolean | undefined;
        } | undefined;
        databaseInitSQL?: {
            key: string;
            name: string;
        } | undefined;
        disableDefaultPodScheduling?: boolean | undefined;
        service?: {
            type?: "ClusterIP" | "NodePort" | "LoadBalancer" | undefined;
            metadata?: {
                annotations?: Record<string, string> | undefined;
                labels?: Record<string, string> | undefined;
            } | undefined;
            nodePort?: number | undefined;
        } | undefined;
        monitoring?: {
            pgmonitor?: {
                exporter?: {
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    configuration?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    customTLSSecret?: {
                        name?: string | undefined;
                        items?: {
                            key: string;
                            path: string;
                            mode?: number | undefined;
                        }[] | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
        openshift?: boolean | undefined;
        paused?: boolean | undefined;
        postGISVersion?: string | undefined;
        proxy?: {
            pgBouncer: {
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                port?: number | undefined;
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                sidecars?: {
                    pgbouncerConfig?: {
                        resources?: {
                            requests?: Record<string, string | number> | undefined;
                            limits?: Record<string, string | number> | undefined;
                        } | undefined;
                    } | undefined;
                } | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                config?: {
                    users?: Record<string, string> | undefined;
                    databases?: Record<string, string> | undefined;
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    global?: Record<string, string> | undefined;
                } | undefined;
                image?: string | undefined;
                priorityClassName?: string | undefined;
                topologySpreadConstraints?: {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }[] | undefined;
                customTLSSecret?: {
                    name?: string | undefined;
                    items?: {
                        key: string;
                        path: string;
                        mode?: number | undefined;
                    }[] | undefined;
                    optional?: boolean | undefined;
                } | undefined;
                service?: {
                    type?: "ClusterIP" | "NodePort" | "LoadBalancer" | undefined;
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                } | undefined;
                containers?: {
                    name: string;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    env?: {
                        name: string;
                        value?: string | undefined;
                        valueFrom?: {
                            fieldRef?: {
                                fieldPath: string;
                                apiVersion?: string | undefined;
                            } | undefined;
                            resourceFieldRef?: {
                                resource: string;
                                containerName?: string | undefined;
                                divisor?: string | number | undefined;
                            } | undefined;
                            configMapKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                            secretKeyRef?: {
                                key: string;
                                name?: string | undefined;
                                optional?: boolean | undefined;
                            } | undefined;
                        } | undefined;
                    }[] | undefined;
                    image?: string | undefined;
                    imagePullPolicy?: string | undefined;
                    args?: string[] | undefined;
                    command?: string[] | undefined;
                    envFrom?: {
                        configMapRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        prefix?: string | undefined;
                        secretRef?: {
                            name?: string | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                    }[] | undefined;
                    lifecycle?: {
                        postStart?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                        preStop?: {
                            exec?: {
                                command?: string[] | undefined;
                            } | undefined;
                            httpGet?: {
                                port: string | number;
                                path?: string | undefined;
                                host?: string | undefined;
                                httpHeaders?: {
                                    name: string;
                                    value: string;
                                }[] | undefined;
                                scheme?: string | undefined;
                            } | undefined;
                            tcpSocket?: {
                                port: string | number;
                                host?: string | undefined;
                            } | undefined;
                        } | undefined;
                    } | undefined;
                    livenessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    ports?: {
                        containerPort: number;
                        name?: string | undefined;
                        hostIP?: string | undefined;
                        hostPort?: number | undefined;
                        protocol?: string | undefined;
                    }[] | undefined;
                    readinessProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    securityContext?: {
                        allowPrivilegeEscalation?: boolean | undefined;
                        capabilities?: {
                            add?: string[] | undefined;
                            drop?: string[] | undefined;
                        } | undefined;
                        privileged?: boolean | undefined;
                        procMount?: string | undefined;
                        readOnlyRootFilesystem?: boolean | undefined;
                        runAsGroup?: number | undefined;
                        runAsNonRoot?: boolean | undefined;
                        runAsUser?: number | undefined;
                        seLinuxOptions?: {
                            type?: string | undefined;
                            user?: string | undefined;
                            level?: string | undefined;
                            role?: string | undefined;
                        } | undefined;
                        seccompProfile?: {
                            type: string;
                            localhostProfile?: string | undefined;
                        } | undefined;
                        windowsOptions?: {
                            gmsaCredentialSpec?: string | undefined;
                            gmsaCredentialSpecName?: string | undefined;
                            hostProcess?: boolean | undefined;
                            runAsUserName?: string | undefined;
                        } | undefined;
                    } | undefined;
                    startupProbe?: {
                        exec?: {
                            command?: string[] | undefined;
                        } | undefined;
                        httpGet?: {
                            port: string | number;
                            path?: string | undefined;
                            host?: string | undefined;
                            httpHeaders?: {
                                name: string;
                                value: string;
                            }[] | undefined;
                            scheme?: string | undefined;
                        } | undefined;
                        tcpSocket?: {
                            port: string | number;
                            host?: string | undefined;
                        } | undefined;
                        failureThreshold?: number | undefined;
                        grpc?: {
                            port: number;
                            service?: string | undefined;
                        } | undefined;
                        initialDelaySeconds?: number | undefined;
                        periodSeconds?: number | undefined;
                        successThreshold?: number | undefined;
                        terminationGracePeriodSeconds?: number | undefined;
                        timeoutSeconds?: number | undefined;
                    } | undefined;
                    stdin?: boolean | undefined;
                    stdinOnce?: boolean | undefined;
                    terminationMessagePath?: string | undefined;
                    terminationMessagePolicy?: string | undefined;
                    tty?: boolean | undefined;
                    volumeDevices?: {
                        name: string;
                        devicePath: string;
                    }[] | undefined;
                    volumeMounts?: {
                        name: string;
                        mountPath: string;
                        subPath?: string | undefined;
                        mountPropagation?: string | undefined;
                        readOnly?: boolean | undefined;
                        subPathExpr?: string | undefined;
                    }[] | undefined;
                    workingDir?: string | undefined;
                }[] | undefined;
                minAvailable?: string | number | undefined;
                replicas?: number | undefined;
            };
        } | undefined;
        shutdown?: boolean | undefined;
        supplementalGroups?: number[] | undefined;
        userInterface?: {
            pgAdmin: {
                dataVolumeClaimSpec: {
                    accessModes?: string[] | undefined;
                    resources?: {
                        requests?: Record<string, string | number> | undefined;
                        limits?: Record<string, string | number> | undefined;
                    } | undefined;
                    selector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    dataSource?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    dataSourceRef?: {
                        kind: string;
                        name: string;
                        apiGroup?: string | undefined;
                    } | undefined;
                    storageClassName?: string | undefined;
                    volumeMode?: string | undefined;
                    volumeName?: string | undefined;
                };
                resources?: {
                    requests?: Record<string, string | number> | undefined;
                    limits?: Record<string, string | number> | undefined;
                } | undefined;
                metadata?: {
                    annotations?: Record<string, string> | undefined;
                    labels?: Record<string, string> | undefined;
                } | undefined;
                tolerations?: {
                    key?: string | undefined;
                    operator?: string | undefined;
                    value?: string | undefined;
                    effect?: string | undefined;
                    tolerationSeconds?: number | undefined;
                }[] | undefined;
                affinity?: {
                    nodeAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            preference: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            };
                            weight: number;
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            nodeSelectorTerms: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchFields?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                            }[];
                        } | undefined;
                    } | undefined;
                    podAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                    podAntiAffinity?: {
                        preferredDuringSchedulingIgnoredDuringExecution?: {
                            weight: number;
                            podAffinityTerm: {
                                topologyKey: string;
                                labelSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaceSelector?: {
                                    matchExpressions?: {
                                        key: string;
                                        operator: string;
                                        values?: string[] | undefined;
                                    }[] | undefined;
                                    matchLabels?: Record<string, string> | undefined;
                                } | undefined;
                                namespaces?: string[] | undefined;
                            };
                        }[] | undefined;
                        requiredDuringSchedulingIgnoredDuringExecution?: {
                            topologyKey: string;
                            labelSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaceSelector?: {
                                matchExpressions?: {
                                    key: string;
                                    operator: string;
                                    values?: string[] | undefined;
                                }[] | undefined;
                                matchLabels?: Record<string, string> | undefined;
                            } | undefined;
                            namespaces?: string[] | undefined;
                        }[] | undefined;
                    } | undefined;
                } | undefined;
                config?: {
                    files?: {
                        configMap?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        downwardAPI?: {
                            items?: {
                                path: string;
                                mode?: number | undefined;
                                fieldRef?: {
                                    fieldPath: string;
                                    apiVersion?: string | undefined;
                                } | undefined;
                                resourceFieldRef?: {
                                    resource: string;
                                    containerName?: string | undefined;
                                    divisor?: string | number | undefined;
                                } | undefined;
                            }[] | undefined;
                        } | undefined;
                        secret?: {
                            name?: string | undefined;
                            items?: {
                                key: string;
                                path: string;
                                mode?: number | undefined;
                            }[] | undefined;
                            optional?: boolean | undefined;
                        } | undefined;
                        serviceAccountToken?: {
                            path: string;
                            audience?: string | undefined;
                            expirationSeconds?: number | undefined;
                        } | undefined;
                    }[] | undefined;
                    ldapBindPassword?: {
                        key: string;
                        name?: string | undefined;
                        optional?: boolean | undefined;
                    } | undefined;
                    settings?: {} | undefined;
                } | undefined;
                image?: string | undefined;
                priorityClassName?: string | undefined;
                topologySpreadConstraints?: {
                    topologyKey: string;
                    maxSkew: number;
                    whenUnsatisfiable: string;
                    labelSelector?: {
                        matchExpressions?: {
                            key: string;
                            operator: string;
                            values?: string[] | undefined;
                        }[] | undefined;
                        matchLabels?: Record<string, string> | undefined;
                    } | undefined;
                    minDomains?: number | undefined;
                }[] | undefined;
                service?: {
                    type?: "ClusterIP" | "NodePort" | "LoadBalancer" | undefined;
                    metadata?: {
                        annotations?: Record<string, string> | undefined;
                        labels?: Record<string, string> | undefined;
                    } | undefined;
                    nodePort?: number | undefined;
                } | undefined;
                replicas?: number | undefined;
            };
        } | undefined;
    } | undefined;
}>;
